[−][src]Struct arena::SyncDroplessArena
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
lock: MTLock<DroplessArena>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SyncDroplessArena[src]
impl SyncDroplessArenapub fn new() -> SyncDroplessArena[src]
pub fn new() -> SyncDroplessArena🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn in_arena<T: ?Sized>(&self, ptr: *const T) -> bool[src]
pub fn in_arena<T: ?Sized>(&self, ptr: *const T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc_raw(&self, bytes: usize, align: usize) -> &mut [u8][src]
pub fn alloc_raw(&self, bytes: usize, align: usize) -> &mut [u8]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc<T>(&self, object: T) -> &mut T[src]
pub fn alloc<T>(&self, object: T) -> &mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc_slice<T>(&self, slice: &[T]) -> &mut [T] where
T: Copy, [src]
pub fn alloc_slice<T>(&self, slice: &[T]) -> &mut [T] where
T: Copy, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?