Struct arena::TypedArenaChunk [−][src]
struct TypedArenaChunk<T> {
storage: RawVec<T>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
storage: RawVec<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The raw storage for the arena chunk.
Methods
impl<T> TypedArenaChunk<T>[src]
impl<T> TypedArenaChunk<T>unsafe fn new(capacity: usize) -> TypedArenaChunk<T>[src]
unsafe fn new(capacity: usize) -> TypedArenaChunk<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unsafe fn destroy(&mut self, len: usize)[src]
unsafe fn destroy(&mut self, len: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Destroys this arena chunk.
fn start(&self) -> *mut T[src]
fn start(&self) -> *mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn end(&self) -> *mut T[src]
fn end(&self) -> *mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?