[−][src]Macro build_helper::t
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A helper macro to unwrap a result except also print out details like:
- The file/line of the panic
- The expression that failed
- The error itself
This is currently used judiciously throughout the build system rather than
using a Result with try!, but this may change one day...