Trait collections::dlist::ListInsertionDeprecated
[-]
[+]
[src]
pub trait ListInsertion<A> {
fn insert_next(&mut self, elt: A);
fn peek_next<'a>(&'a mut self) -> Option<&'a mut A>;
}Allows mutating a DList while iterating.
Required Methods
fn insert_next(&mut self, elt: A)
Inserts elt just after to the element most recently returned by
.next()
The inserted element does not appear in the iteration.
fn peek_next<'a>(&'a mut self) -> Option<&'a mut A>
Provides a reference to the next element, without changing the iterator