Struct collections::str::MatchIndicesExperimental
[-]
[+]
[src]
pub struct MatchIndices<'a> {
// some fields omitted
}An iterator over the start and end indices of the matches of a substring within a larger string