Trait core::any::AnyMutRefExtUnstable
[-]
[+]
[src]
pub trait AnyMutRefExt<'a> {
fn downcast_mut<T: 'static>(self) -> Option<&'a mut T>;
}Extension methods for a mutable referenced Any trait object
Required Methods
fn downcast_mut<T: 'static>(self) -> Option<&'a mut T>
Returns some mutable reference to the boxed value if it is of type T, or
None if it isn't.
Implementors
impl<'a> AnyMutRefExt<'a> for &'a mut Any