vcombine_f16

Function vcombine_f16 

pub fn vcombine_f16(a: float16x4_t, b: float16x4_t) -> float16x8_t
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and non-target_arch=arm64ec and target feature neon and target feature v7 and target feature fp16 only.
Join two smaller vectors into a single larger vector Arm’s documentation