pub unsafe fn vld1_p8(ptr: *const u8) -> poly8x8_t🔬This is a nightly-only experimental API. (
stdarch_arm_neon_intrinsics #111800)Available on (AArch64 or
target_arch=arm64ec) and ARM and target feature neon and target feature v7 only.Expand description
Load multiple single-element structures to one, two, three, or four registers. Arm’s documentation
Safety
- Neon instrinsic unsafe