vld1q_p64

Function vld1q_p64 

pub unsafe fn vld1q_p64(ptr: *const u64) -> poly64x2_t
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and ARM and target feature neon and target feature aes only.
Load multiple single-element structures to one, two, three, or four registers. Arm’s documentation

Safety

  • Neon instrinsic unsafe