vld1q_p64_x2

Function vld1q_p64_x2 

1.59.0 · Source
pub unsafe fn vld1q_p64_x2(a: *const u64) -> poly64x2x2_t
Available on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.
Load multiple single-element structures to one, two, three, or four registers Arm’s documentation

Safety

  • Neon intrinsic unsafe