pub unsafe fn vld1q_u32_x4(a: *const u32) -> uint32x4x4_t🔬This is a nightly-only experimental API. (
stdarch_arm_neon_intrinsics #111800)Available on (AArch64 or
target_arch=arm64ec) and little-endian and target feature neon and target feature v7 only.Expand description
Load multiple single-element structures to one, two, three, or four registers Arm’s documentation
Safety
- Neon instrinsic unsafe