pub unsafe fn vld2_dup_p64(a: *const u64) -> poly64x1x2_tAvailable on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature
v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.Expand description
Load single 2-element structure and replicate to all lanes of two registers Arm’s documentation
Safety
- Neon intrinsic unsafe