vld3_dup_p64

Function vld3_dup_p64 

1.59.0 · Source
pub unsafe fn vld3_dup_p64(a: *const u64) -> poly64x1x3_t
Available on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.
Load single 3-element structure and replicate to all lanes of three registers Arm’s documentation

Safety

  • Neon intrinsic unsafe