pub unsafe fn vld3_dup_s8(a: *const i8) -> int8x8x3_t🔬This is a nightly-only experimental API. (
stdarch_arm_neon_intrinsics #111800)Available on (AArch64 or
target_arch=arm64ec) and ARM and target feature neon and target feature v7 only.Expand description
Load single 3-element structure and replicate to all lanes of three registers Arm’s documentation
Safety
- Neon instrinsic unsafe