vld3_dup_u16

Function vld3_dup_u16 

pub unsafe fn vld3_dup_u16(a: *const u16) -> uint16x4x3_t
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and little-endian and target feature neon and target feature v7 only.
Load single 3-element structure and replicate to all lanes of three registers Arm’s documentation

Safety

  • Neon instrinsic unsafe