pub unsafe fn vld3q_dup_s16(a: *const i16) -> int16x8x3_tThis is supported on AArch64 and target feature
neon,v7 only.Expand description
Load single 3-element structure and replicate to all lanes of three registers
pub unsafe fn vld3q_dup_s16(a: *const i16) -> int16x8x3_tneon,v7 only.Load single 3-element structure and replicate to all lanes of three registers