pub unsafe fn vst1_f32_x4(a: *mut f32, b: float32x2x4_t)This is supported on AArch64 and target feature
neon,v7 only.Expand description
Store multiple single-element structures to one, two, three, or four registers
pub unsafe fn vst1_f32_x4(a: *mut f32, b: float32x2x4_t)neon,v7 only.Store multiple single-element structures to one, two, three, or four registers