vst1_lane_p64

Function vst1_lane_p64 

1.59.0 · Source
pub unsafe fn vst1_lane_p64(a: *mut u64, b: poly64x1_t, const LANE: i32)
Available on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.
Store multiple single-element structures from one, two, three, or four registers Arm’s documentation

Safety

  • Neon intrinsic unsafe