This is supported on target feature
neon and target feature v7 and AArch64 only.Expand description
Store multiple single-element structures from one, two, three, or four registers
neon and target feature v7 and AArch64 only.Store multiple single-element structures from one, two, three, or four registers