vst1_p64

Function vst1_p64 

pub unsafe fn vst1_p64(ptr: *mut u64, a: poly64x1_t)
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and ARM and target feature neon and target feature v7 only.
Store multiple single-element structures from one, two, three, or four registers. Arm’s documentation

Safety

  • Neon instrinsic unsafe