pub unsafe fn vst1_s16_x3(a: *mut i16, b: int16x4x3_t)This is supported on AArch64 and target feature
neon,v7 only.Expand description
Store multiple single-element structures from one, two, three, or four registers
pub unsafe fn vst1_s16_x3(a: *mut i16, b: int16x4x3_t)neon,v7 only.Store multiple single-element structures from one, two, three, or four registers