vst1q_p64_x3

Function vst1q_p64_x3 

1.59.0 · Source
pub unsafe fn vst1q_p64_x3(a: *mut u64, b: poly64x2x3_t)
Available on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.
Store multiple single-element structures to one, two, three, or four registers Arm’s documentation

Safety

  • Neon intrinsic unsafe