pub unsafe fn vst1q_s64_x3(a: *mut i64, b: int64x2x3_t)This is supported on AArch64 and target feature
neon,v7 only.Expand description
Store multiple single-element structures from one, two, three, or four registers
pub unsafe fn vst1q_s64_x3(a: *mut i64, b: int64x2x3_t)neon,v7 only.Store multiple single-element structures from one, two, three, or four registers