vst1q_s8_x3

Function vst1q_s8_x3 

pub unsafe fn vst1q_s8_x3(a: *mut i8, b: int8x16x3_t)
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and ARM and target feature neon and target feature v7 only.
Store multiple single-element structures from one, two, three, or four registers Arm’s documentation

Safety

  • Neon instrinsic unsafe