permlane16_var

Function permlane16_var 

pub unsafe fn permlane16_var<const FI: bool, const BOUND_CONTROL: bool>(
    old: u32,
    src0: u32,
    src1: u32,
) -> u32
🔬This is a nightly-only experimental API. (stdarch_amdgpu #149988)
Available on AMD GPU only.
Performs arbitrary gather-style operation within a row (16 contiguous lanes) of the second input operand.

In contrast to permlane16_u32, allows each lane to specify its own gather lane.

This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.