permlane64_u32

Function permlane64_u32 

pub unsafe fn permlane64_u32(value: u32) -> u32
🔬This is a nightly-only experimental API. (stdarch_amdgpu #149988)
Available on AMD GPU only.
Swap value between upper and lower 32 lanes in a wavefront.

Does nothing for wave32.

This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.