s_barrier_signal

Function s_barrier_signal 

pub unsafe fn s_barrier_signal<const BARRIER_TYPE: i32>()
🔬This is a nightly-only experimental API. (stdarch_amdgpu #149988)
Available on AMD GPU only.
Signal a specific barrier type.

Only for non-named barriers.

This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.