s_barrier_signal_isfirst

Function s_barrier_signal_isfirst 

pub unsafe fn s_barrier_signal_isfirst<const BARRIER_TYPE: i32>() -> bool
🔬This is a nightly-only experimental API. (stdarch_amdgpu #149988)
Available on AMD GPU only.
Signal a specific barrier type.

Only for non-named barriers. Provides access to the s_barrier_signal_first instruction; additionally ensures that the result value is valid even when the intrinsic is used from a wavefront that is not running in a workgroup.

This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.