wave_barrier

Function wave_barrier 

pub fn wave_barrier()
🔬This is a nightly-only experimental API. (stdarch_amdgpu #149988)
Available on AMD GPU only.
A barrier for only the threads within the current wavefront.

Does not result in an instruction but restricts the compiler.

This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.