pub unsafe fn vld2_dup_s16(a: *const i16) -> int16x4x2_tThis is supported on ARM and target feature
neon,v7 only.Expand description
Load single 2-element structure and replicate to all lanes of two registers
pub unsafe fn vld2_dup_s16(a: *const i16) -> int16x4x2_tneon,v7 only.Load single 2-element structure and replicate to all lanes of two registers