vld4_dup_p64

Function vld4_dup_p64 

pub unsafe fn vld4_dup_p64(a: *const u64) -> poly64x1x4_t
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on ARM and (AArch64 or ARM64EC or target feature v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.
Load single 4-element structure and replicate to all lanes of four registers Arm’s documentation

Safety

  • Neon intrinsic unsafe