vrndn_f32

Function vrndn_f32 

pub fn vrndn_f32(a: float32x2_t) -> float32x2_t
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on ARM and target feature neon and target feature fp-armv8 and target feature v8 only.
Floating-point round to integral, to nearest with ties to even Arm’s documentation