This is supported on target feature
neon and target feature v7 and ARM only.Expand description
Store multiple single-element structures from one, two, three, or four registers
neon and target feature v7 and ARM only.Store multiple single-element structures from one, two, three, or four registers