Function core::arch::mips::__msa_adds_s_w [−][src]
pub unsafe fn __msa_adds_s_w(a: v4i32, b: v4i32) -> v4i32This is supported on MIPS and target feature
msa only.Expand description
Vector Signed Saturated Add of Signed Values
The elements in vector in a (four signed 32-bit integer numbers)
are added to the elements in vector b (four signed 32-bit integer numbers).
Signed arithmetic is performed and overflows clamp to the largest and/or smallest
representable signed values before writing the result to vector (four signed 32-bit integer numbers).