Function core::arch::mips::__msa_asub_s_w [−][src]
pub unsafe fn __msa_asub_s_w(a: v4i32, b: v4i32) -> v4i32This is supported on MIPS and target feature
msa only.Expand description
Vector Absolute Values of Signed Subtract
The signed elements in vector a (four signed 32-bit integer numbers)
are subtracted from the signed elements in vector b (four signed 32-bit integer numbers).
The absolute value of the signed result is written to vector (four signed 32-bit integer numbers).