Function core::arch::mips::__msa_bclri_w [−][src]
pub unsafe fn __msa_bclri_w<const IMM5: i32>(a: v4u32) -> v4u32This is supported on MIPS and target feature
msa only.Expand description
Immediate Bit Clear
Clear (set to 0) one bit in each element of vector a (four unsigned 32-bit integer numbers).
The bit position is given by the immediate m modulo the size of the element in bits.
The result is written to vector (four unsigned 32-bit integer numbers).