Function core::arch::mips::__msa_binsli_d [−][src]
pub unsafe fn __msa_binsli_d<const IMM6: i32>(a: v2u64, b: v2u64) -> v2u64This is supported on MIPS and target feature
msa only.Expand description
Immediate Bit Insert Left
Copy most significant (left) bits in each element of vector b (two unsigned 64-bit integer numbers)
to elements in vector a (two unsigned 64-bit integer numbers) while preserving the least significant (right) bits.
The number of bits to copy is given by the immediate imm6 modulo the size of the element in bits plus 1.