Function core::arch::mips::__msa_binsri_b [−][src]
pub unsafe fn __msa_binsri_b<const IMM3: i32>(a: v16u8, b: v16u8) -> v16u8This is supported on MIPS and target feature
msa only.Expand description
Immediate Bit Insert Right
Copy most significant (right) bits in each element of vector b (sixteen unsigned 8-bit integer numbers)
to elements in vector a (sixteen unsigned 8-bit integer numbers) while preserving the least significant (left) bits.
The number of bits to copy is given by the immediate imm3 modulo the size of the element in bits plus 1.