Function core::arch::mips::__msa_bmzi_b [−][src]
pub unsafe fn __msa_bmzi_b<const IMM8: i32>(a: v16u8, b: v16u8) -> v16u8This is supported on MIPS and target feature
msa only.Expand description
Immediate Bit Move If Zero
Copy to destination vector a (sixteen unsigned 8-bit integer numbers) all bits from source vector
b (sixteen unsigned 8-bit integer numbers) for which the corresponding bits from from immediate imm8
are 0 and leaves unchanged all destination bits for which the corresponding immediate bits are 1.