Function core::arch::mips64::__msa_adds_a_w [−][src]
pub unsafe fn __msa_adds_a_w(a: v4i32, b: v4i32) -> v4i32This is supported on MIPS-64 and target feature
msa only.Expand description
Vector Saturated Add of Absolute Values
The absolute values of the elements in vector in a (four signed 32-bit integer numbers)
are added to the absolute values of the elements in vector b (four signed 32-bit integer numbers).
The saturated signed result is written to vector (four signed 32-bit integer numbers).