Function core::arch::mips64::__msa_bclri_b [−][src]
pub unsafe fn __msa_bclri_b<const IMM3: i32>(a: v16u8) -> v16u8This is supported on MIPS-64 and target feature
msa only.Expand description
Immediate Bit Clear
Clear (set to 0) one bit in each element of vector a (sixteen unsigned 8-bit integer numbers).
The bit position is given by the immediate m modulo the size of the element in bits.
The result is written to vector (sixteen unsigned 8-bit integer numbers).