Function core::arch::mips64::__msa_bclri_d [−][src]
pub unsafe fn __msa_bclri_d<const IMM6: i32>(a: v2u64) -> v2u64This is supported on MIPS-64 and target feature
msa only.Expand description
Immediate Bit Clear
Clear (set to 0) one bit in each element of vector a (two unsigned 64-bit integer numbers).
The bit position is given by the immediate m modulo the size of the element in bits.
The result is written to vector (two unsigned 64-bit integer numbers).