Function core::arch::mips64::__msa_bclri_h [−][src]
pub unsafe fn __msa_bclri_h<const IMM4: i32>(a: v8u16) -> v8u16This is supported on MIPS-64 and target feature
msa only.Expand description
Immediate Bit Clear
Clear (set to 0) one bit in each element of vector a (eight unsigned 16-bit integer numbers).
The bit position is given by the immediate m modulo the size of the element in bits.
The result is written to vector (eight unsigned 16-bit integer numbers).