Function core::arch::mips64::__msa_bset_h [−][src]
pub unsafe fn __msa_bset_h(a: v8u16, b: v8u16) -> v8u16This is supported on MIPS-64 and target feature
msa only.Expand description
Vector Bit Set
Set to 1 one bit in each element of vector a (eight unsigned 16-bit integer numbers).
The bit position is given by the elements in vector b (eight unsigned 16-bit integer numbers)
modulo the size of the element in bits.
The result is written to vector (eight unsigned 16-bit integer numbers).