Function core::arch::mips64::__msa_bset_w [−][src]
pub unsafe fn __msa_bset_w(a: v4u32, b: v4u32) -> v4u32This is supported on MIPS-64 and target feature
msa only.Expand description
Vector Bit Set
Set to 1 one bit in each element of vector a (four unsigned 32-bit integer numbers).
The bit position is given by the elements in vector b (four unsigned 32-bit integer numbers)
modulo the size of the element in bits.
The result is written to vector (four unsigned 32-bit integer numbers).