vec_cmpne

Function vec_cmpne 

pub unsafe fn vec_cmpne<T, U>(a: T, b: U) -> <T as VectorCmpNe<U>>::Result
where T: VectorCmpNe<U>,
🔬This is a nightly-only experimental API. (stdarch_powerpc #111145)
Available on PowerPC64 and (PowerPC or PowerPC64) and target feature altivec only.
Vector Compare Not Equal

Result value

For each element of r, the value of each bit is 1 if the corresponding elements of a and b are not equal. Otherwise, the value of each bit is 0.