vec_mul

Function vec_mul 

pub unsafe fn vec_mul<T>(a: T, b: T) -> T
where T: VectorMul,
🔬This is a nightly-only experimental API. (stdarch_powerpc #111145)
Available on PowerPC64 and (PowerPC or PowerPC64) and target feature altivec only.
Vector Multiply

Purpose

Compute the products of corresponding elements of two vectors.

Result value

Each element of r receives the product of the corresponding elements of a and b.