pub unsafe fn sinval_vma(vaddr: usize, asid: usize)🔬This is a nightly-only experimental API. (
riscv_ext_intrinsics #114544)Available on (RISC-V RV32) and (RISC-V RV32 or RISC-V RV64) only.
Invalidate supervisor translation cache for given virtual address and address space
This instruction invalidates any address-translation cache entries that an
SFENCE.VMA instruction with the same values of vaddr and asid would invalidate.