pub fn _mm256_movepi64_mask(a: __m256i) -> __mmask8Available on x86 and (x86 or x86-64) and target feature
avx512dq and target feature avx512vl only.Expand description
Set each bit of mask register k based on the most significant bit of the corresponding packed 64-bit integer in a.