Struct core::cell::RefStable
[-]
[+]
[src]
pub struct Ref<'b, T: 'b> {
// some fields omitted
}Wraps a borrowed reference to a value in a RefCell box.
pub struct Ref<'b, T: 'b> {
// some fields omitted
}Wraps a borrowed reference to a value in a RefCell box.
impl<'b, T> Deref<T> for Ref<'b, T>fn deref<'a>(&'a self) -> &'a Timpl<'b, T: Show> Show for Ref<'b, T>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).