Struct core::cell::RefMutStable
[-]
[+]
[src]
pub struct RefMut<'b, T: 'b> {
// some fields omitted
}Wraps a mutable borrowed reference to a value in a RefCell box.
pub struct RefMut<'b, T: 'b> {
// some fields omitted
}Wraps a mutable borrowed reference to a value in a RefCell box.
impl<'b, T> Deref<T> for RefMut<'b, T>fn deref<'a>(&'a self) -> &'a Timpl<'b, T> DerefMut<T> for RefMut<'b, T>fn deref_mut<'a>(&'a mut self) -> &'a mut Timpl<'b, T: Show> Show for RefMut<'b, T>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).