Enum core::fmt::rt::FlagExperimental
[-]
[+]
[src]
pub enum Flag {
FlagSignPlus,
FlagSignMinus,
FlagAlternate,
FlagSignAwareZeroPad,
}Flags which can be passed to formatting via a directive.
These flags are discovered through the flags field of the Formatter
structure. The flag in that structure is a union of these flags into a
uint where each flag's discriminant is the corresponding bit.