Trait core::hash::HasherExperimental
[-]
[+]
[src]
pub trait Hasher<S> {
fn hash<T: Hash<S> + ?Sized>(&self, value: &T) -> u64;
}A trait that computes a hash for a value. The main users of this trait are
containers like HashMap, which need a generic way hash multiple types.