core::intrinsics::copysignf64
[−]
[src]
pub unsafe extern "rust-intrinsic" fn copysignf64(x: f64, y: f64) -> f64
Unstable
: intrinsics are unlikely to ever be stabilized, instead they should be used through stabilized interfaces in the rest of the standard library
Copies the sign from y`yto` to x`xfor` for f64`f64` values.