core::intrinsics::cttz16Experimental
[-]
[+]
[src]
pub unsafe fn cttz16(x: u16) -> u16
Returns the number of trailing bits unset in a u16.
pub unsafe fn cttz16(x: u16) -> u16
Returns the number of trailing bits unset in a u16.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).