core::intrinsics::needs_drop
[−]
[src]
pub unsafe extern "rust-intrinsic" fn needs_drop<T>() -> bool
: intrinsics are unlikely to ever be stabilized, instead they should be used through stabilized interfaces in the rest of the standard library
Returns true`trueif the actual type given asTrequires drop glue; returnsfalseif the actual type provided forTimplementsCopy`.
If the actual type neither requires drop glue nor implements
Copy`Copy, then may returntrueor` or false`false`.