Function core::intrinsics::rintf64

source ·
pub unsafe extern "rust-intrinsic" fn rintf64(x: f64) -> f64
🔬This is a nightly-only experimental API. (core_intrinsics)
Returns the nearest integer to an f64. Changing the rounding mode is not possible in Rust, so this rounds half-way cases to the number with an even least significant digit.

May raise an inexact floating-point exception if the argument is not an integer. However, Rust assumes floating-point exceptions cannot be observed, so this is not something that can actually be used from Rust code.

The stabilized version of this intrinsic is f64::round_ties_even