Struct core::intrinsics::TypeIdExperimental
[-]
[+]
[src]
pub struct TypeId {
// some fields omitted
}TypeId represents a globally unique identifier for a type
Methods
impl TypeId
fn of<T: 'static>() -> TypeId
Returns the TypeId of the type this generic function has been instantiated with