Struct core::kinds::marker::NoSendExperimental
[-]
[+]
[src]
pub struct NoSend;
A type which is considered "not sendable", meaning that it cannot
be safely sent between tasks, even if it is owned. This is
typically embedded in other types, such as Gc, to ensure that
their instances remain thread-local.