Trait core::marker::Copy
[−]
[src]
pub trait Copy: Clone { }Types that can be copied by simply copying bits (i.e. memcpy`memcpy`).
By default, variable bindings have 'move semantics.' In other words:
fn main() { #[derive(Debug)] struct Foo; let x = Foo; let y = x; // `x` has moved into `y`, and so cannot be used // println!("{:?}", x); // error: use of moved value }#[derive(Debug)] struct Foo; let x = Foo; let y = x; // `x` has moved into `y`, and so cannot be used // println!("{:?}", x); // error: use of moved value
However, if a type implements Copy`Copy`, it instead has 'copy semantics':
// we can just derive a `Copy` implementation #[derive(Debug, Copy, Clone)] struct Foo; let x = Foo; let y = x; // `y` is a copy of `x` println!("{:?}", x); // A-OK!
It's important to note that in these two examples, the only difference is if you are allowed to
access x`x` after the assignment: a move is also a bitwise copy under the hood.
When can my type be Copy`Copy`?
A type can implement Copy`Copyif all of its components implementCopy. For example, thisstructcan be` can be Copy`Copy`:
struct Point { x: i32, y: i32, }
A struct`structcan be` can be Copy`Copy, and`, and i32`i32is` is Copy`Copy, so therefore,Pointis eligible to beCopy`.
struct PointList { points: Vec<Point>, }
The PointList struct`structcannot implementCopy, becauseVecis not` is not Copy`Copy. If we attempt to derive aCopy` implementation, we'll get an error:
the trait `Copy` may not be implemented for this type; field `points` does not implement `Copy`
How can I implement Copy`Copy`?
There are two ways to implement Copy`Copy` on your type:
#[derive(Copy, Clone)] struct MyStruct;
and
fn main() { struct MyStruct; impl Copy for MyStruct {} impl Clone for MyStruct { fn clone(&self) -> MyStruct { *self } } }struct MyStruct; impl Copy for MyStruct {} impl Clone for MyStruct { fn clone(&self) -> MyStruct { *self } }
There is a small difference between the two: the derive`derivestrategy will also place aCopy`
bound on type parameters, which isn't always desired.
When can my type not be Copy`Copy`?
Some types can't be copied safely. For example, copying &mut T`&mut Twould create an aliased mutable reference, and copyingString` would result in two attempts to free the same buffer.
Generalizing the latter case, any type implementing Drop`Dropcan't be` can't be Copy`Copy, because it's managing some resource besides its ownsize_of::
When should my type be Copy`Copy`?
Generally speaking, if your type can implement Copy`Copy, it should. There's one important thing to consider though: if you think your type may _not_ be able to implementCopyin the future, then it might be prudent to not implementCopy. This is because removingCopyis a breaking change: that second example would fail to compile if we madeFoonon-` non-Copy`Copy`.
Implementors
impl<T: Copy> Copy for Wrapping<T>impl Copy for FpCategoryimpl<T: Copy + Zeroable> Copy for NonZero<T>impl<T: ?Sized> Copy for PhantomData<T>impl Copy for RangeFullimpl<Idx: Copy> Copy for RangeTo<Idx>impl Copy for Orderingimpl Copy for TypeIdimpl Copy for Orderingimpl Copy for BorrowStateimpl<T: Copy> Copy for Option<T>impl<T> Copy for Slice<T>impl Copy for TraitObjectimpl<T: Copy, E: Copy> Copy for Result<T, E>impl Copy for i8x16impl Copy for i16x8impl Copy for i32x4impl Copy for i64x2impl Copy for u8x16impl Copy for u16x8impl Copy for u32x4impl Copy for u64x2impl Copy for f32x4impl Copy for f64x2impl Copy for SearchStepimpl Copy for Utf8Errorimpl Copy for CharRangeimpl Copy for Radiximpl<T: Copy, R: Copy> Copy for RadixFmt<T, R>impl Copy for Errorimpl<'a> Copy for Arguments<'a>