Function core::num::powDeprecated
[-]
[+]
[src]
pub fn pow<T: Int>(base: T, exp: uint) -> T
Raises a base to the power of exp, using exponentiation by squaring.
pub fn pow<T: Int>(base: T, exp: uint) -> T
Raises a base to the power of exp, using exponentiation by squaring.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).