Trait core::ops::FnExperimental
[-]
[+]
[src]
pub trait Fn<Args, Result>: ?Sized {
fn call(&self, args: Args) -> Result;
}A version of the call operator that takes an immutable receiver.
Required Methods
fn call(&self, args: Args) -> Result
This is called when the call operator is used.