Trait core::ops::FnOnceExperimental
[-]
[+]
[src]
pub trait FnOnce<Args, Result> {
fn call_once(self, args: Args) -> Result;
}A version of the call operator that takes a by-value receiver.
Required Methods
fn call_once(self, args: Args) -> Result
This is called when the call operator is used.