Struct core::option::IntoIterStable
[-]
[+]
[src]
pub struct IntoIter<A> {
// some fields omitted
}An iterator over the item contained inside an Option.
pub struct IntoIter<A> {
// some fields omitted
}An iterator over the item contained inside an Option.
impl<A> Iterator<A> for IntoIter<A>impl<A> DoubleEndedIterator<A> for IntoIter<A>impl<A> ExactSizeIterator<A> for IntoIter<A>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).