Function core::str::is_utf8Deprecated
[-]
[+]
[src]
pub fn is_utf8(v: &[u8]) -> bool
Determines if a vector of bytes contains valid UTF-8.
pub fn is_utf8(v: &[u8]) -> bool
Determines if a vector of bytes contains valid UTF-8.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).