Struct core::str::LinesStable
[-]
[+]
[src]
pub struct Lines<'a> {
// some fields omitted
}An iterator over the lines of a string, separated by \n.
pub struct Lines<'a> {
// some fields omitted
}An iterator over the lines of a string, separated by \n.
impl<'a> Iterator<&'a str> for Lines<'a>impl<'a> DoubleEndedIterator<&'a str> for Lines<'a>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).