Trait core::str::StrUnstable
[-]
[+]
[src]
pub trait Str: ?Sized {
fn as_slice<'a>(&'a self) -> &'a str;
}Any string that can be represented as a slice
pub trait Str: ?Sized {
fn as_slice<'a>(&'a self) -> &'a str;
}Any string that can be represented as a slice
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).