pub unsafe trait AtomicPrimitive:
Sized
+ Copy
+ Sealed {
type Storage: Sized;
}🔬This is a nightly-only experimental API. (
atomic_internals)Expand description
A marker trait for primitive types which can be modified atomically.
This is an implementation detail for Atomic<T> which may disappear or be replaced at any time.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl AtomicPrimitive for i128
Available on target_has_atomic_load_store=128 only.
impl AtomicPrimitive for i128
Available on
target_has_atomic_load_store=128 only.Sourceimpl AtomicPrimitive for u128
Available on target_has_atomic_load_store=128 only.
impl AtomicPrimitive for u128
Available on
target_has_atomic_load_store=128 only.