Enum fmt_macros::Piece
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A piece is a portion of the format string which represents the next part
to emit. These are emitted as a stream by the Parser class.
Variants
String(&'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal string which should directly be emitted
NextArgument(Argument<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This describes that formatting should process the next argument (as specified inside) for emission.