Struct rustdoc::html::format::WhereClauseUnstable
[-] [+]
[src]
pub struct WhereClause<'a>(pub &'a Generics);
Wrapper struct for emitting a where clause from Generics.
pub struct WhereClause<'a>(pub &'a Generics);
Wrapper struct for emitting a where clause from Generics.
impl<'a> Display for WhereClause<'a>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).