Module inline_text

Module inline_text 

Inline text elements

Use the HTML inline text semantic to define the meaning, structure, or style of a word, line, or any arbitrary piece of text.

Modules

builders
Element builders
children
Child elements

Structs

Abbreviation
The HTML <abbr> element
Anchor
The HTML <a> element
BidirectionalIsolate
The HTML <bdi> element
BidirectionalTextOverride
The HTML <bdo> element
Bold
The HTML <b> element
Cite
The HTML <cite> element
Code
The HTML <code> element
Data
The HTML <data> element
Definition
The HTML <dfn> element
Emphasis
The HTML <em> element
Italic
The HTML <i> element
KeyboardInput
The HTML <kbd> element
LineBreak
The HTML <br> element
LineBreakOpportunity
The HTML <wbr> element
MarkText
The HTML <mark> element
Quotation
The HTML <q> element
RubyAnnotation
The HTML <ruby> element
RubyFallbackParenthesis
The HTML <rp> element
RubyText
The HTML <rt> element
SampleOutput
The HTML <samp> element
SideComment
The HTML <small> element
Span
The HTML <span> element
StrikeThrough
The HTML <s> element
Strong
The HTML <strong> element
SubScript
The HTML <sub> element
SuperScript
The HTML <sup> element
Time
The HTML <time> element
Underline
The HTML <u> element
Variable
The HTML <var> element