[−][src]Struct minifier::json::read::json_read::JsonRead
Fields
minifier: JsonMinifier
read: Option<R>
iter: Option<ByteToChar<R>>
predicate: P
initialized: bool
item_iter: Option<IntoIter<u8>>
item1: Option<char>
Methods
impl<P, R: Read> JsonRead<P, R>[src]
impl<P, R: Read> JsonRead<P, R>pub fn new(read: R, predicate: P) -> Self[src]
pub fn new(read: R, predicate: P) -> Selffn get_next(&mut self) -> Result<Option<char>, CharsError>[src]
fn get_next(&mut self) -> Result<Option<char>, CharsError>fn add_char_to_buffer(&mut self, buf: &mut [u8], buf_pos: &mut usize)[src]
fn add_char_to_buffer(&mut self, buf: &mut [u8], buf_pos: &mut usize)Trait Implementations
impl<P, R: Read + Debug> Debug for JsonRead<P, R>[src]
impl<P, R: Read + Debug> Debug for JsonRead<P, R>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<P, R> Read for JsonRead<P, R> where
R: Read,
P: FnMut(&mut JsonMinifier, &char, Option<&char>) -> bool, [src]
impl<P, R> Read for JsonRead<P, R> where
R: Read,
P: FnMut(&mut JsonMinifier, &char, Option<&char>) -> bool, fn read(&mut self, buf: &mut [u8]) -> Result<usize, Error>[src]
fn read(&mut self, buf: &mut [u8]) -> Result<usize, Error>Pull some bytes from this source into the specified buffer, returning how many bytes were read. Read more
unsafe fn initializer(&self) -> Initializer[src]
unsafe fn initializer(&self) -> Initializerread_initializer)Determines if this Reader can work with buffers of uninitialized memory. Read more
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>1.0.0[src]
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>Read all bytes until EOF in this source, placing them into buf. Read more
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>1.0.0[src]
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>Read all bytes until EOF in this source, appending them to buf. Read more
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>1.6.0[src]
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>Read the exact number of bytes required to fill buf. Read more
fn by_ref(&mut self) -> &mut Self1.0.0[src]
fn by_ref(&mut self) -> &mut SelfCreates a "by reference" adaptor for this instance of Read. Read more
fn bytes(self) -> Bytes<Self>1.0.0[src]
fn bytes(self) -> Bytes<Self>Transforms this Read instance to an [Iterator] over its bytes. Read more
fn chain<R>(self, next: R) -> Chain<Self, R> where
R: Read, 1.0.0[src]
fn chain<R>(self, next: R) -> Chain<Self, R> where
R: Read, Creates an adaptor which will chain this stream with another. Read more
fn take(self, limit: u64) -> Take<Self>1.0.0[src]
fn take(self, limit: u64) -> Take<Self>Creates an adaptor which will read at most limit bytes from it. Read more