[−][src]Trait rand::distributions::float::IntoFloat
Associated Types
type F
Required Methods
fn into_float_with_exponent(self, exponent: i32) -> Self::F
Helper method to combine the fraction and a contant exponent into a float.
Only the least significant bits of self may be set, 23 for f32 and
52 for f64.
The resulting value will fall in a range that depends on the exponent.
As an example the range with exponent 0 will be
[20..21), which is [1..2).
Implementations on Foreign Types
impl IntoFloat for u32[src]
impl IntoFloat for u32impl IntoFloat for u64[src]
impl IntoFloat for u64