[−][src]Struct rand::distributions::gamma::GammaSmallShape
Gamma distribution where the shape parameter is less than 1.
Note, samples from this require a compulsory floating-point pow
call, which makes it significantly slower than sampling from a
gamma distribution where the shape parameter is greater than or
equal to 1.
See Gamma for sampling from a Gamma distribution with general
shape parameters.
Fields
inv_shape: f64
large_shape: GammaLargeShape
Methods
impl GammaSmallShape[src]
impl GammaSmallShapefn new_raw(shape: f64, scale: f64) -> GammaSmallShape[src]
fn new_raw(shape: f64, scale: f64) -> GammaSmallShapeTrait Implementations
impl Clone for GammaSmallShape[src]
impl Clone for GammaSmallShapefn clone(&self) -> GammaSmallShape[src]
fn clone(&self) -> GammaSmallShapeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for GammaSmallShape[src]
impl Copy for GammaSmallShapeimpl Debug for GammaSmallShape[src]
impl Debug for GammaSmallShapefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Distribution<f64> for GammaSmallShape[src]
impl Distribution<f64> for GammaSmallShapefn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> f64[src]
fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> f64Generate a random value of T, using rng as the source of randomness.
ⓘImportant traits for DistIter<'a, D, R, T>fn sample_iter<'a, R>(&'a self, rng: &'a mut R) -> DistIter<'a, Self, R, T> where
Self: Sized,
R: Rng, [src]
fn sample_iter<'a, R>(&'a self, rng: &'a mut R) -> DistIter<'a, Self, R, T> where
Self: Sized,
R: Rng, Create an iterator that generates random values of T, using rng as the source of randomness. Read more