Enum rand::jitter::TimerError [−][src]
pub enum TimerError {
NoTimer,
CoarseTimer,
NotMonotonic,
TinyVariantions,
TooManyStuck,
__Nonexhaustive,
}An error that can occur when test_timer fails.
Variants
NoTimerNo timer available.
CoarseTimerTimer too coarse to use as an entropy source.
NotMonotonicTimer is not monotonically increasing.
TinyVariantionsVariations of deltas of time too small.
TooManyStuckToo many stuck results (indicating no added entropy).
__Nonexhaustive
Methods
impl TimerError[src]
impl TimerErrorfn description(&self) -> &'static str[src]
fn description(&self) -> &'static strTrait Implementations
impl Debug for TimerError[src]
impl Debug for TimerErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Clone for TimerError[src]
impl Clone for TimerErrorfn clone(&self) -> TimerError[src]
fn clone(&self) -> TimerErrorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl PartialEq for TimerError[src]
impl PartialEq for TimerErrorfn eq(&self, other: &TimerError) -> bool[src]
fn eq(&self, other: &TimerError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for TimerError[src]
impl Eq for TimerErrorfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Display for TimerError[src]
impl Display for TimerErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for TimerError[src]
impl Error for TimerErrorfn description(&self) -> &str[src]
fn description(&self) -> &strThis method is soft-deprecated. Read more
fn cause(&self) -> Option<&Error>1.0.0[src]
fn cause(&self) -> Option<&Error>1.0.0
[src]The lower-level cause of this error, if any. Read more
fn type_id(&self) -> TypeId where
Self: 'static, [src]
fn type_id(&self) -> TypeId where
Self: 'static, 🔬 This is a nightly-only experimental API. (error_type_id)
unclear whether to commit to this public implementation detail
Get the TypeId of self