Struct regex::dfa::State [−][src]
State is a DFA state. It contains an ordered set of NFA states (not
necessarily complete) and a smattering of flags.
The flags are packed into the first byte of data.
States don't carry their transitions. Instead, transitions are stored in a single row-major table.
Delta encoding is used to store the instruction pointers. The first instruction pointer is stored directly starting at data[1], and each following pointer is stored as an offset to the previous one. If a delta is in the range -127..127, it is packed into a single byte; Otherwise the byte 128 (-128 as an i8) is coded as a flag, followed by 4 bytes encoding the delta.
Fields
data: Box<[u8]>
Methods
impl State[src]
impl Statefn flags(&self) -> StateFlags[src]
fn flags(&self) -> StateFlagsⓘImportant traits for InstPtrs<'a>fn inst_ptrs(&self) -> InstPtrs[src]
fn inst_ptrs(&self) -> InstPtrsTrait Implementations
impl Clone for State[src]
impl Clone for Statefn clone(&self) -> State[src]
fn clone(&self) -> StateReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for State[src]
impl Eq for Statefn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Hash for State[src]
impl Hash for Statefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl PartialEq for State[src]
impl PartialEq for Statefn eq(&self, other: &State) -> bool[src]
fn eq(&self, other: &State) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &State) -> bool[src]
fn ne(&self, other: &State) -> boolThis method tests for !=.
impl Debug for State[src]
impl Debug for State