Struct regex::dfa::StateFlags [−][src]
struct StateFlags(u8);
A set of flags describing various configurations of a DFA state. This is
represented by a u8 so that it is compact.
Methods
impl StateFlags[src]
impl StateFlagsfn is_match(&self) -> bool[src]
fn is_match(&self) -> boolfn set_match(&mut self)[src]
fn set_match(&mut self)fn is_word(&self) -> bool[src]
fn is_word(&self) -> boolfn set_word(&mut self)[src]
fn set_word(&mut self)fn has_empty(&self) -> bool[src]
fn has_empty(&self) -> boolfn set_empty(&mut self)[src]
fn set_empty(&mut self)Trait Implementations
impl Clone for StateFlags[src]
impl Clone for StateFlagsfn clone(&self) -> StateFlags[src]
fn clone(&self) -> StateFlagsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Copy for StateFlags[src]
impl Copy for StateFlagsimpl Eq for StateFlags[src]
impl Eq for StateFlagsfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Default for StateFlags[src]
impl Default for StateFlagsfn default() -> StateFlags[src]
fn default() -> StateFlagsReturns the "default value" for a type. Read more
impl Hash for StateFlags[src]
impl Hash for StateFlagsfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl PartialEq for StateFlags[src]
impl PartialEq for StateFlagsfn eq(&self, other: &StateFlags) -> bool[src]
fn eq(&self, other: &StateFlags) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &StateFlags) -> bool[src]
fn ne(&self, other: &StateFlags) -> boolThis method tests for !=.
impl Debug for StateFlags[src]
impl Debug for StateFlagsAuto Trait Implementations
impl Send for StateFlags
impl Send for StateFlagsimpl Sync for StateFlags
impl Sync for StateFlags