Enum regex::error::Error [−][src]
An error that occurred during parsing or compiling a regular expression.
Variants
Syntax(String)A syntax error.
CompiledTooBig(usize)The compiled program exceeded the set size limit. The argument is the size limit imposed.
__NonexhaustiveHints that destructuring should not be exhaustive.
This enum may grow additional variants, so this makes sure clients don't count on exhaustive matching. (Otherwise, adding a new variant could break existing code.)