Enum regex::exec::MatchNfaType [−][src]
enum MatchNfaType {
Auto,
Backtrack,
PikeVM,
}Variants
AutoChoose between Backtrack and PikeVM.
BacktrackNFA bounded backtracking.
(This is only set by tests, since it never makes sense to always want backtracking.)
PikeVMThe Pike VM.
(This is only set by tests, since it never makes sense to always want the Pike VM.)