Enum regex::exec::MatchType [−][src]
enum MatchType {
Literal(MatchLiteralType),
Dfa,
DfaAnchoredReverse,
DfaSuffix,
DfaMany,
Nfa(MatchNfaType),
Nothing,
}Variants
Literal(MatchLiteralType)A single or multiple literal search. This is only used when the regex can be decomposed into unambiguous literal search.
DfaA normal DFA search.
DfaAnchoredReverseA reverse DFA search starting from the end of a haystack.
DfaSuffixA reverse DFA search with suffix literal scanning.
DfaManyUse the DFA on two or more regular expressions.
Nfa(MatchNfaType)An NFA variant.
NothingNo match is ever possible, so don't ever try to search.