Struct regex::exec::Exec [−][src]
pub struct Exec {
ro: Arc<ExecReadOnly>,
cache: CachedThreadLocal<RefCell<ProgramCacheInner>>,
}Exec manages the execution of a regular expression.
In particular, this manages the various compiled forms of a single regular expression and the choice of which matching engine to use to execute a regular expression.
Fields
ro: Arc<ExecReadOnly>
All read only state.
cache: CachedThreadLocal<RefCell<ProgramCacheInner>>
Caches for the various matching engines.
Methods
impl Exec[src]
impl Execpub fn searcher(&self) -> ExecNoSync[src]
pub fn searcher(&self) -> ExecNoSyncGet a searcher that isn't Sync.
pub fn searcher_str(&self) -> ExecNoSyncStr[src]
pub fn searcher_str(&self) -> ExecNoSyncStrGet a searcher that isn't Sync and can match on &str.
pub fn into_regex(self) -> Regex[src]
pub fn into_regex(self) -> RegexBuild a Regex from this executor.
pub fn into_regex_set(self) -> RegexSet[src]
pub fn into_regex_set(self) -> RegexSetBuild a RegexSet from this executor.
pub fn into_byte_regex(self) -> Regex[src]
pub fn into_byte_regex(self) -> RegexBuild a Regex from this executor that can match arbitrary bytes.
pub fn into_byte_regex_set(self) -> RegexSet[src]
pub fn into_byte_regex_set(self) -> RegexSetBuild a RegexSet from this executor that can match arbitrary bytes.
pub fn regex_strings(&self) -> &[String][src]
pub fn regex_strings(&self) -> &[String]The original regular expressions given by the caller that were compiled.
pub fn capture_names(&self) -> &[Option<String>][src]
pub fn capture_names(&self) -> &[Option<String>]Return a slice of capture names.
Any capture that isn't named is None.
pub fn capture_name_idx(&self) -> &Arc<HashMap<String, usize>>[src]
pub fn capture_name_idx(&self) -> &Arc<HashMap<String, usize>>Return a reference to named groups mapping (from group name to group position).