Struct regex::exec::ExecNoSyncStr [−][src]
pub struct ExecNoSyncStr<'c>(ExecNoSync<'c>);
ExecNoSyncStr is like ExecNoSync, but matches on &str instead of &u8.
Methods
impl<'c> ExecNoSyncStr<'c>[src]
impl<'c> ExecNoSyncStr<'c>Trait Implementations
impl<'c> RegularExpression for ExecNoSyncStr<'c>[src]
impl<'c> RegularExpression for ExecNoSyncStr<'c>type Text = str
The type of the haystack.
fn slots_len(&self) -> usize[src]
fn slots_len(&self) -> usizeThe number of capture slots in the compiled regular expression. This is always two times the number of capture groups (two slots per group). Read more
fn next_after_empty(&self, text: &str, i: usize) -> usize[src]
fn next_after_empty(&self, text: &str, i: usize) -> usizeReturns the position of the next character after i. Read more
fn shortest_match_at(&self, text: &str, start: usize) -> Option<usize>[src]
fn shortest_match_at(&self, text: &str, start: usize) -> Option<usize>Returns the location of the shortest match.
fn is_match_at(&self, text: &str, start: usize) -> bool[src]
fn is_match_at(&self, text: &str, start: usize) -> boolReturns whether the regex matches the text given.
fn find_at(&self, text: &str, start: usize) -> Option<(usize, usize)>[src]
fn find_at(&self, text: &str, start: usize) -> Option<(usize, usize)>Returns the leftmost-first match location if one exists.
fn read_captures_at(
&self,
locs: &mut Locations,
text: &str,
start: usize
) -> Option<(usize, usize)>[src]
fn read_captures_at(
&self,
locs: &mut Locations,
text: &str,
start: usize
) -> Option<(usize, usize)>Returns the leftmost-first match location if one exists, and also fills in any matching capture slot locations. Read more
fn locations(&self) -> Locations[src]
fn locations(&self) -> LocationsAllocates fresh space for all capturing groups in this regex.
ⓘImportant traits for Matches<'t, R>fn find_iter(self, text: &Self::Text) -> Matches<Self>[src]
fn find_iter(self, text: &Self::Text) -> Matches<Self>Returns an iterator over all non-overlapping successive leftmost-first matches. Read more
ⓘImportant traits for CaptureMatches<'t, R>fn captures_iter(self, text: &Self::Text) -> CaptureMatches<Self>[src]
fn captures_iter(self, text: &Self::Text) -> CaptureMatches<Self>Returns an iterator over all non-overlapping successive leftmost-first matches with captures. Read more