Enum regex::expand::Ref [−][src]
A reference to a capture group in some text.
e.g., $2, $foo, ${foo}.
Variants
Named(&'a str)Number(usize)Trait Implementations
impl<'a> Clone for Ref<'a>[src]
impl<'a> Clone for Ref<'a>fn clone(&self) -> Ref<'a>[src]
fn clone(&self) -> Ref<'a>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl<'a> Copy for Ref<'a>[src]
impl<'a> Copy for Ref<'a>impl<'a> Debug for Ref<'a>[src]
impl<'a> Debug for Ref<'a>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<'a> Eq for Ref<'a>[src]
impl<'a> Eq for Ref<'a>fn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl<'a> PartialEq for Ref<'a>[src]
impl<'a> PartialEq for Ref<'a>fn eq(&self, other: &Ref<'a>) -> bool[src]
fn eq(&self, other: &Ref<'a>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Ref<'a>) -> bool[src]
fn ne(&self, other: &Ref<'a>) -> boolThis method tests for !=.
impl<'a> From<&'a str> for Ref<'a>[src]
impl<'a> From<&'a str> for Ref<'a>impl From<usize> for Ref<'static>[src]
impl From<usize> for Ref<'static>