Struct regex::expand::CaptureRef [−][src]
CaptureRef represents a reference to a capture group inside some text.
The reference is either a capture group name or a number.
It is also tagged with the position in the text immediately proceding the capture reference.
Fields
cap: Ref<'a>
end: usize