Struct regex::internal::Char [−][src]
pub struct Char(u32);
An inline representation of Option<char>.
This eliminates the need to do case analysis on Option<char> to determine
ordinality with other characters.
(The Option<char> is not related to encoding. Instead, it is used in the
matching engines to represent the beginning and ending boundaries of the
search text.)
Methods
impl Char[src]
impl Charpub fn is_none(self) -> bool[src]
pub fn is_none(self) -> boolReturns true iff the character is absent.
pub fn len_utf8(self) -> usize[src]
pub fn len_utf8(self) -> usizeReturns the length of the character's UTF-8 encoding.
If the character is absent, then 0 is returned.
pub fn is_word_char(self) -> bool[src]
pub fn is_word_char(self) -> boolReturns true iff the character is a word character.
If the character is absent, then false is returned.
pub fn is_word_byte(self) -> bool[src]
pub fn is_word_byte(self) -> boolReturns true iff the byte is a word byte.
If the byte is absent, then false is returned.