Struct regex::internal::InputAt [−][src]
Represents a location in the input.
Fields
pos: usize
c: Char
byte: Option<u8>
len: usize
Methods
impl InputAt[src]
impl InputAtpub fn is_start(&self) -> bool[src]
pub fn is_start(&self) -> boolReturns true iff this position is at the beginning of the input.
pub fn is_end(&self) -> bool[src]
pub fn is_end(&self) -> boolReturns true iff this position is past the end of the input.
pub fn char(&self) -> Char[src]
pub fn char(&self) -> CharReturns the character at this position.
If this position is just before or after the input, then an absent character is returned.
pub fn byte(&self) -> Option<u8>[src]
pub fn byte(&self) -> Option<u8>Returns the byte at this position.
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usizeReturns the UTF-8 width of the character at this position.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> boolReturns whether the UTF-8 width of the character at this position is zero.
pub fn pos(&self) -> usize[src]
pub fn pos(&self) -> usizeReturns the byte offset of this position.
pub fn next_pos(&self) -> usize[src]
pub fn next_pos(&self) -> usizeReturns the byte offset of the next position in the input.