Enum regex::literal::Matcher [−][src]
enum Matcher {
Empty,
Bytes(SingleByteSet),
FreqyPacked(FreqyPacked),
BoyerMoore(BoyerMooreSearch),
AC(FullAcAutomaton<Literal>),
TeddySSSE3(TeddySSSE3),
TeddyAVX2(TeddyAVX2),
}Variants
EmptyNo literals. (Never advances through the input.)
Bytes(SingleByteSet)A set of four or more single byte literals.
FreqyPacked(FreqyPacked)A single substring, find using memchr and frequency analysis.
BoyerMoore(BoyerMooreSearch)A single substring, find using Boyer-Moore.
AC(FullAcAutomaton<Literal>)An Aho-Corasick automaton.
TeddySSSE3(TeddySSSE3)A simd accelerated multiple string matcher. Used only for a small number of small literals.
TeddyAVX2(TeddyAVX2)A simd accelerated multiple string matcher. Used only for a small number of small literals. This uses 256-bit vectors.
Methods
impl Matcher[src]
impl Matcherfn prefixes(lits: &Literals) -> Self[src]
fn prefixes(lits: &Literals) -> Selffn suffixes(lits: &Literals) -> Self[src]
fn suffixes(lits: &Literals) -> Selffn new(lits: &Literals, sset: SingleByteSet) -> Self[src]
fn new(lits: &Literals, sset: SingleByteSet) -> SelfTrait Implementations
impl Clone for Matcher[src]
impl Clone for Matcherfn clone(&self) -> Matcher[src]
fn clone(&self) -> MatcherReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for Matcher[src]
impl Debug for Matcher