Enum regex::pikevm::FollowEpsilon [−][src]
A representation of an explicit stack frame when following epsilon transitions. This is used to avoid recursion.
Variants
IP(usize)Follow transitions at the given instruction pointer.
CaptureRestore the capture slot with the given position in the input.
Fields of Capture
slot: usize | |
pos: Option<usize> |