Struct regex::prog::InstBytes [−][src]
Representation of the Bytes instruction.
Fields
goto: usize
The next location to execute in the program if this instruction succeeds.
start: u8
The start (inclusive) of this byte range.
end: u8
The end (inclusive) of this byte range.
Methods
impl InstBytes[src]
impl InstBytespub fn matches(&self, byte: u8) -> bool[src]
pub fn matches(&self, byte: u8) -> boolReturns true if and only if the given byte is in this range.