Struct regex::prog::InstRanges [−][src]
Representation of the Ranges instruction.
Fields
goto: usize
The next location to execute in the program if this instruction succeeds.
ranges: Vec<(char, char)>
The set of Unicode scalar value ranges to test.
Methods
impl InstRanges[src]
impl InstRangespub fn matches(&self, c: Char) -> bool[src]
pub fn matches(&self, c: Char) -> boolTests whether the given input character matches this instruction.
pub fn num_chars(&self) -> usize[src]
pub fn num_chars(&self) -> usizeReturn the number of distinct characters represented by all of the ranges.