Struct regex::prog::InstSplit [−][src]
Representation of the Split instruction.
Fields
goto1: usize
The first instruction to try. A match resulting from following goto1 has precedence over a match resulting from following goto2.
goto2: usize
The second instruction to try. A match resulting from following goto1 has precedence over a match resulting from following goto2.