Type Definition regex::prog::InstPtr [−][src]
type InstPtr = usize;
InstPtr represents the index of an instruction in a regex program.
type InstPtr = usize;
InstPtr represents the index of an instruction in a regex program.