Struct regex::re_bytes::Match [−][src]
Match represents a single match of a regex in a haystack.
The lifetime parameter 't refers to the lifetime of the matched text.
Fields
text: &'t [u8]
start: usize
end: usize
Methods
impl<'t> Match<'t>[src]
impl<'t> Match<'t>pub fn start(&self) -> usize[src]
pub fn start(&self) -> usizeReturns the starting byte offset of the match in the haystack.
pub fn end(&self) -> usize[src]
pub fn end(&self) -> usizeReturns the ending byte offset of the match in the haystack.
pub fn as_bytes(&self) -> &'t [u8][src]
pub fn as_bytes(&self) -> &'t [u8]Returns the matched text.
fn new(haystack: &'t [u8], start: usize, end: usize) -> Match<'t>[src]
fn new(haystack: &'t [u8], start: usize, end: usize) -> Match<'t>Creates a new match from the given haystack and byte offsets.