Enum regex_syntax::ast::parse::ClassState [−][src]
enum ClassState {
Open {
union: ClassSetUnion,
set: ClassBracketed,
},
Op {
kind: ClassSetBinaryOpKind,
lhs: ClassSet,
},
}ClassState represents a single stack frame while parsing character classes. Each frame records the state up to an intersection, difference, symmetric difference or nested class.
Note that a parser's character class stack is only non-empty when parsing a character class. In all other cases, it is empty.
Variants
OpenThis state is pushed whenever an opening bracket is found.
Fields of Open
union: ClassSetUnion | The union of class items immediately preceding this class. |
set: ClassBracketed | The class that has been opened. Typically this just corresponds
to the |
OpThis state is pushed when a operator is seen. When popped, the stored set becomes the left hand side of the operator.
Fields of Op
kind: ClassSetBinaryOpKind | The type of the operation, i.e., &&, -- or ~~. |
lhs: ClassSet | The left-hand side of the operator. |