Enum regex_syntax::ast::parse::Primitive [−][src]
enum Primitive {
Literal(Literal),
Assertion(Assertion),
Dot(Span),
Perl(ClassPerl),
Unicode(ClassUnicode),
}A primitive is an expression with no sub-expressions. This includes literals, assertions and non-set character classes. This representation is used as intermediate state in the parser.
This does not include ASCII character classes, since they can only appear within a set character class.
Variants
Literal(Literal)Assertion(Assertion)Dot(Span)Perl(ClassPerl)Unicode(ClassUnicode)
Methods
impl Primitive[src]
impl Primitivefn span(&self) -> &Span[src]
fn span(&self) -> &SpanReturn the span of this primitive.
fn into_ast(self) -> Ast[src]
fn into_ast(self) -> AstConvert this primitive into a proper AST.
fn into_class_set_item<P: Borrow<Parser>>(
self,
p: &ParserI<P>
) -> Result<ClassSetItem, Error>[src]
fn into_class_set_item<P: Borrow<Parser>>(
self,
p: &ParserI<P>
) -> Result<ClassSetItem, Error>Convert this primitive into an item in a character class.
If this primitive is not a legal item (i.e., an assertion or a dot), then return an error.
fn into_class_literal<P: Borrow<Parser>>(
self,
p: &ParserI<P>
) -> Result<Literal, Error>[src]
fn into_class_literal<P: Borrow<Parser>>(
self,
p: &ParserI<P>
) -> Result<Literal, Error>Convert this primitive into a literal in a character class. In particular, literals are the only valid items that can appear in ranges.
If this primitive is not a legal item (i.e., a class, assertion or a dot), then return an error.