Struct regex_syntax::ast::print::Writer [−][src]
struct Writer<'p, W> {
printer: &'p mut Printer,
wtr: W,
}Fields
printer: &'p mut Printer
wtr: W
Methods
impl<'p, W: Write> Writer<'p, W>[src]
impl<'p, W: Write> Writer<'p, W>fn fmt_group_pre(&mut self, ast: &Group) -> Result[src]
fn fmt_group_pre(&mut self, ast: &Group) -> Resultfn fmt_group_post(&mut self, _ast: &Group) -> Result[src]
fn fmt_group_post(&mut self, _ast: &Group) -> Resultfn fmt_repetition(&mut self, ast: &Repetition) -> Result[src]
fn fmt_repetition(&mut self, ast: &Repetition) -> Resultfn fmt_repetition_range(&mut self, ast: &RepetitionRange) -> Result[src]
fn fmt_repetition_range(&mut self, ast: &RepetitionRange) -> Resultfn fmt_literal(&mut self, ast: &Literal) -> Result[src]
fn fmt_literal(&mut self, ast: &Literal) -> Resultfn fmt_assertion(&mut self, ast: &Assertion) -> Result[src]
fn fmt_assertion(&mut self, ast: &Assertion) -> Resultfn fmt_set_flags(&mut self, ast: &SetFlags) -> Result[src]
fn fmt_set_flags(&mut self, ast: &SetFlags) -> Resultfn fmt_flags(&mut self, ast: &Flags) -> Result[src]
fn fmt_flags(&mut self, ast: &Flags) -> Resultfn fmt_class_bracketed_pre(&mut self, ast: &ClassBracketed) -> Result[src]
fn fmt_class_bracketed_pre(&mut self, ast: &ClassBracketed) -> Resultfn fmt_class_bracketed_post(&mut self, _ast: &ClassBracketed) -> Result[src]
fn fmt_class_bracketed_post(&mut self, _ast: &ClassBracketed) -> Resultfn fmt_class_set_binary_op_kind(&mut self, ast: &ClassSetBinaryOpKind) -> Result[src]
fn fmt_class_set_binary_op_kind(&mut self, ast: &ClassSetBinaryOpKind) -> Resultfn fmt_class_perl(&mut self, ast: &ClassPerl) -> Result[src]
fn fmt_class_perl(&mut self, ast: &ClassPerl) -> Resultfn fmt_class_ascii(&mut self, ast: &ClassAscii) -> Result[src]
fn fmt_class_ascii(&mut self, ast: &ClassAscii) -> Resultfn fmt_class_unicode(&mut self, ast: &ClassUnicode) -> Result[src]
fn fmt_class_unicode(&mut self, ast: &ClassUnicode) -> ResultTrait Implementations
impl<'p, W: Debug> Debug for Writer<'p, W>[src]
impl<'p, W: Debug> Debug for Writer<'p, W>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<'p, W: Write> Visitor for Writer<'p, W>[src]
impl<'p, W: Write> Visitor for Writer<'p, W>type Output = ()
The result of visiting an AST.
type Err = Error
An error that visiting an AST might return.
fn finish(self) -> Result[src]
fn finish(self) -> ResultAll implementors of Visitor must provide a finish method, which yields the result of visiting the AST or an error. Read more
fn visit_pre(&mut self, ast: &Ast) -> Result[src]
fn visit_pre(&mut self, ast: &Ast) -> ResultThis method is called on an Ast before descending into child Ast nodes. Read more
fn visit_post(&mut self, ast: &Ast) -> Result[src]
fn visit_post(&mut self, ast: &Ast) -> ResultThis method is called on an Ast after descending all of its child Ast nodes. Read more
fn visit_alternation_in(&mut self) -> Result[src]
fn visit_alternation_in(&mut self) -> ResultThis method is called between child nodes of an Alternation. Read more
fn visit_class_set_item_pre(
&mut self,
ast: &ClassSetItem
) -> Result<(), Self::Err>[src]
fn visit_class_set_item_pre(
&mut self,
ast: &ClassSetItem
) -> Result<(), Self::Err>This method is called on every ClassSetItem before descending into child nodes. Read more
fn visit_class_set_item_post(
&mut self,
ast: &ClassSetItem
) -> Result<(), Self::Err>[src]
fn visit_class_set_item_post(
&mut self,
ast: &ClassSetItem
) -> Result<(), Self::Err>This method is called on every ClassSetItem after descending into child nodes. Read more
fn visit_class_set_binary_op_in(
&mut self,
ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>[src]
fn visit_class_set_binary_op_in(
&mut self,
ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>This method is called between the left hand and right hand child nodes of a ClassSetBinaryOp. Read more
fn start(&mut self)[src]
fn start(&mut self)This method is called before beginning traversal of the AST.
fn visit_class_set_binary_op_pre(
&mut self,
_ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>[src]
fn visit_class_set_binary_op_pre(
&mut self,
_ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>This method is called on every ClassSetBinaryOp before descending into child nodes. Read more
fn visit_class_set_binary_op_post(
&mut self,
_ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>[src]
fn visit_class_set_binary_op_post(
&mut self,
_ast: &ClassSetBinaryOp
) -> Result<(), Self::Err>This method is called on every ClassSetBinaryOp after descending into child nodes. Read more