Struct regex_syntax::ast::Error [−][src]
An error that occurred while parsing a regular expression into an abstract syntax tree.
Note that note all ASTs represents a valid regular expression. For example,
an AST is constructed without error for \p{Quux}, but Quux is not a
valid Unicode property name. That particular error is reported when
translating an AST to the high-level intermediate representation (HIR).
Fields
kind: ErrorKind
The kind of error.
pattern: String
The original pattern that the parser generated the error from. Every span in an error is a valid range into this string.
span: Span
The span of this error.
Methods
impl Error[src]
impl Errorpub fn kind(&self) -> &ErrorKind[src]
pub fn kind(&self) -> &ErrorKindReturn the type of this error.
pub fn pattern(&self) -> &str[src]
pub fn pattern(&self) -> &strThe original pattern string in which this error occurred.
Every span reported by this error is reported in terms of this string.
pub fn span(&self) -> &Span[src]
pub fn span(&self) -> &SpanReturn the span at which this error occurred.
pub fn auxiliary_span(&self) -> Option<&Span>[src]
pub fn auxiliary_span(&self) -> Option<&Span>Return an auxiliary span. This span exists only for some errors that benefit from being able to point to two locations in the original regular expression. For example, "duplicate" errors will have the main error position set to the duplicate occurrence while its auxiliary span will be set to the initial occurrence.