Enum regex_syntax::ast::visitor::ClassFrame [−][src]
enum ClassFrame<'a> {
Union {
head: &'a ClassSetItem,
tail: &'a [ClassSetItem],
},
Binary {
op: &'a ClassSetBinaryOp,
},
BinaryLHS {
op: &'a ClassSetBinaryOp,
lhs: &'a ClassSet,
rhs: &'a ClassSet,
},
BinaryRHS {
op: &'a ClassSetBinaryOp,
rhs: &'a ClassSet,
},
}Represents a single stack frame while performing structural induction over a character class.
Variants
UnionThe stack frame used while visiting every child node of a union of character class items.
Fields of Union
head: &'a ClassSetItem | The child node we are currently visiting. |
tail: &'a [ClassSetItem] | The remaining child nodes to visit (which may be empty). |
BinaryThe stack frame used while a binary class operation.
Fields of Binary
op: &'a ClassSetBinaryOp |
BinaryLHSA stack frame allocated just before descending into a binary operator's left hand child node.
Fields of BinaryLHS
op: &'a ClassSetBinaryOp | |
lhs: &'a ClassSet | |
rhs: &'a ClassSet |
BinaryRHSA stack frame allocated just before descending into a binary operator's right hand child node.
Fields of BinaryRHS
op: &'a ClassSetBinaryOp | |
rhs: &'a ClassSet |
Methods
impl<'a> ClassFrame<'a>[src]
impl<'a> ClassFrame<'a>fn child(&self) -> ClassInduct<'a>[src]
fn child(&self) -> ClassInduct<'a>Perform the next inductive step on this frame and return the next child class node to visit.