Enum regex_syntax::ast::visitor::ClassInduct [−][src]
enum ClassInduct<'a> {
Item(&'a ClassSetItem),
BinaryOp(&'a ClassSetBinaryOp),
}A representation of the inductive step when performing structural induction over a character class.
Note that there is no analogous explicit type for the inductive step for
Ast nodes because the inductive step is just an Ast. For character
classes, the inductive step can produce one of two possible child nodes:
an item or a binary operation. (An item cannot be a binary operation
because that would imply binary operations can be unioned in the concrete
syntax, which is not possible.)
Variants
Item(&'a ClassSetItem)BinaryOp(&'a ClassSetBinaryOp)Methods
impl<'a> ClassInduct<'a>[src]
impl<'a> ClassInduct<'a>fn from_bracketed(ast: &'a ClassBracketed) -> ClassInduct<'a>[src]
fn from_bracketed(ast: &'a ClassBracketed) -> ClassInduct<'a>fn from_set(ast: &'a ClassSet) -> ClassInduct<'a>[src]
fn from_set(ast: &'a ClassSet) -> ClassInduct<'a>Trait Implementations
impl<'a> Debug for ClassInduct<'a>[src]
impl<'a> Debug for ClassInduct<'a>Auto Trait Implementations
impl<'a> Send for ClassInduct<'a>
impl<'a> Send for ClassInduct<'a>impl<'a> Sync for ClassInduct<'a>
impl<'a> Sync for ClassInduct<'a>