Enum regex_syntax::error::Error [−][src]
This error type encompasses any error that can be returned by this crate.
Variants
Parse(Error)An error that occurred while translating concrete syntax into abstract syntax (AST).
Translate(Error)An error that occurred while translating abstract syntax into a high level intermediate representation (HIR).
__NonexhaustiveHints that destructuring should not be exhaustive.
This enum may grow additional variants, so this makes sure clients don't count on exhaustive matching. (Otherwise, adding a new variant could break existing code.)