pub enum Literal {
Unicode(char),
Byte(u8),
}The high-level intermediate representation of a literal.
A literal corresponds to a single character, where a character is either
defined by a Unicode scalar value or an arbitrary byte. Unicode characters
are preferred whenever possible. In particular, a Byte variant is only
ever produced when it could match invalid UTF-8.
A single character represented by a Unicode scalar value.
A single character represented by an arbitrary byte.
Returns true if and only if this literal corresponds to a Unicode
scalar value.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.