Struct regex_syntax::hir::print::Writer [−][src]
struct Writer<'p, W> {
printer: &'p mut Printer,
wtr: W,
}Fields
printer: &'p mut Printer
wtr: W
Methods
impl<'p, W: Write> Writer<'p, W>[src]
impl<'p, W: Write> Writer<'p, W>fn write_literal_char(&mut self, c: char) -> Result[src]
fn write_literal_char(&mut self, c: char) -> Resultfn write_literal_byte(&mut self, b: u8) -> Result[src]
fn write_literal_byte(&mut self, b: u8) -> Resultfn write_literal_class_byte(&mut self, b: u8) -> Result[src]
fn write_literal_class_byte(&mut self, b: u8) -> ResultTrait Implementations
impl<'p, W: Debug> Debug for Writer<'p, W>[src]
impl<'p, W: Debug> Debug for Writer<'p, W>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<'p, W: Write> Visitor for Writer<'p, W>[src]
impl<'p, W: Write> Visitor for Writer<'p, W>type Output = ()
The result of visiting an HIR.
type Err = Error
An error that visiting an HIR might return.
fn finish(self) -> Result[src]
fn finish(self) -> ResultAll implementors of Visitor must provide a finish method, which yields the result of visiting the HIR or an error. Read more
fn visit_pre(&mut self, hir: &Hir) -> Result[src]
fn visit_pre(&mut self, hir: &Hir) -> ResultThis method is called on an Hir before descending into child Hir nodes. Read more
fn visit_post(&mut self, hir: &Hir) -> Result[src]
fn visit_post(&mut self, hir: &Hir) -> ResultThis method is called on an Hir after descending all of its child Hir nodes. Read more
fn visit_alternation_in(&mut self) -> Result[src]
fn visit_alternation_in(&mut self) -> ResultThis method is called between child nodes of an alternation.
fn start(&mut self)[src]
fn start(&mut self)This method is called before beginning traversal of the HIR.