Struct regex_syntax::hir::ClassBytesRange [−][src]
A single range of characters represented by arbitrary bytes.
The range is closed. That is, the start and end of the range are included in the range.
Fields
start: u8
end: u8
Methods
impl ClassBytesRange[src]
impl ClassBytesRangepub fn new(start: u8, end: u8) -> ClassBytesRange[src]
pub fn new(start: u8, end: u8) -> ClassBytesRangeCreate a new byte range for a character class.
The returned range is always in a canonical form. That is, the range
returned always satisfies the invariant that start <= end.
pub fn start(&self) -> u8[src]
pub fn start(&self) -> u8Return the start of this range.
The start of a range is always less than or equal to the end of the range.
pub fn end(&self) -> u8[src]
pub fn end(&self) -> u8Return the end of this range.
The end of a range is always greater than or equal to the start of the range.