Struct regex_syntax::hir::ClassUnicodeRange [−][src]
A single range of characters represented by Unicode scalar values.
The range is closed. That is, the start and end of the range are included in the range.
Fields
start: char
end: char
Methods
impl ClassUnicodeRange[src]
impl ClassUnicodeRangepub fn new(start: char, end: char) -> ClassUnicodeRange[src]
pub fn new(start: char, end: char) -> ClassUnicodeRangeCreate a new Unicode scalar value range for a character class.
The returned range is always in a canonical form. That is, the range
returned always satisfies the invariant that start <= end.
pub fn start(&self) -> char[src]
pub fn start(&self) -> charReturn the start of this range.
The start of a range is always less than or equal to the end of the range.
pub fn end(&self) -> char[src]
pub fn end(&self) -> charReturn the end of this range.
The end of a range is always greater than or equal to the start of the range.