Struct regex_syntax::hir::HirInfo [−][src]
struct HirInfo {
bools: u8,
}A type that documents various attributes of an HIR expression.
These attributes are typically defined inductively on the HIR.
Fields
bools: u8
Represent yes/no questions by a bitfield to conserve space, since this is included in every HIR expression.
If more attributes need to be added, it is OK to increase the size of this as appropriate.
Methods
impl HirInfo[src]
impl HirInfofn new() -> HirInfo[src]
fn new() -> HirInfofn is_always_utf8(&self) -> bool[src]
fn is_always_utf8(&self) -> boolfn set_always_utf8(&mut self, yes: bool)[src]
fn set_always_utf8(&mut self, yes: bool)fn is_all_assertions(&self) -> bool[src]
fn is_all_assertions(&self) -> boolfn set_all_assertions(&mut self, yes: bool)[src]
fn set_all_assertions(&mut self, yes: bool)fn is_anchored_start(&self) -> bool[src]
fn is_anchored_start(&self) -> boolfn set_anchored_start(&mut self, yes: bool)[src]
fn set_anchored_start(&mut self, yes: bool)fn is_anchored_end(&self) -> bool[src]
fn is_anchored_end(&self) -> boolfn set_anchored_end(&mut self, yes: bool)[src]
fn set_anchored_end(&mut self, yes: bool)fn is_any_anchored_start(&self) -> bool[src]
fn is_any_anchored_start(&self) -> boolfn set_any_anchored_start(&mut self, yes: bool)[src]
fn set_any_anchored_start(&mut self, yes: bool)fn is_any_anchored_end(&self) -> bool[src]
fn is_any_anchored_end(&self) -> boolfn set_any_anchored_end(&mut self, yes: bool)[src]
fn set_any_anchored_end(&mut self, yes: bool)fn is_match_empty(&self) -> bool[src]
fn is_match_empty(&self) -> boolfn set_match_empty(&mut self, yes: bool)[src]
fn set_match_empty(&mut self, yes: bool)Trait Implementations
impl Clone for HirInfo[src]
impl Clone for HirInfofn clone(&self) -> HirInfo[src]
fn clone(&self) -> HirInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for HirInfo[src]
impl Debug for HirInfofn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for HirInfo[src]
impl Eq for HirInfofn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl PartialEq for HirInfo[src]
impl PartialEq for HirInfo