Struct regex_syntax::hir::translate::TranslatorI [−][src]
struct TranslatorI<'t, 'p> {
trans: &'t Translator,
pattern: &'p str,
}The internal implementation of a translator.
This type is responsible for carrying around the original pattern string, which is not tied to the internal state of a translator.
A TranslatorI exists for the time it takes to translate a single Ast.
Fields
trans: &'t Translator
pattern: &'p str
Methods
impl<'t, 'p> TranslatorI<'t, 'p>[src]
impl<'t, 'p> TranslatorI<'t, 'p>fn new(trans: &'t Translator, pattern: &'p str) -> TranslatorI<'t, 'p>[src]
fn new(trans: &'t Translator, pattern: &'p str) -> TranslatorI<'t, 'p>Build a new internal translator.
fn trans(&self) -> &Translator[src]
fn trans(&self) -> &TranslatorReturn a reference to the underlying translator.
fn push(&self, frame: HirFrame)[src]
fn push(&self, frame: HirFrame)Push the given frame on to the call stack.
fn pop(&self) -> Option<HirFrame>[src]
fn pop(&self) -> Option<HirFrame>Pop the top of the call stack. If the call stack is empty, return None.
fn error(&self, span: Span, kind: ErrorKind) -> Error[src]
fn error(&self, span: Span, kind: ErrorKind) -> ErrorCreate a new error with the given span and error type.
fn flags(&self) -> Flags[src]
fn flags(&self) -> FlagsReturn a copy of the active flags.
fn set_flags(&self, ast_flags: &Flags) -> Flags[src]
fn set_flags(&self, ast_flags: &Flags) -> FlagsSet the flags of this translator from the flags set in the given AST. Then, return the old flags.
fn hir_literal(&self, lit: &Literal) -> Result<Hir, Error>[src]
fn hir_literal(&self, lit: &Literal) -> Result<Hir, Error>fn literal_to_char(&self, lit: &Literal) -> Result<Literal, Error>[src]
fn literal_to_char(&self, lit: &Literal) -> Result<Literal, Error>Convert an Ast literal to its scalar representation.
When Unicode mode is enabled, then this always succeeds and returns a
char (Unicode scalar value).
When Unicode mode is disabled, then a raw byte is returned. If that byte is not ASCII and invalid UTF-8 is not allowed, then this returns an error.
fn hir_from_char(&self, span: Span, c: char) -> Result<Hir, Error>[src]
fn hir_from_char(&self, span: Span, c: char) -> Result<Hir, Error>fn hir_from_char_case_insensitive(
&self,
span: Span,
c: char
) -> Result<Hir, Error>[src]
fn hir_from_char_case_insensitive(
&self,
span: Span,
c: char
) -> Result<Hir, Error>fn hir_dot(&self, span: Span) -> Result<Hir, Error>[src]
fn hir_dot(&self, span: Span) -> Result<Hir, Error>fn hir_assertion(&self, asst: &Assertion) -> Result<Hir, Error>[src]
fn hir_assertion(&self, asst: &Assertion) -> Result<Hir, Error>fn hir_group(&self, group: &Group, expr: Hir) -> Hir[src]
fn hir_group(&self, group: &Group, expr: Hir) -> Hirfn hir_repetition(&self, rep: &Repetition, expr: Hir) -> Hir[src]
fn hir_repetition(&self, rep: &Repetition, expr: Hir) -> Hirfn hir_unicode_class(
&self,
ast_class: &ClassUnicode
) -> Result<ClassUnicode, Error>[src]
fn hir_unicode_class(
&self,
ast_class: &ClassUnicode
) -> Result<ClassUnicode, Error>fn hir_perl_unicode_class(&self, ast_class: &ClassPerl) -> ClassUnicode[src]
fn hir_perl_unicode_class(&self, ast_class: &ClassPerl) -> ClassUnicodefn hir_perl_byte_class(&self, ast_class: &ClassPerl) -> ClassBytes[src]
fn hir_perl_byte_class(&self, ast_class: &ClassPerl) -> ClassBytesfn unicode_fold_and_negate(&self, negated: bool, class: &mut ClassUnicode)[src]
fn unicode_fold_and_negate(&self, negated: bool, class: &mut ClassUnicode)fn bytes_fold_and_negate(
&self,
span: &Span,
negated: bool,
class: &mut ClassBytes
) -> Result<(), Error>[src]
fn bytes_fold_and_negate(
&self,
span: &Span,
negated: bool,
class: &mut ClassBytes
) -> Result<(), Error>fn class_literal_byte(&self, ast: &Literal) -> Result<u8, Error>[src]
fn class_literal_byte(&self, ast: &Literal) -> Result<u8, Error>Return a scalar byte value suitable for use as a literal in a byte character class.