Struct regex_syntax::hir::visitor::HeapVisitor [−][src]
HeapVisitor visits every item in an Hir recursively using constant stack
size and a heap size proportional to the size of the Hir.
Fields
stack: Vec<(&'a Hir, Frame<'a>)>
A stack of Hir nodes. This is roughly analogous to the call stack
used in a typical recursive visitor.
Methods
impl<'a> HeapVisitor<'a>[src]
impl<'a> HeapVisitor<'a>fn new() -> HeapVisitor<'a>[src]
fn new() -> HeapVisitor<'a>fn visit<V: Visitor>(
&mut self,
hir: &'a Hir,
visitor: V
) -> Result<V::Output, V::Err>[src]
fn visit<V: Visitor>(
&mut self,
hir: &'a Hir,
visitor: V
) -> Result<V::Output, V::Err>fn induct(&mut self, hir: &'a Hir) -> Option<Frame<'a>>[src]
fn induct(&mut self, hir: &'a Hir) -> Option<Frame<'a>>Build a stack frame for the given HIR if one is needed (which occurs if and only if there are child nodes in the HIR). Otherwise, return None.
fn pop(&self, induct: Frame<'a>) -> Option<Frame<'a>>[src]
fn pop(&self, induct: Frame<'a>) -> Option<Frame<'a>>Pops the given frame. If the frame has an additional inductive step,
then return it, otherwise return None.