Enum regex_syntax::unicode::CanonicalClassQuery [−][src]
enum CanonicalClassQuery {
Binary(&'static str),
GeneralCategory(&'static str),
Script(&'static str),
ByValue {
property_name: &'static str,
property_value: &'static str,
},
}Like ClassQuery, but its parameters have been canonicalized. This also differentiates binary properties from flattened general categories and scripts.
Variants
Binary(&'static str)The canonical binary property name.
GeneralCategory(&'static str)The canonical general category name.
Script(&'static str)The canonical script name.
ByValueAn arbitrary association between property and value, both of which have been canonicalized.
Note that by construction, the property name of ByValue will never be General_Category or Script. Those two cases are subsumed by the eponymous variants.
Fields of ByValue
property_name: &'static str | The canonical property name. |
property_value: &'static str | The canonical property value. |