HtmlBuilder

Struct HtmlBuilder 

pub struct HtmlBuilder { /* private fields */ }
A builder struct for Html

Implementations

Source

impl HtmlBuilder

pub fn build(&mut self) -> Html

Finish building the element

pub fn data( &mut self, data_key: impl Into<Cow<'static, str>>, value: impl Into<Cow<'static, str>>, ) -> &mut HtmlBuilder

Insert a data-* property

pub fn body<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut BodyBuilder) -> &'a mut BodyBuilder,

Append a new Body element

pub fn head<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut HeadBuilder) -> &'a mut HeadBuilder,

Append a new Head element

pub fn role(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the role attribute

pub fn access_key(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the accesskey attribute

pub fn auto_capitalize( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the autocapitalize attribute

pub fn autofocus(&mut self, value: bool) -> &mut Self

Set the value of the autofocus attribute

pub fn class(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the class attribute

pub fn content_editable( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the contenteditable attribute

pub fn direction(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the dir attribute

pub fn draggable(&mut self, value: bool) -> &mut Self

Set the value of the draggable attribute

pub fn enter_key_hint( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the enterkeyhint attribute

pub fn export_parts(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the exportparts attribute

pub fn hidden(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the hidden attribute

pub fn id(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the id attribute

pub fn inert(&mut self, value: bool) -> &mut Self

Set the value of the inert attribute

pub fn input_mode(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the inputmode attribute

pub fn is_(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the is attribute

pub fn item_id(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemid attribute

pub fn item_prop(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemprop attribute

pub fn item_ref(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemref attribute

pub fn item_scope(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemscope attribute

pub fn item_type(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemtype attribute

pub fn lang(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the lang attribute

pub fn nonce(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the nonce attribute

pub fn part(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the part attribute

pub fn slot(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the slot attribute

pub fn spellcheck(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the spellcheck attribute

pub fn style(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the style attribute

pub fn tab_index(&mut self, value: i64) -> &mut Self

Set the value of the tabindex attribute

pub fn title(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the title attribute

pub fn translate(&mut self, value: bool) -> &mut Self

Set the value of the translate attribute

pub fn push<T>(&mut self, child_el: T) -> &mut Self
where T: Into<HtmlChild>,

Push a new child element to the list of children.

pub fn extend<I, T>(&mut self, iter: I) -> &mut Self
where I: IntoIterator<Item = T>, T: Into<HtmlChild>,

Extend the list of children with an iterator of child elements.