adacore_zynqmp::uart

Function uart0

pub unsafe fn uart0() -> MmioUart<'static>
Obtains a reference to the UART0 device.

Safety

The caller must ensure that the reference is not used concurrently in a way that could result in data races.