pub fn libgccjit_path_relative_to_cg_dir(
target_pair: &GccTargetPair,
libgccjit: &GccOutput,
) -> PathBufExpand description
Returns a path where libgccjit.so should be stored, relative to the codegen backend directory.
pub fn libgccjit_path_relative_to_cg_dir(
target_pair: &GccTargetPair,
libgccjit: &GccOutput,
) -> PathBufReturns a path where libgccjit.so should be stored, relative to the codegen backend directory.