check_incompatible_options_for_ci_rustc

Function check_incompatible_options_for_ci_rustc 

pub fn check_incompatible_options_for_ci_rustc(
    host: TargetSelection,
    current_config_toml: TomlConfig,
    ci_config_toml: TomlConfig,
) -> Result<(), String>
Compares the current Rust options against those in the CI rustc builder and detects any incompatible options. It does this by destructuring the Rust instance to make sure every Rust field is covered and not missing.