pub enum TestFilterCategory<'a> {
Fullsuite,
Arg(&'a str),
Uninteresting,
}Expand description
Value returned from is_valid_test_suite_arg, which figures out which paths start with the
suite name (and therefore which should be run).
Variants
Fullsuite
If a path is equal to the name of the suite, this is returned.
Arg(&'a str)
If a path starts with the suite, the suite prefix is stripped and the rest is returned as this variant.
Uninteresting
For paths that don’t start with the suite.