pub struct CleanOptions<'gctx> {
pub gctx: &'gctx GlobalContext,
pub spec: IndexSet<String>,
pub targets: Vec<String>,
pub profile_specified: bool,
pub requested_profile: InternedString,
pub doc: bool,
pub dry_run: bool,
pub explicit_target_dir_arg: bool,
}Fields
gctx: &'gctx GlobalContextspec: IndexSet<String>A list of packages to clean. If empty, everything is cleaned.
targets: Vec<String>The target arch triple to clean, or None for the host arch
profile_specified: boolWhether to clean the release directory
requested_profile: InternedStringWhether to clean the directory of a certain build profile
doc: boolWhether to just clean the doc directory
dry_run: boolIf set, doesn’t delete anything.
explicit_target_dir_arg: booltrue if target-dir was was explicitly specified via –target-dir