struct WorkerServer {
incoming_work: Receiver<Message>,
multi: Multi,
handles: HashMap<usize, (Easy2Handle<Collector>, Sender<Result<Response<Vec<u8>>, Error>>)>,
token: usize,
timeout: HttpTimeout,
stats: Arc<Stats>,
low_speed_window_start: Instant,
low_speed_window_initial: u64,
}Expand description
Manages the cURL Multi. Processes incoming work sent over the
channel, and returns responses.
Fields
incoming_work: Receiver<Message>Channel to receive new work
multi: Multicurl multi interface
handles: HashMap<usize, (Easy2Handle<Collector>, Sender<Result<Response<Vec<u8>>, Error>>)>Map of token to curl handle and response channel
token: usizeNext token to use
timeout: HttpTimeoutGlobal timeout configuration
stats: Arc<Stats>Global transfer statistics
low_speed_window_start: InstantInstant when the current low speed window started
low_speed_window_initial: u64Amount of total bytes transferred when the current low speed window started
Implementations
Sourceimpl WorkerServer
impl WorkerServer
fn run( incoming_work: Receiver<Message>, multiplex: bool, timeout: HttpTimeout, stats: Arc<Stats>, )
fn fail_and_drain(&mut self, e: &Error)
fn process_response(easy: Easy2<Collector>) -> Response<Vec<u8>>
Sourcefn reset_low_speed_timeout(&mut self)
fn reset_low_speed_timeout(&mut self)
Marks the start of a new timeout window.
Sourcefn check_low_speed_timeout(&mut self) -> Option<Error>
fn check_low_speed_timeout(&mut self) -> Option<Error>
Return an error if we’re at the end of a timeout window, we haven’t made enough progress.
fn worker_loop(&mut self)
Sourcefn enqueue_request(&mut self, message: Message)
fn enqueue_request(&mut self, message: Message)
Adds the request to the Multi, or send an error back through the channel.