NormalizeToExpected

Struct NormalizeToExpected 

pub struct NormalizeToExpected<'a> {
    substitutions: Option<&'a Redactions>,
    unordered: bool,
}
Adjust actual based on expected

Fields

substitutions: Option<&'a Redactions>unordered: bool

Implementations



impl<'a> NormalizeToExpected<'a>

pub fn new() -> NormalizeToExpected<'a>

pub fn unordered(self) -> NormalizeToExpected<'a>

Make unordered content comparable

This is done by re-ordering actual according to expected.

pub fn redact(self) -> NormalizeToExpected<'a>

Apply built-in redactions.

Built-in redactions:

  • ... on a line of its own: match multiple complete lines
  • [..]: match multiple characters within a line

Built-ins cannot automatically be applied to actual but are inferred from expected

pub fn redact_with(self, redactions: &'a Redactions) -> NormalizeToExpected<'a>

Apply built-in and user Redactions

Built-in redactions:

  • ... on a line of its own: match multiple complete lines
  • [..]: match multiple characters within a line

Built-ins cannot automatically be applied to actual but are inferred from expected

pub fn normalize(&self, actual: Data, expected: &Data) -> Data