enum IncrRevKind {
CheckPass,
BuildFail,
BuildPass,
RunPass,
}Expand description
How far an incremental test revision should proceed through the compile/run sequence, and whether the last step should succeed or fail, as determined from the start of the revision name.
Variants
Implementations
Sourceimpl IncrRevKind
impl IncrRevKind
Sourceimpl IncrRevKind
impl IncrRevKind
fn for_revision_name(rev_name: &str) -> Result<Self, &'static str>