Error

Enum Error 

#[non_exhaustive]
pub enum Error<T> { Transport(T), Http(Error), Json(Error), Io(Error), Utf8(FromUtf8Error), Api { code: StatusCode, headers: Vec<String>, errors: Vec<String>, }, Code { code: StatusCode, headers: Vec<String>, body: String, }, InvalidToken(TokenError), Timeout(u64), }
Error returned when interacting with a registry.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Transport(T)

Error from underlying transport.



Http(Error)

Error from http.



Json(Error)

Error from serializing the request payload and deserializing the response body (like response body didn’t match expected structure).



Io(Error)

Error from IO. Mostly from reading the tarball to upload.



Utf8(FromUtf8Error)

Response body was not valid utf8.



Api

Error from API response containing JSON field errors.details.

Fields

code: StatusCode
headers: Vec<String>
errors: Vec<String>


Code

Error from API response which didn’t have pre-programmed errors.details.

Fields

code: StatusCode
headers: Vec<String>
body: String


InvalidToken(TokenError)



Timeout(u64)

Server was unavailable and timed out. Happened when uploading a way too large tarball to crates.io.