no_valid_exposed_references_error

Function no_valid_exposed_references_error 

pub fn no_valid_exposed_references_error<'tcx>(
    _: &DiagnosticInfo,
) -> InterpErrorKind<'tcx>
Cannot access this allocation with wildcard provenance, as there are no valid exposed references for this access kind.