ResolverAstLoweringExt

Trait ResolverAstLoweringExt 

pub(crate) trait ResolverAstLoweringExt<'tcx> {
    // Required methods
    fn legacy_const_generic_args(
        &self,
        expr: &Expr,
        tcx: TyCtxt<'tcx>,
    ) -> Option<Vec<usize>>;
    fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>;
    fn get_label_res(&self, id: NodeId) -> Option<NodeId>;
    fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>;
    fn extra_lifetime_params(
        &self,
        id: NodeId,
    ) -> &[(Ident, NodeId, LifetimeRes)];
    fn delegation_info(&self, id: LocalDefId) -> Option<&DelegationInfo>;
    fn opt_local_def_id(&self, id: NodeId) -> Option<LocalDefId>;
    fn local_def_id(&self, id: NodeId) -> LocalDefId;
    fn lifetime_elision_allowed(&self, id: NodeId) -> bool;
}

Required Methods

fn legacy_const_generic_args( &self, expr: &Expr, tcx: TyCtxt<'tcx>, ) -> Option<Vec<usize>>

fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>

Obtains per-namespace resolutions for use statement with the given NodeId.

fn get_label_res(&self, id: NodeId) -> Option<NodeId>

Obtains resolution for a label with the given NodeId.

fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>

Obtains resolution for a lifetime with the given NodeId.

fn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]

Obtain the list of lifetimes parameters to add to an item.

Extra lifetime parameters should only be added in places that can appear as a binder in LifetimeRes.

The extra lifetimes that appear from the parenthesized Fn-trait desugaring should appear at the enclosing PolyTraitRef.

fn delegation_info(&self, id: LocalDefId) -> Option<&DelegationInfo>

fn opt_local_def_id(&self, id: NodeId) -> Option<LocalDefId>

fn local_def_id(&self, id: NodeId) -> LocalDefId

fn lifetime_elision_allowed(&self, id: NodeId) -> bool

Implementations on Foreign Types

Source

impl<'tcx> ResolverAstLoweringExt<'tcx> for ResolverAstLowering<'tcx>

Source

fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>

Obtains per-namespace resolutions for use statement with the given NodeId.

Source

fn get_label_res(&self, id: NodeId) -> Option<NodeId>

Obtains resolution for a label with the given NodeId.

Source

fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>

Obtains resolution for a lifetime with the given NodeId.

Source

fn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]

Obtain the list of lifetimes parameters to add to an item.

Extra lifetime parameters should only be added in places that can appear as a binder in LifetimeRes.

The extra lifetimes that appear from the parenthesized Fn-trait desugaring should appear at the enclosing PolyTraitRef.

Source

fn legacy_const_generic_args( &self, expr: &Expr, tcx: TyCtxt<'tcx>, ) -> Option<Vec<usize>>

Source

fn delegation_info(&self, id: LocalDefId) -> Option<&DelegationInfo>

Source

fn opt_local_def_id(&self, id: NodeId) -> Option<LocalDefId>

Source

fn local_def_id(&self, id: NodeId) -> LocalDefId

Source

fn lifetime_elision_allowed(&self, id: NodeId) -> bool

Implementors