fn check_attr_crate_level(cx: &mut AcceptContext<'_, '_>, span: Span) -> boolExpand description
Checks that an attribute is used at the crate level. Returns true if valid.
fn check_attr_crate_level(cx: &mut AcceptContext<'_, '_>, span: Span) -> boolChecks that an attribute is used at the crate level. Returns true if valid.