fn check_attr_not_crate_level(
cx: &mut AcceptContext<'_, '_>,
span: Span,
attr_name: Symbol,
) -> boolExpand description
Checks that an attribute is not used at the crate level. Returns true if valid.
fn check_attr_not_crate_level(
cx: &mut AcceptContext<'_, '_>,
span: Span,
attr_name: Symbol,
) -> boolChecks that an attribute is not used at the crate level. Returns true if valid.