pub(crate) enum OnDuplicate {
Warn,
WarnButFutureError,
Error,
Ignore,
Custom(fn(cx: &AcceptContext<'_, '_>, used: Span, unused: Span)),
}Variants
Warn
Give a default warning
WarnButFutureError
Duplicates will be a warning, with a note that this will be an error in the future.
Error
Give a default error
Ignore
Ignore duplicates
Custom(fn(cx: &AcceptContext<'_, '_>, used: Span, unused: Span))
Custom function called when a duplicate attribute is found.
unusedis the span of the attribute that was unused or bad because of some duplicate reasonusedis the span of the attribute that was used in favor of the unused attribute
Implementations
Sourceimpl OnDuplicate
impl OnDuplicate
fn exec<P: SingleAttributeParser>( &self, cx: &mut AcceptContext<'_, '_>, used: Span, unused: Span, )