pub(crate) struct RustcNeverTypeOptionsParser;Trait Implementations
Sourceimpl SingleAttributeParser for RustcNeverTypeOptionsParser
impl SingleAttributeParser for RustcNeverTypeOptionsParser
const ALLOWED_TARGETS: AllowedTargets
Sourceconst TEMPLATE: AttributeTemplate
const TEMPLATE: AttributeTemplate
The template this attribute parser should implement. Used for diagnostics.
Sourcefn convert(
cx: &mut AcceptContext<'_, '_>,
args: &ArgParser,
) -> Option<AttributeKind>
fn convert( cx: &mut AcceptContext<'_, '_>, args: &ArgParser, ) -> Option<AttributeKind>
Converts a single syntactical attribute to a single semantic attribute, or
AttributeKindSourceconst ON_DUPLICATE: OnDuplicate = OnDuplicate::Error
const ON_DUPLICATE: OnDuplicate = OnDuplicate::Error
Configures what to do when when the same attribute is
applied more than once on the same syntax node.
const SAFETY: AttributeSafety = AttributeSafety::Normal