fn insert_value_into_option_or_error(
cx: &mut AcceptContext<'_, '_>,
param: &MetaItemParser,
item: &mut Option<Symbol>,
name: Ident,
) -> Option<()>Expand description
Tries to insert the value of a key = value meta item into an option.
Emits an error when either the option was already Some, or the arguments weren’t of form
name = value