struct AscribeUserTypeQuery<'tcx> {
canonical_query: CanonicalTypeOpAscribeUserTypeGoal<'tcx>,
base_universe: UniverseIndex,
}Fields
canonical_query: CanonicalTypeOpAscribeUserTypeGoal<'tcx>base_universe: UniverseIndexTrait Implementations
Sourceimpl<'tcx> TypeOpInfo<'tcx> for AscribeUserTypeQuery<'tcx>
impl<'tcx> TypeOpInfo<'tcx> for AscribeUserTypeQuery<'tcx>
Sourcefn fallback_error(&self, tcx: TyCtxt<'tcx>, span: Span) -> Diag<'tcx>
fn fallback_error(&self, tcx: TyCtxt<'tcx>, span: Span) -> Diag<'tcx>
Returns an error to be reported if rerunning the type op fails to
recover the error’s cause.
fn base_universe(&self) -> UniverseIndex
fn nice_error<'infcx>( &self, mbcx: &mut MirBorrowckCtxt<'_, 'infcx, 'tcx>, cause: ObligationCause<'tcx>, placeholder_region: Region<'tcx>, error_region: Option<Region<'tcx>>, ) -> Option<Diag<'infcx>>
Sourcefn report_erroneous_element(
&self,
mbcx: &mut MirBorrowckCtxt<'_, '_, 'tcx>,
placeholder: PlaceholderRegion<'tcx>,
error_element: Option<PlaceholderRegion<'tcx>>,
cause: ObligationCause<'tcx>,
)
fn report_erroneous_element( &self, mbcx: &mut MirBorrowckCtxt<'_, '_, 'tcx>, placeholder: PlaceholderRegion<'tcx>, error_element: Option<PlaceholderRegion<'tcx>>, cause: ObligationCause<'tcx>, )
Constraints require that
error_element appear in the
values of placeholder, but this cannot be proven to
hold. Report an error.Auto Trait Implementations
impl<'tcx> DynSend for AscribeUserTypeQuery<'tcx>
impl<'tcx> DynSync for AscribeUserTypeQuery<'tcx>
impl<'tcx> Freeze for AscribeUserTypeQuery<'tcx>
impl<'tcx> !RefUnwindSafe for AscribeUserTypeQuery<'tcx>
impl<'tcx> Send for AscribeUserTypeQuery<'tcx>
impl<'tcx> Sync for AscribeUserTypeQuery<'tcx>
impl<'tcx> Unpin for AscribeUserTypeQuery<'tcx>
impl<'tcx> UnsafeUnpin for AscribeUserTypeQuery<'tcx>
impl<'tcx> !UnwindSafe for AscribeUserTypeQuery<'tcx>