handle_unconstrained_hidden_type_errors

Function handle_unconstrained_hidden_type_errors 

pub(crate) fn handle_unconstrained_hidden_type_errors<'tcx>(
    tcx: TyCtxt<'tcx>,
    hidden_types: &mut FxIndexMap<LocalDefId, DefinitionSiteHiddenType<'tcx>>,
    unconstrained_hidden_type_errors: &mut Vec<UnexpectedHiddenRegion<'tcx>>,
    collect_region_constraints_results: &mut FxIndexMap<LocalDefId, CollectRegionConstraintsResult<'tcx>>,
)
We handle UnexpectedHiddenRegion error lazily in the next solver as there may be a fully defining use in another body.

In case such a defining use does not exist, we register an error here.