struct LivenessResults<'a, 'typeck, 'tcx> {
cx: LivenessContext<'a, 'typeck, 'tcx>,
defs: DenseBitSet<PointIndex>,
use_live_at: IntervalSet<PointIndex>,
drop_live_at: IntervalSet<PointIndex>,
drop_locations: Vec<Location>,
stack: Vec<PointIndex>,
}Fields
cx: LivenessContext<'a, 'typeck, 'tcx>defs: DenseBitSet<PointIndex>Set of points that define the current local.
use_live_at: IntervalSet<PointIndex>Points where the current variable is “use live” – meaning that there is a future “full use” that may use its value.
drop_live_at: IntervalSet<PointIndex>Points where the current variable is “drop live” – meaning that there is no future “full use” that may use its value, but there is a future drop.
drop_locations: Vec<Location>Locations where drops may occur.
stack: Vec<PointIndex>Stack used when doing (reverse) DFS.
Implementations
Sourceimpl<'a, 'typeck, 'tcx> LivenessResults<'a, 'typeck, 'tcx>
impl<'a, 'typeck, 'tcx> LivenessResults<'a, 'typeck, 'tcx>
fn new(cx: LivenessContext<'a, 'typeck, 'tcx>) -> Self
fn compute_for_all_locals(&mut self, relevant_live_locals: Vec<Local>)
Sourcefn dropck_boring_locals(&mut self, boring_locals: Vec<Local>)
fn dropck_boring_locals(&mut self, boring_locals: Vec<Local>)
Runs dropck for locals whose liveness isn’t relevant. This is necessary to eagerly detect unbound recursion during drop glue computation.
These are all the locals which do not potentially reference a region local to this body. Locals which only reference free regions are always drop-live and can therefore safely be dropped.
Sourcefn add_extra_drop_facts(&mut self, relevant_live_locals: &[Local])
fn add_extra_drop_facts(&mut self, relevant_live_locals: &[Local])
Add extra drop facts needed for Polonius.
Add facts for all locals with free regions, since regions may outlive the function body only at certain nodes in the CFG.
Sourcefn reset_local_state(&mut self)
fn reset_local_state(&mut self)
Clear the value of fields that are “per local variable”.
Sourcefn add_defs_for(&mut self, local: Local)
fn add_defs_for(&mut self, local: Local)
Adds the definitions of local into self.defs.
Sourcefn compute_use_live_points_for(&mut self, local: Local)
fn compute_use_live_points_for(&mut self, local: Local)
Computes all points where local is “use live” – meaning its
current value may be used later (except by a drop). This is
done by walking backwards from each use of local until we
find a def of local.
Requires add_defs_for(local) to have been executed.
Sourcefn compute_drop_live_points_for(&mut self, local: Local)
fn compute_drop_live_points_for(&mut self, local: Local)
Computes all points where local is “drop live” – meaning its
current value may be dropped later (but not used). This is
done by iterating over the drops of local where local (or
some subpart of local) is initialized. For each such drop,
we walk backwards until we find a point where local is
either defined or use-live.
Requires compute_use_live_points_for and add_defs_for to
have been executed.
Sourcefn compute_drop_live_points_for_block(
&mut self,
mpi: MovePathIndex,
term_point: PointIndex,
)
fn compute_drop_live_points_for_block( &mut self, mpi: MovePathIndex, term_point: PointIndex, )
Executes one iteration of the drop-live analysis loop.
The parameter mpi is the MovePathIndex of the local variable
we are currently analyzing.
The point term_point represents some terminator in the MIR,
where the local mpi is drop-live on entry to that terminator.
This method adds all drop-live points within the block and –
where applicable – pushes the terminators of preceding blocks
onto self.stack.