fn invalid_type_err(
cx: &ExtCtxt<'_>,
token_lit: Lit,
span: Span,
is_nested: bool,
) -> ErrorGuaranteedExpand description
Emits errors for literal expressions that are invalid inside and outside of an array.
fn invalid_type_err(
cx: &ExtCtxt<'_>,
token_lit: Lit,
span: Span,
is_nested: bool,
) -> ErrorGuaranteedEmits errors for literal expressions that are invalid inside and outside of an array.