fn build_union_type_di_node<'ll, 'tcx>(
cx: &GenericCx<'ll, FullCx<'ll, 'tcx>>,
unique_type_id: UniqueTypeId<'tcx>,
span: Span,
) -> DINodeCreationResult<'ll>Expand description
Build the debuginfo node for a Rust union type.
fn build_union_type_di_node<'ll, 'tcx>(
cx: &GenericCx<'ll, FullCx<'ll, 'tcx>>,
unique_type_id: UniqueTypeId<'tcx>,
span: Span,
) -> DINodeCreationResult<'ll>Build the debuginfo node for a Rust union type.