type_di_node

Function type_di_node 

pub(crate) fn type_di_node<'ll, 'tcx>(
    cx: &GenericCx<'ll, FullCx<'ll, 'tcx>>,
    t: Ty<'tcx>,
) -> &'ll Metadata
Get the debuginfo node for the given type.

This function will look up the debuginfo node in the TypeMap. If it can’t find it, it will create the node by dispatching to the corresponding build_*_di_node() function.