enum VarArgCompatible {
Compatible,
Incompatible,
CastIntTo {
source_is_signed: bool,
},
}Expand description
Whether two types T and U are compatible when a value of type T is passed as a c-variadic
argument and read as a value of type U.
Variants
Compatible
T and U are compatible, e.g.
- They’re the same type.
- One is
usize/isize, the other an integer type of the same width and sign on the current target. - They are compatible pointer types (see the exact rules below).
Incompatible
T and U are definitely not compatible.
CastIntTo
T and U are corresponding signed and unsigned integer types.