compare_eii_function_types

Function compare_eii_function_types 

pub(crate) fn compare_eii_function_types<'tcx>(
    tcx: TyCtxt<'tcx>,
    external_impl: LocalDefId,
    foreign_item: DefId,
    eii_name: Symbol,
    eii_attr_span: Span,
) -> Result<(), ErrorGuaranteed>
Checks whether the signature of some external_impl, matches the signature of declaration, which it is supposed to be compatible with in order to implement the item.