struct ExprPlaceDelegate;Trait Implementations
Sourceimpl<'tcx> Delegate<'tcx> for ExprPlaceDelegate
impl<'tcx> Delegate<'tcx> for ExprPlaceDelegate
Sourcefn consume(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
fn consume(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
The value found at
place is moved, depending
on mode. Where diag_expr_id is the id used for diagnostics for place. Read moreSourcefn use_cloned(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
fn use_cloned(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
The value found at
place is used, depending
on mode. Where diag_expr_id is the id used for diagnostics for place. Read moreSourcefn borrow(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId, _: BorrowKind)
fn borrow(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId, _: BorrowKind)
The value found at
place is being borrowed with kind bk.
diag_expr_id is the id used for diagnostics (see consume for more details).Sourcefn mutate(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
fn mutate(&mut self, _: &PlaceWithHirId<'tcx>, _: HirId)
The path at
assignee_place is being assigned to.
diag_expr_id is the id used for diagnostics (see consume for more details).Sourcefn fake_read(&mut self, _: &PlaceWithHirId<'tcx>, _: FakeReadCause, _: HirId)
fn fake_read(&mut self, _: &PlaceWithHirId<'tcx>, _: FakeReadCause, _: HirId)
The
place should be a fake read because of specified cause.Auto Trait Implementations
impl DynSend for ExprPlaceDelegate
impl DynSync for ExprPlaceDelegate
impl Freeze for ExprPlaceDelegate
impl RefUnwindSafe for ExprPlaceDelegate
impl Send for ExprPlaceDelegate
impl Sync for ExprPlaceDelegate
impl Unpin for ExprPlaceDelegate
impl UnsafeUnpin for ExprPlaceDelegate
impl UnwindSafe for ExprPlaceDelegate