pub fn destructure_type_outlives_constraints_in_root<Infcx, I>(
infcx: &Infcx,
constraint: RegionConstraint<I>,
assumptions: &Assumptions<I>,
) -> RegionConstraint<I>where
Infcx: InferCtxtLike<Interner = I>,
I: Interner,Expand description
Converts type outlives constraints into region outlives constraints. This assumes the complete set of assumptions are known. This should not be called until the end of type checking.
The returned region constraint will not have any PlaceholderTyOutlives or AliasTyOutlivesViaEnv constraints.