fn maybe_normalize_erasing_regions<'tcx>(
cx: &LateContext<'tcx>,
value: Unnormalized<'tcx, Ty<'tcx>>,
) -> Ty<'tcx>Expand description
A common pattern in this lint is to attempt normalize_erasing_regions,
but keep the original type if it were to fail.
This may or may not be supported in the logic behind the Unnormalized wrapper,
(FIXME?)
but it should be enough for non-wrapped types to be as normalised as this lint needs them to be.