struct ImproperCTypesVisitor<'a, 'tcx> {
cx: &'a LateContext<'tcx>,
cache: FxHashSet<Ty<'tcx>>,
base_ty: Ty<'tcx>,
base_fn_mode: CItemKind,
}Expand description
Visitor used to recursively traverse MIR types and evaluate FFI-safety.
It uses check_* methods as entrypoints to be called elsewhere,
and visit_* methods to recurse.
Fields
cx: &'a LateContext<'tcx>cache: FxHashSet<Ty<'tcx>>To prevent problems with recursive types, add a types-in-check cache.
base_ty: Ty<'tcx>The original type being checked, before we recursed to any other types it contains.
base_fn_mode: CItemKindImplementations
Sourceimpl<'a, 'tcx> ImproperCTypesVisitor<'a, 'tcx>
impl<'a, 'tcx> ImproperCTypesVisitor<'a, 'tcx>
fn new( cx: &'a LateContext<'tcx>, base_ty: Ty<'tcx>, base_fn_mode: CItemKind, ) -> Self
Sourcefn visit_indirection(
&mut self,
state: VisitorState,
ty: Ty<'tcx>,
inner_ty: Ty<'tcx>,
indirection_kind: IndirectionKind,
) -> FfiResult<'tcx>
fn visit_indirection( &mut self, state: VisitorState, ty: Ty<'tcx>, inner_ty: Ty<'tcx>, indirection_kind: IndirectionKind, ) -> FfiResult<'tcx>
Checks if the given indirection (box,ref,pointer) is “ffi-safe”.
Sourcefn visit_variant_fields(
&mut self,
state: VisitorState,
ty: Ty<'tcx>,
def: AdtDef<'tcx>,
variant: &VariantDef,
args: GenericArgsRef<'tcx>,
) -> FfiResult<'tcx>
fn visit_variant_fields( &mut self, state: VisitorState, ty: Ty<'tcx>, def: AdtDef<'tcx>, variant: &VariantDef, args: GenericArgsRef<'tcx>, ) -> FfiResult<'tcx>
Checks if the given VariantDef’s field types are “ffi-safe”.
fn visit_struct_or_union( &mut self, state: VisitorState, ty: Ty<'tcx>, def: AdtDef<'tcx>, args: GenericArgsRef<'tcx>, ) -> FfiResult<'tcx>
fn visit_enum( &mut self, state: VisitorState, ty: Ty<'tcx>, def: AdtDef<'tcx>, args: GenericArgsRef<'tcx>, ) -> FfiResult<'tcx>
Sourcefn visit_type(
&mut self,
state: VisitorState,
outer_ty: OuterTyData,
ty: Ty<'tcx>,
) -> FfiResult<'tcx>
fn visit_type( &mut self, state: VisitorState, outer_ty: OuterTyData, ty: Ty<'tcx>, ) -> FfiResult<'tcx>
Checks if the given type is “ffi-safe” (has a stable, well-defined representation which can be exported to C code).
fn visit_for_opaque_ty(&mut self, ty: Ty<'tcx>) -> Option<FfiResult<'tcx>>
fn check_type(&mut self, state: VisitorState, ty: Ty<'tcx>) -> FfiResult<'tcx>