pub type ProvidedValue<'tcx> = Value<'tcx>;Expand description
Type returned from query providers and loaded from disk-cache.
Aliased Type
pub enum ProvidedValue<'tcx> {
None,
Some(&'tcx UnordMap<ItemLocalId, &'tcx [TraitCandidate<'tcx>]>),
}Variants
None
No value.
Some(&'tcx UnordMap<ItemLocalId, &'tcx [TraitCandidate<'tcx>]>)
Some value of type T.
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.