pub type ProvidedValue<'tcx> = Value<'tcx>;Expand description
Type returned from query providers and loaded from disk-cache.
Aliased Type
pub enum ProvidedValue<'tcx> {
Ok(&'tcx IndexMap<LocalDefId, DefinitionSiteHiddenType<'tcx>, FxBuildHasher>),
Err(ErrorGuaranteed),
}Variants
Ok(&'tcx IndexMap<LocalDefId, DefinitionSiteHiddenType<'tcx>, FxBuildHasher>)
Contains the success value
Err(ErrorGuaranteed)
Contains the error value
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.