pub type ProvidedValue<'tcx> = Value<'tcx>;Expand description
Type returned from query providers and loaded from disk-cache.
Aliased Type
pub enum ProvidedValue<'tcx> {
FnReturn {
parent: DefId,
in_trait_or_impl: Option<RpitContext>,
},
AsyncFn {
parent: DefId,
in_trait_or_impl: Option<RpitContext>,
},
TyAlias {
parent: DefId,
in_assoc_ty: bool,
},
}Variants
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.