pub(crate) enum ProjectedUserTypesNode<'a> {
None,
Chain {
parent: &'a Self,
op: ProjectedUserTypesOp,
},
}Variants
Implementations
Sourceimpl<'a> ProjectedUserTypesNode<'a>
impl<'a> ProjectedUserTypesNode<'a>
pub(crate) fn push_user_types( &'a self, base_types: SmallVec<[UserTypeAnnotationIndex; 4]>, ) -> Self
Sourcefn maybe_push(&'a self, op_fn: impl FnOnce() -> ProjectedUserTypesOp) -> Self
fn maybe_push(&'a self, op_fn: impl FnOnce() -> ProjectedUserTypesOp) -> Self
Push another projection op onto the chain, but only if it is already non-empty.
pub(crate) fn index(&'a self) -> Self
pub(crate) fn subslice(&'a self, from: u64, to: u64) -> Self
pub(crate) fn deref(&'a self) -> Self
pub(crate) fn leaf(&'a self, field: FieldIdx) -> Self
pub(crate) fn variant( &'a self, adt_def: AdtDef<'_>, variant: VariantIdx, field: FieldIdx, ) -> Self
Sourcefn iter_ops_reversed(&'a self) -> impl Iterator<Item = &'a ProjectedUserTypesOp>
fn iter_ops_reversed(&'a self) -> impl Iterator<Item = &'a ProjectedUserTypesOp>
Traverses the chain of nodes to yield each op in the chain. Because this walks from child node to parent node, the ops are naturally yielded in “reverse” order.
Sourcepub(crate) fn build_user_type_projections(
&self,
) -> Option<Box<UserTypeProjections>>
pub(crate) fn build_user_type_projections( &self, ) -> Option<Box<UserTypeProjections>>
Assembles this chain of user-type projections into a proper data structure.