pub(crate) type UserTypeIndices = SmallVec<[UserTypeAnnotationIndex; 4]>;Expand description
A single thir::Pat node should almost never have more than 0-2 user types.
We can store up to 4 inline in the same size as an ordinary Vec.
Aliased Type
pub(crate) struct UserTypeIndices { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 24 bytes