pub struct NormalizationFolder<'a, Infcx, I, F>where
Infcx: InferCtxtLike<Interner = I>,
I: Interner,{
infcx: &'a Infcx,
universes: Vec<Option<UniverseIndex>>,
stalled_goals: Vec<Goal<I, I::Predicate>>,
normalize: F,
}Expand description
This folder normalizes value and collects ambiguous goals.
Note that for ambiguous alias which contains escaping bound vars, we just return the original alias and don’t collect the ambiguous goal.
Fields
infcx: &'a Infcxuniverses: Vec<Option<UniverseIndex>>stalled_goals: Vec<Goal<I, I::Predicate>>normalize: FImplementations
Sourceimpl<'a, Infcx, I, F> NormalizationFolder<'a, Infcx, I, F>where
Infcx: InferCtxtLike<Interner = I>,
I: Interner,
F: FnMut(I::Term) -> Result<(I::Term, Option<Goal<I, I::Predicate>>), NoSolution>,
impl<'a, Infcx, I, F> NormalizationFolder<'a, Infcx, I, F>where
Infcx: InferCtxtLike<Interner = I>,
I: Interner,
F: FnMut(I::Term) -> Result<(I::Term, Option<Goal<I, I::Predicate>>), NoSolution>,
pub fn new( infcx: &'a Infcx, universes: Vec<Option<UniverseIndex>>, stalled_goals: Vec<Goal<I, I::Predicate>>, normalize: F, ) -> Self
pub fn stalled_goals(self) -> Vec<Goal<I, I::Predicate>>
fn normalize_alias_term( &mut self, alias_term: I::Term, has_escaping: HasEscapingBoundVars, ) -> Result<I::Term, NoSolution>