ParseSess

Struct ParseSess 

pub struct ParseSess {
    dcx: DiagCtxt,
    pub edition: Edition,
    pub raw_identifier_spans: AppendOnlyVec<Span>,
    pub bad_unicode_identifiers: Lock<FxIndexMap<Symbol, Vec<Span>>>,
    source_map: Arc<SourceMap>,
    pub buffered_lints: Lock<Vec<BufferedEarlyLint>>,
    pub ambiguous_block_expr_parse: Lock<FxIndexMap<Span, Span>>,
    pub gated_spans: GatedSpans,
    pub symbol_gallery: SymbolGallery,
    pub attr_id_generator: AttrIdGenerator,
}
Info about a parsing session.

Fields

dcx: DiagCtxtedition: Editionraw_identifier_spans: AppendOnlyVec<Span>

Places where raw identifiers were used. This is used to avoid complaining about idents clashing with keywords in new editions.

bad_unicode_identifiers: Lock<FxIndexMap<Symbol, Vec<Span>>>

Places where identifiers that contain invalid Unicode codepoints but that look like they should be. Useful to avoid bad tokenization when encountering emoji. We group them to provide a single error per unique incorrect identifier.

source_map: Arc<SourceMap>buffered_lints: Lock<Vec<BufferedEarlyLint>>ambiguous_block_expr_parse: Lock<FxIndexMap<Span, Span>>

Contains the spans of block expressions that could have been incomplete based on the operation token that followed it, but that the parser cannot identify without further analysis.

gated_spans: GatedSpanssymbol_gallery: SymbolGalleryattr_id_generator: AttrIdGenerator

Used to generate new AttrIds. Every AttrId is unique.

Implementations

Source

impl ParseSess

pub fn new() -> Self

Used for testing.

pub fn with_dcx(dcx: DiagCtxt, source_map: Arc<SourceMap>) -> Self

pub fn emitter_with_note(note: String) -> Self

pub fn source_map(&self) -> &SourceMap

pub fn clone_source_map(&self) -> Arc<SourceMap>

pub fn buffer_lint( &self, lint: &'static Lint, span: impl Into<MultiSpan>, node_id: NodeId, diagnostic: impl Into<DecorateDiagCompat>, )

pub fn dyn_buffer_lint<F: for<'a> FnOnce(DiagCtxtHandle<'a>, Level) -> Diag<'a, ()> + DynSync + DynSend + 'static>( &self, lint: &'static Lint, span: impl Into<MultiSpan>, node_id: NodeId, callback: F, )

pub fn dyn_buffer_lint_sess<F: for<'a> FnOnce(DiagCtxtHandle<'a>, Level, &Session) -> Diag<'a, ()> + DynSync + DynSend + 'static>( &self, lint: &'static Lint, span: impl Into<MultiSpan>, node_id: NodeId, callback: F, )

pub(crate) fn opt_span_buffer_lint( &self, lint: &'static Lint, span: Option<MultiSpan>, node_id: NodeId, diagnostic: DecorateDiagCompat, )

pub fn dcx(&self) -> DiagCtxtHandle<'_>