alias_outlives_candidates_from_assumptions

Function alias_outlives_candidates_from_assumptions 

fn alias_outlives_candidates_from_assumptions<Infcx: InferCtxtLike<Interner = I>, I: Interner>(
    infcx: &Infcx,
    bound_outlives: Binder<I, (AliasTy<I>, I::Region)>,
    assumptions: &Assumptions<I>,
) -> RegionConstraint<I>
Converts an AliasTyOutlivesViaEnv constraint into an OR of region outlives constraints by matching the alias against any Alias: 'a assumptions. This is somewhat tricky as we have a potentially higher ranked alias being equated with a potentially higher ranked assumption and we don’t handle it correctly right now (though it is a somewhat reasonable halfway step).