destructure_type_outlives_constraints_in_root

Function destructure_type_outlives_constraints_in_root 

pub fn destructure_type_outlives_constraints_in_root<Infcx: InferCtxtLike<Interner = I>, I: Interner>(
    infcx: &Infcx,
    constraint: RegionConstraint<I>,
    assumptions: &Assumptions<I>,
) -> RegionConstraint<I>
Converts type outlives constraints into region outlives constraints. This assumes the complete set of assumptions are known. This should not be called until the end of type checking.

The returned region constraint will not have any PlaceholderTyOutlives or AliasTyOutlivesViaEnv constraints.