write_resources

Function write_resources 

fn write_resources(
    dst: &Path,
    opt: &RenderOptions,
    style_files: &[StylePath],
    css_file_extension: Option<&Path>,
    resource_suffix: &str,
) -> Result<(), Error>
Writes the static files, the style files, and the css extensions. Have to be careful about these, because they write to the root out dir.