fn primitive_type_to_ty<'tcx>(
tcx: TyCtxt<'tcx>,
prim: PrimitiveType,
) -> Option<Ty<'tcx>>Expand description
Convert a PrimitiveType to a Ty, where possible.
This is used for resolving trait impls for primitives
fn primitive_type_to_ty<'tcx>(
tcx: TyCtxt<'tcx>,
prim: PrimitiveType,
) -> Option<Ty<'tcx>>Convert a PrimitiveType to a Ty, where possible.
This is used for resolving trait impls for primitives