pub enum FloatLiteralTrailingZero {
Preserve,
Always,
IfNoPostfix,
Never,
}Variants
Preserve
Leave the literal as-is.
Always
Add a trailing zero to the literal.
IfNoPostfix
Add a trailing zero by default. If the literal contains an exponent or a suffix, the zero and the preceding period are removed.
Never
Remove the trailing zero. If the literal contains an exponent or a suffix, the preceding period is also removed.