fn prepare_compiler_for_check(
builder: &Builder<'_>,
target: TargetSelection,
mode: Mode,
) -> CompilerExpand description
Prepares a compiler that will check something with the given mode.
fn prepare_compiler_for_check(
builder: &Builder<'_>,
target: TargetSelection,
mode: Mode,
) -> CompilerPrepares a compiler that will check something with the given mode.