pub struct Rustfmt {
pub target: TargetSelection,
}Fields
target: TargetSelectionTrait Implementations
sourceimpl PartialEq for Rustfmt
impl PartialEq for Rustfmt
sourceimpl Step for Rustfmt
impl Step for Rustfmt
type Output = ()
type Output = ()
PathBuf when directories are created or to return a Compiler once
it’s been assembled.sourceconst DEFAULT: bool = false
const DEFAULT: bool = false
Whether this step is run by default as part of its respective phase.
true here can still be overwritten by should_run calling default_condition.sourcefn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
fn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
When bootstrap is passed a set of paths, this controls whether this rule
will execute. However, it does not get called in a “default” context
when we are not passed any paths; in that case,
make_run is called
directly.sourcefn make_run(run: RunConfig<'_>)
fn make_run(run: RunConfig<'_>)
Builds up a “root” rule, either as a default rule or from a path passed
to us. Read more
sourcefn run(self, builder: &Builder<'_>) -> Self::Output
fn run(self, builder: &Builder<'_>) -> Self::Output
Primary function to execute this rule. Can call
builder.ensure()
with other steps to run those. Read moresourceconst ONLY_HOSTS: bool = false
const ONLY_HOSTS: bool = false
If true, then this rule should be skipped if –target was specified, but –host was not
impl Eq for Rustfmt
impl StructuralPartialEq for Rustfmt