pub struct Std {
pub target: TargetSelection,
pub compiler: Compiler,
crates: Vec<String>,
force_recompile: bool,
extra_rust_args: &'static [&'static str],
is_for_mir_opt_tests: bool,
}Fields
target: TargetSelectioncompiler: Compilercrates: Vec<String>Whether to build only a subset of crates in the standard library.
This shouldn’t be used from other steps; see the comment on Rustc.
force_recompile: boolWhen using download-rustc, we need to use a new build of std for running unit tests of Std itself,
but we need to use the downloaded copy of std for linking to rustdoc. Allow this to be overridden by builder.ensure from other steps.
extra_rust_args: &'static [&'static str]is_for_mir_opt_tests: boolImplementations
sourceimpl Std
impl Std
pub fn new(compiler: Compiler, target: TargetSelection) -> Self
pub fn force_recompile(compiler: Compiler, target: TargetSelection) -> Self
pub fn new_for_mir_opt_tests( compiler: Compiler, target: TargetSelection, ) -> Self
pub fn new_with_extra_rust_args( compiler: Compiler, target: TargetSelection, extra_rust_args: &'static [&'static str], ) -> Self
fn copy_extra_objects( &self, builder: &Builder<'_>, compiler: &Compiler, target: TargetSelection, ) -> Vec<(PathBuf, DependencyType)>