pub struct Releases {
compiler: Compiler,
target: TargetSelection,
}Fields
compiler: Compilertarget: TargetSelectionTrait Implementations
sourceimpl PartialEq for Releases
impl PartialEq for Releases
sourceimpl Step for Releases
impl Step for Releases
sourcefn run(self, builder: &Builder<'_>)
fn run(self, builder: &Builder<'_>)
Generates HTML release notes to include in the final docs bundle.
This uses the same stylesheet and other tools as Standalone, but the RELEASES.md file is included at the root of the repository and gets the headline added. In the end, the conversion is done by Rustdoc.
type Output = ()
type Output = ()
PathBuf when directories are created or to return a Compiler once
it’s been assembled.sourceconst DEFAULT: bool = true
const DEFAULT: bool = true
Whether this step is run by default as part of its respective phase.
true here can still be overwritten by should_run calling default_condition.sourcefn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
fn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
When bootstrap is passed a set of paths, this controls whether this rule
will execute. However, it does not get called in a “default” context
when we are not passed any paths; in that case,
make_run is called
directly.sourcefn make_run(run: RunConfig<'_>)
fn make_run(run: RunConfig<'_>)
Builds up a “root” rule, either as a default rule or from a path passed
to us. Read more
sourceconst ONLY_HOSTS: bool = false
const ONLY_HOSTS: bool = false
If true, then this rule should be skipped if –target was specified, but –host was not
impl Copy for Releases
impl Eq for Releases
impl StructuralPartialEq for Releases