pub struct BumpStage0;Trait Implementations
Sourceimpl Clone for BumpStage0
impl Clone for BumpStage0
Sourcefn clone(&self) -> BumpStage0
fn clone(&self) -> BumpStage0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BumpStage0
impl Debug for BumpStage0
Sourceimpl Hash for BumpStage0
impl Hash for BumpStage0
Sourceimpl Ord for BumpStage0
impl Ord for BumpStage0
Sourcefn cmp(&self, other: &BumpStage0) -> Ordering
fn cmp(&self, other: &BumpStage0) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BumpStage0
impl PartialEq for BumpStage0
Sourceimpl PartialOrd for BumpStage0
impl PartialOrd for BumpStage0
Sourceimpl Step for BumpStage0
impl Step for BumpStage0
Sourceconst ONLY_HOSTS: bool = true
const ONLY_HOSTS: bool = true
If true, then this rule should be skipped if –target was specified, but –host was not
Sourcefn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
fn should_run(run: ShouldRun<'_>) -> ShouldRun<'_>
Determines if this
Step should be run when given specific paths (e.g., x build $path).Sourcefn make_run(run: RunConfig<'_>)
fn make_run(run: RunConfig<'_>)
Called directly by the bootstrap
Step handler when not triggered indirectly by other Steps using Builder::ensure.
For example, ./x.py test bootstrap runs this for test::Bootstrap. Similarly, ./x.py test runs it for every step
that is listed by the describe macro in Builder::get_step_descriptions.Sourcefn run(self, builder: &Builder<'_>) -> Self::Output
fn run(self, builder: &Builder<'_>) -> Self::Output
Primary function to implement
Step logic. Read moreSourceconst DEFAULT: bool = false
const DEFAULT: bool = false
Whether this step is run by default as part of its respective phase, as defined by the
describe
macro in Builder::get_step_descriptions. Read moreSourcefn metadata(&self) -> Option<StepMetadata>
fn metadata(&self) -> Option<StepMetadata>
Returns metadata of the step, for tests
impl Eq for BumpStage0
impl StructuralPartialEq for BumpStage0