Function bootstrap::prepare_behaviour_dump_dir
source · pub fn prepare_behaviour_dump_dir(build: &Build)Expand description
Ensures that the behavior dump directory is properly initialized.
pub fn prepare_behaviour_dump_dir(build: &Build)Ensures that the behavior dump directory is properly initialized.