Function bootstrap::utils::helpers::get_closest_merge_base_commit
source · pub fn get_closest_merge_base_commit(
source_dir: Option<&Path>,
config: &GitConfig<'_>,
author: &str,
target_paths: &[PathBuf],
) -> Result<String, String>Expand description
Returns the closest commit available from upstream for the given author and target_paths.
If it fails to find the commit from upstream using git merge-base, fallbacks to HEAD.