Function parse_rustc_stage

pub fn parse_rustc_stage() -> u32
Parses the value of the “RUSTC_STAGE” environment variable and returns it as a String. This is the stage of the build compiler, which we are wrapping using a rustc/rustdoc wrapper.

If “RUSTC_STAGE” was not set, the program will be terminated with 101.