Function clippy_utils::is_block_like
source · pub fn is_block_like(expr: &Expr<'_>) -> boolExpand description
Returns true if the given expr is a block or resembled as a block,
such as if, loop, match expressions etc.
pub fn is_block_like(expr: &Expr<'_>) -> boolReturns true if the given expr is a block or resembled as a block,
such as if, loop, match expressions etc.