Function clippy_utils::is_inside_let_else
source · pub fn is_inside_let_else(tcx: TyCtxt<'_>, expr: &Expr<'_>) -> boolExpand description
Checks if the given expression is a part of let else
returns true for both the init and the else part