Struct clippy_utils::ExprUseCtxt
source · pub struct ExprUseCtxt<'tcx> {
pub node: ExprUseNode<'tcx>,
pub adjustments: &'tcx [Adjustment<'tcx>],
pub is_ty_unified: bool,
pub moved_before_use: bool,
}Expand description
The context an expressions value is used in.
Fields
node: ExprUseNode<'tcx>The parent node which consumes the value.
adjustments: &'tcx [Adjustment<'tcx>]Any adjustments applied to the type.
is_ty_unified: boolWhether or not the type must unify with another code path.
moved_before_use: boolWhether or not the value will be moved before it’s used.