Function clippy_utils::ty::is_recursively_primitive_type
source · pub fn is_recursively_primitive_type(ty: Ty<'_>) -> boolExpand description
Returns true if the given type is a primitive (a bool or char, any integer or
floating-point number type, a str, or an array, slice, or tuple of those types).