pub fn is_type_lang_item(
cx: &LateContext<'_>,
ty: Ty<'_>,
lang_item: LangItem,
) -> boolExpand description
Checks if the type is equal to a lang item.
Returns false if the LangItem is not defined.
pub fn is_type_lang_item(
cx: &LateContext<'_>,
ty: Ty<'_>,
lang_item: LangItem,
) -> boolChecks if the type is equal to a lang item.
Returns false if the LangItem is not defined.