pub fn type_is_unsafe_function<'tcx>(
cx: &LateContext<'tcx>,
ty: Ty<'tcx>,
) -> boolExpand description
Returns true if the given type is an unsafe function.
pub fn type_is_unsafe_function<'tcx>(
cx: &LateContext<'tcx>,
ty: Ty<'tcx>,
) -> boolReturns true if the given type is an unsafe function.