Enum clippy_utils::ty::type_certainty::certainty::Certainty
source · pub enum Certainty {
Uncertain,
Certain(Option<DefId>),
Contradiction,
}Variants
Uncertain
Determining the type requires contextual information.
Certain(Option<DefId>)
The type can be determined purely from subexpressions. If the argument is Some(..), the
specific DefId is known. Such arguments are needed to handle path segments whose res is
Res::Err.
Contradiction
The heuristic believes that more than one DefId applies to a type—this is a bug.
Implementations
sourceimpl Certainty
impl Certainty
sourcepub fn join(self, other: Self) -> Self
pub fn join(self, other: Self) -> Self
Join two Certaintys preserving their DefIds (if any). Generally speaking, this method
should be used only when self and other refer directly to types. Otherwise,
join_clearing_def_ids should be used.
sourcepub fn join_clearing_def_ids(self, other: Self) -> Self
pub fn join_clearing_def_ids(self, other: Self) -> Self
Join two Certaintys after clearing their DefIds. This method should be used when self
or other do not necessarily refer to types, e.g., when they are aggregations of other
Certaintys.
pub fn clear_def_id(self) -> Certainty
pub fn with_def_id(self, def_id: DefId) -> Certainty
pub fn to_def_id(self) -> Option<DefId>
pub fn is_certain(self) -> bool