Struct rustc::dep_graph::debug::DepNodeFilter [−][src]
pub struct DepNodeFilter {
text: String,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A dep-node filter goes from a user-defined string to a query over nodes. Right now the format is like this:
x & y & z
where the format-string of the dep-node must contain x, y, and
z.
Fields
text: String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DepNodeFilter[src]
impl DepNodeFilterpub fn new(text: &str) -> Self[src]
pub fn new(text: &str) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn accepts_all(&self) -> bool[src]
pub fn accepts_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if all nodes always pass the filter.
pub fn test(&self, node: &DepNode) -> bool[src]
pub fn test(&self, node: &DepNode) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Tests whether node meets the filter, returning true if so.