Struct rustc::dep_graph::debug::EdgeFilter
[−]
[src]
pub struct EdgeFilter {
pub source: DepNodeFilter,
pub target: DepNodeFilter,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A filter like F -> G where F and G are valid dep-node
filters. This can be used to test the source/target independently.
Fields
source: DepNodeFilter
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
target: DepNodeFilter
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl EdgeFilter[src]
impl EdgeFilterpub fn new(test: &str) -> Result<EdgeFilter, Box<Error>>[src]
pub fn new(test: &str) -> Result<EdgeFilter, Box<Error>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn test(&self, source: &DepNode, target: &DepNode) -> bool[src]
pub fn test(&self, source: &DepNode, target: &DepNode) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?