[−][src]Struct rustc::dep_graph::dep_node::DepNode
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
kind: DepKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
hash: Fingerprint
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DepNode[src]
impl DepNodepub fn new<'a, 'gcx, 'tcx>(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
dep: DepConstructor<'gcx>
) -> DepNode where
'gcx: 'a + 'tcx,
'tcx: 'a, [src]
pub fn new<'a, 'gcx, 'tcx>(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
dep: DepConstructor<'gcx>
) -> DepNode where
'gcx: 'a + 'tcx,
'tcx: 'a, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_def_path_hash(kind: DepKind, def_path_hash: DefPathHash) -> DepNode[src]
pub fn from_def_path_hash(kind: DepKind, def_path_hash: DefPathHash) -> DepNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Construct a DepNode from the given DepKind and DefPathHash. This method will assert that the given DepKind actually requires a single DefId/DefPathHash parameter.
pub fn new_no_params(kind: DepKind) -> DepNode[src]
pub fn new_no_params(kind: DepKind) -> DepNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new, parameterless DepNode. This method will assert that the DepNode corresponding to the given DepKind actually does not require any parameters.
pub fn extract_def_id(&self, tcx: TyCtxt) -> Option<DefId>[src]
pub fn extract_def_id(&self, tcx: TyCtxt) -> Option<DefId>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extract the DefId corresponding to this DepNode. This will work if two conditions are met:
- The Fingerprint of the DepNode actually is a DefPathHash, and
- the item that the DefPath refers to exists in the current tcx.
Condition (1) is determined by the DepKind variant of the DepNode. Condition (2) might not be fulfilled if a DepNode refers to something from the previous compilation session that has been removed.
pub fn from_label_string(
label: &str,
def_path_hash: DefPathHash
) -> Result<DepNode, ()>[src]
pub fn from_label_string(
label: &str,
def_path_hash: DefPathHash
) -> Result<DepNode, ()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used in testing
pub fn has_label_string(label: &str) -> bool[src]
pub fn has_label_string(label: &str) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used in testing
impl DepNode[src]
impl DepNodepub fn cache_on_disk(&self, tcx: TyCtxt) -> bool[src]
pub fn cache_on_disk(&self, tcx: TyCtxt) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn load_from_on_disk_cache(&self, tcx: TyCtxt)[src]
pub fn load_from_on_disk_cache(&self, tcx: TyCtxt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?