Enum rustc::dep_graph::graph::OpenTask [−][src]
pub enum OpenTask {
Regular(Lock<RegularOpenTask>),
Anon(Lock<AnonOpenTask>),
Ignore,
EvalAlways {
node: DepNode,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Regular(Lock<RegularOpenTask>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Anon(Lock<AnonOpenTask>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ignore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
EvalAlways🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of EvalAlways
node: DepNode | 🔬 This is a nightly-only experimental API. ( |