Struct rustc::dep_graph::graph::CurrentDepGraph [−][src]
struct CurrentDepGraph {
nodes: IndexVec<DepNodeIndex, DepNode>,
edges: IndexVec<DepNodeIndex, Vec<DepNodeIndex>>,
node_to_node_index: FxHashMap<DepNode, DepNodeIndex>,
forbidden_edge: Option<EdgeFilter>,
anon_id_seed: Fingerprint,
total_read_count: u64,
total_duplicate_read_count: u64,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
nodes: IndexVec<DepNodeIndex, DepNode>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
edges: IndexVec<DepNodeIndex, Vec<DepNodeIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
node_to_node_index: FxHashMap<DepNode, DepNodeIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
forbidden_edge: Option<EdgeFilter>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
anon_id_seed: Fingerprint
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
total_read_count: u64
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
total_duplicate_read_count: u64
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CurrentDepGraph[src]
impl CurrentDepGraphfn new() -> CurrentDepGraph[src]
fn new() -> CurrentDepGraph🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn complete_task(&mut self, key: DepNode, task: OpenTask) -> DepNodeIndex[src]
fn complete_task(&mut self, key: DepNode, task: OpenTask) -> DepNodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pop_anon_task(&mut self, kind: DepKind, task: OpenTask) -> DepNodeIndex[src]
fn pop_anon_task(&mut self, kind: DepKind, task: OpenTask) -> DepNodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn complete_eval_always_task(
&mut self,
key: DepNode,
task: OpenTask
) -> DepNodeIndex[src]
fn complete_eval_always_task(
&mut self,
key: DepNode,
task: OpenTask
) -> DepNodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn read_index(&mut self, source: DepNodeIndex)[src]
fn read_index(&mut self, source: DepNodeIndex)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn alloc_node(
&mut self,
dep_node: DepNode,
edges: Vec<DepNodeIndex>
) -> DepNodeIndex[src]
fn alloc_node(
&mut self,
dep_node: DepNode,
edges: Vec<DepNodeIndex>
) -> DepNodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?