Struct rustc::dep_graph::graph::DepNodeIndex [−]
pub struct DepNodeIndex(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DepNodeIndex[src]
impl DepNodeIndexconst INVALID: DepNodeIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
INVALID: DepNodeIndex = DepNodeIndex(::std::u32::MAX)