[−][src]Struct rustc::dep_graph::DepGraphQuery
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
graph: Graph<DepNode, ()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
indices: FxHashMap<DepNode, NodeIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DepGraphQuery[src]
impl DepGraphQuerypub fn new(nodes: &[DepNode], edges: &[(DepNode, DepNode)]) -> DepGraphQuery[src]
pub fn new(nodes: &[DepNode], edges: &[(DepNode, DepNode)]) -> DepGraphQuery🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains_node(&self, node: &DepNode) -> bool[src]
pub fn contains_node(&self, node: &DepNode) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn nodes(&self) -> Vec<&DepNode>[src]
pub fn nodes(&self) -> Vec<&DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn edges(&self) -> Vec<(&DepNode, &DepNode)>[src]
pub fn edges(&self) -> Vec<(&DepNode, &DepNode)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn reachable_nodes(&self, node: &DepNode, direction: Direction) -> Vec<&DepNode>[src]
fn reachable_nodes(&self, node: &DepNode, direction: Direction) -> Vec<&DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn transitive_successors(&self, node: &DepNode) -> Vec<&DepNode>[src]
pub fn transitive_successors(&self, node: &DepNode) -> Vec<&DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
All nodes reachable from node. In other words, things that
will have to be recomputed if node changes.
pub fn transitive_predecessors(&self, node: &DepNode) -> Vec<&DepNode>[src]
pub fn transitive_predecessors(&self, node: &DepNode) -> Vec<&DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
All nodes that can reach node.
pub fn immediate_successors(&self, node: &DepNode) -> Vec<&DepNode>[src]
pub fn immediate_successors(&self, node: &DepNode) -> Vec<&DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Just the outgoing edges from node.