Struct rustc::dep_graph::WorkProductId
[−]
[src]
pub struct WorkProductId { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A "work product" corresponds to a .o (or other) file that we
save in between runs. These ids do not have a DefId but rather
some independent path or string that persists between runs without
the need to be mapped or unmapped. (This ensures we can serialize
them even in the absence of a tcx.)
Methods
impl WorkProductId[src]
impl WorkProductIdpub fn from_cgu_name(cgu_name: &str) -> WorkProductId[src]
pub fn from_cgu_name(cgu_name: &str) -> WorkProductId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_fingerprint(fingerprint: Fingerprint) -> WorkProductId[src]
pub fn from_fingerprint(fingerprint: Fingerprint) -> WorkProductId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?