Struct rustc::hir::check_attr::CheckAttrVisitor [−][src]
struct CheckAttrVisitor<'a, 'tcx: 'a> {
tcx: TyCtxt<'a, 'tcx, 'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> CheckAttrVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> CheckAttrVisitor<'a, 'tcx>fn check_attributes(&self, item: &Item, target: Target)[src]
fn check_attributes(&self, item: &Item, target: Target)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check any attribute.
fn check_inline(&self, attr: &Attribute, span: &Span, target: Target)[src]
fn check_inline(&self, attr: &Attribute, span: &Span, target: Target)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if an #[inline] is applied to a function or a closure.
fn check_non_exhaustive(&self, attr: &Attribute, item: &Item, target: Target)[src]
fn check_non_exhaustive(&self, attr: &Attribute, item: &Item, target: Target)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if the #[non_exhaustive] attribute on an item is valid.
fn check_repr(&self, item: &Item, target: Target)[src]
fn check_repr(&self, item: &Item, target: Target)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if the #[repr] attributes on item are valid.
fn emit_repr_error(
&self,
hint_span: Span,
label_span: Span,
hint_message: &str,
label_message: &str
)[src]
fn emit_repr_error(
&self,
hint_span: Span,
label_span: Span,
hint_message: &str,
label_message: &str
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_stmt_attributes(&self, stmt: &Stmt)[src]
fn check_stmt_attributes(&self, stmt: &Stmt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr_attributes(&self, expr: &Expr)[src]
fn check_expr_attributes(&self, expr: &Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_used(&self, item: &Item, target: Target)[src]
fn check_used(&self, item: &Item, target: Target)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?