Enum rustc::hir::def::CtorKind [−][src]
pub enum CtorKind {
Fn,
Const,
Fictive,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Fn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Constructor function automatically created by a tuple struct/variant.
Const🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Constructor constant automatically created by a unit struct/variant.
Fictive🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Unusable name in value namespace created by a struct variant.
Methods
impl CtorKind[src]
impl CtorKindpub fn from_ast(vdata: &VariantData) -> CtorKind[src]
pub fn from_ast(vdata: &VariantData) -> CtorKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_hir(vdata: &VariantData) -> CtorKind[src]
pub fn from_hir(vdata: &VariantData) -> CtorKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?