[−][src]Struct rustc::hir::def::PerNS
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Just a helper ‒ separate structure for each namespace.
Fields
value_ns: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type_ns: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
macro_ns: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> PerNS<T>[src]
impl<T> PerNS<T>pub fn map<U, F: FnMut(T) -> U>(self, f: F) -> PerNS<U>[src]
pub fn map<U, F: FnMut(T) -> U>(self, f: F) -> PerNS<U>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T> PerNS<Option<T>>[src]
impl<T> PerNS<Option<T>>pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns whether all the items in this collection are None.
pub fn present_items(
self
) -> impl Iterator<Item = T>[src]
pub fn present_items(
self
) -> impl Iterator<Item = T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an iterator over the items which are Some.