Struct rustc::hir::def_id::CrateNum
[−]
pub struct CrateNum(_);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CrateNum[src]
impl CrateNumpub fn new(x: usize) -> CrateNum[src]
pub fn new(x: usize) -> CrateNum🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_u32(x: u32) -> CrateNum[src]
pub fn from_u32(x: u32) -> CrateNum🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_usize(&self) -> usize[src]
pub fn as_usize(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_u32(&self) -> u32[src]
pub fn as_u32(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_def_id(&self) -> DefId[src]
pub fn as_def_id(&self) -> DefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?