Struct rustc::hir::def_id::DefId [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A DefId identifies a particular definition, by combining a crate index and a def index.
Fields
krate: CrateNum
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
index: DefIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DefId[src]
impl DefIdpub fn to_dep_node(self, tcx: TyCtxt, kind: DepKind) -> DepNode[src]
pub fn to_dep_node(self, tcx: TyCtxt, kind: DepKind) -> DepNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl DefId[src]
impl DefIdpub fn local(index: DefIndex) -> DefId[src]
pub fn local(index: DefIndex) -> DefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Make a local DefId with the given index.
pub fn is_local(self) -> bool[src]
pub fn is_local(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_local(self) -> LocalDefId[src]
pub fn to_local(self) -> LocalDefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?