[−][src]Struct rustc::hir::def_id::DefIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A DefIndex is an index into the hir-map for a crate, identifying a particular definition. It should really be considered an interned shorthand for a particular DefPath.
At the moment we are allocating the numerical values of DefIndexes from two address spaces: DefIndexAddressSpace::Low and DefIndexAddressSpace::High. This allows us to allocate the DefIndexes of all item-likes (Items, TraitItems, and ImplItems) into one of these spaces and consequently use a simple array for lookup tables keyed by DefIndex and known to be densely populated. This is especially important for the HIR map.
Since the DefIndex is mostly treated as an opaque ID, you probably don't have to care about these address spaces.
Methods
impl DefIndex[src]
impl DefIndexpub fn address_space(&self) -> DefIndexAddressSpace[src]
pub fn address_space(&self) -> DefIndexAddressSpace🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_array_index(&self) -> usize[src]
pub fn as_array_index(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts this DefIndex into a zero-based array index. This index is the offset within the given DefIndexAddressSpace.
pub fn from_array_index(
i: usize,
address_space: DefIndexAddressSpace
) -> DefIndex[src]
pub fn from_array_index(
i: usize,
address_space: DefIndexAddressSpace
) -> DefIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_proc_macro_index(proc_macro_index: usize) -> DefIndex[src]
pub fn from_proc_macro_index(proc_macro_index: usize) -> DefIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_proc_macro_index(self: DefIndex) -> usize[src]
pub fn to_proc_macro_index(self: DefIndex) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_raw_u32(x: u32) -> DefIndex[src]
pub fn from_raw_u32(x: u32) -> DefIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_raw_u32(&self) -> u32[src]
pub fn as_raw_u32(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?