Enum rustc::hir::ForeignItem_
[−]
[src]
pub enum ForeignItem_ {
ForeignItemFn(P<FnDecl>, HirVec<Spanned<Name>>, Generics),
ForeignItemStatic(P<Ty>, bool),
ForeignItemType,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An item within an extern block
Variants
ForeignItemFn(P<FnDecl>, HirVec<Spanned<Name>>, Generics)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A foreign function
ForeignItemStatic(P<Ty>, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A foreign static item (static ext: u8), with optional mutability
(the boolean is true when mutable)
ForeignItemType🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A foreign type
Methods
impl ForeignItem_[src]
impl ForeignItem_pub fn descriptive_variant(&self) -> &str[src]
pub fn descriptive_variant(&self) -> &str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?