Enum rustc::hir::ImplItemKind [−][src]
pub enum ImplItemKind {
Const(P<Ty>, BodyId),
Method(MethodSig, BodyId),
Type(P<Ty>),
Existential(GenericBounds),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents different contents within impls
Variants
Const(P<Ty>, BodyId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An associated constant of the given type, set to the constant result of the expression
Method(MethodSig, BodyId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A method implementation with the given signature and body
Type(P<Ty>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An associated type
Existential(GenericBounds)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An associated existential type