Enum rustc::hir::LocalSource [−][src]
pub enum LocalSource {
Normal,
ForLoopDesugar,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Hints at the original code for a let statement
Variants
Normal🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A match _ { .. }
ForLoopDesugar🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A desugared for _ in _ { .. } loop