Enum rustc::hir::MatchSource [−][src]
pub enum MatchSource {
Normal,
IfLetDesugar {
contains_else_clause: bool,
},
WhileLetDesugar,
ForLoopDesugar,
TryDesugar,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Hints at the original code for a match _ { .. }
Variants
Normal🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A match _ { .. }
IfLetDesugar🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An if let _ = _ { .. } (optionally with else { .. })
Fields of IfLetDesugar
contains_else_clause: bool | 🔬 This is a nightly-only experimental API. ( |
WhileLetDesugar🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A while let _ = _ { .. } (which was desugared to a
loop { match _ { .. } })
ForLoopDesugar🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A desugared for _ in _ { .. } loop
TryDesugar🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A desugared ? operator