Enum rustc::hir::ParamName [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Plain(Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Some user-given name like T or 'x.
Fresh(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Synthetic name generated when user elided a lifetime in an impl header, e.g. the lifetimes in cases like these:
impl Foo for &u32 impl Foo<'_> for u32
in that case, we rewrite to
impl<'f> Foo for &'f u32 impl<'f> Foo<'f> for u32
where 'f is something like Fresh(0). The indices are
unique per impl, but not necessarily continuous.
Methods
impl ParamName[src]
impl ParamNamepub fn ident(&self) -> Ident[src]
pub fn ident(&self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern(&self) -> ParamName[src]
pub fn modern(&self) -> ParamName🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?