Enum rustc::hir::PatKind [−][src]
pub enum PatKind {
Wild,
Binding(BindingAnnotation, NodeId, Spanned<Name>, Option<P<Pat>>),
Struct(QPath, HirVec<Spanned<FieldPat>>, bool),
TupleStruct(QPath, HirVec<P<Pat>>, Option<usize>),
Path(QPath),
Tuple(HirVec<P<Pat>>, Option<usize>),
Box(P<Pat>),
Ref(P<Pat>, Mutability),
Lit(P<Expr>),
Range(P<Expr>, P<Expr>, RangeEnd),
Slice(HirVec<P<Pat>>, Option<P<Pat>>, HirVec<P<Pat>>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Wild🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a wildcard pattern (_)
Binding(BindingAnnotation, NodeId, Spanned<Name>, Option<P<Pat>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A fresh binding ref mut binding @ OPT_SUBPATTERN.
The NodeId is the canonical ID for the variable being bound,
e.g. in Ok(x) | Err(x), both x use the same canonical ID,
which is the pattern ID of the first x.
Struct(QPath, HirVec<Spanned<FieldPat>>, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A struct or struct variant pattern, e.g. Variant {x, y, ..}.
The bool is true in the presence of a ...
TupleStruct(QPath, HirVec<P<Pat>>, Option<usize>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A tuple struct/variant pattern Variant(x, y, .., z).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Path(QPath)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A path pattern for an unit struct/variant or a (maybe-associated) constant.
Tuple(HirVec<P<Pat>>, Option<usize>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A tuple pattern (a, b).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Box(P<Pat>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A box pattern
Ref(P<Pat>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A reference pattern, e.g. &mut (a, b)
Lit(P<Expr>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal
Range(P<Expr>, P<Expr>, RangeEnd)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A range pattern, e.g. 1...2 or 1..2
Slice(HirVec<P<Pat>>, Option<P<Pat>>, HirVec<P<Pat>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
[a, b, ..i, y, z] is represented as:
PatKind::Slice(box [a, b], Some(i), box [y, z])