Enum rustc::hir::QPath
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Optionally Self-qualified value/type path or associated extension.
Variants
Resolved(Option<P<Ty>>, P<Path>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Path to a definition, optionally "fully-qualified" with a Self
type, if the path points to an associated item in a trait.
E.g. an unqualified path like Clone::clone has None for Self,
while <Vec<T> as Clone>::clone has Some(Vec<T>) for Self,
even though they both have the same two-segment Clone::clone Path.
TypeRelative(P<Ty>, P<PathSegment>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type-related paths, e.g. <T>::default or <T>::Output.
Will be resolved by type-checking to an associated item.
UFCS source paths can desugar into this, with Vec::new turning into
<Vec>::new, and T::X::Y::method into <<<T>::X>::Y>::method,
the X and Y nodes each being a TyPath(QPath::TypeRelative(..)).