Enum rustc::hir::ScopeTarget
[−]
[src]
pub enum ScopeTarget {
Block(NodeId),
Loop(LoopIdResult),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Block(NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Loop(LoopIdResult)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ScopeTarget[src]
impl ScopeTargetpub fn opt_id(self) -> Option<NodeId>[src]
pub fn opt_id(self) -> Option<NodeId>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?