Enum rustc::hir::Stmt_
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
StmtDecl(P<Decl>, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Could be an item or a local (let) binding:
StmtExpr(P<Expr>, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Expr without trailing semi-colon (must have unit type):
StmtSemi(P<Expr>, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Expr with trailing semi-colon (may have any type):
Methods
impl Stmt_[src]
impl Stmt_pub fn attrs(&self) -> &[Attribute][src]
pub fn attrs(&self) -> &[Attribute]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn id(&self) -> NodeId[src]
pub fn id(&self) -> NodeId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?