Enum rustc::hir::SyntheticTyParamKind [−][src]
pub enum SyntheticTyParamKind {
ImplTrait,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Synthetic Type Parameters are converted to an other form during lowering, this allows to track the original form they had. Useful for error messages.
Variants
ImplTrait🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?