Enum rustc::hir::TraitBoundModifier
[−]
[src]
pub enum TraitBoundModifier {
None,
Maybe,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A modifier on a bound, currently this is only used for ?Sized, where the
modifier is Maybe. Negative bounds should also be handled here.
Variants
None🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maybe🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?