[−][src]Enum rustc::hir::VariantData
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields and Ids of enum variants and structs
For enum variants: NodeId represents both an Id of the variant itself (relevant for all
variant kinds) and an Id of the variant's constructor (not relevant for Struct-variants).
One shared Id can be successfully used for these two purposes.
Id of the whole enum lives in Item.
For structs: NodeId represents an Id of the structure's constructor, so it is not actually
used for Struct-structs (but still presents). Structures don't have an analogue of "Id of
the variant itself" from enum variants.
Id of the whole struct lives in Item.
Variants
Struct(HirVec<StructField>, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Tuple(HirVec<StructField>, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Unit(NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl VariantData[src]
impl VariantDatapub fn fields(&self) -> &[StructField][src]
pub fn fields(&self) -> &[StructField]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn id(&self) -> NodeId[src]
pub fn id(&self) -> NodeId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_struct(&self) -> bool[src]
pub fn is_struct(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_tuple(&self) -> bool[src]
pub fn is_tuple(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_unit(&self) -> bool[src]
pub fn is_unit(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?