Enum rustc::hir::intravisit::FnKind [−][src]
pub enum FnKind<'a> {
ItemFn(Name, &'a Generics, FnHeader, &'a Visibility, &'a [Attribute]),
Method(Ident, &'a MethodSig, Option<&'a Visibility>, &'a [Attribute]),
Closure(&'a [Attribute]),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
ItemFn(Name, &'a Generics, FnHeader, &'a Visibility, &'a [Attribute])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[xxx] pub async/const/extern "Abi" fn foo()
Method(Ident, &'a MethodSig, Option<&'a Visibility>, &'a [Attribute])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn foo(&self)
Closure(&'a [Attribute])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|x, y| {}
Methods
impl<'a> FnKind<'a>[src]
impl<'a> FnKind<'a>pub fn attrs(&self) -> &'a [Attribute][src]
pub fn attrs(&self) -> &'a [Attribute]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?