Struct rustc::hir::map::blocks::ClosureParts [−][src]
struct ClosureParts<'a> {
decl: &'a FnDecl,
body: BodyId,
id: NodeId,
span: Span,
attrs: &'a [Attribute],
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
These are all the components one can extract from a closure expr for use when implementing FnLikeNode operations.
Fields
decl: &'a FnDecl
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
body: BodyId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
attrs: &'a [Attribute]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> ClosureParts<'a>[src]
impl<'a> ClosureParts<'a>fn new(
d: &'a FnDecl,
b: BodyId,
id: NodeId,
s: Span,
attrs: &'a [Attribute]
) -> Self[src]
fn new(
d: &'a FnDecl,
b: BodyId,
id: NodeId,
s: Span,
attrs: &'a [Attribute]
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?