Struct rustc::hir::map::definitions::DefKey [−][src]
pub struct DefKey {
pub parent: Option<DefIndex>,
pub disambiguated_data: DisambiguatedDefPathData,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A unique identifier that we can use to lookup a definition
precisely. It combines the index of the definition's parent (if
any) with a DisambiguatedDefPathData.
Fields
parent: Option<DefIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parent path.
disambiguated_data: DisambiguatedDefPathData
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier of this node.
Methods
impl DefKey[src]
impl DefKeyfn compute_stable_hash(&self, parent_hash: DefPathHash) -> DefPathHash[src]
fn compute_stable_hash(&self, parent_hash: DefPathHash) -> DefPathHash🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn root_parent_stable_hash(
crate_name: &str,
crate_disambiguator: CrateDisambiguator
) -> DefPathHash[src]
fn root_parent_stable_hash(
crate_name: &str,
crate_disambiguator: CrateDisambiguator
) -> DefPathHash🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?