Struct rustc::hir::map::definitions::DefPathHash [−][src]
pub struct DefPathHash(pub Fingerprint);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DefPathHash[src]
impl DefPathHashpub fn to_dep_node(self, kind: DepKind) -> DepNode[src]
pub fn to_dep_node(self, kind: DepKind) -> DepNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?