[−][src]Struct rustc::hir::map::definitions::DefPathTable
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The DefPathTable maps DefIndexes to DefKeys and vice versa. Internally the DefPathTable holds a tree of DefKeys, where each DefKey stores the DefIndex of its parent. There is one DefPathTable for each crate.
Fields
index_to_key: [Vec<DefKey>; 2]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def_path_hashes: [Vec<DefPathHash>; 2]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DefPathTable[src]
impl DefPathTablefn allocate(
&mut self,
key: DefKey,
def_path_hash: DefPathHash,
address_space: DefIndexAddressSpace
) -> DefIndex[src]
fn allocate(
&mut self,
key: DefKey,
def_path_hash: DefPathHash,
address_space: DefIndexAddressSpace
) -> DefIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn next_id(&self, address_space: DefIndexAddressSpace) -> DefIndex[src]
pub fn next_id(&self, address_space: DefIndexAddressSpace) -> DefIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn def_key(&self, index: DefIndex) -> DefKey[src]
pub fn def_key(&self, index: DefIndex) -> DefKey🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn def_path_hash(&self, index: DefIndex) -> DefPathHash[src]
pub fn def_path_hash(&self, index: DefIndex) -> DefPathHash🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_def_path_hashes_to(
&self,
cnum: CrateNum,
out: &mut FxHashMap<DefPathHash, DefId>
)[src]
pub fn add_def_path_hashes_to(
&self,
cnum: CrateNum,
out: &mut FxHashMap<DefPathHash, DefId>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn size(&self) -> usize[src]
pub fn size(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?