Struct rustc::hir::map::definitions::DisambiguatedDefPathData [−][src]
pub struct DisambiguatedDefPathData {
pub data: DefPathData,
pub disambiguator: u32,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pair of DefPathData and an integer disambiguator. The integer is
normally 0, but in the event that there are multiple defs with the
same parent and data, we use this field to disambiguate
between them. This introduces some artificial ordering dependency
but means that if you have (e.g.) two impls for the same type in
the same module, they do get distinct def-ids.
Fields
data: DefPathData
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
disambiguator: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?