Trait rustc::hir::map::Named [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn name(&self) -> Name
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<T: Named> Named for Spanned<T>[src]
impl<T: Named> Named for Spanned<T>Implementors
impl Named for Itemimpl Named for ForeignItemimpl Named for VariantKindimpl Named for StructFieldimpl Named for TraitItemimpl Named for ImplItem