[−][src]Trait rustc::hir::print::PpAnn
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provided Methods
fn nested(&self, _state: &mut State, _nested: Nested) -> Result<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn try_fetch_item(&self, _: NodeId) -> Option<&Item>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl PpAnn for NoAnn[src]
impl PpAnn for NoAnnfn nested(&self, _state: &mut State, _nested: Nested) -> Result<()>[src]
fn nested(&self, _state: &mut State, _nested: Nested) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn try_fetch_item(&self, _: NodeId) -> Option<&Item>[src]
fn try_fetch_item(&self, _: NodeId) -> Option<&Item>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PpAnn for Crate[src]
impl PpAnn for Cratefn try_fetch_item(&self, item: NodeId) -> Option<&Item>[src]
fn try_fetch_item(&self, item: NodeId) -> Option<&Item>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn nested(&self, state: &mut State, nested: Nested) -> Result<()>[src]
fn nested(&self, state: &mut State, nested: Nested) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'hir> PpAnn for Map<'hir>[src]
impl<'hir> PpAnn for Map<'hir>Identical to the PpAnn implementation for hir::Crate,
except it avoids creating a dependency on the whole crate.
fn nested(&self, state: &mut State, nested: Nested) -> Result<()>[src]
fn nested(&self, state: &mut State, nested: Nested) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn try_fetch_item(&self, _: NodeId) -> Option<&Item>[src]
fn try_fetch_item(&self, _: NodeId) -> Option<&Item>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?