[−]Struct rustc::hir::CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bits: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CodegenFnAttrFlags
impl CodegenFnAttrFlagspub const COLD: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[cold], a hint to LLVM that this function, when called, is never on the hot path
pub const ALLOCATOR: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[allocator], a hint to LLVM that the pointer returned from this function is never null
pub const UNWIND: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[unwind], an indicator that this function may unwind despite what its ABI signature may otherwise imply
pub const RUSTC_ALLOCATOR_NOUNWIND: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[rust_allocator_nounwind], an indicator that an imported FFI function will never unwind. Probably obsolete by recent changes with #[unwind], but hasn't been removed/migrated yet
pub const NAKED: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[naked], indicates to LLVM that no function prologue/epilogue should be generated
pub const NO_MANGLE: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[no_mangle], the function's name should be the same as its symbol
pub const RUSTC_STD_INTERNAL_SYMBOL: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[rustc_std_internal_symbol], and indicator that this symbol is a "weird symbol" for the standard library in that it has slightly different linkage, visibility, and reachability rules.
pub const NO_DEBUG: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[no_debug], indicates that no debugging information should be generated for this function by LLVM
pub const THREAD_LOCAL: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[thread_local], indicates a static is actually a thread local piece of memory
pub const USED: CodegenFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
#[used], indicates that LLVM can't eliminate this function (but the linker can!)
pub fn empty() -> CodegenFnAttrFlags
pub fn empty() -> CodegenFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an empty set of flags.
pub fn all() -> CodegenFnAttrFlags
pub fn all() -> CodegenFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<CodegenFnAttrFlags>
pub fn from_bits(bits: u32) -> Option<CodegenFnAttrFlags>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> CodegenFnAttrFlags
pub fn from_bits_truncate(bits: u32) -> CodegenFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if all flags are currently set.
pub fn intersects(&self, other: CodegenFnAttrFlags) -> bool
pub fn intersects(&self, other: CodegenFnAttrFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: CodegenFnAttrFlags) -> bool
pub fn contains(&self, other: CodegenFnAttrFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CodegenFnAttrFlags)
pub fn insert(&mut self, other: CodegenFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts the specified flags in-place.
pub fn remove(&mut self, other: CodegenFnAttrFlags)
pub fn remove(&mut self, other: CodegenFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes the specified flags in-place.
pub fn toggle(&mut self, other: CodegenFnAttrFlags)
pub fn toggle(&mut self, other: CodegenFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Toggles the specified flags in-place.
pub fn set(&mut self, other: CodegenFnAttrFlags, value: bool)
pub fn set(&mut self, other: CodegenFnAttrFlags, value: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts or removes the specified flags depending on the passed value.