[−][src]Struct rustc::hir::GenericArgs
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
args: HirVec<GenericArg>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The generic arguments for this path segment.
bindings: HirVec<TypeBinding>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Bindings (equality constraints) on associated types, if present.
E.g., Foo<A=Bar>.
parenthesized: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Were arguments written in parenthesized form Fn(T) -> U?
This is required mostly for pretty-printing and diagnostics,
but also for changing lifetime elision rules to be "function-like".
Methods
impl GenericArgs[src]
impl GenericArgspub fn none() -> Self[src]
pub fn none() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn inputs(&self) -> &[Ty][src]
pub fn inputs(&self) -> &[Ty]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn own_counts(&self) -> GenericParamCount[src]
pub fn own_counts(&self) -> GenericParamCount🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?