Struct rustc::hir::ItemLocalId [−][src]
pub struct ItemLocalId(pub u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An ItemLocalId uniquely identifies something within a given "item-like",
that is within a hir::Item, hir::TraitItem, or hir::ImplItem. There is no
guarantee that the numerical value of a given ItemLocalId corresponds to
the node's position within the owning item in any way, but there is a
guarantee that the LocalItemIds within an owner occupy a dense range of
integers starting at zero, so a mapping that maps all or most nodes within
an "item-like" to something else can be implement by a Vec instead of a
tree or hash map.
Methods
impl ItemLocalId[src]
impl ItemLocalIdpub fn as_usize(&self) -> usize[src]
pub fn as_usize(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?