Struct rustc::hir::PolyTraitRef [−][src]
pub struct PolyTraitRef {
pub bound_generic_params: HirVec<GenericParam>,
pub trait_ref: TraitRef,
pub span: Span,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bound_generic_params: HirVec<GenericParam>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The 'a in <'a> Foo<&'a T>
trait_ref: TraitRef
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The Foo<&'a T> in <'a> Foo<&'a T>
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?