Struct rustc::hir::TransFnAttrFlags
[−]
pub struct TransFnAttrFlags { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl TransFnAttrFlags
impl TransFnAttrFlagspub const COLD: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
COLD: TransFnAttrFlags = TransFnAttrFlags{bits: 1,}
pub const ALLOCATOR: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ALLOCATOR: TransFnAttrFlags = TransFnAttrFlags{bits: 2,}
pub const UNWIND: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
UNWIND: TransFnAttrFlags = TransFnAttrFlags{bits: 4,}
pub const RUSTC_ALLOCATOR_NOUNWIND: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
RUSTC_ALLOCATOR_NOUNWIND: TransFnAttrFlags = TransFnAttrFlags{bits: 8,}
pub const NAKED: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NAKED: TransFnAttrFlags = TransFnAttrFlags{bits: 16,}
pub const NO_MANGLE: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NO_MANGLE: TransFnAttrFlags = TransFnAttrFlags{bits: 32,}
pub const RUSTC_STD_INTERNAL_SYMBOL: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
RUSTC_STD_INTERNAL_SYMBOL: TransFnAttrFlags = TransFnAttrFlags{bits: 64,}
pub const NO_DEBUG: TransFnAttrFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NO_DEBUG: TransFnAttrFlags = TransFnAttrFlags{bits: 128,}
pub fn empty() -> TransFnAttrFlags
pub fn empty() -> TransFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an empty set of flags.
pub fn all() -> TransFnAttrFlags
pub fn all() -> TransFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the set containing all flags.
pub fn bits(&self) -> u8
pub fn bits(&self) -> u8🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<TransFnAttrFlags>
pub fn from_bits(bits: u8) -> Option<TransFnAttrFlags>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u8) -> TransFnAttrFlags
pub fn from_bits_truncate(bits: u8) -> TransFnAttrFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if all flags are currently set.
pub fn intersects(&self, other: TransFnAttrFlags) -> bool
pub fn intersects(&self, other: TransFnAttrFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: TransFnAttrFlags) -> bool
pub fn contains(&self, other: TransFnAttrFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: TransFnAttrFlags)
pub fn insert(&mut self, other: TransFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts the specified flags in-place.
pub fn remove(&mut self, other: TransFnAttrFlags)
pub fn remove(&mut self, other: TransFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes the specified flags in-place.
pub fn toggle(&mut self, other: TransFnAttrFlags)
pub fn toggle(&mut self, other: TransFnAttrFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Toggles the specified flags in-place.
pub fn set(&mut self, other: TransFnAttrFlags, value: bool)
pub fn set(&mut self, other: TransFnAttrFlags, value: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts or removes the specified flags depending on the passed value.