Struct rustc::hir::svh::Svh [−][src]
pub struct Svh {
hash: u64,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
hash: u64
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Svh[src]
impl Svhpub fn new(hash: u64) -> Svh[src]
pub fn new(hash: u64) -> Svh🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new Svh given the hash. If you actually want to
compute the SVH from some HIR, you want the calculate_svh
function found in librustc_incremental.
pub fn as_u64(&self) -> u64[src]
pub fn as_u64(&self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_string(&self) -> String[src]
pub fn to_string(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?