Trait rustc::hir::GenericParamsExt [−][src]
pub trait GenericParamsExt {
fn lifetimes<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&LifetimeDef>>;
fn ty_params<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&TyParam>>;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
ⓘImportant traits for FilterMap<I, F>
fn lifetimes<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&LifetimeDef>>
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&LifetimeDef>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for FilterMap<I, F>
fn ty_params<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&TyParam>>
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&TyParam>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl GenericParamsExt for [GenericParam][src]
impl GenericParamsExt for [GenericParam]ⓘImportant traits for FilterMap<I, F>fn lifetimes<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&LifetimeDef>>[src]
ⓘImportant traits for FilterMap<I, F>
fn lifetimes<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&LifetimeDef>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for FilterMap<I, F>fn ty_params<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&TyParam>>[src]
ⓘImportant traits for FilterMap<I, F>
fn ty_params<'a>(
&'a self
) -> FilterMap<Iter<GenericParam>, fn(_: &GenericParam) -> Option<&TyParam>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?