Struct rustc::ich::hcx::BodyResolver [−][src]
struct BodyResolver<'gcx>(&'gcx Crate);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The BodyResolver allows to map a BodyId to the corresponding hir::Body. We could also just store a plain reference to the hir::Crate but we want to avoid that the crate is used to get untracked access to all of the HIR.
Methods
impl<'gcx> BodyResolver<'gcx>[src]
impl<'gcx> BodyResolver<'gcx>fn body(self, id: BodyId) -> &'gcx Body[src]
fn body(self, id: BodyId) -> &'gcx Body🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?