Struct rustc::ich::CachingCodemapView
[−]
[src]
pub struct CachingCodemapView<'cm> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'cm> CachingCodemapView<'cm>[src]
impl<'cm> CachingCodemapView<'cm>pub fn new(codemap: &'cm CodeMap) -> CachingCodemapView<'cm>[src]
pub fn new(codemap: &'cm CodeMap) -> CachingCodemapView<'cm>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn byte_pos_to_line_and_col(
&mut self,
pos: BytePos
) -> Option<(Lrc<FileMap>, usize, BytePos)>[src]
pub fn byte_pos_to_line_and_col(
&mut self,
pos: BytePos
) -> Option<(Lrc<FileMap>, usize, BytePos)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?