Struct rustc::infer::canonical::canonicalizer::CanonicalizeRegionMode [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this flag is true, then all free regions will be replaced with
a canonical var. This is used to make queries as generic as
possible. For example, the query F: Foo<'static> would be
canonicalized to F: Foo<'0>.
Fields
static_region: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
other_free_regions: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CanonicalizeRegionMode[src]
impl CanonicalizeRegionModefn any(&self) -> bool[src]
fn any(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?