Enum rustc::infer::canonical::CanonicalVarKind [−][src]
pub enum CanonicalVarKind {
Ty(CanonicalTyVarKind),
Region,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Describes the "kind" of the canonical variable. This is a "kind" in the type-theory sense of the term -- i.e., a "meta" type system that analyzes type-like values.
Variants
Ty(CanonicalTyVarKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Some kind of type inference variable.
Region🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Region variable '?R.