Enum rustc::infer::canonical::Certainty [−][src]
pub enum Certainty {
Proven,
Ambiguous,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates whether or not we were able to prove the query to be true.
Variants
Proven🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The query is known to be true, presuming that you apply the
given var_values and the region-constraints are satisfied.
Ambiguous🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The query is not known to be true, but also not known to be
false. The var_values represent either values that must
hold in order for the query to be true, or helpful tips that
might make it true. Currently rustc's trait solver cannot
distinguish the two (e.g., due to our preference for where
clauses over impls).
After some unifiations and things have been done, it makes sense to try and prove again -- of course, at that point, the canonical form will be different, making this a distinct query.
Methods
impl Certainty[src]
impl Certaintypub fn is_proven(&self) -> bool[src]
pub fn is_proven(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_ambiguous(&self) -> bool[src]
pub fn is_ambiguous(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?