[−][src]Struct rustc::infer::equate::Equate
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ensures a is made equal to b. Returns a on success.
Fields
fields: &'combine mut CombineFields<'infcx, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
a_is_expected: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'combine, 'infcx, 'gcx, 'tcx> Equate<'combine, 'infcx, 'gcx, 'tcx>[src]
impl<'combine, 'infcx, 'gcx, 'tcx> Equate<'combine, 'infcx, 'gcx, 'tcx>pub fn new(
fields: &'combine mut CombineFields<'infcx, 'gcx, 'tcx>,
a_is_expected: bool
) -> Equate<'combine, 'infcx, 'gcx, 'tcx>[src]
pub fn new(
fields: &'combine mut CombineFields<'infcx, 'gcx, 'tcx>,
a_is_expected: bool
) -> Equate<'combine, 'infcx, 'gcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?