Struct rustc::infer::error_reporting::nice_region_error::NiceRegionError
[−]
[src]
pub struct NiceRegionError<'cx, 'gcx: 'tcx, 'tcx: 'cx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'cx, 'gcx, 'tcx> NiceRegionError<'cx, 'gcx, 'tcx>[src]
impl<'cx, 'gcx, 'tcx> NiceRegionError<'cx, 'gcx, 'tcx>pub fn new(
tcx: TyCtxt<'cx, 'gcx, 'tcx>,
error: RegionResolutionError<'tcx>,
tables: Option<&'cx TypeckTables<'tcx>>
) -> Self[src]
pub fn new(
tcx: TyCtxt<'cx, 'gcx, 'tcx>,
error: RegionResolutionError<'tcx>,
tables: Option<&'cx TypeckTables<'tcx>>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_from_span(
tcx: TyCtxt<'cx, 'gcx, 'tcx>,
span: Span,
sub: Region<'tcx>,
sup: Region<'tcx>,
tables: Option<&'cx TypeckTables<'tcx>>
) -> Self[src]
pub fn new_from_span(
tcx: TyCtxt<'cx, 'gcx, 'tcx>,
span: Span,
sub: Region<'tcx>,
sup: Region<'tcx>,
tables: Option<&'cx TypeckTables<'tcx>>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn try_report(&self) -> Option<ErrorReported>[src]
pub fn try_report(&self) -> Option<ErrorReported>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_regions(&self) -> (Span, Region<'tcx>, Region<'tcx>)[src]
pub fn get_regions(&self) -> (Span, Region<'tcx>, Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?