Struct rustc::infer::lexical_region_resolve::LexicalRegionResolutions [−][src]
pub struct LexicalRegionResolutions<'tcx> {
values: IndexVec<RegionVid, VarValue<'tcx>>,
error_region: Region<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contains the result of lexical region resolution. Offers methods to lookup up the final value of a region variable.
Fields
values: IndexVec<RegionVid, VarValue<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error_region: Region<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> LexicalRegionResolutions<'tcx>[src]
impl<'tcx> LexicalRegionResolutions<'tcx>fn normalize(&self, r: Region<'tcx>) -> Region<'tcx>[src]
fn normalize(&self, r: Region<'tcx>) -> Region<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn value(&self, rid: RegionVid) -> &VarValue<'tcx>[src]
fn value(&self, rid: RegionVid) -> &VarValue<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn value_mut(&mut self, rid: RegionVid) -> &mut VarValue<'tcx>[src]
fn value_mut(&mut self, rid: RegionVid) -> &mut VarValue<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn resolve_var(&self, rid: RegionVid) -> Region<'tcx>[src]
pub fn resolve_var(&self, rid: RegionVid) -> Region<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?