Struct rustc::infer::outlives::free_region_map::FreeRegionMap
[−]
[src]
pub struct FreeRegionMap<'tcx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> FreeRegionMap<'tcx>[src]
impl<'tcx> FreeRegionMap<'tcx>pub fn new() -> Self[src]
pub fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn relate_regions(&mut self, sub: Region<'tcx>, sup: Region<'tcx>)[src]
pub fn relate_regions(&mut self, sub: Region<'tcx>, sup: Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn lub_free_regions<'a, 'gcx>(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
r_a: Region<'tcx>,
r_b: Region<'tcx>
) -> Region<'tcx>[src]
pub fn lub_free_regions<'a, 'gcx>(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
r_a: Region<'tcx>,
r_b: Region<'tcx>
) -> Region<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compute the least-upper-bound of two free regions. In some
cases, this is more conservative than necessary, in order to
avoid making arbitrary choices. See
TransitiveRelation::postdom_upper_bound for more details.