[−][src]Trait rustc::infer::outlives::free_region_map::FreeRegionRelations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The NLL region handling code represents free region relations in a slightly different way; this trait allows functions to be abstract over which version is in use.
Required Methods
fn sub_free_regions(&self, shorter: Region<'tcx>, longer: Region<'tcx>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Tests whether r_a <= r_b. Both must be free regions or
'static.
Implementors
impl<'tcx> FreeRegionRelations<'tcx> for FreeRegionMap<'tcx>[src]
impl<'tcx> FreeRegionRelations<'tcx> for FreeRegionMap<'tcx>fn sub_free_regions(&self, r_a: Region<'tcx>, r_b: Region<'tcx>) -> bool[src]
fn sub_free_regions(&self, r_a: Region<'tcx>, r_b: Region<'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?