[−][src]Enum rustc::infer::region_constraints::Constraint
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A constraint that influences the inference process.
Variants
VarSubVar(RegionVid, RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
One region variable is subregion of another
RegSubVar(Region<'tcx>, RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Concrete region is subregion of region variable
VarSubReg(RegionVid, Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Region variable is subregion of concrete region. This does not directly affect inference, but instead is checked after inference is complete.
RegSubReg(Region<'tcx>, Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A constraint where neither side is a variable. This does not directly affect inference, but instead is checked after inference is complete.