Struct rustc::infer::TypeFreshener [−][src]
pub struct TypeFreshener<'a, 'gcx: 'a + 'tcx, 'tcx: 'a> {
infcx: &'a InferCtxt<'a, 'gcx, 'tcx>,
freshen_count: u32,
freshen_map: FxHashMap<InferTy, Ty<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
infcx: &'a InferCtxt<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
freshen_count: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
freshen_map: FxHashMap<InferTy, Ty<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> TypeFreshener<'a, 'gcx, 'tcx>[src]
impl<'a, 'gcx, 'tcx> TypeFreshener<'a, 'gcx, 'tcx>pub fn new(
infcx: &'a InferCtxt<'a, 'gcx, 'tcx>
) -> TypeFreshener<'a, 'gcx, 'tcx>[src]
pub fn new(
infcx: &'a InferCtxt<'a, 'gcx, 'tcx>
) -> TypeFreshener<'a, 'gcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn freshen<F>(
&mut self,
opt_ty: Option<Ty<'tcx>>,
key: InferTy,
freshener: F
) -> Ty<'tcx> where
F: FnOnce(u32) -> InferTy, [src]
fn freshen<F>(
&mut self,
opt_ty: Option<Ty<'tcx>>,
key: InferTy,
freshener: F
) -> Ty<'tcx> where
F: FnOnce(u32) -> InferTy, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?