Struct rustc::infer::type_variable::Snapshot [−][src]
pub struct Snapshot<'tcx> {
snapshot: Snapshot,
eq_snapshot: Snapshot<InPlace<TyVidEqKey<'tcx>>>,
sub_snapshot: Snapshot<InPlace<TyVid>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
snapshot: Snapshot
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
eq_snapshot: Snapshot<InPlace<TyVidEqKey<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
sub_snapshot: Snapshot<InPlace<TyVid>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?