[−][src]Struct rustc::lint::context::LateContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Context for lint checking after type checking.
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type context we're checking in.
tables: &'a TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Side-tables for the body we are in.
param_env: ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parameter environment for the item we are in.
access_levels: &'a AccessLevels
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Items accessible from the crate being checked.
lint_sess: LintSession<'tcx, LateLintPassObject>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The store of registered lints and the lint levels.
last_ast_node_with_lint_attrs: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
generics: Option<&'tcx Generics>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Generic type parameters in scope for the item we are in.
Methods
impl<'a, 'tcx> LateContext<'a, 'tcx>[src]
impl<'a, 'tcx> LateContext<'a, 'tcx>fn with_param_env<F>(&mut self, id: NodeId, f: F) where
F: FnOnce(&mut Self), [src]
fn with_param_env<F>(&mut self, id: NodeId, f: F) where
F: FnOnce(&mut Self), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn current_lint_root(&self) -> NodeId[src]
pub fn current_lint_root(&self) -> NodeId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?