Struct rustc::lint::context::LintSession [−][src]
pub struct LintSession<'a, PassObject> {
lints: ReadGuard<'a, LintStore>,
passes: Option<Vec<PassObject>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
lints: ReadGuard<'a, LintStore>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Reference to the store of registered lints.
passes: Option<Vec<PassObject>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Trait objects for each lint pass.
Methods
impl<'a, PassObject: LintPassObject> LintSession<'a, PassObject>[src]
impl<'a, PassObject: LintPassObject> LintSession<'a, PassObject>fn new(store: &'a RwLock<LintStore>) -> LintSession<'a, PassObject>[src]
fn new(store: &'a RwLock<LintStore>) -> LintSession<'a, PassObject>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a new LintSession, by moving out the LintStore's initial
lint levels and pass objects. These can be restored using the restore
method.
fn restore(self, store: &RwLock<LintStore>)[src]
fn restore(self, store: &RwLock<LintStore>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Restores the levels back to the original lint store.