Enum rustc::lint::levels::LintSet [−][src]
enum LintSet {
CommandLine {
specs: FxHashMap<LintId, (Level, LintSource)>,
},
Node {
specs: FxHashMap<LintId, (Level, LintSource)>,
parent: u32,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
CommandLine🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of CommandLine
specs: FxHashMap<LintId, (Level, LintSource)> | 🔬 This is a nightly-only experimental API. ( |
Node🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of Node
specs: FxHashMap<LintId, (Level, LintSource)> | 🔬 This is a nightly-only experimental API. ( |
parent: u32 | 🔬 This is a nightly-only experimental API. ( |