[−][src]Struct rustc::lint::LintBuffer
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
map: NodeMap<Vec<BufferedEarlyLint>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LintBuffer[src]
impl LintBufferpub fn new() -> LintBuffer[src]
pub fn new() -> LintBuffer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_lint(
&mut self,
lint: &'static Lint,
id: NodeId,
sp: MultiSpan,
msg: &str,
diagnostic: BuiltinLintDiagnostics
)[src]
pub fn add_lint(
&mut self,
lint: &'static Lint,
id: NodeId,
sp: MultiSpan,
msg: &str,
diagnostic: BuiltinLintDiagnostics
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn take(&mut self, id: NodeId) -> Vec<BufferedEarlyLint>[src]
pub fn take(&mut self, id: NodeId) -> Vec<BufferedEarlyLint>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_any(&self) -> Option<&[BufferedEarlyLint]>[src]
pub fn get_any(&self) -> Option<&[BufferedEarlyLint]>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?