Struct rustc::lint::LintLevelSets
[−]
[src]
pub struct LintLevelSets { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LintLevelSets[src]
impl LintLevelSetspub fn new(sess: &Session) -> LintLevelSets[src]
pub fn new(sess: &Session) -> LintLevelSets🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn builder(sess: &Session) -> LintLevelsBuilder[src]
pub fn builder(sess: &Session) -> LintLevelsBuilder🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?