[−][src]Trait rustc::lint::LateLintPass
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provided Methods
fn check_body(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_body_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_name(&mut self, _: &LateContext<'a, 'tcx>, _: Span, _: Name)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_crate(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_crate_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_mod(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_mod_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_item(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_local(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Local)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_block(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_block_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_stmt(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Stmt)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_arm(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Arm)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_pat(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Pat)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_decl(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Decl)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_ty(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Ty)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_generic_param(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx GenericParam
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx GenericParam
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_generics(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Generics)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_where_predicate(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx WherePredicate
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx WherePredicate
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_poly_trait_ref(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx PolyTraitRef,
_: TraitBoundModifier
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx PolyTraitRef,
_: TraitBoundModifier
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_fn(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_fn_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_trait_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx TraitItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_trait_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx TraitItem
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx TraitItem
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_impl_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_impl_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_def(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_def_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_field(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx StructField
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx StructField
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_variant(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_variant_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_lifetime(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Lifetime)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_path(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Path, _: HirId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_attribute(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Attribute)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn enter_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn exit_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<'a, 'tcx> LateLintPass<'a, 'tcx> for HardwiredLints[src]
impl<'a, 'tcx> LateLintPass<'a, 'tcx> for HardwiredLintsfn check_body(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)[src]
fn check_body(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_body_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)[src]
fn check_body_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Body)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_name(&mut self, _: &LateContext<'a, 'tcx>, _: Span, _: Name)[src]
fn check_name(&mut self, _: &LateContext<'a, 'tcx>, _: Span, _: Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_crate(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)[src]
fn check_crate(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_crate_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)[src]
fn check_crate_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Crate)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_mod(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)[src]
fn check_mod(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_mod_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)[src]
fn check_mod_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Mod,
_: Span,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_item(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)[src]
fn check_foreign_item(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)[src]
fn check_foreign_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx ForeignItem
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)[src]
fn check_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)[src]
fn check_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Item)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_local(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Local)[src]
fn check_local(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Local)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_block(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)[src]
fn check_block(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_block_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)[src]
fn check_block_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Block)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_stmt(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Stmt)[src]
fn check_stmt(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Stmt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_arm(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Arm)[src]
fn check_arm(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Arm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_pat(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Pat)[src]
fn check_pat(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Pat)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_decl(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Decl)[src]
fn check_decl(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Decl)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)[src]
fn check_expr(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)[src]
fn check_expr_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_ty(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Ty)[src]
fn check_ty(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Ty)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_generic_param(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx GenericParam
)[src]
fn check_generic_param(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx GenericParam
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_generics(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Generics)[src]
fn check_generics(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Generics)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_where_predicate(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx WherePredicate
)[src]
fn check_where_predicate(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx WherePredicate
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_poly_trait_ref(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx PolyTraitRef,
_: TraitBoundModifier
)[src]
fn check_poly_trait_ref(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx PolyTraitRef,
_: TraitBoundModifier
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_fn(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)[src]
fn check_fn(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_fn_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)[src]
fn check_fn_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: FnKind<'tcx>,
_: &'tcx FnDecl,
_: &'tcx Body,
_: Span,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_trait_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx TraitItem)[src]
fn check_trait_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx TraitItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_trait_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx TraitItem
)[src]
fn check_trait_item_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx TraitItem
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_impl_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)[src]
fn check_impl_item(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_impl_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)[src]
fn check_impl_item_post(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx ImplItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_def(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)[src]
fn check_struct_def(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_def_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)[src]
fn check_struct_def_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx VariantData,
_: Name,
_: &'tcx Generics,
_: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_struct_field(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx StructField
)[src]
fn check_struct_field(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx StructField
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_variant(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)[src]
fn check_variant(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_variant_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)[src]
fn check_variant_post(
&mut self,
_: &LateContext<'a, 'tcx>,
_: &'tcx Variant,
_: &'tcx Generics
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_lifetime(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Lifetime)[src]
fn check_lifetime(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Lifetime)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_path(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Path, _: HirId)[src]
fn check_path(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Path, _: HirId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_attribute(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Attribute)[src]
fn check_attribute(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn enter_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])[src]
fn enter_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn exit_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])[src]
fn exit_lint_attrs(&mut self, _: &LateContext<'a, 'tcx>, _: &'tcx [Attribute])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?