rustc::lint::LintPassObjectExperimental
[-]
[+]
[src]
type LintPassObject = Box<LintPass + 'static>;
A lint pass boxed up as a trait object.
type LintPassObject = Box<LintPass + 'static>;
A lint pass boxed up as a trait object.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).