Enum rustc::middle::const_val::ConstEvalErrDescription
[−]
[src]
pub enum ConstEvalErrDescription<'a, 'tcx: 'a> {
Simple(Cow<'a, str>),
Backtrace(&'a EvalError<'tcx>, &'a [FrameInfo]),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Simple(Cow<'a, str>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Backtrace(&'a EvalError<'tcx>, &'a [FrameInfo])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> ConstEvalErrDescription<'a, 'tcx>[src]
impl<'a, 'tcx> ConstEvalErrDescription<'a, 'tcx>pub fn into_oneline(self) -> Cow<'a, str>[src]
pub fn into_oneline(self) -> Cow<'a, str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a one-line description of the error, for lints and such