Struct rustc::middle::cstore::ExternCrate
[−]
[src]
pub struct ExternCrate {
pub def_id: DefId,
pub span: Span,
pub direct: bool,
pub path_len: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def_id of an extern crate in the current crate that caused
this crate to be loaded; note that there could be multiple
such ids
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span of the extern crate that caused this to be loaded
direct: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If true, then this crate is the crate named by the extern crate referenced above. If false, then this crate is a dep of the crate.
path_len: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Number of links to reach the extern crate def_id
declaration; used to select the extern crate with the shortest
path