Struct rustc::middle::dataflow::PropagationContext [−][src]
struct PropagationContext<'a, 'b: 'a, 'tcx: 'b, O: 'a> {
dfcx: &'a mut DataFlowContext<'b, 'tcx, O>,
changed: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
dfcx: &'a mut DataFlowContext<'b, 'tcx, O>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
changed: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'b, 'tcx, O: DataFlowOperator> PropagationContext<'a, 'b, 'tcx, O>[src]
impl<'a, 'b, 'tcx, O: DataFlowOperator> PropagationContext<'a, 'b, 'tcx, O>fn walk_cfg(&mut self, cfg: &CFG, nodes_po: &[CFGIndex], in_out: &mut [usize])[src]
fn walk_cfg(&mut self, cfg: &CFG, nodes_po: &[CFGIndex], in_out: &mut [usize])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn reset(&mut self, bits: &mut [usize])[src]
fn reset(&mut self, bits: &mut [usize])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_bits_into_graph_successors_of(
&mut self,
pred_bits: &[usize],
cfg: &CFG,
cfgidx: CFGIndex
)[src]
fn propagate_bits_into_graph_successors_of(
&mut self,
pred_bits: &[usize],
cfg: &CFG,
cfgidx: CFGIndex
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_bits_into_entry_set_for(
&mut self,
pred_bits: &[usize],
edge: &CFGEdge
)[src]
fn propagate_bits_into_entry_set_for(
&mut self,
pred_bits: &[usize],
edge: &CFGEdge
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?