Struct rustc::middle::dead::DeadVisitor [−][src]
struct DeadVisitor<'a, 'tcx: 'a> {
tcx: TyCtxt<'a, 'tcx, 'tcx>,
live_symbols: Box<FxHashSet<NodeId>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
live_symbols: Box<FxHashSet<NodeId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> DeadVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> DeadVisitor<'a, 'tcx>fn should_warn_about_item(&mut self, item: &Item) -> bool[src]
fn should_warn_about_item(&mut self, item: &Item) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_warn_about_field(&mut self, field: &StructField) -> bool[src]
fn should_warn_about_field(&mut self, field: &StructField) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_warn_about_variant(&mut self, variant: &Variant_) -> bool[src]
fn should_warn_about_variant(&mut self, variant: &Variant_) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_warn_about_foreign_item(&mut self, fi: &ForeignItem) -> bool[src]
fn should_warn_about_foreign_item(&mut self, fi: &ForeignItem) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn symbol_is_live(&mut self, id: NodeId, ctor_id: Option<NodeId>) -> bool[src]
fn symbol_is_live(&mut self, id: NodeId, ctor_id: Option<NodeId>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn warn_dead_code(
&mut self,
id: NodeId,
span: Span,
name: Name,
node_type: &str,
participle: &str
)[src]
fn warn_dead_code(
&mut self,
id: NodeId,
span: Span,
name: Name,
node_type: &str,
participle: &str
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?