[−][src]Struct rustc::middle::dead::MarkSymbolVisitor
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
worklist: Vec<NodeId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tables: &'a TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
live_symbols: Box<FxHashSet<NodeId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
repr_has_repr_c: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
in_pat: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
inherited_pub_visibility: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ignore_variant_stack: Vec<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> MarkSymbolVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> MarkSymbolVisitor<'a, 'tcx>fn check_def_id(&mut self, def_id: DefId)[src]
fn check_def_id(&mut self, def_id: DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn insert_def_id(&mut self, def_id: DefId)[src]
fn insert_def_id(&mut self, def_id: DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn handle_definition(&mut self, def: Def)[src]
fn handle_definition(&mut self, def: Def)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lookup_and_handle_method(&mut self, id: HirId)[src]
fn lookup_and_handle_method(&mut self, id: HirId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn handle_field_access(&mut self, lhs: &Expr, node_id: NodeId)[src]
fn handle_field_access(&mut self, lhs: &Expr, node_id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn handle_field_pattern_match(
&mut self,
lhs: &Pat,
def: Def,
pats: &[Spanned<FieldPat>]
)[src]
fn handle_field_pattern_match(
&mut self,
lhs: &Pat,
def: Def,
pats: &[Spanned<FieldPat>]
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mark_live_symbols(&mut self)[src]
fn mark_live_symbols(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_node(&mut self, node: &Node<'tcx>)[src]
fn visit_node(&mut self, node: &Node<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mark_as_used_if_union(&mut self, adt: &AdtDef, fields: &HirVec<Field>)[src]
fn mark_as_used_if_union(&mut self, adt: &AdtDef, fields: &HirVec<Field>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?