Enum rustc::middle::exported_symbols::ExportedSymbol
[−]
[src]
pub enum ExportedSymbol {
NonGeneric(DefId),
NoDefId(SymbolName),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
NonGeneric(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NoDefId(SymbolName)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ExportedSymbol[src]
impl ExportedSymbolpub fn symbol_name(&self, tcx: TyCtxt) -> SymbolName[src]
pub fn symbol_name(&self, tcx: TyCtxt) -> SymbolName🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn compare_stable(&self, tcx: TyCtxt, other: &ExportedSymbol) -> Ordering[src]
pub fn compare_stable(&self, tcx: TyCtxt, other: &ExportedSymbol) -> Ordering🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?