Struct rustc::middle::infer::unify::NodeExperimental
[-]
[+]
[src]
pub struct Node<K, V> {
pub key: K,
pub value: V,
pub rank: uint,
}Internal type used to represent the result of a get() operation.
Conveys the current root and value of the key.
Fields
key | |
value | |
rank |