Struct rustc::middle::infer::unify::SnapshotExperimental
[-]
[+]
[src]
pub struct Snapshot<K> {
// some fields omitted
}At any time, users may snapshot a unification table. The changes made during the snapshot may either be committed or rolled back.