Enum rustc::middle::liveness::LoopKind [−][src]
enum LoopKind<'a> {
LoopLoop,
WhileLoop(&'a Expr),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For use with propagate_through_loop.
Variants
LoopLoop🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An endless loop loop.
WhileLoop(&'a Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A while loop, with the given expression as condition.