Struct rustc::middle::liveness::LiveNode [−][src]
struct LiveNode(usize);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LiveNode[src]
impl LiveNodefn get(&self) -> usize[src]
fn get(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl LiveNode[src]
impl LiveNodefn is_valid(&self) -> bool[src]
fn is_valid(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?