Struct rustc::middle::liveness::Liveness [−][src]
struct Liveness<'a, 'tcx: 'a> {
ir: &'a mut IrMaps<'a, 'tcx>,
tables: &'a TypeckTables<'tcx>,
s: Specials,
successors: Vec<LiveNode>,
users: Vec<Users>,
break_ln: NodeMap<LiveNode>,
cont_ln: NodeMap<LiveNode>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ir: &'a mut IrMaps<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tables: &'a TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
s: Specials
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
successors: Vec<LiveNode>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
users: Vec<Users>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
break_ln: NodeMap<LiveNode>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cont_ln: NodeMap<LiveNode>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> Liveness<'a, 'tcx>[src]
impl<'a, 'tcx> Liveness<'a, 'tcx>fn new(ir: &'a mut IrMaps<'a, 'tcx>, body: BodyId) -> Liveness<'a, 'tcx>[src]
fn new(ir: &'a mut IrMaps<'a, 'tcx>, body: BodyId) -> Liveness<'a, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn live_node(&self, hir_id: HirId, span: Span) -> LiveNode[src]
fn live_node(&self, hir_id: HirId, span: Span) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn variable(&self, hir_id: HirId, span: Span) -> Variable[src]
fn variable(&self, hir_id: HirId, span: Span) -> Variable🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pat_bindings<F>(&mut self, pat: &Pat, f: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, LiveNode, Variable, Span, HirId), [src]
fn pat_bindings<F>(&mut self, pat: &Pat, f: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, LiveNode, Variable, Span, HirId), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn arm_pats_bindings<F>(&mut self, pat: Option<&Pat>, f: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, LiveNode, Variable, Span, HirId), [src]
fn arm_pats_bindings<F>(&mut self, pat: Option<&Pat>, f: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, LiveNode, Variable, Span, HirId), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn define_bindings_in_pat(&mut self, pat: &Pat, succ: LiveNode) -> LiveNode[src]
fn define_bindings_in_pat(&mut self, pat: &Pat, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn define_bindings_in_arm_pats(
&mut self,
pat: Option<&Pat>,
succ: LiveNode
) -> LiveNode[src]
fn define_bindings_in_arm_pats(
&mut self,
pat: Option<&Pat>,
succ: LiveNode
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn idx(&self, ln: LiveNode, var: Variable) -> usize[src]
fn idx(&self, ln: LiveNode, var: Variable) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn live_on_entry(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>[src]
fn live_on_entry(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn live_on_exit(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>[src]
fn live_on_exit(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn used_on_entry(&self, ln: LiveNode, var: Variable) -> bool[src]
fn used_on_entry(&self, ln: LiveNode, var: Variable) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn assigned_on_entry(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>[src]
fn assigned_on_entry(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn assigned_on_exit(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>[src]
fn assigned_on_exit(&self, ln: LiveNode, var: Variable) -> Option<LiveNodeKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn indices2<F>(&mut self, ln: LiveNode, succ_ln: LiveNode, op: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, usize, usize), [src]
fn indices2<F>(&mut self, ln: LiveNode, succ_ln: LiveNode, op: F) where
F: FnMut(&mut Liveness<'a, 'tcx>, usize, usize), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn write_vars<F>(&self, wr: &mut Write, ln: LiveNode, test: F) -> Result<()> where
F: FnMut(usize) -> LiveNode, [src]
fn write_vars<F>(&self, wr: &mut Write, ln: LiveNode, test: F) -> Result<()> where
F: FnMut(usize) -> LiveNode, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn ln_str(&self, ln: LiveNode) -> String[src]
fn ln_str(&self, ln: LiveNode) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn init_empty(&mut self, ln: LiveNode, succ_ln: LiveNode)[src]
fn init_empty(&mut self, ln: LiveNode, succ_ln: LiveNode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn init_from_succ(&mut self, ln: LiveNode, succ_ln: LiveNode)[src]
fn init_from_succ(&mut self, ln: LiveNode, succ_ln: LiveNode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn merge_from_succ(
&mut self,
ln: LiveNode,
succ_ln: LiveNode,
first_merge: bool
) -> bool[src]
fn merge_from_succ(
&mut self,
ln: LiveNode,
succ_ln: LiveNode,
first_merge: bool
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn define(&mut self, writer: LiveNode, var: Variable)[src]
fn define(&mut self, writer: LiveNode, var: Variable)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn acc(&mut self, ln: LiveNode, var: Variable, acc: u32)[src]
fn acc(&mut self, ln: LiveNode, var: Variable, acc: u32)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn compute(&mut self, body: &Expr) -> LiveNode[src]
fn compute(&mut self, body: &Expr) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_block(&mut self, blk: &Block, succ: LiveNode) -> LiveNode[src]
fn propagate_through_block(&mut self, blk: &Block, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_stmt(&mut self, stmt: &Stmt, succ: LiveNode) -> LiveNode[src]
fn propagate_through_stmt(&mut self, stmt: &Stmt, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_decl(&mut self, decl: &Decl, succ: LiveNode) -> LiveNode[src]
fn propagate_through_decl(&mut self, decl: &Decl, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_local(&mut self, local: &Local, succ: LiveNode) -> LiveNode[src]
fn propagate_through_local(&mut self, local: &Local, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_exprs(
&mut self,
exprs: &[Expr],
succ: LiveNode
) -> LiveNode[src]
fn propagate_through_exprs(
&mut self,
exprs: &[Expr],
succ: LiveNode
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_opt_expr(
&mut self,
opt_expr: Option<&Expr>,
succ: LiveNode
) -> LiveNode[src]
fn propagate_through_opt_expr(
&mut self,
opt_expr: Option<&Expr>,
succ: LiveNode
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_expr(&mut self, expr: &Expr, succ: LiveNode) -> LiveNode[src]
fn propagate_through_expr(&mut self, expr: &Expr, succ: LiveNode) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_place_components(
&mut self,
expr: &Expr,
succ: LiveNode
) -> LiveNode[src]
fn propagate_through_place_components(
&mut self,
expr: &Expr,
succ: LiveNode
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn write_place(&mut self, expr: &Expr, succ: LiveNode, acc: u32) -> LiveNode[src]
fn write_place(&mut self, expr: &Expr, succ: LiveNode, acc: u32) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn access_var(
&mut self,
hir_id: HirId,
nid: NodeId,
succ: LiveNode,
acc: u32,
span: Span
) -> LiveNode[src]
fn access_var(
&mut self,
hir_id: HirId,
nid: NodeId,
succ: LiveNode,
acc: u32,
span: Span
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn access_path(
&mut self,
hir_id: HirId,
path: &Path,
succ: LiveNode,
acc: u32
) -> LiveNode[src]
fn access_path(
&mut self,
hir_id: HirId,
path: &Path,
succ: LiveNode,
acc: u32
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate_through_loop(
&mut self,
expr: &Expr,
kind: LoopKind,
body: &Block,
succ: LiveNode
) -> LiveNode[src]
fn propagate_through_loop(
&mut self,
expr: &Expr,
kind: LoopKind,
body: &Block,
succ: LiveNode
) -> LiveNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx> Liveness<'a, 'tcx>[src]
impl<'a, 'tcx> Liveness<'a, 'tcx>fn check_place(&mut self, expr: &'tcx Expr)[src]
fn check_place(&mut self, expr: &'tcx Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_warn(&self, var: Variable) -> Option<String>[src]
fn should_warn(&self, var: Variable) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn warn_about_unused_args(&self, body: &Body, entry_ln: LiveNode)[src]
fn warn_about_unused_args(&self, body: &Body, entry_ln: LiveNode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn warn_about_unused_or_dead_vars_in_pat(&mut self, pat: &Pat)[src]
fn warn_about_unused_or_dead_vars_in_pat(&mut self, pat: &Pat)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn warn_about_unused(
&self,
sp: Span,
hir_id: HirId,
ln: LiveNode,
var: Variable
) -> bool[src]
fn warn_about_unused(
&self,
sp: Span,
hir_id: HirId,
ln: LiveNode,
var: Variable
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn warn_about_dead_assign(
&self,
sp: Span,
hir_id: HirId,
ln: LiveNode,
var: Variable
)[src]
fn warn_about_dead_assign(
&self,
sp: Span,
hir_id: HirId,
ln: LiveNode,
var: Variable
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn report_dead_assign(
&self,
hir_id: HirId,
sp: Span,
var: Variable,
is_argument: bool
)[src]
fn report_dead_assign(
&self,
hir_id: HirId,
sp: Span,
var: Variable,
is_argument: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?