Enum rustc::middle::mem_categorization::InteriorKind
[−]
[src]
pub enum InteriorKind {
InteriorField(FieldName),
InteriorElement(InteriorOffsetKind),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
InteriorField(FieldName)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
InteriorElement(InteriorOffsetKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?