Enum rustc::middle::mem_categorization::MutabilityCategory [−][src]
pub enum MutabilityCategory {
McImmutable,
McDeclared,
McInherited,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
McImmutable🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
McDeclared🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
McInherited🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl MutabilityCategory[src]
impl MutabilityCategorypub fn from_mutbl(m: Mutability) -> MutabilityCategory[src]
pub fn from_mutbl(m: Mutability) -> MutabilityCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_borrow_kind(borrow_kind: BorrowKind) -> MutabilityCategory[src]
pub fn from_borrow_kind(borrow_kind: BorrowKind) -> MutabilityCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn from_pointer_kind(
base_mutbl: MutabilityCategory,
ptr: PointerKind
) -> MutabilityCategory[src]
fn from_pointer_kind(
base_mutbl: MutabilityCategory,
ptr: PointerKind
) -> MutabilityCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn from_local(
tcx: TyCtxt,
tables: &TypeckTables,
id: NodeId
) -> MutabilityCategory[src]
fn from_local(
tcx: TyCtxt,
tables: &TypeckTables,
id: NodeId
) -> MutabilityCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn inherit(&self) -> MutabilityCategory[src]
pub fn inherit(&self) -> MutabilityCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_mutable(&self) -> bool[src]
pub fn is_mutable(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_immutable(&self) -> bool[src]
pub fn is_immutable(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_user_str(&self) -> &'static str[src]
pub fn to_user_str(&self) -> &'static str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?