Struct rustc::middle::mem_categorization::cmt_Experimental
[-]
[+]
[src]
pub struct cmt_<'tcx> {
pub id: NodeId,
pub span: Span,
pub cat: categorization<'tcx>,
pub mutbl: MutabilityCategory,
pub ty: Ty<'tcx>,
pub note: Note,
}Fields
id | |
span | |
cat | |
mutbl | |
ty | |
note |
Methods
impl<'tcx> cmt_<'tcx>
fn guarantor(&self) -> cmt<'tcx>
Returns self after stripping away any owned pointer derefs or
interior content. The return value is basically the cmt which
determines how long the value in self remains live.
fn freely_aliasable(&self, ctxt: &ctxt<'tcx>) -> Option<AliasableReason>
Returns Some(_) if this lvalue represents a freely aliasable pointer type.