Struct rustc::middle::privacy::AccessLevels
[−]
[src]
pub struct AccessLevels<Id = NodeId> { pub map: FxHashMap<Id, AccessLevel>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
map: FxHashMap<Id, AccessLevel>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<Id: Hash + Eq> AccessLevels<Id>[src]
impl<Id: Hash + Eq> AccessLevels<Id>pub fn is_reachable(&self, id: Id) -> bool[src]
pub fn is_reachable(&self, id: Id) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_exported(&self, id: Id) -> bool[src]
pub fn is_exported(&self, id: Id) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_public(&self, id: Id) -> bool[src]
pub fn is_public(&self, id: Id) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?