Struct rustc::middle::region::Context [−][src]
pub struct Context {
root_id: Option<ItemLocalId>,
var_parent: Option<Scope>,
parent: Option<Scope>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
root_id: Option<ItemLocalId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
the root of the current region tree. This is typically the id of the innermost fn body. Each fn forms its own disjoint tree in the region hierarchy. These fn bodies are themselves arranged into a tree. See the "Modeling closures" section of the README in infer::region_constraints for more details.
var_parent: Option<Scope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
the scope that contains any new variables declared
parent: Option<Scope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region parent of expressions etc