Struct rustc::middle::region::RegionResolutionVisitor [−][src]
struct RegionResolutionVisitor<'a, 'tcx: 'a> {
tcx: TyCtxt<'a, 'tcx, 'tcx>,
expr_and_pat_count: usize,
scope_tree: ScopeTree,
cx: Context,
terminating_scopes: FxHashSet<ItemLocalId>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
expr_and_pat_count: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
scope_tree: ScopeTree
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cx: Context
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
terminating_scopes: FxHashSet<ItemLocalId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
terminating_scopes is a set containing the ids of each
statement, or conditional/repeating expression. These scopes
are calling "terminating scopes" because, when attempting to
find the scope of a temporary, by default we search up the
enclosing scopes until we encounter the terminating scope. A
conditional/repeating expression is one which is not
guaranteed to execute exactly once upon entering the parent
scope. This could be because the expression only executes
conditionally, such as the expression b in a && b, or
because the expression may execute many times, such as a loop
body. The reason that we distinguish such expressions is that,
upon exiting the parent scope, we cannot statically know how
many times the expression executed, and thus if the expression
creates temporaries we cannot know statically how many such
temporaries we would have to cleanup. Therefore we ensure that
the temporaries never outlast the conditional/repeating
expression, preventing the need for dynamic checks and/or
arbitrary amounts of stack space. Terminating scopes end
up being contained in a DestructionScope that contains the
destructor's execution.
Methods
impl<'a, 'tcx> RegionResolutionVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> RegionResolutionVisitor<'a, 'tcx>fn record_child_scope(&mut self, child_scope: Scope) -> ScopeDepth[src]
fn record_child_scope(&mut self, child_scope: Scope) -> ScopeDepth🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Records the current parent (if any) as the parent of child_scope.
Returns the depth of child_scope.
fn enter_scope(&mut self, child_scope: Scope)[src]
fn enter_scope(&mut self, child_scope: Scope)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Records the current parent (if any) as the parent of child_scope,
and sets child_scope as the new current parent.
fn enter_node_scope_with_dtor(&mut self, id: ItemLocalId)[src]
fn enter_node_scope_with_dtor(&mut self, id: ItemLocalId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?