Enum rustc::middle::resolve_lifetime::Elide [−][src]
enum Elide {
FreshLateAnon(Cell<u32>),
Exact(Region),
Error(Vec<ElisionFailureInfo>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
FreshLateAnon(Cell<u32>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Use a fresh anonymous late-bound lifetime each time, by incrementing the counter to generate sequential indices.
Exact(Region)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Always use this one lifetime.
Error(Vec<ElisionFailureInfo>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Less or more than one lifetime were found, error on unspecified.