Enum rustc::middle::resolve_lifetime::Set1
[−]
[src]
pub enum Set1<T> {
Empty,
One(T),
Many,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A set containing, at most, one known element.
If two distinct values are inserted into a set, then it
becomes Many, which can be used to detect ambiguities.
Variants
Empty🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
One(T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Many🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: PartialEq> Set1<T>[src]
impl<T: PartialEq> Set1<T>pub fn insert(&mut self, value: T)[src]
pub fn insert(&mut self, value: T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?