Struct rustc::middle::resolve_lifetime::NamedRegionMap [−][src]
struct NamedRegionMap {
pub defs: NodeMap<Region>,
pub late_bound: NodeSet,
pub object_lifetime_defaults: NodeMap<Vec<ObjectLifetimeDefault>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps the id of each lifetime reference to the lifetime decl that it corresponds to.
FIXME. This struct gets converted to a ResolveLifetimes for
actual use. It has the same data, but indexed by DefIndex. This
is silly.
Fields
defs: NodeMap<Region>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
late_bound: NodeSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
object_lifetime_defaults: NodeMap<Vec<ObjectLifetimeDefault>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?