Struct rustc::middle::stability::DeprecationEntry [−][src]
pub struct DeprecationEntry {
pub attr: Deprecation,
origin: Option<HirId>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An entry in the depr_map.
Fields
attr: Deprecation
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The metadata of the attribute associated with this entry.
origin: Option<HirId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The def id where the attr was originally attached. None for non-local
DefId's.
Methods
impl DeprecationEntry[src]
impl DeprecationEntryfn local(attr: Deprecation, id: HirId) -> DeprecationEntry[src]
fn local(attr: Deprecation, id: HirId) -> DeprecationEntry🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn external(attr: Deprecation) -> DeprecationEntry[src]
pub fn external(attr: Deprecation) -> DeprecationEntry🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn same_origin(&self, other: &DeprecationEntry) -> bool[src]
pub fn same_origin(&self, other: &DeprecationEntry) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?