Struct rustc::middle::stability::Index [−][src]
pub struct Index<'tcx> {
stab_map: FxHashMap<HirId, &'tcx Stability>,
depr_map: FxHashMap<HirId, DeprecationEntry>,
staged_api: FxHashMap<CrateNum, bool>,
active_features: FxHashSet<Symbol>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A stability index, giving the stability level for items and methods.
Fields
stab_map: FxHashMap<HirId, &'tcx Stability>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is mostly a cache, except the stabilities of local items are filled by the annotator.
depr_map: FxHashMap<HirId, DeprecationEntry>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
staged_api: FxHashMap<CrateNum, bool>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps for each crate whether it is part of the staged API.
active_features: FxHashSet<Symbol>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Features enabled for this crate.
Methods
impl<'a, 'tcx> Index<'tcx>[src]
impl<'a, 'tcx> Index<'tcx>pub fn new(tcx: TyCtxt<'a, 'tcx, 'tcx>) -> Index<'tcx>[src]
pub fn new(tcx: TyCtxt<'a, 'tcx, 'tcx>) -> Index<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn local_stability(&self, id: HirId) -> Option<&'tcx Stability>[src]
pub fn local_stability(&self, id: HirId) -> Option<&'tcx Stability>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn local_deprecation_entry(&self, id: HirId) -> Option<DeprecationEntry>[src]
pub fn local_deprecation_entry(&self, id: HirId) -> Option<DeprecationEntry>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?