Struct rustc::middle::subst::VecPerParamSpaceExperimental
[-]
[+]
[src]
pub struct VecPerParamSpace<T> {
// some fields omitted
}Vector of things sorted by param space. Used to keep the set of things declared on the type, self, or method distinct.
Methods
impl<T> VecPerParamSpace<T>
fn empty() -> VecPerParamSpace<T>
fn params_from_type(types: Vec<T>) -> VecPerParamSpace<T>
fn new(t: Vec<T>, s: Vec<T>, f: Vec<T>) -> VecPerParamSpace<T>
t is the type space.
s is the self space.
a is the assoc space.
f is the fn space.
fn push(&mut self, space: ParamSpace, value: T)
Appends value to the vector associated with space.
Unlike the push method in Vec, this should not be assumed
to be a cheap operation (even when amortized over many calls).