Struct rustc::middle::ty::CrateAnalysisExperimental
[-]
[+]
[src]
pub struct CrateAnalysis<'tcx> {
pub export_map: ExportMap,
pub exported_items: ExportedItems,
pub public_items: PublicItems,
pub ty_cx: ctxt<'tcx>,
pub reachable: NodeSet,
pub name: String,
pub glob_map: Option<GlobMap>,
}The complete set of all analyses described in this module. This is produced by the driver and fed to trans and later passes.
Fields
export_map | |
exported_items | |
public_items | |
ty_cx | |
reachable | |
name | |
glob_map |