Struct rustc::middle::ty::TransmuteRestrictionExperimental
[-]
[+]
[src]
pub struct TransmuteRestriction<'tcx> {
pub span: Span,
pub original_from: Ty<'tcx>,
pub original_to: Ty<'tcx>,
pub substituted_from: Ty<'tcx>,
pub substituted_to: Ty<'tcx>,
pub id: NodeId,
}A restriction that certain types must be the same size. The use of
transmute gives rise to these restrictions. These generally
cannot be checked until trans; therefore, each call to transmute
will push one or more such restriction into the
transmute_restrictions vector during intrinsicck. They are
then checked during trans by the fn check_intrinsics.