Struct rustc::mir::cache::Cache [−][src]
pub struct Cache {
predecessors: RwLock<Option<IndexVec<BasicBlock, Vec<BasicBlock>>>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
predecessors: RwLock<Option<IndexVec<BasicBlock, Vec<BasicBlock>>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Cache[src]
impl Cachepub fn new() -> Self[src]
pub fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn invalidate(&self)[src]
pub fn invalidate(&self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn predecessors(
&self,
mir: &Mir
) -> ReadGuard<IndexVec<BasicBlock, Vec<BasicBlock>>>[src]
pub fn predecessors(
&self,
mir: &Mir
) -> ReadGuard<IndexVec<BasicBlock, Vec<BasicBlock>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?