Enum rustc::mir::Operand [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
These are values that can appear inside an rvalue (or an index place). They are intentionally limited to prevent rvalues from being nested in one another.
Variants
Copy(Place<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Copy: The value must be available for use afterwards.
This implies that the type of the place must be Copy; this is true
by construction during build, but also checked by the MIR type checker.
Move(Place<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Move: The value (including old borrows of it) will not be used again.
Safe for values of all types (modulo future developments towards ?Move).
Correct usage patterns are enforced by the borrow checker for safe code.
Copy may be converted to Move to enable "last-use" optimizations.
Constant(Box<Constant<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> Operand<'tcx>[src]
impl<'tcx> Operand<'tcx>pub fn ty<'a, 'gcx, D>(
&self,
local_decls: &D,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> Ty<'tcx> where
D: HasLocalDecls<'tcx>, [src]
pub fn ty<'a, 'gcx, D>(
&self,
local_decls: &D,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> Ty<'tcx> where
D: HasLocalDecls<'tcx>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> Operand<'tcx>[src]
impl<'tcx> Operand<'tcx>pub fn function_handle<'a>(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
def_id: DefId,
substs: &'tcx Substs<'tcx>,
span: Span
) -> Self[src]
pub fn function_handle<'a>(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
def_id: DefId,
substs: &'tcx Substs<'tcx>,
span: Span
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_copy(&self) -> Self[src]
pub fn to_copy(&self) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?