[−][src]Enum rustc::mir::Rvalue
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Rvalues
Variants
Use(Operand<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
x (either a move or copy, depending on type of x)
Repeat(Operand<'tcx>, u64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
[x; 32]
Ref(Region<'tcx>, BorrowKind, Place<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
&x or &mut x
Len(Place<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
length of a [X] or [X;n] value
Cast(CastKind, Operand<'tcx>, Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
BinaryOp(BinOp, Operand<'tcx>, Operand<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
CheckedBinaryOp(BinOp, Operand<'tcx>, Operand<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NullaryOp(NullOp, Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
UnaryOp(UnOp, Operand<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Discriminant(Place<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Read the discriminant of an ADT.
Undefined (i.e. no effort is made to make it defined, but there’s no reason why it cannot be defined to return, say, a 0) if ADT is not an enum.
Aggregate(Box<AggregateKind<'tcx>>, Vec<Operand<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an aggregate value, like a tuple or struct. This is
only needed because we want to distinguish dest = Foo { x: ..., y: ... } from dest.x = ...; dest.y = ...; in the case
that Foo has a destructor. These rvalues can be optimized
away after type-checking and before lowering.
Methods
impl<'tcx> Rvalue<'tcx>[src]
impl<'tcx> Rvalue<'tcx>pub fn ty<'a, 'gcx, D>(
&self,
local_decls: &D,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> Ty<'tcx> where
D: HasLocalDecls<'tcx>, [src]
pub fn ty<'a, 'gcx, D>(
&self,
local_decls: &D,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> Ty<'tcx> where
D: HasLocalDecls<'tcx>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn initialization_state(&self) -> RvalueInitializationState[src]
pub fn initialization_state(&self) -> RvalueInitializationState🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns whether this rvalue is deeply initialized (most rvalues) or
whether its only shallowly initialized (Rvalue::Box).