Enum rustc::mir::interpret::ConstValue [−][src]
pub enum ConstValue<'tcx> {
Scalar(Scalar),
ScalarPair(Scalar, Scalar),
ByRef(&'tcx Allocation, Size),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a constant value in Rust. ByVal and ScalarPair are optimizations which matches Value's optimizations for easy conversions between these two types
Variants
Scalar(Scalar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used only for types with layout::abi::Scalar ABI and ZSTs which use Scalar::undef()
ScalarPair(Scalar, Scalar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used only for types with layout::abi::ScalarPair
ByRef(&'tcx Allocation, Size)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used only for the remaining cases. An allocation + offset into the allocation
Methods
impl<'tcx> ConstValue<'tcx>[src]
impl<'tcx> ConstValue<'tcx>pub fn from_byval_value(val: Value) -> Self[src]
pub fn from_byval_value(val: Value) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_byval_value(&self) -> Option<Value>[src]
pub fn to_byval_value(&self) -> Option<Value>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_scalar(val: Scalar) -> Self[src]
pub fn from_scalar(val: Scalar) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar(&self) -> Option<Scalar>[src]
pub fn to_scalar(&self) -> Option<Scalar>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_bits(&self, size: Size) -> Option<u128>[src]
pub fn to_bits(&self, size: Size) -> Option<u128>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr(&self) -> Option<Pointer>[src]
pub fn to_ptr(&self) -> Option<Pointer>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?