Struct rustc::mir::interpret::AllocDecodingState [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
decoding_state: Vec<Mutex<State>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
data_offsets: Vec<u32>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl AllocDecodingState[src]
impl AllocDecodingStatepub fn new_decoding_session(&self) -> AllocDecodingSession[src]
pub fn new_decoding_session(&self) -> AllocDecodingSession🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new(data_offsets: Vec<u32>) -> AllocDecodingState[src]
pub fn new(data_offsets: Vec<u32>) -> AllocDecodingState🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?