Struct rustc::mir::interpret::GlobalId [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Uniquely identifies a specific constant or static.
Fields
instance: Instance<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For a constant or static, the Instance of the item itself.
For a promoted global, the Instance of the function they belong to.
promoted: Option<Promoted>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The index for promoted globals within their function's Mir.