Struct rustc::mir::interpret::Pointer [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
alloc_id: AllocId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
offset: Size
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> Pointer[src]
impl<'tcx> Pointerpub fn new(alloc_id: AllocId, offset: Size) -> Self[src]
pub fn new(alloc_id: AllocId, offset: Size) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn wrapping_signed_offset<C: HasDataLayout>(
self,
i: i64,
cx: C
) -> Self[src]
pub(crate) fn wrapping_signed_offset<C: HasDataLayout>(
self,
i: i64,
cx: C
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn overflowing_signed_offset<C: HasDataLayout>(
self,
i: i128,
cx: C
) -> (Self, bool)[src]
pub fn overflowing_signed_offset<C: HasDataLayout>(
self,
i: i128,
cx: C
) -> (Self, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn signed_offset<C: HasDataLayout>(
self,
i: i64,
cx: C
) -> EvalResult<'tcx, Self>[src]
pub(crate) fn signed_offset<C: HasDataLayout>(
self,
i: i64,
cx: C
) -> EvalResult<'tcx, Self>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn overflowing_offset<C: HasDataLayout>(
self,
i: Size,
cx: C
) -> (Self, bool)[src]
pub fn overflowing_offset<C: HasDataLayout>(
self,
i: Size,
cx: C
) -> (Self, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn offset<C: HasDataLayout>(self, i: Size, cx: C) -> EvalResult<'tcx, Self>[src]
pub fn offset<C: HasDataLayout>(self, i: Size, cx: C) -> EvalResult<'tcx, Self>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?