Struct rustc::mir::interpret::UndefMask
[−]
[src]
pub struct UndefMask { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl UndefMask[src]
impl UndefMaskpub fn new(size: u64) -> Self[src]
pub fn new(size: u64) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_range_defined(&self, start: u64, end: u64) -> bool[src]
pub fn is_range_defined(&self, start: u64, end: u64) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check whether the range start..end (end-exclusive) is entirely defined.
pub fn set_range(&mut self, start: u64, end: u64, new_state: bool)[src]
pub fn set_range(&mut self, start: u64, end: u64, new_state: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_range_inbounds(&mut self, start: u64, end: u64, new_state: bool)[src]
pub fn set_range_inbounds(&mut self, start: u64, end: u64, new_state: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, i: u64) -> bool[src]
pub fn get(&self, i: u64) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set(&mut self, i: u64, new_state: bool)[src]
pub fn set(&mut self, i: u64, new_state: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn grow(&mut self, amount: u64, new_state: bool)[src]
pub fn grow(&mut self, amount: u64, new_state: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?