Enum rustc::mir::interpret::value::Value [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Value represents a single self-contained Rust value.
A Value can either refer to a block of memory inside an allocation (ByRef) or to a primitve
value held directly, outside of any allocation (Scalar). For ByRef-values, we remember
whether the pointer is supposed to be aligned or not (also see Place).
For optimization of a few very common cases, there is also a representation for a pair of
primitive values (ScalarPair). It allows Miri to avoid making allocations for checked binary
operations and fat pointers. This idea was taken from rustc's codegen.
Variants
ByRef(Scalar, Align)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Scalar(Scalar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ScalarPair(Scalar, Scalar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?