Struct rustc::mir::BasicBlock [−]
pub struct BasicBlock(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl BasicBlock[src]
impl BasicBlockpub fn start_location(self) -> Location[src]
pub fn start_location(self) -> Location🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?