Struct rustc::mir::ClosureOutlivesRequirement [−][src]
pub struct ClosureOutlivesRequirement<'tcx> {
pub subject: ClosureOutlivesSubject<'tcx>,
pub outlived_free_region: RegionVid,
pub blame_span: Span,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates an outlives constraint between a type or between two free-regions declared on the closure.
Fields
subject: ClosureOutlivesSubject<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
outlived_free_region: RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
blame_span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?