[−][src]Struct rustc::mir::LocalDecl
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A MIR local.
This can be a binding declared by the user, a temporary inserted by the compiler, a function argument, or the return place.
Fields
mutability: Mutability
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
let mut x vs let x.
Temporaries and the return place are always mutable.
is_user_variable: Option<ClearCrossCrate<BindingForm<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Some(binding_mode) if this corresponds to a user-declared local variable.
This is solely used for local diagnostics when generating
warnings/errors when compiling the current crate, and
therefore it need not be visible across crates. pnkfelix
currently hypothesized we need to wrap this in a
ClearCrossCrate as long as it carries as HirId.
internal: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if this is an internal local
These locals are not based on types in the source code and are only used for a few desugarings at the moment.
The generator transformation will sanity check the locals which are live across a suspension point against the type components of the generator which type checking knows are live across a suspension point. We need to flag drop flags to avoid triggering this check as they are introduced after typeck.
Unsafety checking will also ignore dereferences of these locals, so they can be used for raw pointers only used in a desugaring.
This should be sound because the drop flags are fully algebraic, and therefore don't affect the OIBIT or outlives properties of the generator.
ty: Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type of this local.
user_ty: Option<CanonicalTy<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the user manually ascribed a type to this variable,
e.g. via let x: T, then we carry that type here. The MIR
borrow checker needs this information since it can affect
region inference.
name: Option<Name>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Name of the local, used in debuginfo and pretty-printing.
Note that function arguments can also have this set to Some(_)
to generate better debuginfo.
source_info: SourceInfo
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The syntactic (i.e. not visibility) source scope the local is defined in. If the local was defined in a let-statement, this is within the let-statement, rather than outside of it.
This is needed because the visibility source scope of locals within a let-statement is weird.
The reason is that we want the local to be within the let-statement for lint purposes, but we want the local to be after the let-statement for names-in-scope purposes.
That's it, if we have a let-statement like the one in this function:
fn foo(x: &str) { #[allow(unused_mut)] let mut x: u32 = { // <- one unused mut let mut y: u32 = x.parse().unwrap(); y + 2 }; drop(x); }
Then, from a lint point of view, the declaration of x: u32
(and y: u32) are within the #[allow(unused_mut)] scope - the
lint scopes are the same as the AST/HIR nesting.
However, from a name lookup point of view, the scopes look more like
as if the let-statements were match expressions:
fn foo(x: &str) { match { match x.parse().unwrap() { y => y + 2 } } { x => drop(x) }; }
We care about the name-lookup scopes for debuginfo - if the
debuginfo instruction pointer is at the call to x.parse(), we
want x to refer to x: &str, but if it is at the call to
drop(x), we want it to refer to x: u32.
To allow both uses to work, we need to have more than a single scope
for a local. We have the source_info.scope represent the
"syntactic" lint scope (with a variable being under its let
block) while the visibility_scope represents the "local variable"
scope (where the "rest" of a block is under all prior let-statements).
The end result looks like this:
ROOT SCOPE
│{ argument x: &str }
│
│ │{ #[allow(unused_mut)] } // this is actually split into 2 scopes
│ │ // in practice because I'm lazy.
│ │
│ │← x.source_info.scope
│ │← `x.parse().unwrap()`
│ │
│ │ │← y.source_info.scope
│ │
│ │ │{ let y: u32 }
│ │ │
│ │ │← y.visibility_scope
│ │ │← `y + 2`
│
│ │{ let x: u32 }
│ │← x.visibility_scope
│ │← `drop(x)` // this accesses `x: u32`
visibility_scope: SourceScope
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Source scope within which the local is visible (for debuginfo)
(see source_info for more details).
Methods
impl<'tcx> LocalDecl<'tcx>[src]
impl<'tcx> LocalDecl<'tcx>pub fn can_be_made_mutable(&self) -> bool[src]
pub fn can_be_made_mutable(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true only if local is a binding that can itself be
made mutable via the addition of the mut keyword, namely
something like the occurrences of x in:
fn foo(x: Type) { ... },let x = ...,- or
match ... { C(x) => ... }
pub fn is_nonref_binding(&self) -> bool[src]
pub fn is_nonref_binding(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if local is definitely not a ref ident or
ref mut ident binding. (Such bindings cannot be made into
mutable bindings, but the inverse does not necessarily hold).
pub fn new_temp(ty: Ty<'tcx>, span: Span) -> Self[src]
pub fn new_temp(ty: Ty<'tcx>, span: Span) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new LocalDecl for a temporary.
pub fn new_immutable_temp(ty: Ty<'tcx>, span: Span) -> Self[src]
pub fn new_immutable_temp(ty: Ty<'tcx>, span: Span) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new immutable LocalDecl for a temporary.
pub fn new_internal(ty: Ty<'tcx>, span: Span) -> Self[src]
pub fn new_internal(ty: Ty<'tcx>, span: Span) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new LocalDecl for a internal temporary.
fn new_local(
ty: Ty<'tcx>,
mutability: Mutability,
internal: bool,
span: Span
) -> Self[src]
fn new_local(
ty: Ty<'tcx>,
mutability: Mutability,
internal: bool,
span: Span
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_return_place(return_ty: Ty, span: Span) -> LocalDecl[src]
pub fn new_return_place(return_ty: Ty, span: Span) -> LocalDecl🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Builds a LocalDecl for the return place.
This must be inserted into the local_decls list as the first local.