Struct rustc::mir::Location [−][src]
pub struct Location {
pub block: BasicBlock,
pub statement_index: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
block: BasicBlock
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
the location is within this block
statement_index: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
the location is the start of the statement; or, if statement_index
== num-statements, then the start of the terminator.
Methods
impl Location[src]
impl Locationpub const START: Location
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
START: Location = Location{block: START_BLOCK, statement_index: 0,}
pub fn successor_within_block(&self) -> Location[src]
pub fn successor_within_block(&self) -> Location🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the location immediately after this one within the enclosing block.
Note that if this location represents a terminator, then the resulting location would be out of bounds and invalid.
pub fn dominates(
&self,
other: Location,
dominators: &Dominators<BasicBlock>
) -> bool[src]
pub fn dominates(
&self,
other: Location,
dominators: &Dominators<BasicBlock>
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?