Struct rustc::mir::UnsafetyCheckResult [−][src]
pub struct UnsafetyCheckResult {
pub violations: Lrc<[UnsafetyViolation]>,
pub unsafe_blocks: Lrc<[(NodeId, bool)]>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
violations: Lrc<[UnsafetyViolation]>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Violations that are propagated upwards from this function
unsafe_blocks: Lrc<[(NodeId, bool)]>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unsafe blocks in this function, along with whether they are used. This is used for the "unused_unsafe" lint.