[−][src]Struct rustc::mir::VarBindingForm
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
binding_mode: BindingMode
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Is variable bound via x, mut x, ref x, or ref mut x?
opt_ty_info: Option<Span>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If an explicit type was provided for this variable binding, this holds the source Span of that type.
NOTE: If you want to change this to a HirId, be wary that
doing so breaks incremental compilation (as of this writing),
while a Span does not cause our tests to fail.
opt_match_place: Option<(Option<Place<'tcx>>, Span)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Place of the RHS of the =, or the subject of the match where this
variable is initialized. None in the case of let PATTERN;.
Some((None, ..)) in the case of and let [mut] x = ... because
(a) the right-hand side isn't evaluated as a place expression.
(b) it gives a way to separate this case from the remaining cases
for diagnostics.
pat_span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Span of the pattern in which this variable was bound.