Enum rustc::mir::tcx::PlaceTy [−][src]
pub enum PlaceTy<'tcx> {
Ty {
ty: Ty<'tcx>,
},
Downcast {
adt_def: &'tcx AdtDef,
substs: &'tcx Substs<'tcx>,
variant_index: usize,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Ty🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Normal type.
Fields of Ty
ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
Downcast🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Downcast to a particular variant of an enum.
Fields of Downcast
adt_def: &'tcx AdtDef | 🔬 This is a nightly-only experimental API. ( |
substs: &'tcx Substs<'tcx> | 🔬 This is a nightly-only experimental API. ( |
variant_index: usize | 🔬 This is a nightly-only experimental API. ( |
Methods
impl<'a, 'gcx, 'tcx> PlaceTy<'tcx>[src]
impl<'a, 'gcx, 'tcx> PlaceTy<'tcx>pub fn from_ty(ty: Ty<'tcx>) -> PlaceTy<'tcx>[src]
pub fn from_ty(ty: Ty<'tcx>) -> PlaceTy<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ty(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Ty<'tcx>[src]
pub fn to_ty(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn projection_ty(
self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
elem: &PlaceElem<'tcx>
) -> PlaceTy<'tcx>[src]
pub fn projection_ty(
self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
elem: &PlaceElem<'tcx>
) -> PlaceTy<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?