Enum rustc::mir::visit::TyContext [−][src]
pub enum TyContext {
LocalDecl {
local: Local,
source_info: SourceInfo,
},
ReturnTy(SourceInfo),
YieldTy(SourceInfo),
Location(Location),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extra information passed to visit_ty and friends to give context
about where the type etc appears.
Variants
LocalDecl🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of LocalDecl
local: Local | 🔬 This is a nightly-only experimental API. ( |
source_info: SourceInfo | 🔬 This is a nightly-only experimental API. ( |
ReturnTy(SourceInfo)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The return type of the function.
YieldTy(SourceInfo)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Location(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A type found at some location.