Function miri::alloc_addresses::align_addr
source · fn align_addr(addr: u64, align: u64) -> u64Expand description
Shifts addr to make it aligned with align by rounding addr to the smallest multiple
of align that is larger or equal to addr