Function miri::shims::native_lib::imm_to_carg

source ·
fn imm_to_carg<'tcx>(
    v: ImmTy<'tcx, Provenance>,
    cx: &impl HasDataLayout
) -> InterpResult<'tcx, CArg>
Extract the scalar value from the result of reading a scalar from the machine, and convert it to a CArg.