Trait miri::shims::native_lib::EvalContextExtPriv

source ·
trait EvalContextExtPriv<'mir, 'tcx: 'mir>: MiriInterpCxExt<'mir, 'tcx> {
    // Provided methods
    fn call_native_with_args<'a>(
        &mut self,
        link_name: Symbol,
        dest: &MPlaceTy<'tcx, Provenance>,
        ptr: CodePtr,
        libffi_args: Vec<Arg<'a>>
    ) -> InterpResult<'tcx, ImmTy<'tcx, Provenance>> { ... }
    fn get_func_ptr_explicitly_from_lib(
        &mut self,
        link_name: Symbol
    ) -> Option<CodePtr> { ... }
}

Provided Methods

source

fn call_native_with_args<'a>( &mut self, link_name: Symbol, dest: &MPlaceTy<'tcx, Provenance>, ptr: CodePtr, libffi_args: Vec<Arg<'a>> ) -> InterpResult<'tcx, ImmTy<'tcx, Provenance>>

Call native host function and return the output as an immediate.

source

fn get_func_ptr_explicitly_from_lib( &mut self, link_name: Symbol ) -> Option<CodePtr>

Get the pointer to the function of the specified name in the shared object file, if it exists. The function must be in the shared object file specified: we do not return pointers to functions in dependencies of the library.

Implementors

source

impl<'mir, 'tcx: 'mir> EvalContextExtPriv<'mir, 'tcx> for MiriInterpCx<'mir, 'tcx>