pub struct DirHandler {
streams: FxHashMap<u64, OpenDir>,
next_id: u64,
}Fields
streams: FxHashMap<u64, OpenDir>Directory iterators used to emulate libc “directory streams”, as used in opendir, readdir, and closedir.
When opendir is called, a directory iterator is created on the host for the target directory, and an entry is stored in this hash map, indexed by an ID which represents the directory stream. When readdir is called, the directory stream ID is used to look up the corresponding ReadDir iterator from this map, and information from the next directory entry is returned. When closedir is called, the ReadDir iterator is removed from the map.
next_id: u64ID number to be used by the next call to opendir
Implementations
sourceimpl DirHandler
impl DirHandler
fn insert_new(&mut self, read_dir: ReadDir) -> u64