Struct run_make_support::diff::Diff

source ·
pub struct Diff {
    expected: Option<String>,
    expected_name: Option<String>,
    expected_file: Option<PathBuf>,
    actual: Option<String>,
    actual_name: Option<String>,
    normalizers: Vec<(String, String)>,
    drop_bomb: DropBomb,
}

Fields

expected: Option<String>expected_name: Option<String>expected_file: Option<PathBuf>actual: Option<String>actual_name: Option<String>normalizers: Vec<(String, String)>drop_bomb: DropBomb

Implementations

source

impl Diff

source

pub fn new() -> Self

Construct a bare diff invocation.

source

pub fn expected_file<P: AsRef<Path>>(&mut self, path: P) -> &mut Self

Specify the expected output for the diff from a file.

source

pub fn expected_text<T: AsRef<[u8]>>( &mut self, name: &str, text: T, ) -> &mut Self

Specify the expected output for the diff from a given text string.

source

pub fn actual_file<P: AsRef<Path>>(&mut self, path: P) -> &mut Self

Specify the actual output for the diff from a file.

source

pub fn actual_text<T: AsRef<[u8]>>(&mut self, name: &str, text: T) -> &mut Self

Specify the actual output for the diff from a given text string.

source

pub fn normalize<R: Into<String>, I: Into<String>>( &mut self, regex: R, replacement: I, ) -> &mut Self

Specify a regex that should replace text in the “actual” text that will be compared.

source

fn run_common(&self) -> (&str, &str, String, String)

source

pub fn run(&mut self)

source

pub fn run_fail(&mut self)