pub fn get_windows_path<P: AsRef<Path>>(path: P) -> String
Use cygpath -w on a path to get a Windows path string back. This assumes that cygpath is available on the platform!

FIXME

FIXME(jieyouxu): we should consider not depending on cygpath.

The cygpath program is a utility that converts Windows native filenames to Cygwin POSIX-style pathnames and vice versa.

[irrelevant entries omitted…]

-w, --windows print Windows form of NAMEs (C:\WINNT)

from cygpath documentation.