Function run_make_support::external_deps::python::python_command
source · pub fn python_command() -> CommandExpand description
Obtain path of python as provided by the PYTHON environment variable. It is up to the caller
to document and check if the python version is compatible with its intended usage.