Function run_make_support::cygpath_windows

source ·
pub fn cygpath_windows<P: AsRef<Path>>(path: P) -> String
Use cygpath -w on a path to get a Windows path string back. This assumes that cygpath is available on the platform!