Function run_make_support::dynamic_lib_name
source · pub fn dynamic_lib_name(name: &str) -> StringExpand description
Construct the dynamic library name based on the platform.
pub fn dynamic_lib_name(name: &str) -> StringConstruct the dynamic library name based on the platform.