Function run_make_support::has_extension
source · pub fn has_extension<P: AsRef<Path>>(path: P, extension: &str) -> boolExpand description
Returns true if the filename at path has the extension extension.
pub fn has_extension<P: AsRef<Path>>(path: P, extension: &str) -> boolReturns true if the filename at path has the extension extension.