Function run_make_support::has_prefix
source · pub fn has_prefix<P: AsRef<Path>>(path: P, prefix: &str) -> boolExpand description
Returns true if the filename at path starts with prefix.
pub fn has_prefix<P: AsRef<Path>>(path: P, prefix: &str) -> boolReturns true if the filename at path starts with prefix.