Function run_make_support::invalid_utf8_not_contains

source ·
pub fn invalid_utf8_not_contains<P: AsRef<Path>>(path: P, expected: &str)
Read the contents of a file that cannot simply be read by read_to_string, due to invalid utf8 data, then assert that it does not contain expected.