Function run_make_support::set_host_rpath
source · pub fn set_host_rpath(cmd: &mut Command)Expand description
Set the runtime library path as needed for running the host rustc/rustdoc/etc.
pub fn set_host_rpath(cmd: &mut Command)Set the runtime library path as needed for running the host rustc/rustdoc/etc.