Function run_make_support::static_lib_name
source · pub fn static_lib_name(name: &str) -> StringExpand description
Construct the static library name based on the platform.
pub fn static_lib_name(name: &str) -> StringConstruct the static library name based on the platform.