Function run_make_support::test_while_readonly

source ·
pub fn test_while_readonly<P: AsRef<Path>, F: FnOnce() + UnwindSafe>(
    path: P,
    closure: F,
)
Ensure that the path P is read-only while the test runs, and restore original permissions at the end so compiletest can clean up. This will panic on Windows if the path is a directory (as it would otherwise do nothing)