Function run_make_support::fs_wrapper::copy
source · pub fn copy<P: AsRef<Path>, Q: AsRef<Path>>(from: P, to: Q)Expand description
A wrapper around std::fs::copy which includes the file path in the panic message.
pub fn copy<P: AsRef<Path>, Q: AsRef<Path>>(from: P, to: Q)A wrapper around std::fs::copy which includes the file path in the panic message.