Function run_make_support::fs_wrapper::create_dir
source · pub fn create_dir<P: AsRef<Path>>(path: P)Expand description
A wrapper around std::fs::create_dir which includes the file path in the panic message.
pub fn create_dir<P: AsRef<Path>>(path: P)A wrapper around std::fs::create_dir which includes the file path in the panic message.