Function run_make_support::fs_wrapper::metadata
source · pub fn metadata<P: AsRef<Path>>(path: P) -> MetadataExpand description
A wrapper around std::fs::metadata which includes the file path in the panic message.
pub fn metadata<P: AsRef<Path>>(path: P) -> MetadataA wrapper around std::fs::metadata which includes the file path in the panic message.