Function run_make_support::fs_wrapper::remove_file
source · pub fn remove_file<P: AsRef<Path>>(path: P)Expand description
A wrapper around std::fs::remove_file which includes the file path in the panic message.
pub fn remove_file<P: AsRef<Path>>(path: P)A wrapper around std::fs::remove_file which includes the file path in the panic message.