Function run_make_support::fs_wrapper::write
source · pub fn write<P: AsRef<Path>, C: AsRef<[u8]>>(path: P, contents: C)Expand description
A wrapper around std::fs::write which includes the file path in the panic message.
pub fn write<P: AsRef<Path>, C: AsRef<[u8]>>(path: P, contents: C)A wrapper around std::fs::write which includes the file path in the panic message.