Function run_make_support::run::run
source · pub fn run(name: &str) -> CompletedProcessExpand description
Run a built binary and make sure it succeeds.
pub fn run(name: &str) -> CompletedProcessRun a built binary and make sure it succeeds.