Enum rustc_ast::token::NonterminalKind
source · pub enum NonterminalKind {
Show 15 variants
Item,
Block,
Stmt,
PatParam {
inferred: bool,
},
PatWithOr,
Expr,
Expr2021,
Ty,
Ident,
Lifetime,
Literal,
Meta,
Path,
Vis,
TT,
}Variants
Item
Block
Stmt
PatParam
Fields
PatWithOr
Expr
Expr2021
Matches an expression using the rules from edition 2021 and earlier.
Ty
Ident
Lifetime
Literal
Meta
Path
Vis
TT
Implementations
sourceimpl NonterminalKind
impl NonterminalKind
sourcepub fn from_symbol(
symbol: Symbol,
edition: impl FnOnce() -> Edition
) -> Option<NonterminalKind>
pub fn from_symbol( symbol: Symbol, edition: impl FnOnce() -> Edition ) -> Option<NonterminalKind>
The edition closure is used to get the edition for the given symbol. Doing
span.edition() is expensive, so we do it lazily.
fn symbol(self) -> Symbol