enum FutureKind {
    Future,
    AsyncIterator,
}
Used by LoweringContext::make_lowered_await to customize the desugaring based on what kind of future we are awaiting.

Variants



Future

We are awaiting a normal future



AsyncIterator

We are awaiting something that’s known to be an AsyncIterator (i.e. we are in the header of a for await loop)