struct PoloniusOutOfScopePrecomputer<'mir, 'tcx> {
    visited: BitSet<BasicBlock>,
    visit_stack: Vec<BasicBlock>,
    body: &'mir Body<'tcx>,
    regioncx: &'mir RegionInferenceContext<'tcx>,
    loans_out_of_scope_at_location: FxIndexMap<Location, Vec<BorrowIndex>>,
}

Fields

visited: BitSet<BasicBlock>visit_stack: Vec<BasicBlock>body: &'mir Body<'tcx>regioncx: &'mir RegionInferenceContext<'tcx>loans_out_of_scope_at_location: FxIndexMap<Location, Vec<BorrowIndex>>

Implementations

source

impl<'mir, 'tcx> PoloniusOutOfScopePrecomputer<'mir, 'tcx>

source

fn new( body: &'mir Body<'tcx>, regioncx: &'mir RegionInferenceContext<'tcx> ) -> Self

source

impl<'tcx> PoloniusOutOfScopePrecomputer<'_, 'tcx>

source

fn precompute_loans_out_of_scope( &mut self, loan_idx: BorrowIndex, issuing_region: RegionVid, loan_issued_at: Location )

Loans are in scope while they are live: whether they are contained within any live region. In the location-insensitive analysis, a loan will be contained in a region if the issuing region can reach it in the subset graph. So this is a reachability problem.

source

fn loan_kill_location( &self, loan_idx: BorrowIndex, loan_issued_at: Location, block: BasicBlock, start: usize, end: usize ) -> Option<Location>

Returns the lowest statement in start..=end, where the loan goes out of scope, if any. This is the statement where the issuing region can’t reach any of the regions that are live at this point.