pub(crate) struct RegionErrors<'tcx>(Vec<RegionErrorKind<'tcx>>, TyCtxt<'tcx>);
A collection of errors encountered during region inference. This is needed to efficiently report errors after borrow checking.

Usually we expect this to either be empty or contain a small number of items, so we can avoid allocation most of the time.

Tuple Fields

0: Vec<RegionErrorKind<'tcx>>1: TyCtxt<'tcx>

Implementations

source

impl<'tcx> RegionErrors<'tcx>

source

pub fn new(tcx: TyCtxt<'tcx>) -> Self

source

pub fn push(&mut self, val: impl Into<RegionErrorKind<'tcx>>)

source

pub fn is_empty(&self) -> bool

source

pub fn into_iter(self) -> impl Iterator<Item = RegionErrorKind<'tcx>>