pub(crate) struct RegionName {
    pub(crate) name: Symbol,
    pub(crate) source: RegionNameSource,
}
A name for a particular region used in emitting diagnostics. This name could be a generated name like '1, a name used by the user like 'a, or a name like 'static.

Fields

name: Symbol

The name of the region (interned).

source: RegionNameSource

Where the region comes from.

Implementations

source

impl RegionName

source

pub(crate) fn was_named(&self) -> bool

source

pub(crate) fn span(&self) -> Option<Span>

source

pub(crate) fn highlight_region_name(&self, diag: &mut Diagnostic)