Struct rustc_borrowck::polonius::loan_kills::LoanKillsGenerator
source · struct LoanKillsGenerator<'cx, 'tcx> {
tcx: TyCtxt<'tcx>,
all_facts: &'cx mut AllFacts,
location_table: &'cx LocationTable,
borrow_set: &'cx BorrowSet<'tcx>,
body: &'cx Body<'tcx>,
}Fields
tcx: TyCtxt<'tcx>all_facts: &'cx mut AllFactslocation_table: &'cx LocationTableborrow_set: &'cx BorrowSet<'tcx>body: &'cx Body<'tcx>Implementations
sourceimpl<'tcx> LoanKillsGenerator<'_, 'tcx>
impl<'tcx> LoanKillsGenerator<'_, 'tcx>
sourcefn record_killed_borrows_for_place(
&mut self,
place: Place<'tcx>,
location: Location
)
fn record_killed_borrows_for_place( &mut self, place: Place<'tcx>, location: Location )
Records the borrows on the specified place as killed. For example, when assigning to a
local, or on a call’s return destination.
sourcefn record_killed_borrows_for_local(&mut self, local: Local, location: Location)
fn record_killed_borrows_for_local(&mut self, local: Local, location: Location)
Records the borrows on the specified local as killed.