localize_terminator_constraint

Function localize_terminator_constraint 

fn localize_terminator_constraint<'tcx>(
    tcx: TyCtxt<'tcx>,
    body: &Body<'tcx>,
    terminator: &Terminator<'tcx>,
    liveness: &LivenessValues,
    outlives_constraint: &OutlivesConstraint<'tcx>,
    current_point: PointIndex,
    universal_regions: &UniversalRegions<'tcx>,
) -> LocalizedOutlivesConstraint
For a given outlives constraint arising from a MIR terminator, localize the constraint with the needed CFG from-to inter-block nodes.