add_concrete_opaque_type

Function add_concrete_opaque_type 

fn add_concrete_opaque_type<'tcx>(
    tcx: TyCtxt<'tcx>,
    concrete_opaque_types: &mut ConcreteOpaqueTypes<'tcx>,
    def_id: LocalDefId,
    hidden_ty: OpaqueHiddenType<'tcx>,
)
Collect all defining uses of opaque types inside of this typeck root. This expects the hidden type to be mapped to the definition parameters of the opaque and errors if we end up with distinct hidden types.