struct LiveVariablesVisitor<'cx, 'tcx> {
    tcx: TyCtxt<'tcx>,
    liveness_constraints: &'cx mut LivenessValues,
}
Visitor looking for regions that should be live within rvalues or calls.

Fields

tcx: TyCtxt<'tcx>liveness_constraints: &'cx mut LivenessValues

Implementations

source

impl<'cx, 'tcx> LiveVariablesVisitor<'cx, 'tcx>

source

fn record_regions_live_at<T>(&mut self, value: T, location: Location)
where T: TypeVisitable<TyCtxt<'tcx>>,

Some variable is “regular live” at location – i.e., it may be used later. This means that all regions appearing in the type of value must be live at location.