struct ConstrainOpaqueTypeRegionVisitor<'tcx, OP: FnMut(Region<'tcx>)> {
tcx: TyCtxt<'tcx>,
op: OP,
}Expand description
Visitor that requires that (almost) all regions in the type visited outlive
least_region. We cannot use push_outlives_components because regions in
closure signatures are not included in their outlives components. We need to
ensure all regions outlive the given bound so that we don’t end up with,
say, ReVar appearing in a return type and causing ICEs when other
functions end up with region constraints involving regions from other
functions.
We also cannot use for_each_free_region because for closures it includes
the regions parameters from the enclosing item.
We ignore any type parameters because impl trait values are assumed to capture all the in-scope type parameters.
Fields
tcx: TyCtxt<'tcx>op: OPTrait Implementations
Sourceimpl<'tcx, OP> TypeVisitor<TyCtxt<'tcx>> for ConstrainOpaqueTypeRegionVisitor<'tcx, OP>
impl<'tcx, OP> TypeVisitor<TyCtxt<'tcx>> for ConstrainOpaqueTypeRegionVisitor<'tcx, OP>
fn visit_region(&mut self, r: Region<'tcx>)
fn visit_ty(&mut self, ty: Ty<'tcx>)
type Result = ()
fn visit_binder<T>(&mut self, t: &Binder<I, T>) -> Self::Resultwhere
T: TypeVisitable<I>,
fn visit_const(&mut self, c: <I as Interner>::Const) -> Self::Result
fn visit_predicate(&mut self, p: <I as Interner>::Predicate) -> Self::Result
fn visit_clauses(&mut self, c: <I as Interner>::Clauses) -> Self::Result
fn visit_error( &mut self, _guar: <I as Interner>::ErrorGuaranteed, ) -> Self::Result