pub struct BlockOrExpr(ThinVec<Stmt>, Option<P<Expr>>);
The code snippets built up for derived code are sometimes used as blocks (e.g. in a function body) and sometimes used as expressions (e.g. in a match arm). This structure avoids committing to either form until necessary, avoiding the insertion of any unnecessary blocks.

The statements come before the expression.

Tuple Fields

0: ThinVec<Stmt>1: Option<P<Expr>>

Implementations

source

impl BlockOrExpr

source

pub fn new_stmts(stmts: ThinVec<Stmt>) -> BlockOrExpr

source

pub fn new_expr(expr: P<Expr>) -> BlockOrExpr

source

pub fn new_mixed(stmts: ThinVec<Stmt>, expr: Option<P<Expr>>) -> BlockOrExpr

source

fn into_block(self, cx: &ExtCtxt<'_>, span: Span) -> P<Block>

source

fn into_expr(self, cx: &ExtCtxt<'_>, span: Span) -> P<Expr>