pub struct FieldInfo {
    pub span: Span,
    pub name: Option<Ident>,
    pub self_expr: P<Expr>,
    pub other_selflike_exprs: Vec<P<Expr>>,
}
Summary of the relevant parts of a struct/enum field.

Fields

span: Spanname: Option<Ident>

None for tuple structs/normal enum variants, Some for normal structs/struct enum variants.

self_expr: P<Expr>

The expression corresponding to this field of self (specifically, a reference to it).

other_selflike_exprs: Vec<P<Expr>>

The expressions corresponding to references to this field in the other selflike arguments.