struct MacroInput {
    fmtstr: P<Expr>,
    args: FormatArguments,
    is_direct_literal: bool,
}

Fields

fmtstr: P<Expr>args: FormatArgumentsis_direct_literal: bool

Whether the first argument was a string literal or a result from eager macro expansion. If it’s not a string literal, we disallow implicit argument capturing.

This does not correspond to whether we can treat spans to the literal normally, as the whole invocation might be the result of another macro expansion, in which case this flag may still be true.

See RFC 2795 for more information.