Struct rustc_codegen_llvm::coverageinfo::map_data::ZeroExpressions
source · struct ZeroExpressions(FxIndexSet<ExpressionId>);Expand description
Set of expression IDs that are known to always evaluate to zero. Any mapping or expression operand that refers to these expressions can have that reference replaced with a constant zero value.
Tuple Fields
0: FxIndexSet<ExpressionId>Implementations
sourceimpl ZeroExpressions
impl ZeroExpressions
fn insert(&mut self, id: ExpressionId)
fn contains(&self, id: ExpressionId) -> bool