pub struct ArchiveRO {
    pub raw: &'static mut Archive,
}

Fields

raw: &'static mut Archive

Implementations

source

impl ArchiveRO

source

pub fn open(dst: &Path) -> Result<ArchiveRO, String>

Opens a static archive for read-only purposes. This is more optimized than the open method because it uses LLVM’s internal Archive class rather than shelling out to ar for everything.

If this archive is used with a mutable method, then an error will be raised.

source

pub fn iter(&self) -> Iter<'_>