enum LocalRef<'tcx, V> {
    Place(PlaceRef<'tcx, V>),
    UnsizedPlace(PlaceRef<'tcx, V>),
    Operand(OperandRef<'tcx, V>),
    PendingOperand,
}

Variants



Place(PlaceRef<'tcx, V>)



UnsizedPlace(PlaceRef<'tcx, V>)

UnsizedPlace(p): p itself is a thin pointer (indirect place). *p is the fat pointer that references the actual unsized place. Every time it is initialized, we have to reallocate the place and update the fat pointer. That’s the reason why it is indirect.



Operand(OperandRef<'tcx, V>)

The backend OperandValue has already been generated.



PendingOperand

Will be a Self::Operand once we get to its definition.

Implementations

source

impl<'tcx, V: CodegenObject> LocalRef<'tcx, V>

source

fn new_operand(layout: TyAndLayout<'tcx>) -> LocalRef<'tcx, V>