pub(super) enum LocalValue<Prov: Provenance = CtfeProvenance> {
Dead,
Live(Operand<Prov>),
}Expand description
Current value of a local variable
This does not store the type of the local; the type is given by body.local_decls and can never
change, so by not storing here we avoid having to maintain that as an invariant.
Variants
Dead
This local is not currently alive, and cannot be used at all.
Live(Operand<Prov>)
A normal, live local.
Mostly for convenience, we re-use the Operand type here.
This is an optimization over just always having a pointer here;
we can thus avoid doing an allocation when the local just stores
immediate values and never has its address taken.