pub struct ArrayIterator<'tcx, 'a, Prov: Provenance, P: Projectable<'tcx, Prov>> {
    base: &'a P,
    range: Range<u64>,
    stride: Size,
    field_layout: TyAndLayout<'tcx>,
    _phantom: PhantomData<Prov>,
}
A type representing iteration over the elements of an array.

Fields

base: &'a Prange: Range<u64>stride: Sizefield_layout: TyAndLayout<'tcx>_phantom: PhantomData<Prov>

Implementations

source

impl<'tcx, 'a, Prov: Provenance, P: Projectable<'tcx, Prov>> ArrayIterator<'tcx, 'a, Prov, P>

source

pub fn next<'mir, M: Machine<'mir, 'tcx, Provenance = Prov>>( &mut self, ecx: &InterpCx<'mir, 'tcx, M> ) -> InterpResult<'tcx, Option<(u64, P)>>

Should be the same ecx on each call, and match the one used to create the iterator.