Struct rustc_data_structures::sync::OneThread
source · pub struct OneThread<T> {
thread: ThreadId,
inner: T,
}Expand description
A type which only allows its inner value to be used in one thread. It will panic if it is used on multiple threads.
Fields
thread: ThreadIdinner: TImplementations