struct Expander {
    shell_argfiles: bool,
    next_is_unstable_option: bool,
    expanded: Vec<String>,
}
Expands argfiles in command line arguments.

Fields

shell_argfiles: boolnext_is_unstable_option: boolexpanded: Vec<String>

Implementations

source

impl Expander

source

fn arg(&mut self, arg: &str) -> Result<(), Error>

Handles the next argument. If the argument is an argfile, it is expanded inline.

source

fn push(&mut self, arg: String)

Adds a command line argument verbatim with no argfile expansion.

source

fn finish(self) -> Vec<String>

Consumes the Expander, returning the expanded arguments.

source

fn inspect_unstable_option(&mut self, option: &str)

Parses any relevant unstable flags specified on the command line.

source

fn read_file(path: &str) -> Result<String, Error>

Reads the contents of a file as UTF-8.