pub(crate) struct DiagCtxtInner {
Show 20 fields pub(crate) flags: DiagCtxtFlags, pub(crate) err_guars: Vec<ErrorGuaranteed>, pub(crate) lint_err_guars: Vec<ErrorGuaranteed>, pub(crate) delayed_bugs: Vec<(DelayedDiagnostic, ErrorGuaranteed)>, pub(crate) good_path_delayed_bugs: Vec<DelayedDiagnostic>, pub(crate) stashed_err_count: usize, pub(crate) deduplicated_err_count: usize, pub(crate) deduplicated_warn_count: usize, pub(crate) has_printed: bool, pub(crate) emitter: Box<DynEmitter>, pub(crate) suppressed_expected_diag: bool, pub(crate) taught_diagnostics: FxHashSet<ErrCode>, pub(crate) emitted_diagnostic_codes: FxIndexSet<ErrCode>, pub(crate) emitted_diagnostics: FxHashSet<Hash128>, pub(crate) stashed_diagnostics: FxIndexMap<(Span, StashKey), Diagnostic>, pub(crate) future_breakage_diagnostics: Vec<Diagnostic>, pub(crate) check_unstable_expect_diagnostics: bool, pub(crate) unstable_expect_diagnostics: Vec<Diagnostic>, pub(crate) fulfilled_expectations: FxHashSet<LintExpectationId>, pub(crate) ice_file: Option<PathBuf>,
}
This inner struct exists to keep it all behind a single lock; this is done to prevent possible deadlocks in a multi-threaded compiler, as well as inconsistent state observation.

Fields

flags: DiagCtxtFlagserr_guars: Vec<ErrorGuaranteed>

The error guarantees from all emitted errors. The length gives the error count.

lint_err_guars: Vec<ErrorGuaranteed>

The error guarantee from all emitted lint errors. The length gives the lint error count.

delayed_bugs: Vec<(DelayedDiagnostic, ErrorGuaranteed)>

The delayed bugs and their error guarantees.

good_path_delayed_bugs: Vec<DelayedDiagnostic>stashed_err_count: usize

The number of stashed errors. Unlike the other counts, this can go up and down, so it doesn’t guarantee anything.

deduplicated_err_count: usize

The error count shown to the user at the end.

deduplicated_warn_count: usize

The warning count shown to the user at the end.

has_printed: bool

Has this diagnostic context printed any diagnostics? (I.e. has self.emitter.emit_diagnostic() been called?

emitter: Box<DynEmitter>suppressed_expected_diag: bool

This flag indicates that an expected diagnostic was emitted and suppressed. This is used for the good_path_delayed_bugs check.

taught_diagnostics: FxHashSet<ErrCode>

This set contains the code of all emitted diagnostics to avoid emitting the same diagnostic with extended help (--teach) twice, which would be unnecessary repetition.

emitted_diagnostic_codes: FxIndexSet<ErrCode>

Used to suggest rustc –explain <error code>

emitted_diagnostics: FxHashSet<Hash128>

This set contains a hash of every diagnostic that has been emitted by this DiagCtxt. These hashes is used to avoid emitting the same error twice.

stashed_diagnostics: FxIndexMap<(Span, StashKey), Diagnostic>

Stashed diagnostics emitted in one stage of the compiler that may be stolen by other stages (e.g. to improve them and add more information). The stashed diagnostics count towards the total error count. When .abort_if_errors() is called, these are also emitted.

future_breakage_diagnostics: Vec<Diagnostic>check_unstable_expect_diagnostics: bool

The Self::unstable_expect_diagnostics should be empty when this struct is dropped. However, it can have values if the compilation is stopped early or is only partially executed. To avoid ICEs, like in rust#94953 we only check if Self::unstable_expect_diagnostics is empty, if the expectation ids have been converted.

unstable_expect_diagnostics: Vec<Diagnostic>

Expected Diagnostics store a LintExpectationId as part of the lint level. LintExpectationIds created early during the compilation (before HirIds have been defined) are not stable and can therefore not be stored on disk. This buffer stores these diagnostics until the ID has been replaced by a stable LintExpectationId. The Diagnostics are the submitted for storage and added to the list of fulfilled expectations.

fulfilled_expectations: FxHashSet<LintExpectationId>

expected diagnostic will have the level Expect which additionally carries the LintExpectationId of the expectation that can be marked as fulfilled. This is a collection of all LintExpectationIds that have been marked as fulfilled this way.

ice_file: Option<PathBuf>

The file where the ICE information is stored. This allows delayed_span_bug backtraces to be stored along side the main panic backtrace.

Implementations

source

impl DiagCtxtInner

source

pub(crate) fn emit_stashed_diagnostics(&mut self)

Emit all stashed diagnostics.

source

pub(crate) fn emit_diagnostic( &mut self, diagnostic: Diagnostic ) -> Option<ErrorGuaranteed>

source

pub(crate) fn treat_err_as_bug(&self) -> bool

source

pub(crate) fn treat_next_err_as_bug(&self) -> bool

source

pub(crate) fn has_errors(&self) -> Option<ErrorGuaranteed>

source

pub(crate) fn has_errors_or_lint_errors(&self) -> Option<ErrorGuaranteed>

source

pub(crate) fn has_errors_or_lint_errors_or_delayed_bugs( &self ) -> Option<ErrorGuaranteed>

source

pub(crate) fn failure_note(&mut self, msg: impl Into<DiagnosticMessage>)

source

pub(crate) fn flush_delayed(&mut self, kind: DelayedBugKind)

source

pub(crate) fn panic_if_treat_err_as_bug(&self)