Struct rustc_errors::ErrorGuaranteed
source · pub struct ErrorGuaranteed(pub(crate) ());Expand description
Useful type to use with Result<> indicate that an error has already
been reported to the user, so no need to continue checking.
The () field is necessary: it is non-pub, which means values of this
type cannot be constructed outside of this crate.
Tuple Fields
0: ()Trait Implementations
sourceimpl EmissionGuarantee for ErrorGuaranteed
impl EmissionGuarantee for ErrorGuaranteed
sourcefn emit_producing_guarantee(db: DiagnosticBuilder<'_, Self>) -> Self::EmitResult
fn emit_producing_guarantee(db: DiagnosticBuilder<'_, Self>) -> Self::EmitResult
Implementation of
DiagnosticBuilder::emit, fully controlled by each
impl of EmissionGuarantee, to make it impossible to create a value
of Self::EmitResult without actually performing the emission.type EmitResult = Self
type EmitResult = Self
This exists so that bugs and fatal errors can both result in
! (an
abort) when emitted, but have different aborting behaviour.Auto Trait Implementations
impl RefUnwindSafe for ErrorGuaranteed
impl Send for ErrorGuaranteed
impl Sync for ErrorGuaranteed
impl Unpin for ErrorGuaranteed
impl UnwindSafe for ErrorGuaranteed