struct MacroState<'a> {
    binders: &'a FxHashMap<MacroRulesNormalizedIdent, BinderInfo>,
    ops: SmallVec<[KleeneToken; 1]>,
}
The state at which we entered a macro definition in the RHS of another macro definition.

Fields

binders: &'a FxHashMap<MacroRulesNormalizedIdent, BinderInfo>

The binders of the branch where we entered the macro definition.

ops: SmallVec<[KleeneToken; 1]>

The stack of Kleene operators (outermost first) where we entered the macro definition.