pub enum CoroutineSource {
    Block,
    Closure,
    Fn,
}
In the case of a coroutine created as part of an async/gen construct, which kind of async/gen construct caused it to be created?

This helps error messages but is also used to drive coercions in type-checking (see #60424).

Variants



Block

An explicit async/gen block written by the user.



Closure

An explicit async/gen closure written by the user.



Fn

The async/gen block generated as the body of an async/gen function.