struct GATSubstCollector<'tcx> {
    gat: DefId,
    regions: FxHashSet<(Region<'tcx>, usize)>,
    types: FxHashSet<(Ty<'tcx>, usize)>,
}
TypeVisitor that looks for uses of GATs like <P0 as Trait<P1..Pn>>::GAT<Pn..Pm> and adds the arguments P0..Pm into the two vectors, regions and types (depending on their kind). For each parameter Pi also track the index i.

Fields

gat: DefIdregions: FxHashSet<(Region<'tcx>, usize)>types: FxHashSet<(Ty<'tcx>, usize)>

Implementations

source

impl<'tcx> GATSubstCollector<'tcx>

source

fn visit<T: TypeFoldable<TyCtxt<'tcx>>>( gat: DefId, t: T ) -> (FxHashSet<(Region<'tcx>, usize)>, FxHashSet<(Ty<'tcx>, usize)>)