struct FieldUniquenessCheckContext<'tcx> {
    tcx: TyCtxt<'tcx>,
    seen_fields: FxHashMap<Ident, FieldDeclSpan>,
}

Fields

tcx: TyCtxt<'tcx>seen_fields: FxHashMap<Ident, FieldDeclSpan>

Implementations

source

impl<'tcx> FieldUniquenessCheckContext<'tcx>

source

fn new(tcx: TyCtxt<'tcx>) -> Self

source

fn check_field_decl(&mut self, ident: Ident, field_decl: FieldDeclSpan)

Check if a given field ident declared at field_decl has been declared elsewhere before.

source

fn check_field_in_nested_adt( &mut self, adt_def: AdtDef<'_>, unnamed_field_span: Span )

Check the uniqueness of fields across adt where there are nested fields imported from an unnamed field.

source

fn check_field(&mut self, field: &FieldDef<'_>)

Check the uniqueness of fields in a struct variant, and recursively check the nested fields if it is an unnamed field with type of an annoymous adt.