pub enum CastError {
Show 15 variants ErrorGuaranteed(ErrorGuaranteed), CastToBool, CastToChar, DifferingKinds, SizedUnsizedCast, IllegalCast, NeedDeref, NeedViaPtr, NeedViaThinPtr, NeedViaInt, NonScalar, UnknownExprPtrKind, UnknownCastPtrKind, IntToFatCast(Option<&'static str>), ForeignNonExhaustiveAdt,
}

Variants



ErrorGuaranteed(ErrorGuaranteed)



CastToBool



CastToChar



DifferingKinds



SizedUnsizedCast

Cast of thin to fat raw ptr (e.g., *const () as *const [u8]).



IllegalCast



NeedDeref



NeedViaPtr



NeedViaThinPtr



NeedViaInt



NonScalar



UnknownExprPtrKind



UnknownCastPtrKind



IntToFatCast(Option<&'static str>)

Cast of int to (possibly) fat raw pointer.

Argument is the specific name of the metadata in plain words, such as “a vtable” or “a length”. If this argument is None, then the metadata is unknown, for example, when we’re typechecking a type parameter with a ?Sized bound.



ForeignNonExhaustiveAdt