struct ClosureSignatures<'tcx> {
    bound_sig: PolyFnSig<'tcx>,
    liberated_sig: FnSig<'tcx>,
}

Fields

bound_sig: PolyFnSig<'tcx>

The signature users of the closure see.

liberated_sig: FnSig<'tcx>

The signature within the function body. This mostly differs in the sense that lifetimes are now early bound and any opaque types from the signature expectation are overridden in case there are explicit hidden types written by the user in the closure signature.