Struct rustc_hir_typeck::expr_use_visitor::PlaceWithHirId
source · pub struct PlaceWithHirId<'tcx> {
pub hir_id: HirId,
pub place: Place<'tcx>,
}Expand description
A PlaceWithHirId represents how a value is located in memory.
This is an HIR version of rustc_middle::mir::Place.
Fields
hir_id: HirIdHirId of the expression or pattern producing this value.
place: Place<'tcx>Information about the Place.