enum BinOpCategory {
    Shortcircuit,
    Shift,
    Math,
    Bitwise,
    Comparison,
}

Variants



Shortcircuit

&&, || – cannot be overridden



Shift

<<, >> – when shifting a single integer, rhs can be any integer type. For simd, types must match.



Math

+, -, etc – takes equal types, produces same type as input, applicable to ints/floats/simd



Bitwise

&, |, ^ – takes equal types, produces same type as input, applicable to ints/floats/simd/bool



Comparison

==, !=, etc – takes equal types, produces bools, except for simd, which produce the input type

Implementations