Function rustc_hir_typeck::upvar::drop_location_span
source · fn drop_location_span(tcx: TyCtxt<'_>, hir_id: HirId) -> SpanExpand description
Returns the Span of where the value with the provided HirId would be dropped
fn drop_location_span(tcx: TyCtxt<'_>, hir_id: HirId) -> SpanReturns the Span of where the value with the provided HirId would be dropped