pub enum ProbeStep<I>where
I: Interner,{
AddGoal(GoalSource, Canonical<I, State<I, Goal<I, <I as Interner>::Predicate>>>),
EvaluateGoals(AddedGoalsEvaluation<I>),
NestedProbe(Probe<I>),
RecordImplArgs {
impl_args: Canonical<I, State<I, <I as Interner>::GenericArgs>>,
},
MakeCanonicalResponse {
shallow_certainty: Certainty,
},
}Variants
AddGoal(GoalSource, Canonical<I, State<I, Goal<I, <I as Interner>::Predicate>>>)
We added a goal to the EvalCtxt which will get proven
the next time EvalCtxt::try_evaluate_added_goals is called.
EvaluateGoals(AddedGoalsEvaluation<I>)
The inside of a EvalCtxt::try_evaluate_added_goals call.
NestedProbe(Probe<I>)
A call to probe while proving the current goal. This is
used whenever there are multiple candidates to prove the
current goalby .
RecordImplArgs
A trait goal was satisfied by an impl candidate.
Fields
impl_args: Canonical<I, State<I, <I as Interner>::GenericArgs>>MakeCanonicalResponse
A call to EvalCtxt::evaluate_added_goals_make_canonical_response with
Certainty was made. This is the certainty passed in, so it’s not unified
with the certainty of the try_evaluate_added_goals that is done within;
if it’s Certainty::Yes, then we can trust that the candidate is “finished”
and we didn’t force ambiguity for some reason.