pub enum TyOrConstInferVar {
    Ty(TyVid),
    TyInt(IntVid),
    TyFloat(FloatVid),
    Const(ConstVid),
    Effect(EffectVid),
}
Helper for InferCtxt::ty_or_const_infer_var_changed (see comment on that), currently used only for traits::fulfill’s list of stalled_on inference variables.

Variants



Ty(TyVid)

Equivalent to ty::Infer(ty::TyVar(_)).



TyInt(IntVid)

Equivalent to ty::Infer(ty::IntVar(_)).



TyFloat(FloatVid)

Equivalent to ty::Infer(ty::FloatVar(_)).



Const(ConstVid)

Equivalent to ty::ConstKind::Infer(ty::InferConst::Var(_)).



Effect(EffectVid)

Equivalent to ty::ConstKind::Infer(ty::InferConst::EffectVar(_)).

Implementations

source

impl<'tcx> TyOrConstInferVar

source

pub fn maybe_from_generic_arg(arg: GenericArg<'tcx>) -> Option<Self>

Tries to extract an inference variable from a type or a constant, returns None for types other than ty::Infer(_) (or InferTy::Fresh*) and for constants other than ty::ConstKind::Infer(_) (or InferConst::Fresh).

source

fn maybe_from_ty(ty: Ty<'tcx>) -> Option<Self>

Tries to extract an inference variable from a type, returns None for types other than ty::Infer(_) (or InferTy::Fresh*).

source

fn maybe_from_const(ct: Const<'tcx>) -> Option<Self>

Tries to extract an inference variable from a constant, returns None for constants other than ty::ConstKind::Infer(_) (or InferConst::Fresh).