pub enum TyCategory {
    Closure,
    Opaque,
    OpaqueFuture,
    Coroutine(CoroutineKind),
    Foreign,
}
This is a bare signal of what kind of type we’re dealing with. ty::TyKind tracks extra information about each type, but we only care about the category.

Variants



Closure



Opaque



OpaqueFuture



Coroutine(CoroutineKind)



Foreign

Implementations

source

impl TyCategory

source

pub fn from_ty(tcx: TyCtxt<'_>, ty: Ty<'_>) -> Option<(Self, DefId)>