pub struct AnonymousParamInfo<'tcx> {
    pub param: &'tcx Param<'tcx>,
    pub param_ty: Ty<'tcx>,
    pub bound_region: BoundRegionKind,
    pub param_ty_span: Span,
    pub is_first: bool,
}
Information about the anonymous region we are searching for.

Fields

param: &'tcx Param<'tcx>

The parameter corresponding to the anonymous region.

param_ty: Ty<'tcx>

The type corresponding to the anonymous region parameter.

bound_region: BoundRegionKind

The ty::BoundRegionKind corresponding to the anonymous region.

param_ty_span: Span

The Span of the parameter type.

is_first: bool

Signals that the argument is the first parameter in the declaration.