pub enum MaybeCause {
    Ambiguity,
    Overflow,
}
Why we failed to evaluate a goal.

Variants



Ambiguity

We failed due to ambiguity. This ambiguity can either be a true ambiguity, i.e. there are multiple different answers, or we hit a case where we just don’t bother, e.g. ?x: Trait goals.



Overflow

We gave up due to an overflow, most often by hitting the recursion limit.