Struct rustc_infer::traits::util::Elaborator
source · pub struct Elaborator<'tcx, O> {
stack: Vec<O>,
visited: PredicateSet<'tcx>,
mode: Filter,
}Expand description
“Elaboration” is the process of identifying all the predicates that
are implied by a source predicate. Currently, this basically means
walking the “supertraits” and other similar assumptions. For example,
if we know that T: Ord, the elaborator would deduce that T: PartialOrd
holds as well. Similarly, if we have trait Foo: 'static, and we know that
T: Foo, then we know that T: 'static.
Fields
stack: Vec<O>visited: PredicateSet<'tcx>mode: FilterImplementations
sourceimpl<'tcx, O: Elaboratable<'tcx>> Elaborator<'tcx, O>
impl<'tcx, O: Elaboratable<'tcx>> Elaborator<'tcx, O>
fn extend_deduped(&mut self, obligations: impl IntoIterator<Item = O>)
sourcepub fn filter_only_self(self) -> Self
pub fn filter_only_self(self) -> Self
Filter to only the supertraits of trait predicates, i.e. only the predicates
that have Self as their self type, instead of all implied predicates.
sourcepub fn filter_only_self_that_defines(self, assoc_ty: Ident) -> Self
pub fn filter_only_self_that_defines(self, assoc_ty: Ident) -> Self
Filter to only the supertraits of trait predicates that define the assoc_ty.
fn elaborate(&mut self, elaboratable: &O)
sourceimpl<'tcx> Elaborator<'tcx, Predicate<'tcx>>
impl<'tcx> Elaborator<'tcx, Predicate<'tcx>>
fn filter_to_traits(self) -> FilterToTraits<Self> ⓘ