fn track_diagnostic(diagnostic: Diagnostic, f: &mut dyn FnMut(Diagnostic))
This is a callback from rustc_errors as it cannot access the implicit state in rustc_middle otherwise. It is used when diagnostic messages are emitted and stores them in the current query, if there is one.