pub type Value<'tcx> = CoerceUnsizedInfo;

Aliased Type

struct Value<'tcx> {
    pub custom_kind: Option<CustomCoerceUnsized>,
}

Fields

custom_kind: Option<CustomCoerceUnsized>

If this is a “custom coerce” impl, then what kind of custom coercion is it? This applies to impls of CoerceUnsized for structs, primarily, where we store a bit of info about which fields need to be coerced.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 4 bytes