pub struct RegionFolder<'a, 'tcx> {
    tcx: TyCtxt<'tcx>,
    current_index: DebruijnIndex,
    fold_region_fn: &'a mut (dyn FnMut(Region<'tcx>, DebruijnIndex) -> Region<'tcx> + 'a),
}
Folds over the substructure of a type, visiting its component types and all regions that occur free within it.

That is, function pointer types and trait object can introduce new bound regions which are not visited by this visitors as they are not free; only regions that occur free will be visited by fld_r.

Fields

tcx: TyCtxt<'tcx>current_index: DebruijnIndex

Stores the index of a binder just outside the stuff we have visited. So this begins as INNERMOST; when we pass through a binder, it is incremented (via shift_in).

fold_region_fn: &'a mut (dyn FnMut(Region<'tcx>, DebruijnIndex) -> Region<'tcx> + 'a)

Callback invokes for each free region. The DebruijnIndex points to the binder just outside the ones we have passed through.

Implementations

source

impl<'a, 'tcx> RegionFolder<'a, 'tcx>

source

pub fn new( tcx: TyCtxt<'tcx>, fold_region_fn: &'a mut dyn FnMut(Region<'tcx>, DebruijnIndex) -> Region<'tcx> ) -> RegionFolder<'a, 'tcx>