struct ParseCtxt<'tcx, 'body> {
    tcx: TyCtxt<'tcx>,
    param_env: ParamEnv<'tcx>,
    thir: &'body Thir<'tcx>,
    source_scope: SourceScope,
    body: &'body mut Body<'tcx>,
    local_map: FxHashMap<LocalVarId, Local>,
    block_map: FxHashMap<LocalVarId, BasicBlock>,
}

Fields

tcx: TyCtxt<'tcx>param_env: ParamEnv<'tcx>thir: &'body Thir<'tcx>source_scope: SourceScopebody: &'body mut Body<'tcx>local_map: FxHashMap<LocalVarId, Local>block_map: FxHashMap<LocalVarId, BasicBlock>

Implementations

source

impl<'tcx, 'body> ParseCtxt<'tcx, 'body>

source

impl<'tcx, 'body> ParseCtxt<'tcx, 'body>

source

fn preparse(&self, expr_id: ExprId) -> ExprId

Expressions should only ever be matched on after preparsing them. This removes extra scopes we don’t care about.

source

fn statement_as_expr(&self, stmt_id: StmtId) -> Result<ExprId, ParseError>

source

pub fn parse_args( &mut self, params: &IndexSlice<ParamId, Param<'tcx>> ) -> Result<(), ParseError>

source

pub fn parse_body(&mut self, expr_id: ExprId) -> Result<(), ParseError>

Bodies are of the form:

{
    let bb1: BasicBlock;
    let bb2: BasicBlock;
    {
        let RET: _;
        let local1;
        let local2;

        {
            { // entry block
                statement1;
                terminator1
            };

            bb1 = {
                statement2;
                terminator2
            };

            bb2 = {
                statement3;
                terminator3
            }

            RET
        }
    }
}

This allows us to easily parse the basic blocks declarations, local declarations, and basic block definitions in order.

source

fn parse_block_decls( &mut self, stmts: impl Iterator<Item = StmtId> ) -> Result<(), ParseError>

source

fn parse_basic_block_decl(&mut self, stmt: StmtId) -> Result<(), ParseError>

source

fn parse_local_decls( &mut self, stmts: impl Iterator<Item = StmtId> ) -> Result<(), ParseError>

source

fn parse_debuginfo( &mut self, stmts: impl Iterator<Item = StmtId> ) -> Result<(), ParseError>

source

fn parse_let_statement( &mut self, stmt_id: StmtId ) -> Result<(LocalVarId, Ty<'tcx>, Span), ParseError>

source

fn parse_var( &mut self, pat: &Pat<'tcx> ) -> Result<(LocalVarId, Ty<'tcx>, Span), ParseError>

source

fn parse_block_def( &self, expr_id: ExprId, is_cleanup: bool ) -> Result<BasicBlockData<'tcx>, ParseError>

source

impl<'tcx, 'body> ParseCtxt<'tcx, 'body>

source

fn expr_error(&self, expr: ExprId, expected: &'static str) -> ParseError

source

fn stmt_error(&self, stmt: StmtId, expected: &'static str) -> ParseError