Struct rustc_mir_build::build::CFG

source ·
struct CFG<'tcx> {
    basic_blocks: IndexVec<BasicBlock, BasicBlockData<'tcx>>,
}

Fields

basic_blocks: IndexVec<BasicBlock, BasicBlockData<'tcx>>

Implementations

source

impl<'tcx> CFG<'tcx>

source

pub(crate) fn block_data(&self, blk: BasicBlock) -> &BasicBlockData<'tcx>

source

pub(crate) fn block_data_mut( &mut self, blk: BasicBlock ) -> &mut BasicBlockData<'tcx>

source

pub(crate) fn start_new_block(&mut self) -> BasicBlock

source

pub(crate) fn start_new_cleanup_block(&mut self) -> BasicBlock

source

pub(crate) fn push(&mut self, block: BasicBlock, statement: Statement<'tcx>)

source

pub(crate) fn push_assign( &mut self, block: BasicBlock, source_info: SourceInfo, place: Place<'tcx>, rvalue: Rvalue<'tcx> )

source

pub(crate) fn push_assign_constant( &mut self, block: BasicBlock, source_info: SourceInfo, temp: Place<'tcx>, constant: ConstOperand<'tcx> )

source

pub(crate) fn push_assign_unit( &mut self, block: BasicBlock, source_info: SourceInfo, place: Place<'tcx>, tcx: TyCtxt<'tcx> )

source

pub(crate) fn push_fake_read( &mut self, block: BasicBlock, source_info: SourceInfo, cause: FakeReadCause, place: Place<'tcx> )

source

pub(crate) fn push_place_mention( &mut self, block: BasicBlock, source_info: SourceInfo, place: Place<'tcx> )

source

pub(crate) fn push_coverage_span_marker( &mut self, block: BasicBlock, source_info: SourceInfo )

Adds a dummy statement whose only role is to associate a span with its enclosing block for the purposes of coverage instrumentation.

This results in more accurate coverage reports for certain kinds of syntax (e.g. continue or if !) that would otherwise not appear in MIR.

source

pub(crate) fn terminate( &mut self, block: BasicBlock, source_info: SourceInfo, kind: TerminatorKind<'tcx> )

source

pub(crate) fn goto( &mut self, origin: BasicBlock, source_info: SourceInfo, target: BasicBlock )

In the origin block, push a goto -> target terminator.