struct RustcMirAttrs {
    basename_and_suffix: Option<PathBuf>,
    formatter: Option<Symbol>,
}

Fields

basename_and_suffix: Option<PathBuf>formatter: Option<Symbol>

Implementations

source

impl RustcMirAttrs

source

fn parse(tcx: TyCtxt<'_>, def_id: DefId) -> Result<Self, ()>

source

fn set_field<T>( field: &mut Option<T>, tcx: TyCtxt<'_>, attr: &NestedMetaItem, mapper: impl FnOnce(Symbol) -> Result<T, ()> ) -> Result<(), ()>

source

fn output_path(&self, analysis_name: &str) -> Option<PathBuf>

Returns the path where dataflow results should be written, or None borrowck_graphviz_postflow was not specified.

This performs the following transformation to the argument of borrowck_graphviz_postflow:

“path/suffix.dot” -> “path/analysis_name_suffix.dot”