pub struct MaybeBorrowedLocals;
A dataflow analysis that tracks whether a pointer or reference could possibly exist that points to a given local. This analysis ignores fake borrows, so it should not be used by borrowck.

At present, this is used as a very limited form of alias analysis. For example, MaybeBorrowedLocals is used to compute which locals are live during a yield expression for immovable coroutines.

Implementations

source

impl MaybeBorrowedLocals

source

pub(super) fn transfer_function<'a, T>( &'a self, trans: &'a mut T ) -> TransferFunction<'a, T>