pub struct MaybeRequiresStorage<'mir, 'tcx> {
    borrowed_locals: ResultsCursor<'mir, 'tcx, MaybeBorrowedLocals>,
}
Dataflow analysis that determines whether each local requires storage at a given location; i.e. whether its storage can go away without being observed.

Fields

borrowed_locals: ResultsCursor<'mir, 'tcx, MaybeBorrowedLocals>

Implementations

source

impl<'mir, 'tcx> MaybeRequiresStorage<'mir, 'tcx>

source

pub fn new( borrowed_locals: ResultsCursor<'mir, 'tcx, MaybeBorrowedLocals> ) -> Self

source

impl<'tcx> MaybeRequiresStorage<'_, 'tcx>

source

fn check_for_move(&mut self, trans: &mut impl GenKill<Local>, loc: Location)

Kill locals that are fully moved and have not been borrowed.