pub struct DenseLocationMap {
    statements_before_block: IndexVec<BasicBlock, usize>,
    basic_blocks: IndexVec<PointIndex, BasicBlock>,
    num_points: usize,
}
Maps between a Location and a PointIndex (and vice versa).

Fields

statements_before_block: IndexVec<BasicBlock, usize>

For each basic block, how many points are contained within?

basic_blocks: IndexVec<PointIndex, BasicBlock>

Map backward from each point to the basic block that it belongs to.

num_points: usize

Implementations

source

impl DenseLocationMap

source

pub fn new(body: &Body<'_>) -> Self

source

pub fn num_points(&self) -> usize

Total number of point indices

source

pub fn point_from_location(&self, location: Location) -> PointIndex

Converts a Location into a PointIndex. O(1).

source

pub fn entry_point(&self, block: BasicBlock) -> PointIndex

Returns the PointIndex for the first statement in the given BasicBlock. O(1).

source

pub fn to_block_start(&self, index: PointIndex) -> PointIndex

Return the PointIndex for the block start of this index.

source

pub fn to_location(&self, index: PointIndex) -> Location

Converts a PointIndex back to a location. O(1).

source

pub fn point_in_range(&self, index: PointIndex) -> bool

Sometimes we get point-indices back from bitsets that may be out of range (because they round up to the nearest 2^N number of bits). Use this function to filter such points out if you like.