Struct rustc_mir_dataflow::points::Visitor
source · struct Visitor<'a, N: Idx> {
elements: &'a DenseLocationMap,
values: SparseIntervalMatrix<N, PointIndex>,
}Fields
elements: &'a DenseLocationMapvalues: SparseIntervalMatrix<N, PointIndex>Trait Implementations
sourceimpl<'mir, 'tcx, R, N> ResultsVisitor<'mir, 'tcx, R> for Visitor<'_, N>where
N: Idx,
impl<'mir, 'tcx, R, N> ResultsVisitor<'mir, 'tcx, R> for Visitor<'_, N>where
N: Idx,
type FlowState = BitSet<N>
sourcefn visit_statement_after_primary_effect(
&mut self,
_results: &mut R,
state: &Self::FlowState,
_statement: &'mir Statement<'tcx>,
location: Location
)
fn visit_statement_after_primary_effect( &mut self, _results: &mut R, state: &Self::FlowState, _statement: &'mir Statement<'tcx>, location: Location )
Called with both the
before_statement_effect and the statement_effect of the given
statement applied to state.sourcefn visit_terminator_after_primary_effect(
&mut self,
_results: &mut R,
state: &Self::FlowState,
_terminator: &'mir Terminator<'tcx>,
location: Location
)
fn visit_terminator_after_primary_effect( &mut self, _results: &mut R, state: &Self::FlowState, _terminator: &'mir Terminator<'tcx>, location: Location )
Called with both the
before_terminator_effect and the terminator_effect of the given
terminator applied to state. Read morefn visit_block_start(&mut self, _state: &Self::FlowState)
sourcefn visit_statement_before_primary_effect(
&mut self,
_results: &mut R,
_state: &Self::FlowState,
_statement: &'mir Statement<'tcx>,
_location: Location
)
fn visit_statement_before_primary_effect( &mut self, _results: &mut R, _state: &Self::FlowState, _statement: &'mir Statement<'tcx>, _location: Location )
Called with the
before_statement_effect of the given statement applied to state but not
its statement_effect.sourcefn visit_terminator_before_primary_effect(
&mut self,
_results: &mut R,
_state: &Self::FlowState,
_terminator: &'mir Terminator<'tcx>,
_location: Location
)
fn visit_terminator_before_primary_effect( &mut self, _results: &mut R, _state: &Self::FlowState, _terminator: &'mir Terminator<'tcx>, _location: Location )
Called with the
before_terminator_effect of the given terminator applied to state but not
its terminator_effect.fn visit_block_end(&mut self, _state: &Self::FlowState)