struct CoroutineSavedLocals(BitSet<Local>);
The set of Locals that must be saved across yield points.

CoroutineSavedLocal is indexed in terms of the elements in this set; i.e. CoroutineSavedLocal::new(1) corresponds to the second local included in this set.

Tuple Fields

0: BitSet<Local>

Implementations

source

impl CoroutineSavedLocals

source

fn iter_enumerated( &self ) -> impl '_ + Iterator<Item = (CoroutineSavedLocal, Local)>

Returns an iterator over each CoroutineSavedLocal along with the Local it corresponds to.

source

fn renumber_bitset(&self, input: &BitSet<Local>) -> BitSet<CoroutineSavedLocal>

Transforms a BitSet<Local> that contains only locals saved across yield points to the equivalent BitSet<CoroutineSavedLocal>.

source

fn get(&self, local: Local) -> Option<CoroutineSavedLocal>