struct SuspensionPoint<'tcx> {
    state: usize,
    resume: BasicBlock,
    resume_arg: Place<'tcx>,
    drop: Option<BasicBlock>,
    storage_liveness: GrowableBitSet<Local>,
}
A yield point in the coroutine.

Fields

state: usize

State discriminant used when suspending or resuming at this point.

resume: BasicBlock

The block to jump to after resumption.

resume_arg: Place<'tcx>

Where to move the resume argument after resumption.

drop: Option<BasicBlock>

Which block to jump to if the coroutine is dropped in this state.

storage_liveness: GrowableBitSet<Local>

Set of locals that have live storage while at this suspension point.