pub(super) struct CoverageCounters {
    counter_increment_sites: IndexVec<CounterId, CounterIncrementSite>,
    bcb_counters: IndexVec<BasicCoverageBlock, Option<BcbCounter>>,
    bcb_edge_counters: FxHashMap<(BasicCoverageBlock, BasicCoverageBlock), BcbCounter>,
    bcb_has_incoming_edge_counters: BitSet<BasicCoverageBlock>,
    expressions: IndexVec<ExpressionId, Expression>,
}
Generates and stores coverage counter and coverage expression information associated with nodes/edges in the BCB graph.

Fields

counter_increment_sites: IndexVec<CounterId, CounterIncrementSite>

List of places where a counter-increment statement should be injected into MIR, each with its corresponding counter ID.

bcb_counters: IndexVec<BasicCoverageBlock, Option<BcbCounter>>

Coverage counters/expressions that are associated with individual BCBs.

bcb_edge_counters: FxHashMap<(BasicCoverageBlock, BasicCoverageBlock), BcbCounter>

Coverage counters/expressions that are associated with the control-flow edge between two BCBs.

We currently don’t iterate over this map, but if we do in the future, switch it back to FxIndexMap to avoid query stability hazards.

bcb_has_incoming_edge_counters: BitSet<BasicCoverageBlock>

Tracks which BCBs have a counter associated with some incoming edge. Only used by assertions, to verify that BCBs with incoming edge counters do not have their own physical counters (expressions are allowed).

expressions: IndexVec<ExpressionId, Expression>

Table of expression data, associating each expression ID with its corresponding operator (+ or -) and its LHS/RHS operands.

Implementations

source

impl CoverageCounters

source

pub(super) fn make_bcb_counters( basic_coverage_blocks: &CoverageGraph, bcb_has_coverage_spans: impl Fn(BasicCoverageBlock) -> bool ) -> Self

Makes BcbCounter Counters and Expressions for the BasicCoverageBlocks directly or indirectly associated with coverage spans, and accumulates additional Expressions representing intermediate values.

source

fn make_counter(&mut self, site: CounterIncrementSite) -> BcbCounter

source

fn make_expression( &mut self, lhs: BcbCounter, op: Op, rhs: BcbCounter ) -> BcbCounter

source

fn make_sum_expression( &mut self, lhs: Option<BcbCounter>, rhs: BcbCounter ) -> BcbCounter

Variant of make_expression that makes lhs optional and assumes Op::Add.

This is useful when using Iterator::fold to build an arbitrary-length sum.

source

pub(super) fn num_counters(&self) -> usize

source

fn set_bcb_counter( &mut self, bcb: BasicCoverageBlock, counter_kind: BcbCounter ) -> BcbCounter

source

fn set_bcb_edge_counter( &mut self, from_bcb: BasicCoverageBlock, to_bcb: BasicCoverageBlock, counter_kind: BcbCounter ) -> BcbCounter

source

pub(super) fn bcb_counter(&self, bcb: BasicCoverageBlock) -> Option<BcbCounter>

source

pub(super) fn counter_increment_sites( &self ) -> impl Iterator<Item = (CounterId, &CounterIncrementSite)>

Returns an iterator over all the nodes/edges in the coverage graph that should have a counter-increment statement injected into MIR, along with each site’s corresponding counter ID.

source

pub(super) fn bcb_nodes_with_coverage_expressions( &self ) -> impl Iterator<Item = (BasicCoverageBlock, ExpressionId)> + Captures<'_>

Returns an iterator over the subset of BCB nodes that have been associated with a counter expression, along with the ID of that expression.

source

pub(super) fn into_expressions(self) -> IndexVec<ExpressionId, Expression>