struct MakeBcbCounters<'a> {
    coverage_counters: &'a mut CoverageCounters,
    basic_coverage_blocks: &'a CoverageGraph,
}
Traverse the CoverageGraph and add either a Counter or Expression to every BCB, to be injected with coverage spans. Expressions have no runtime overhead, so if a viable expression (adding or subtracting two other counters or expressions) can compute the same result as an embedded counter, an Expression should be used.

Fields

coverage_counters: &'a mut CoverageCountersbasic_coverage_blocks: &'a CoverageGraph

Implementations

source

impl<'a> MakeBcbCounters<'a>

source

fn new( coverage_counters: &'a mut CoverageCounters, basic_coverage_blocks: &'a CoverageGraph ) -> Self

source

fn make_bcb_counters( &mut self, bcb_has_coverage_spans: impl Fn(BasicCoverageBlock) -> bool )

If two BasicCoverageBlocks branch from another BasicCoverageBlock, one of the branches can be counted by Expression by subtracting the other branch from the branching block. Otherwise, the BasicCoverageBlock executed the least should have the Counter. One way to predict which branch executes the least is by considering loops. A loop is exited at a branch, so the branch that jumps to a BasicCoverageBlock outside the loop is almost always executed less than the branch that does not exit the loop.

source

fn make_node_and_branch_counters( &mut self, traversal: &TraverseCoverageGraphWithLoops<'_>, from_bcb: BasicCoverageBlock )

source

fn get_or_make_counter_operand(&mut self, bcb: BasicCoverageBlock) -> BcbCounter

source

fn get_or_make_edge_counter_operand( &mut self, from_bcb: BasicCoverageBlock, to_bcb: BasicCoverageBlock ) -> BcbCounter

source

fn choose_preferred_expression_branch( &self, traversal: &TraverseCoverageGraphWithLoops<'_>, from_bcb: BasicCoverageBlock ) -> BasicCoverageBlock

Select a branch for the expression, either the recommended reloop_branch, or if none was found, select any branch.

source

fn find_good_reloop_branch( &self, traversal: &TraverseCoverageGraphWithLoops<'_>, from_bcb: BasicCoverageBlock ) -> Option<BasicCoverageBlock>

Tries to find a branch that leads back to the top of a loop, and that doesn’t already have a counter. Such branches are good candidates to be given an expression (instead of a physical counter), because they will tend to be executed more times than a loop-exit branch.

source

fn bcb_predecessors(&self, bcb: BasicCoverageBlock) -> &[BasicCoverageBlock]

source

fn bcb_successors(&self, bcb: BasicCoverageBlock) -> &[BasicCoverageBlock]

source

fn branch_has_no_counter( &self, from_bcb: BasicCoverageBlock, to_bcb: BasicCoverageBlock ) -> bool

source

fn branch_counter( &self, from_bcb: BasicCoverageBlock, to_bcb: BasicCoverageBlock ) -> Option<&BcbCounter>