pub(super) struct TraverseCoverageGraphWithLoops<'a> {
basic_coverage_blocks: &'a CoverageGraph,
backedges: IndexVec<BasicCoverageBlock, Vec<BasicCoverageBlock>>,
context_stack: Vec<TraversalContext>,
visited: BitSet<BasicCoverageBlock>,
}Fields
basic_coverage_blocks: &'a CoverageGraphbackedges: IndexVec<BasicCoverageBlock, Vec<BasicCoverageBlock>>context_stack: Vec<TraversalContext>visited: BitSet<BasicCoverageBlock>Implementations
sourceimpl<'a> TraverseCoverageGraphWithLoops<'a>
impl<'a> TraverseCoverageGraphWithLoops<'a>
pub(super) fn new(basic_coverage_blocks: &'a CoverageGraph) -> Self
sourcepub(super) fn reloop_bcbs_per_loop(
&self
) -> impl Iterator<Item = &[BasicCoverageBlock]>
pub(super) fn reloop_bcbs_per_loop( &self ) -> impl Iterator<Item = &[BasicCoverageBlock]>
For each loop on the loop context stack (top-down), yields a list of BCBs within that loop that have an outgoing edge back to the loop header.
pub(super) fn next(&mut self) -> Option<BasicCoverageBlock>
pub fn add_successors_to_worklists(&mut self, bcb: BasicCoverageBlock)
pub fn is_complete(&self) -> bool
pub fn unvisited(&self) -> Vec<BasicCoverageBlock>