enum AggregateTy<'tcx> {
    Array,
    Tuple,
    Def(DefId, GenericArgsRef<'tcx>),
}
Computing the aggregate’s type can be quite slow, so we only keep the minimal amount of information to reconstruct it when needed.

Variants



Array

Invariant: this must not be used for an empty array.



Tuple



Def(DefId, GenericArgsRef<'tcx>)