struct OpportunitySet {
    opportunities: Vec<ThreadingOpportunity>,
    involving_tos: IndexVec<BasicBlock, Vec<(usize, usize)>>,
    predecessors: IndexVec<BasicBlock, usize>,
}

Fields

opportunities: Vec<ThreadingOpportunity>involving_tos: IndexVec<BasicBlock, Vec<(usize, usize)>>

For each bb, give the TOs in which it appears. The pair corresponds to the index in opportunities and the index in ThreadingOpportunity::chain.

predecessors: IndexVec<BasicBlock, usize>

Cache the number of predecessors for each block, as we clear the basic block cache..

Implementations

source

impl OpportunitySet

source

fn new( body: &Body<'_>, opportunities: Vec<ThreadingOpportunity> ) -> OpportunitySet

source

fn apply(&mut self, body: &mut Body<'_>)

Apply the opportunities on the graph.

source

fn apply_once(&mut self, index: usize, body: &mut Body<'_>)

source

fn update_predecessor_count( &mut self, terminator: &Terminator<'_>, incr: Update )