struct Validator<'a, 'tcx> {
    ccx: &'a ConstCx<'a, 'tcx>,
    temps: &'a mut IndexSlice<Local, TempState>,
}
Checks whether locals that appear in a promotion context (Candidate) are actually promotable.

This wraps an Item, and has access to all fields of that Item via Deref coercion.

Fields

ccx: &'a ConstCx<'a, 'tcx>temps: &'a mut IndexSlice<Local, TempState>

Implementations

source

impl<'tcx> Validator<'_, 'tcx>

source

fn validate_candidate( &mut self, candidate: Candidate ) -> Result<(), Unpromotable>

source

fn qualif_local<Q: Qualif>(&mut self, local: Local) -> bool

source

fn validate_local(&mut self, local: Local) -> Result<(), Unpromotable>

source

fn validate_place(&mut self, place: PlaceRef<'tcx>) -> Result<(), Unpromotable>

source

fn validate_operand( &mut self, operand: &Operand<'tcx> ) -> Result<(), Unpromotable>

source

fn validate_ref( &mut self, kind: BorrowKind, place: &Place<'tcx> ) -> Result<(), Unpromotable>

source

fn validate_rvalue(&mut self, rvalue: &Rvalue<'tcx>) -> Result<(), Unpromotable>

source

fn validate_call( &mut self, callee: &Operand<'tcx>, args: &[Spanned<Operand<'tcx>>] ) -> Result<(), Unpromotable>