Function rustc_mir_transform::validate::validate_types
source · pub fn validate_types<'tcx>(
tcx: TyCtxt<'tcx>,
mir_phase: MirPhase,
param_env: ParamEnv<'tcx>,
body: &Body<'tcx>,
caller_body: &Body<'tcx>,
) -> Vec<(Location, String)>Expand description
A faster version of the validation pass that only checks those things which may break when instantiating any generic parameters.
caller_body is used to detect cycles in MIR inlining and MIR validation before
optimized_mir is available.