Struct rustc_next_trait_solver::solve::search_graph::SearchGraph
source · pub(super) struct SearchGraph<I: Interner> {
mode: SolverMode,
stack: IndexVec<StackDepth, StackEntry<I>>,
provisional_cache: HashMap<CanonicalInput<I>, ProvisionalCacheEntry<I>>,
}Fields
mode: SolverModestack: IndexVec<StackDepth, StackEntry<I>>The stack of goals currently being computed.
An element is deeper in the stack if its index is lower.
provisional_cache: HashMap<CanonicalInput<I>, ProvisionalCacheEntry<I>>Implementations
sourceimpl<I: Interner> SearchGraph<I>
impl<I: Interner> SearchGraph<I>
pub(super) fn new(mode: SolverMode) -> SearchGraph<I>
pub(super) fn solver_mode(&self) -> SolverMode
sourcefn pop_stack(&mut self) -> StackEntry<I>
fn pop_stack(&mut self) -> StackEntry<I>
Pops the highest goal from the stack, lazily updating the the next goal in the stack.
Directly popping from the stack instead of using this method would cause us to not track overflow and recursion depth correctly.
pub(super) fn is_empty(&self) -> bool
sourcefn allowed_depth_for_nested(
tcx: I,
stack: &IndexVec<StackDepth, StackEntry<I>>,
) -> Option<SolverLimit>
fn allowed_depth_for_nested( tcx: I, stack: &IndexVec<StackDepth, StackEntry<I>>, ) -> Option<SolverLimit>
Returns the remaining depth allowed for nested goals.
This is generally simply one less than the current depth. However, if we encountered overflow, we significantly reduce the remaining depth of all nested goals to prevent hangs in case there is exponential blowup.
fn stack_coinductive_from( tcx: I, stack: &IndexVec<StackDepth, StackEntry<I>>, head: StackDepth, ) -> bool
fn tag_cycle_participants( stack: &mut IndexVec<StackDepth, StackEntry<I>>, usage_kind: HasBeenUsed, head: StackDepth, )
fn clear_dependent_provisional_results( provisional_cache: &mut HashMap<CanonicalInput<I>, ProvisionalCacheEntry<I>>, head: StackDepth, )
sourcepub(super) fn global_cache(&self, tcx: I) -> I::EvaluationCache
pub(super) fn global_cache(&self, tcx: I) -> I::EvaluationCache
The trait solver behavior is different for coherence so we use a separate cache. Alternatively we could use a single cache and share it between coherence and ordinary trait solving.
sourcepub(super) fn with_new_goal<Infcx: SolverDelegate<Interner = I>>(
&mut self,
tcx: I,
input: CanonicalInput<I>,
inspect: &mut ProofTreeBuilder<Infcx>,
prove_goal: impl FnMut(&mut Self, &mut ProofTreeBuilder<Infcx>) -> QueryResult<I>,
) -> QueryResult<I>
pub(super) fn with_new_goal<Infcx: SolverDelegate<Interner = I>>( &mut self, tcx: I, input: CanonicalInput<I>, inspect: &mut ProofTreeBuilder<Infcx>, prove_goal: impl FnMut(&mut Self, &mut ProofTreeBuilder<Infcx>) -> QueryResult<I>, ) -> QueryResult<I>
Probably the most involved method of the whole solver.
Given some goal which is proven via the prove_goal closure, this
handles caching, overflow, and coinductive cycles.
sourcefn lookup_global_cache<Infcx: SolverDelegate<Interner = I>>(
&mut self,
tcx: I,
input: CanonicalInput<I>,
available_depth: SolverLimit,
inspect: &mut ProofTreeBuilder<Infcx>,
) -> Option<QueryResult<I>>
fn lookup_global_cache<Infcx: SolverDelegate<Interner = I>>( &mut self, tcx: I, input: CanonicalInput<I>, available_depth: SolverLimit, inspect: &mut ProofTreeBuilder<Infcx>, ) -> Option<QueryResult<I>>
Try to fetch a previously computed result from the global cache, making sure to only do so if it would match the result of reevaluating this goal.
sourceimpl<I: Interner> SearchGraph<I>
impl<I: Interner> SearchGraph<I>
sourcefn fixpoint_step_in_task<Infcx, F>(
&mut self,
tcx: I,
input: CanonicalInput<I>,
inspect: &mut ProofTreeBuilder<Infcx>,
prove_goal: &mut F,
) -> StepResult<I>where
Infcx: SolverDelegate<Interner = I>,
F: FnMut(&mut Self, &mut ProofTreeBuilder<Infcx>) -> QueryResult<I>,
fn fixpoint_step_in_task<Infcx, F>(
&mut self,
tcx: I,
input: CanonicalInput<I>,
inspect: &mut ProofTreeBuilder<Infcx>,
prove_goal: &mut F,
) -> StepResult<I>where
Infcx: SolverDelegate<Interner = I>,
F: FnMut(&mut Self, &mut ProofTreeBuilder<Infcx>) -> QueryResult<I>,
When we encounter a coinductive cycle, we have to fetch the result of that cycle while we are still computing it. Because of this we continuously recompute the cycle until the result of the previous iteration is equal to the final result, at which point we are done.
fn response_no_constraints( tcx: I, goal: CanonicalInput<I>, certainty: Certainty, ) -> QueryResult<I>
fn check_invariants(&self)