pub(crate) enum ForbiddenLetReason {
    OtherForbidden,
    NotSupportedOr(Span),
    NotSupportedParentheses(Span),
}
Used to forbid let expressions in certain syntactic locations.

Variants



OtherForbidden

let is not valid and the source environment is not important



NotSupportedOr(Span)

A let chain with the || operator



NotSupportedParentheses(Span)

A let chain with invalid parentheses

For example, let 1 = 1 && (expr && expr) is allowed but (let 1 = 1 && (let 1 = 1 && (let 1 = 1))) && let a = 1 is not