pub enum MaybeInfiniteInt {
    NegInfinity,
    Finite(u128),
    JustAfterMax,
    PosInfinity,
}
A possibly infinite integer. Values are encoded such that the ordering on u128 matches the natural order on the original type. For example, -128i8 is encoded as 0 and 127i8 as 255. See signed_bias for details.

Variants



NegInfinity



Finite(u128)

Encoded value. DO NOT CONSTRUCT BY HAND; use new_finite.



JustAfterMax

The integer after u128::MAX. We need it to represent x..=u128::MAX as an exclusive range.



PosInfinity

Implementations

source

impl MaybeInfiniteInt

source

pub fn new_finite_uint(bits: u128) -> Self

source

pub fn new_finite_int(bits: u128, size: u64) -> Self

source

pub fn as_finite_uint(self) -> Option<u128>

source

pub fn as_finite_int(self, size: u64) -> Option<u128>

source

pub fn minus_one(self) -> Self

Note: this will not turn a finite value into an infinite one or vice-versa.

source

pub fn plus_one(self) -> Self

Note: this will not turn a finite value into an infinite one or vice-versa.