pub enum VariantVisibility {
    Visible,
    Hidden,
    Empty,
}

Variants



Visible

Variant that doesn’t fit the other cases, i.e. most variants.



Hidden

Variant behind an unstable gate or with the #[doc(hidden)] attribute. It will not be mentioned in diagnostics unless the user mentioned it first.



Empty

Variant that matches no value. E.g. Some::<Option<!>> if the exhaustive_patterns feature is enabled. Like Hidden, it will not be mentioned in diagnostics unless the user mentioned it first.