Function rustc_pattern_analysis::analyze_match
source · pub fn analyze_match<'p, 'tcx>(
tycx: &RustcMatchCheckCtxt<'p, 'tcx>,
arms: &[MatchArm<'p, 'tcx>],
scrut_ty: Ty<'tcx>
) -> Result<UsefulnessReport<'p, 'tcx>, ErrorGuaranteed>Expand description
The entrypoint for this crate. Computes whether a match is exhaustive and which of its arms are useful, and runs some lints.