#[repr(transparent)]
pub struct IdxContainer<I, T>
where I: Idx,
{ pub raw: Vec<T>, _marker: PhantomData<fn(_: &I)>, }
An owned contiguous collection of Ts, indexed by I rather than by usize. Its purpose is to avoid mixing indexes.

While it’s possible to use u32 or usize directly for I, you almost certainly want to use a newtype_index!-generated type instead.

This allows to index the IndexVec with the new index type.

Fields

raw: Vec<T>_marker: PhantomData<fn(_: &I)>