fn collect_nonexhaustive_missing_variants<'a, 'p, 'tcx>(
    cx: MatchCtxt<'a, 'p, 'tcx>,
    column: &PatternColumn<'p, 'tcx>
) -> Result<Vec<WitnessPat<'p, 'tcx>>, ErrorGuaranteed>
Traverse the patterns to collect any variants of a non_exhaustive enum that fail to be mentioned in a given column.