Struct rustc_pattern_analysis::lints::PatternColumn
source · pub(crate) struct PatternColumn<'p, 'tcx> {
patterns: Vec<&'p DeconstructedPat<'p, 'tcx>>,
}Expand description
A column of patterns in the matrix, where a column is the intuitive notion of “subpatterns that
inspect the same subvalue/place”.
This is used to traverse patterns column-by-column for lints. Despite similarities with the
algorithm in crate::usefulness, this does a different traversal. Notably this is linear in
the depth of patterns, whereas compute_exhaustiveness_and_usefulness is worst-case exponential
(exhaustiveness is NP-complete). The core difference is that we treat sub-columns separately.
This must not contain an or-pattern. expand_and_push takes care to expand them.
This is not used in the usefulness algorithm; only in lints.
Fields
patterns: Vec<&'p DeconstructedPat<'p, 'tcx>>Implementations
sourceimpl<'p, 'tcx> PatternColumn<'p, 'tcx>
impl<'p, 'tcx> PatternColumn<'p, 'tcx>
pub(crate) fn new(arms: &[MatchArm<'p, 'tcx>]) -> Self
sourcefn expand_and_push(&mut self, pat: PatOrWild<'p, RustcMatchCheckCtxt<'p, 'tcx>>)
fn expand_and_push(&mut self, pat: PatOrWild<'p, RustcMatchCheckCtxt<'p, 'tcx>>)
Pushes a pattern onto the column, expanding any or-patterns into its subpatterns.
Internal method, prefer PatternColumn::new.
fn head_ty(&self) -> Option<RevealedTy<'tcx>>
sourcefn analyze_ctors(
&self,
pcx: &PlaceCtxt<'_, 'p, RustcMatchCheckCtxt<'p, 'tcx>>
) -> Result<SplitConstructorSet<RustcMatchCheckCtxt<'p, 'tcx>>, ErrorGuaranteed>
fn analyze_ctors( &self, pcx: &PlaceCtxt<'_, 'p, RustcMatchCheckCtxt<'p, 'tcx>> ) -> Result<SplitConstructorSet<RustcMatchCheckCtxt<'p, 'tcx>>, ErrorGuaranteed>
Do constructor splitting on the constructors of the column.
sourcefn specialize(
&self,
pcx: &PlaceCtxt<'_, 'p, RustcMatchCheckCtxt<'p, 'tcx>>,
ctor: &Constructor<'p, 'tcx>
) -> Vec<PatternColumn<'p, 'tcx>>
fn specialize( &self, pcx: &PlaceCtxt<'_, 'p, RustcMatchCheckCtxt<'p, 'tcx>>, ctor: &Constructor<'p, 'tcx> ) -> Vec<PatternColumn<'p, 'tcx>>
Does specialization: given a constructor, this takes the patterns from the column that match
the constructor, and outputs their fields.
This returns one column per field of the constructor. They usually all have the same length
(the number of patterns in self that matched ctor), except that we expand or-patterns
which may change the lengths.