pub struct WitnessPat<Cx: TypeCx> {
    ctor: Constructor<Cx>,
    pub(crate) fields: Vec<WitnessPat<Cx>>,
    ty: Cx::Ty,
}
Same idea as DeconstructedPat, except this is a fictitious pattern built up for diagnostics purposes. As such they don’t use interning and can be cloned.

Fields

ctor: Constructor<Cx>fields: Vec<WitnessPat<Cx>>ty: Cx::Ty

Implementations

source

impl<Cx: TypeCx> WitnessPat<Cx>

source

pub(crate) fn new(ctor: Constructor<Cx>, fields: Vec<Self>, ty: Cx::Ty) -> Self

source

pub(crate) fn wildcard(ty: Cx::Ty) -> Self

source

pub(crate) fn wild_from_ctor(cx: &Cx, ctor: Constructor<Cx>, ty: Cx::Ty) -> Self

Construct a pattern that matches everything that starts with this constructor. For example, if ctor is a Constructor::Variant for Option::Some, we get the pattern Some(_).

source

pub fn ctor(&self) -> &Constructor<Cx>

source

pub fn ty(&self) -> &Cx::Ty

source

pub fn iter_fields(&self) -> impl Iterator<Item = &WitnessPat<Cx>>