#[repr(transparent)]
pub struct RevealedTy<'tcx>(Ty<'tcx>);
A type which has gone through cx.reveal_opaque_ty, i.e. if it was opaque it was replaced by the hidden type if allowed in the current body. This ensures we consistently inspect the hidden types when we should.

Use .inner() or deref to get to the Ty<'tcx>.

Tuple Fields

0: Ty<'tcx>

Implementations

source

impl<'tcx> RevealedTy<'tcx>

source

pub fn inner(self) -> Ty<'tcx>