pub type DeconstructedPat<'p, 'tcx> = DeconstructedPat<'p, RustcMatchCheckCtxt<'p, 'tcx>>;

Aliased Type

struct DeconstructedPat<'p, 'tcx> {
    ctor: Constructor<RustcMatchCheckCtxt<'p, 'tcx>>,
    fields: &'p [DeconstructedPat<'p, RustcMatchCheckCtxt<'p, 'tcx>>],
    ty: RevealedTy<'tcx>,
    data: Option<&'p Pat<'tcx>>,
    useful: Cell<bool>,
}

Fields

ctor: Constructor<RustcMatchCheckCtxt<'p, 'tcx>>fields: &'p [DeconstructedPat<'p, RustcMatchCheckCtxt<'p, 'tcx>>]ty: RevealedTy<'tcx>data: Option<&'p Pat<'tcx>>

Extra data to store in a pattern. None if the pattern is a wildcard that does not correspond to a user-supplied pattern.

useful: Cell<bool>

Whether removing this arm would change the behavior of the match expression.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 96 bytes