Type Alias rustc_pattern_analysis::rustc::MatchCtxt
source · pub type MatchCtxt<'a, 'p, 'tcx> = MatchCtxt<'a, 'p, RustcMatchCheckCtxt<'p, 'tcx>>;Aliased Type
struct MatchCtxt<'a, 'p, 'tcx> {
pub tycx: &'a RustcMatchCheckCtxt<'p, 'tcx>,
pub wildcard_arena: &'p TypedArena<DeconstructedPat<'p, RustcMatchCheckCtxt<'p, 'tcx>>>,
}Fields
tycx: &'a RustcMatchCheckCtxt<'p, 'tcx>The context for type information.
wildcard_arena: &'p TypedArena<DeconstructedPat<'p, RustcMatchCheckCtxt<'p, 'tcx>>>An arena to store the wildcards we produce during analysis.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes