pub(crate) type PlaceCtxt<'a, 'p, 'tcx> = PlaceCtxt<'a, 'p, RustcMatchCheckCtxt<'p, 'tcx>>;

Aliased Type

struct PlaceCtxt<'a, 'p, 'tcx> {
    pub(crate) mcx: MatchCtxt<'a, 'p, RustcMatchCheckCtxt<'p, 'tcx>>,
    pub(crate) ty: RevealedTy<'tcx>,
    pub(crate) is_scrutinee: bool,
}

Fields

mcx: MatchCtxt<'a, 'p, RustcMatchCheckCtxt<'p, 'tcx>>ty: RevealedTy<'tcx>

Type of the place under investigation.

is_scrutinee: bool

Whether the place is the original scrutinee place, as opposed to a subplace of it.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes