Type Alias rustc_pattern_analysis::rustc::UsefulnessReport
source · pub type UsefulnessReport<'p, 'tcx> = UsefulnessReport<'p, RustcMatchCheckCtxt<'p, 'tcx>>;Aliased Type
struct UsefulnessReport<'p, 'tcx> {
pub arm_usefulness: Vec<(MatchArm<'p, RustcMatchCheckCtxt<'p, 'tcx>>, Usefulness<'p, RustcMatchCheckCtxt<'p, 'tcx>>)>,
pub non_exhaustiveness_witnesses: Vec<WitnessPat<RustcMatchCheckCtxt<'p, 'tcx>>>,
pub overlapping_range_endpoints: Vec<OverlappingRanges<'p, RustcMatchCheckCtxt<'p, 'tcx>>>,
}Fields
arm_usefulness: Vec<(MatchArm<'p, RustcMatchCheckCtxt<'p, 'tcx>>, Usefulness<'p, RustcMatchCheckCtxt<'p, 'tcx>>)>For each arm of the input, whether that arm is useful after the arms above it.
non_exhaustiveness_witnesses: Vec<WitnessPat<RustcMatchCheckCtxt<'p, 'tcx>>>If the match is exhaustive, this is empty. If not, this contains witnesses for the lack of exhaustiveness.
overlapping_range_endpoints: Vec<OverlappingRanges<'p, RustcMatchCheckCtxt<'p, 'tcx>>>Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 72 bytes