pub enum Usefulness<'p, Cx: TypeCx> {
    Useful(Vec<&'p DeconstructedPat<Cx>>),
    Redundant,
}
Indicates whether or not a given arm is useful.

Variants



Useful(Vec<&'p DeconstructedPat<Cx>>)

The arm is useful. This additionally carries a set of or-pattern branches that have been found to be redundant despite the overall arm being useful. Used only in the presence of or-patterns, otherwise it stays empty.



Redundant

The arm is redundant and can be removed without changing the behavior of the match expression.