pub enum ValidityConstraint {
    ValidOnly,
    MaybeInvalid,
    MaybeInvalidButAllowOmittingArms,
}
Serves two purposes:

  • in a wildcard, tracks whether the wildcard matches only valid values (i.e. is a binding _a) or also invalid values (i.e. is a true _ pattern).
  • in the matrix, track whether a given place (aka column) is known to contain a valid value or not.

Variants



ValidOnly



MaybeInvalid



MaybeInvalidButAllowOmittingArms

Option for backwards compatibility: the place is not known to be valid but we allow omitting useful && !reachable arms anyway.

Implementations

source

impl ValidityConstraint

source

pub fn from_bool(is_valid_only: bool) -> Self

source

fn allow_omitting_side_effecting_arms(self) -> Self

source

fn is_known_valid(self) -> bool

source

fn allows_omitting_empty_arms(self) -> bool

source

fn specialize<Cx: TypeCx>(self, ctor: &Constructor<Cx>) -> Self

If the place has validity given by self and we read that the value at the place has constructor ctor, this computes what we can assume about the validity of the constructor fields.

Pending further opsem decisions, the current behavior is: validity is preserved, except inside & and union fields where validity is reset to MaybeInvalid.