pub struct OverlappingRanges<'p, Cx: TypeCx> {
    pub pat: &'p DeconstructedPat<'p, Cx>,
    pub overlaps_on: IntRange,
    pub overlaps_with: Vec<&'p DeconstructedPat<'p, Cx>>,
}
Indicates that the range pat overlapped with all the ranges in overlaps_with, where the range they overlapped over is overlaps_on. We only detect singleton overlaps.

Fields

pat: &'p DeconstructedPat<'p, Cx>overlaps_on: IntRangeoverlaps_with: Vec<&'p DeconstructedPat<'p, Cx>>