struct PatStack<'p, Cx: TypeCx> {
    pats: SmallVec<[PatOrWild<'p, Cx>; 2]>,
    relevant: bool,
}
Represents a pattern-tuple under investigation.

Fields

pats: SmallVec<[PatOrWild<'p, Cx>; 2]>relevant: bool

Sometimes we know that as far as this row is concerned, the current case is already handled by a different, more general, case. When the case is irrelevant for all rows this allows us to skip a case entirely. This is purely an optimization. See at the top for details.

Implementations

source

impl<'p, Cx: TypeCx> PatStack<'p, Cx>

source

fn from_pattern(pat: &'p DeconstructedPat<'p, Cx>) -> Self

source

fn is_empty(&self) -> bool

source

fn len(&self) -> usize

source

fn head(&self) -> PatOrWild<'p, Cx>

source

fn iter(&self) -> impl Iterator<Item = PatOrWild<'p, Cx>> + Captures<'_>

source

fn expand_or_pat(&self) -> impl Iterator<Item = PatStack<'p, Cx>> + Captures<'_>

source

fn pop_head_constructor( &self, ctor: &Constructor<Cx>, ctor_arity: usize, ctor_is_relevant: bool ) -> PatStack<'p, Cx>

This computes specialize(ctor, self). See top of the file for explanations. Only call if ctor.is_covered_by(self.head().ctor()) is true.