pub(crate) struct PlaceCtxt<'a, 'p, Cx: TypeCx> {
    pub(crate) mcx: MatchCtxt<'a, 'p, Cx>,
    pub(crate) ty: Cx::Ty,
    pub(crate) is_scrutinee: bool,
}
Context that provides information local to a place under investigation.

Fields

mcx: MatchCtxt<'a, 'p, Cx>ty: Cx::Ty

Type of the place under investigation.

is_scrutinee: bool

Whether the place is the original scrutinee place, as opposed to a subplace of it.

Implementations

source

impl<'a, 'p, Cx: TypeCx> PlaceCtxt<'a, 'p, Cx>

source

pub(crate) fn new_dummy(mcx: MatchCtxt<'a, 'p, Cx>, ty: Cx::Ty) -> Self

A PlaceCtxt when code other than is_useful needs one.

source

pub(crate) fn ctor_arity(&self, ctor: &Constructor<Cx>) -> usize

source

pub(crate) fn ctor_sub_tys(&self, ctor: &Constructor<Cx>) -> &[Cx::Ty]

source

pub(crate) fn ctors_for_ty(&self) -> Result<ConstructorSet<Cx>, Cx::Error>