struct PlaceInfo<Cx: TypeCx> {
    ty: Cx::Ty,
    validity: ValidityConstraint,
    is_scrutinee: bool,
}
Data about a place under investigation.

Fields

ty: Cx::Ty

The type of the place.

validity: ValidityConstraint

Whether the place is known to contain valid data.

is_scrutinee: bool

Whether the place is the scrutinee itself or a subplace of it.

Implementations

source

impl<Cx: TypeCx> PlaceInfo<Cx>

source

fn specialize<'a>( &'a self, cx: &'a Cx, ctor: &'a Constructor<Cx> ) -> impl Iterator<Item = Self> + ExactSizeIterator + Captures<'a>