pub struct UsefulnessReport<'p, Cx: TypeCx> {
    pub arm_usefulness: Vec<(MatchArm<'p, Cx>, Usefulness<'p, Cx>)>,
    pub non_exhaustiveness_witnesses: Vec<WitnessPat<Cx>>,
}
The output of checking a match for exhaustiveness and arm usefulness.

Fields

arm_usefulness: Vec<(MatchArm<'p, Cx>, Usefulness<'p, Cx>)>

For each arm of the input, whether that arm is useful after the arms above it.

non_exhaustiveness_witnesses: Vec<WitnessPat<Cx>>

If the match is exhaustive, this is empty. If not, this contains witnesses for the lack of exhaustiveness.