Enum rustc_query_system::query::plumbing::QueryResult
source · enum QueryResult {
Started(QueryJob),
Poisoned,
}Expand description
Indicates the state of a query for a given key in a query map.
Variants
Started(QueryJob)
An already executing query. The query job can be used to await for its completion.
Poisoned
The query panicked. Queries trying to wait on this will raise a fatal error which will silently panic.
Implementations
sourceimpl QueryResult
impl QueryResult
sourcefn expect_job(self) -> QueryJob
fn expect_job(self) -> QueryJob
Unwraps the query job expecting that it has started.