pub enum Polonius {
    Off,
    Legacy,
    Next,
}
-Zpolonius values, enabling the borrow checker polonius analysis, and which version: legacy, or future prototype.

Variants



Off

The default value: disabled.



Legacy

Legacy version, using datalog and the polonius-engine crate. Historical value for -Zpolonius.



Next

In-tree prototype, extending the NLL infrastructure.

Implementations

source

impl Polonius

source

pub fn is_legacy_enabled(&self) -> bool

Returns whether the legacy version of polonius is enabled

source

pub fn is_next_enabled(&self) -> bool

Returns whether the “next” version of polonius is enabled