pub struct EarlyDiagCtxt {
    dcx: DiagCtxt,
}
A wrapper around an DiagCtxt that is used for early error emissions.

Fields

dcx: DiagCtxt

Implementations

source

impl EarlyDiagCtxt

source

pub fn new(output: ErrorOutputType) -> Self

source

pub fn abort_if_errors(&self)

source

pub fn abort_if_error_and_set_error_format(&mut self, output: ErrorOutputType)

Swap out the underlying dcx once we acquire the user’s preference on error emission format. Any errors prior to that will cause an abort and all stashed diagnostics of the previous dcx will be emitted.

source

pub fn early_note(&self, msg: impl Into<DiagnosticMessage>)

source

pub fn early_help(&self, msg: impl Into<DiagnosticMessage>)

source

pub fn early_err(&self, msg: impl Into<DiagnosticMessage>) -> ErrorGuaranteed

source

pub fn early_fatal(&self, msg: impl Into<DiagnosticMessage>) -> !

source

pub fn early_struct_fatal( &self, msg: impl Into<DiagnosticMessage> ) -> DiagnosticBuilder<'_, FatalAbort>

source

pub fn early_warn(&self, msg: impl Into<DiagnosticMessage>)

source

pub fn initialize_checked_jobserver(&self)