struct BinderLevel {
    lifetime_depths: Range<u32>,
}

Fields

lifetime_depths: Range<u32>

The range of distances from the root of what’s being printed, to the lifetimes in a binder. Specifically, a BrAnon lifetime has depth lifetime_depths.start + index, going away from the the root and towards its use site, as the var index increases. This is used to flatten rustc’s pairing of BrAnon (intra-binder disambiguation) with a DebruijnIndex (binder addressing), to “true” de Bruijn indices, by subtracting the depth of a certain lifetime, from the innermost depth at its use site.