pub struct OpaqueTypeDecl<'tcx> {
    pub hidden_type: OpaqueHiddenType<'tcx>,
}
Information about the opaque types whose values we are inferring in this function (these are the impl Trait that appear in the return type).

Fields

hidden_type: OpaqueHiddenType<'tcx>

The hidden types that have been inferred for this opaque type. There can be multiple, but they are all lubed together at the end to obtain the canonical hidden type.