pub struct OpaqueTypeStorage<'tcx> {
pub opaque_types: IndexMap<OpaqueTypeKey<'tcx>, OpaqueTypeDecl<'tcx>, BuildHasherDefault<FxHasher>>,
}Fields
opaque_types: IndexMap<OpaqueTypeKey<'tcx>, OpaqueTypeDecl<'tcx>, BuildHasherDefault<FxHasher>>Opaque types found in explicit return types and their associated fresh inference variable. Writeback resolves these variables to get the concrete type, which can be used to ‘de-opaque’ OpaqueTypeDecl, after typeck is done with all functions.