pub enum Constraint<'tcx> {
    VarSubVar(RegionVid, RegionVid),
    RegSubVar(Region<'tcx>, RegionVid),
    VarSubReg(RegionVid, Region<'tcx>),
    RegSubReg(Region<'tcx>, Region<'tcx>),
}
Represents a constraint that influences the inference process.

Variants



VarSubVar(RegionVid, RegionVid)

A region variable is a subregion of another.



RegSubVar(Region<'tcx>, RegionVid)

A concrete region is a subregion of region variable.



VarSubReg(RegionVid, Region<'tcx>)

A region variable is a subregion of a concrete region. This does not directly affect inference, but instead is checked after inference is complete.



RegSubReg(Region<'tcx>, Region<'tcx>)

A constraint where neither side is a variable. This does not directly affect inference, but instead is checked after inference is complete.