pub struct OpportunisticVarResolver<'a, 'tcx> {
    shallow_resolver: ShallowResolver<'a, 'tcx>,
}
The opportunistic resolver can be used at any time. It simply replaces type/const variables that have been unified with the things they have been unified with (similar to shallow_resolve, but deep). This is useful for printing messages etc but also required at various points for correctness.

Fields

shallow_resolver: ShallowResolver<'a, 'tcx>