pub struct UnresolvedTypeOrConstFinder<'a, 'tcx> {
    infcx: &'a InferCtxt<'tcx>,
}
The unresolved type finder walks a type searching for type variables that don’t yet have a value. The first unresolved type is stored. It does not construct the fully resolved type (which might involve some hashing and so forth).

Fields

infcx: &'a InferCtxt<'tcx>