pub struct InferCtxt<'tcx> {
Show 17 fields pub tcx: TyCtxt<'tcx>, pub defining_use_anchor: DefiningAnchor, pub considering_regions: bool, skip_leak_check: bool, pub inner: RefCell<InferCtxtInner<'tcx>>, lexical_region_resolutions: RefCell<Option<LexicalRegionResolutions<'tcx>>>, pub selection_cache: Cache<(ParamEnv<'tcx>, TraitPredicate<'tcx>), Result<Option<SelectionCandidate<'tcx>>, SelectionError<'tcx>>>, pub evaluation_cache: Cache<(ParamEnv<'tcx>, Binder<'tcx, TraitPredicate<'tcx>>), EvaluationResult>, pub reported_trait_errors: RefCell<IndexMap<Span, (Vec<Predicate<'tcx>>, ErrorGuaranteed), BuildHasherDefault<FxHasher>>>, pub reported_signature_mismatch: RefCell<HashSet<(Span, Option<Span>), BuildHasherDefault<FxHasher>>>, tainted_by_errors: Cell<Option<ErrorGuaranteed>>, err_count_on_creation: usize, stashed_err_count_on_creation: usize, universe: Cell<UniverseIndex>, pub intercrate: bool, next_trait_solver: bool, pub obligation_inspector: Cell<Option<fn(_: &InferCtxt<'tcx>, _: &Obligation<'tcx, Predicate<'tcx>>, _: Result<Certainty, NoSolution>)>>,
}

Fields

tcx: TyCtxt<'tcx>defining_use_anchor: DefiningAnchor

The DefId of the item in whose context we are performing inference or typeck. It is used to check whether an opaque type use is a defining use.

If it is DefiningAnchor::Bubble, we can’t resolve opaque types here and need to bubble up the obligation. This frequently happens for short lived InferCtxt within queries. The opaque type obligations are forwarded to the outside until the end up in an InferCtxt for typeck or borrowck.

Its default value is DefiningAnchor::Error, this way it is easier to catch errors that might come up during inference or typeck.

considering_regions: bool

Whether this inference context should care about region obligations in the root universe. Most notably, this is used during hir typeck as region solving is left to borrowck instead.

skip_leak_check: boolinner: RefCell<InferCtxtInner<'tcx>>lexical_region_resolutions: RefCell<Option<LexicalRegionResolutions<'tcx>>>selection_cache: Cache<(ParamEnv<'tcx>, TraitPredicate<'tcx>), Result<Option<SelectionCandidate<'tcx>>, SelectionError<'tcx>>>

Caches the results of trait selection. This cache is used for things that have to do with the parameters in scope.

evaluation_cache: Cache<(ParamEnv<'tcx>, Binder<'tcx, TraitPredicate<'tcx>>), EvaluationResult>

Caches the results of trait evaluation.

reported_trait_errors: RefCell<IndexMap<Span, (Vec<Predicate<'tcx>>, ErrorGuaranteed), BuildHasherDefault<FxHasher>>>

The set of predicates on which errors have been reported, to avoid reporting the same error twice.

reported_signature_mismatch: RefCell<HashSet<(Span, Option<Span>), BuildHasherDefault<FxHasher>>>tainted_by_errors: Cell<Option<ErrorGuaranteed>>err_count_on_creation: usizestashed_err_count_on_creation: usizeuniverse: Cell<UniverseIndex>intercrate: bool

During coherence we have to assume that other crates may add additional impls which we currently don’t know about.

To deal with this evaluation, we should be conservative and consider the possibility of impls from outside this crate. This comes up primarily when resolving ambiguity. Imagine there is some trait reference $0: Bar where $0 is an inference variable. If intercrate is true, then we can never say for sure that this reference is not implemented, even if there are no impls at all for Bar, because $0 could be bound to some type that in a downstream crate that implements Bar.

Outside of coherence, we set this to false because we are only interested in types that the user could actually have written. In other words, we consider $0: Bar to be unimplemented if there is no type that the user could actually name that would satisfy it. This avoids crippling inference, basically.

next_trait_solver: boolobligation_inspector: Cell<Option<fn(_: &InferCtxt<'tcx>, _: &Obligation<'tcx, Predicate<'tcx>>, _: Result<Certainty, NoSolution>)>>