enum DebugSolver<'tcx> {
    Root,
    GoalEvaluation(WipGoalEvaluation<'tcx>),
    CanonicalGoalEvaluation(WipCanonicalGoalEvaluation<'tcx>),
    AddedGoalsEvaluation(WipAddedGoalsEvaluation<'tcx>),
    GoalEvaluationStep(WipGoalEvaluationStep<'tcx>),
    Probe(WipProbe<'tcx>),
}
The current state of the proof tree builder, at most places in the code, only one or two variants are actually possible.

We simply ICE in case that assumption is broken.

Variants



Root



GoalEvaluation(WipGoalEvaluation<'tcx>)



CanonicalGoalEvaluation(WipCanonicalGoalEvaluation<'tcx>)



AddedGoalsEvaluation(WipAddedGoalsEvaluation<'tcx>)



GoalEvaluationStep(WipGoalEvaluationStep<'tcx>)



Probe(WipProbe<'tcx>)