struct DetachedEntry<'tcx> {
    head: StackDepth,
    result: QueryResult<'tcx>,
}
The provisional result for a goal which is not on the stack.

Fields

head: StackDepth

The head of the smallest non-trivial cycle involving this entry.

Given the following rules, when proving A the head for the provisional entry of C would be B.

A :- B
B :- C
C :- A + B + C
result: QueryResult<'tcx>