struct StackEntry<'tcx> {
    input: CanonicalInput<'tcx>,
    available_depth: Limit,
    reached_depth: StackDepth,
    non_root_cycle_participant: Option<StackDepth>,
    encountered_overflow: bool,
    has_been_used: HasBeenUsed,
    provisional_result: Option<QueryResult<'tcx>>,
}

Fields

input: CanonicalInput<'tcx>available_depth: Limitreached_depth: StackDepth

The maximum depth reached by this stack entry, only up-to date for the top of the stack and lazily updated for the rest.

non_root_cycle_participant: Option<StackDepth>

Whether this entry is a non-root cycle participant.

We must not move the result of non-root cycle participants to the global cache. See SearchGraph::cycle_participants for more details. We store the highest stack depth of a head of a cycle this goal is involved in. This necessary to soundly cache its provisional result.

encountered_overflow: boolhas_been_used: HasBeenUsedprovisional_result: Option<QueryResult<'tcx>>

Starts out as None and gets set when rerunning this goal in case we encounter a cycle.