struct CoroutineData<'tcx, 'a>(&'a TypeckResults<'tcx>);

Tuple Fields

0: &'a TypeckResults<'tcx>

Implementations

source

impl<'tcx, 'a> CoroutineData<'tcx, 'a>

source

fn try_get_upvar_span<F>( &self, infer_context: &InferCtxt<'tcx>, coroutine_did: DefId, ty_matches: F ) -> Option<CoroutineInteriorOrUpvar>
where F: Fn(Binder<'tcx, Ty<'tcx>>) -> bool,

Try to get information about variables captured by the coroutine that matches a type we are looking for with ty_matches function. We uses it to find upvar which causes a failure to meet an obligation

source

fn get_from_await_ty<F>( &self, visitor: AwaitsVisitor, hir: Map<'tcx>, ty_matches: F ) -> Option<Span>
where F: Fn(Binder<'tcx, Ty<'tcx>>) -> bool,

Try to get the span of a type being awaited on that matches the type we are looking with the ty_matches function. We uses it to find awaited type which causes a failure to meet an obligation