Struct rustc_trait_selection::traits::project::AssocTypeNormalizer
source · struct AssocTypeNormalizer<'a, 'b, 'tcx> {
selcx: &'a mut SelectionContext<'b, 'tcx>,
param_env: ParamEnv<'tcx>,
cause: ObligationCause<'tcx>,
obligations: &'a mut Vec<PredicateObligation<'tcx>>,
depth: usize,
universes: Vec<Option<UniverseIndex>>,
eager_inference_replacement: bool,
}Fields
selcx: &'a mut SelectionContext<'b, 'tcx>param_env: ParamEnv<'tcx>cause: ObligationCause<'tcx>obligations: &'a mut Vec<PredicateObligation<'tcx>>depth: usizeuniverses: Vec<Option<UniverseIndex>>eager_inference_replacement: boolIf true, when a projection is unable to be completed, an inference variable will be created and an obligation registered to project to that inference variable. Also, constants will be eagerly evaluated.
Implementations
sourceimpl<'a, 'b, 'tcx> AssocTypeNormalizer<'a, 'b, 'tcx>
impl<'a, 'b, 'tcx> AssocTypeNormalizer<'a, 'b, 'tcx>
fn new( selcx: &'a mut SelectionContext<'b, 'tcx>, param_env: ParamEnv<'tcx>, cause: ObligationCause<'tcx>, depth: usize, obligations: &'a mut Vec<PredicateObligation<'tcx>> ) -> AssocTypeNormalizer<'a, 'b, 'tcx>
fn new_without_eager_inference_replacement( selcx: &'a mut SelectionContext<'b, 'tcx>, param_env: ParamEnv<'tcx>, cause: ObligationCause<'tcx>, depth: usize, obligations: &'a mut Vec<PredicateObligation<'tcx>> ) -> AssocTypeNormalizer<'a, 'b, 'tcx>
fn fold<T: TypeFoldable<TyCtxt<'tcx>>>(&mut self, value: T) -> T