pub struct BoundVarReplacer<'me, 'tcx> {
    infcx: &'me InferCtxt<'tcx>,
    mapped_regions: BTreeMap<PlaceholderRegion, BoundRegion>,
    mapped_types: BTreeMap<PlaceholderType, BoundTy>,
    mapped_consts: BTreeMap<PlaceholderConst, BoundVar>,
    current_index: DebruijnIndex,
    universe_indices: &'me mut Vec<Option<UniverseIndex>>,
}

Fields

infcx: &'me InferCtxt<'tcx>mapped_regions: BTreeMap<PlaceholderRegion, BoundRegion>mapped_types: BTreeMap<PlaceholderType, BoundTy>mapped_consts: BTreeMap<PlaceholderConst, BoundVar>current_index: DebruijnIndexuniverse_indices: &'me mut Vec<Option<UniverseIndex>>

Implementations

source

impl<'me, 'tcx> BoundVarReplacer<'me, 'tcx>

source

pub fn replace_bound_vars<T: TypeFoldable<TyCtxt<'tcx>>>( infcx: &'me InferCtxt<'tcx>, universe_indices: &'me mut Vec<Option<UniverseIndex>>, value: T ) -> (T, BTreeMap<PlaceholderRegion, BoundRegion>, BTreeMap<PlaceholderType, BoundTy>, BTreeMap<PlaceholderConst, BoundVar>)

Returns Some if we were able to replace bound vars. If there are any bound vars that use a binding level above universe_indices.len(), we fail.

source

fn universe_for(&mut self, debruijn: DebruijnIndex) -> UniverseIndex