Struct rustc_trait_selection::traits::query::type_op::implied_outlives_bounds::ImpliedOutlivesBounds
source · pub struct ImpliedOutlivesBounds<'tcx> {
pub ty: Ty<'tcx>,
}Fields
ty: Ty<'tcx>Trait Implementations
sourceimpl<'tcx> Clone for ImpliedOutlivesBounds<'tcx>
impl<'tcx> Clone for ImpliedOutlivesBounds<'tcx>
sourcefn clone(&self) -> ImpliedOutlivesBounds<'tcx>
fn clone(&self) -> ImpliedOutlivesBounds<'tcx>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'tcx> Debug for ImpliedOutlivesBounds<'tcx>
impl<'tcx> Debug for ImpliedOutlivesBounds<'tcx>
sourceimpl<'tcx, '__ctx> HashStable<StableHashingContext<'__ctx>> for ImpliedOutlivesBounds<'tcx>
impl<'tcx, '__ctx> HashStable<StableHashingContext<'__ctx>> for ImpliedOutlivesBounds<'tcx>
fn hash_stable( &self, __hcx: &mut StableHashingContext<'__ctx>, __hasher: &mut StableHasher )
sourceimpl<'tcx> QueryTypeOp<'tcx> for ImpliedOutlivesBounds<'tcx>
impl<'tcx> QueryTypeOp<'tcx> for ImpliedOutlivesBounds<'tcx>
type QueryResponse = Vec<OutlivesBound<'tcx>>
sourcefn try_fast_path(
_tcx: TyCtxt<'tcx>,
key: &ParamEnvAnd<'tcx, Self>
) -> Option<Self::QueryResponse>
fn try_fast_path( _tcx: TyCtxt<'tcx>, key: &ParamEnvAnd<'tcx, Self> ) -> Option<Self::QueryResponse>
Give query the option for a simple fast path that never
actually hits the tcx cache lookup etc. Return
Some(r) with
a final result or None to do the full path.sourcefn perform_query(
tcx: TyCtxt<'tcx>,
canonicalized: Canonical<'tcx, ParamEnvAnd<'tcx, Self>>
) -> Result<CanonicalQueryResponse<'tcx, Self::QueryResponse>, NoSolution>
fn perform_query( tcx: TyCtxt<'tcx>, canonicalized: Canonical<'tcx, ParamEnvAnd<'tcx, Self>> ) -> Result<CanonicalQueryResponse<'tcx, Self::QueryResponse>, NoSolution>
Performs the actual query with the canonicalized key – the
real work happens here. This method is not given an
infcx
because it shouldn’t need one – and if it had access to one,
it might do things like invoke sub_regions, which would be
bad, because it would create subregion relationships that are
not captured in the return value.sourcefn perform_locally_with_next_solver(
ocx: &ObligationCtxt<'_, 'tcx>,
key: ParamEnvAnd<'tcx, Self>
) -> Result<Self::QueryResponse, NoSolution>
fn perform_locally_with_next_solver( ocx: &ObligationCtxt<'_, 'tcx>, key: ParamEnvAnd<'tcx, Self> ) -> Result<Self::QueryResponse, NoSolution>
In the new trait solver, we already do caching in the solver itself,
so there’s no need to canonicalize and cache via the query system.
Additionally, even if we were to canonicalize, we’d still need to
make sure to feed it predefined opaque types and the defining anchor
and that would require duplicating all of the tcx queries. Instead,
just perform these ops locally.
fn fully_perform_into( query_key: ParamEnvAnd<'tcx, Self>, infcx: &InferCtxt<'tcx>, output_query_region_constraints: &mut QueryRegionConstraints<'tcx> ) -> Result<(Self::QueryResponse, Option<Canonical<'tcx, ParamEnvAnd<'tcx, Self>>>, PredicateObligations<'tcx>, Certainty), NoSolution>
sourceimpl<'tcx> TypeFoldable<TyCtxt<'tcx>> for ImpliedOutlivesBounds<'tcx>
impl<'tcx> TypeFoldable<TyCtxt<'tcx>> for ImpliedOutlivesBounds<'tcx>
sourcefn try_fold_with<__F: FallibleTypeFolder<TyCtxt<'tcx>>>(
self,
__folder: &mut __F
) -> Result<Self, __F::Error>
fn try_fold_with<__F: FallibleTypeFolder<TyCtxt<'tcx>>>( self, __folder: &mut __F ) -> Result<Self, __F::Error>
sourcefn fold_with<F>(self, folder: &mut F) -> Selfwhere
F: TypeFolder<I>,
fn fold_with<F>(self, folder: &mut F) -> Selfwhere
F: TypeFolder<I>,
A convenient alternative to
try_fold_with for use with infallible
folders. Do not override this method, to ensure coherence with
try_fold_with.sourceimpl<'tcx> TypeVisitable<TyCtxt<'tcx>> for ImpliedOutlivesBounds<'tcx>
impl<'tcx> TypeVisitable<TyCtxt<'tcx>> for ImpliedOutlivesBounds<'tcx>
sourcefn visit_with<__V: TypeVisitor<TyCtxt<'tcx>>>(
&self,
__visitor: &mut __V
) -> ControlFlow<__V::BreakTy>
fn visit_with<__V: TypeVisitor<TyCtxt<'tcx>>>( &self, __visitor: &mut __V ) -> ControlFlow<__V::BreakTy>
impl<'tcx> Copy for ImpliedOutlivesBounds<'tcx>