Struct rustc_trait_selection::traits::query::type_op::AscribeUserType
source · pub struct AscribeUserType<'tcx> {
pub mir_ty: Ty<'tcx>,
pub user_ty: UserType<'tcx>,
}Fields
mir_ty: Ty<'tcx>user_ty: UserType<'tcx>Trait Implementations
sourceimpl<'tcx> QueryTypeOp<'tcx> for AscribeUserType<'tcx>
impl<'tcx> QueryTypeOp<'tcx> for AscribeUserType<'tcx>
type QueryResponse = ()
sourcefn try_fast_path(
_tcx: TyCtxt<'tcx>,
_key: &ParamEnvAnd<'tcx, Self>
) -> Option<Self::QueryResponse>
fn try_fast_path( _tcx: TyCtxt<'tcx>, _key: &ParamEnvAnd<'tcx, Self> ) -> Option<Self::QueryResponse>
Give query the option for a simple fast path that never
actually hits the tcx cache lookup etc. Return
Some(r) with
a final result or None to do the full path.sourcefn perform_query(
tcx: TyCtxt<'tcx>,
canonicalized: Canonical<'tcx, ParamEnvAnd<'tcx, Self>>
) -> Result<CanonicalQueryResponse<'tcx, ()>, NoSolution>
fn perform_query( tcx: TyCtxt<'tcx>, canonicalized: Canonical<'tcx, ParamEnvAnd<'tcx, Self>> ) -> Result<CanonicalQueryResponse<'tcx, ()>, NoSolution>
Performs the actual query with the canonicalized key – the
real work happens here. This method is not given an
infcx
because it shouldn’t need one – and if it had access to one,
it might do things like invoke sub_regions, which would be
bad, because it would create subregion relationships that are
not captured in the return value.sourcefn perform_locally_with_next_solver(
ocx: &ObligationCtxt<'_, 'tcx>,
key: ParamEnvAnd<'tcx, Self>
) -> Result<Self::QueryResponse, NoSolution>
fn perform_locally_with_next_solver( ocx: &ObligationCtxt<'_, 'tcx>, key: ParamEnvAnd<'tcx, Self> ) -> Result<Self::QueryResponse, NoSolution>
In the new trait solver, we already do caching in the solver itself,
so there’s no need to canonicalize and cache via the query system.
Additionally, even if we were to canonicalize, we’d still need to
make sure to feed it predefined opaque types and the defining anchor
and that would require duplicating all of the tcx queries. Instead,
just perform these ops locally.
fn fully_perform_into( query_key: ParamEnvAnd<'tcx, Self>, infcx: &InferCtxt<'tcx>, output_query_region_constraints: &mut QueryRegionConstraints<'tcx> ) -> Result<(Self::QueryResponse, Option<Canonical<'tcx, ParamEnvAnd<'tcx, Self>>>, PredicateObligations<'tcx>, Certainty), NoSolution>