struct Search<'tcx> {
    span: Span,
    tcx: TyCtxt<'tcx>,
    seen: FxHashSet<DefId>,
}
This implements the traversal over the structure of a given type to try to find instances of ADTs (specifically structs or enums) that do not implement StructuralPartialEq.

Fields

span: Spantcx: TyCtxt<'tcx>seen: FxHashSet<DefId>

Tracks ADTs previously encountered during search, so that we will not recur on them again.

Implementations

source

impl<'tcx> Search<'tcx>

source

fn type_marked_structural(&self, adt_ty: Ty<'tcx>) -> bool