Function rustc_ty_utils::assoc::associated_type_for_effects
source · fn associated_type_for_effects(
tcx: TyCtxt<'_>,
def_id: LocalDefId,
) -> Option<DefId>Expand description
Given an def_id of a trait or a trait impl:
If def_id is a trait that has #[const_trait], then it synthesizes
a new def id corresponding to a new associated type for the effects.
If def_id is an impl, then synthesize the associated type according
to the constness of the impl.