Function rustc_ty_utils::assoc::associated_type_for_impl_trait_in_impl
source · fn associated_type_for_impl_trait_in_impl(
tcx: TyCtxt<'_>,
trait_assoc_def_id: DefId,
impl_fn_def_id: LocalDefId,
) -> LocalDefIdExpand description
Given an trait_assoc_def_id corresponding to an associated item synthesized
from an impl Trait in an associated function from a trait, and an
impl_fn_def_id that represents an implementation of the associated function
that the impl Trait comes from, synthesize an associated type for that impl Trait
that inherits properties that we infer from the method and the associated type.