struct OpaqueTypeCollector<'tcx> {
    tcx: TyCtxt<'tcx>,
    opaques: Vec<LocalDefId>,
    item: LocalDefId,
    seen: FxHashSet<LocalDefId>,
    span: Option<Span>,
}

Fields

tcx: TyCtxt<'tcx>opaques: Vec<LocalDefId>item: LocalDefId

The DefId of the item which we are collecting opaque types for.

seen: FxHashSet<LocalDefId>

Avoid infinite recursion due to recursive declarations.

span: Option<Span>

Implementations

source

impl<'tcx> OpaqueTypeCollector<'tcx>

source

fn new(tcx: TyCtxt<'tcx>, item: LocalDefId) -> Self

source

fn span(&self) -> Span

source

fn visit_spanned(&mut self, span: Span, value: impl TypeVisitable<TyCtxt<'tcx>>)

source

fn parent_trait_ref(&self) -> Option<TraitRef<'tcx>>

source

fn parent(&self) -> Option<LocalDefId>

source

fn check_tait_defining_scope(&self, opaque_def_id: LocalDefId) -> bool

Returns true if opaque_hir_id is a sibling or a child of a sibling of self.item.

Example:

pub mod foo {
    pub mod bar {
        pub trait Bar { /* ... */ }
        pub type Baz = impl Bar;

        fn f1() -> Baz { /* ... */ }
    }
    fn f2() -> bar::Baz { /* ... */ }
}

and opaque_def_id is the DefId of the definition of the opaque type Baz. For the above example, this function returns true for f1 and false for f2.

source

fn collect_taits_declared_in_body(&mut self)