pub enum PredicateKind<I: Interner> {
Clause(ClauseKind<I>),
ObjectSafe(I::DefId),
Subtype(I::SubtypePredicate),
Coerce(I::CoercePredicate),
ConstEquate(I::Const, I::Const),
Ambiguous,
NormalizesTo(I::NormalizesTo),
AliasRelate(I::Term, I::Term, AliasRelationDirection),
}Variants
Clause(ClauseKind<I>)
Prove a clause
ObjectSafe(I::DefId)
Trait must be object-safe.
Subtype(I::SubtypePredicate)
T1 <: T2
This obligation is created most often when we have two unresolved type variables and hence don’t have enough information to process the subtyping obligation yet.
Coerce(I::CoercePredicate)
T1 coerced to T2
Like a subtyping obligation, this is created most often when we have two unresolved type variables and hence don’t have enough information to process the coercion obligation yet. At the moment, we actually process coercions very much like subtyping and don’t handle the full coercion logic.
ConstEquate(I::Const, I::Const)
Constants must be equal. The first component is the const that is expected.
Ambiguous
A marker predicate that is always ambiguous. Used for coherence to mark opaque types as possibly equal to each other but ambiguous.
NormalizesTo(I::NormalizesTo)
The alias normalizes to term. Unlike Projection, this always fails if the alias
cannot be normalized in the current context.
Projection(<T as Trait>::Assoc, ?x) results in ?x == <T as Trait>::Assoc while
NormalizesTo(<T as Trait>::Assoc, ?x) results in NoSolution.
Only used in the new solver.
AliasRelate(I::Term, I::Term, AliasRelationDirection)
Separate from ClauseKind::Projection which is used for normalization in new solver.
This predicate requires two terms to be equal to eachother.
Only used for new solver