Struct rustc_type_ir::search_graph::ProvisionalCacheEntry
source · struct ProvisionalCacheEntry<X: Cx> {
stack_depth: Option<StackDepth>,
with_inductive_stack: Option<DetachedEntry<X>>,
with_coinductive_stack: Option<DetachedEntry<X>>,
}Expand description
Stores the stack depth of a currently evaluated goal and already computed results for goals which depend on other goals still on the stack.
The provisional result may depend on whether the stack above it is inductive or coinductive. Because of this, we store separate provisional results for each case. If an provisional entry is not applicable, it may be the case that we already have provisional result while computing a goal. In this case we prefer the provisional result to potentially avoid fixpoint iterations. See tests/ui/traits/next-solver/cycles/mixed-cycles-2.rs for an example.
The provisional cache can theoretically result in changes to the observable behavior, see tests/ui/traits/next-solver/cycles/provisional-cache-impacts-behavior.rs.
Fields
stack_depth: Option<StackDepth>with_inductive_stack: Option<DetachedEntry<X>>with_coinductive_stack: Option<DetachedEntry<X>>Implementations