struct Indentor<'a, 'b> {
f: &'a mut (dyn Write + 'b),
state: IndentorState,
}Expand description
A formatter which adds 4 spaces of indentation to its input before passing it on to its nested formatter.
We can use this for arbitrary levels of indentation by nesting it.
Fields
f: &'a mut (dyn Write + 'b)state: IndentorStateTrait Implementations