Struct rustc_type_ir::CanonicalVarInfo
source · pub struct CanonicalVarInfo<I: Interner> {
pub kind: CanonicalVarKind<I>,
}Expand description
Information about a canonical variable that is included with the canonical value. This is sufficient information for code to create a copy of the canonical value in some other inference context, with fresh inference variables replacing the canonical values.
Fields
kind: CanonicalVarKind<I>Implementations
sourceimpl<I: Interner> CanonicalVarInfo<I>
impl<I: Interner> CanonicalVarInfo<I>
pub fn universe(self) -> UniverseIndex
pub fn with_updated_universe(self, ui: UniverseIndex) -> CanonicalVarInfo<I>
pub fn is_existential(&self) -> bool
pub fn is_region(&self) -> bool
pub fn expect_placeholder_index(self) -> usize