Struct rustc_type_ir::ty_kind::TypeAndMut
source · pub struct TypeAndMut<I: Interner> {
pub ty: I::Ty,
pub mutbl: Mutability,
}Fields
ty: I::Tymutbl: MutabilityTrait Implementations
sourceimpl<I: Interner> Clone for TypeAndMut<I>
impl<I: Interner> Clone for TypeAndMut<I>
sourceimpl<I: Interner> Debug for TypeAndMut<I>
impl<I: Interner> Debug for TypeAndMut<I>
sourceimpl<I: Interner> Hash for TypeAndMut<I>
impl<I: Interner> Hash for TypeAndMut<I>
sourceimpl<I: Interner, __CTX> HashStable<__CTX> for TypeAndMut<I>where
I::Ty: HashStable<__CTX>,
impl<I: Interner, __CTX> HashStable<__CTX> for TypeAndMut<I>where
I::Ty: HashStable<__CTX>,
fn hash_stable(&self, __hcx: &mut __CTX, __hasher: &mut StableHasher)
sourceimpl<I: Interner> Ord for TypeAndMut<I>
impl<I: Interner> Ord for TypeAndMut<I>
sourceimpl<I: Interner> PartialEq for TypeAndMut<I>
impl<I: Interner> PartialEq for TypeAndMut<I>
sourceimpl<I: Interner> PartialOrd for TypeAndMut<I>
impl<I: Interner> PartialOrd for TypeAndMut<I>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl<I: Interner> TypeFoldable<I> for TypeAndMut<I>where
I::Ty: TypeFoldable<I>,
impl<I: Interner> TypeFoldable<I> for TypeAndMut<I>where
I::Ty: TypeFoldable<I>,
sourcefn try_fold_with<F: FallibleTypeFolder<I>>(
self,
folder: &mut F
) -> Result<Self, F::Error>
fn try_fold_with<F: FallibleTypeFolder<I>>( self, folder: &mut F ) -> Result<Self, F::Error>
sourcefn fold_with<F: TypeFolder<I>>(self, folder: &mut F) -> Self
fn fold_with<F: TypeFolder<I>>(self, folder: &mut F) -> Self
A convenient alternative to
try_fold_with for use with infallible
folders. Do not override this method, to ensure coherence with
try_fold_with.sourceimpl<I: Interner> TypeVisitable<I> for TypeAndMut<I>where
I::Ty: TypeVisitable<I>,
impl<I: Interner> TypeVisitable<I> for TypeAndMut<I>where
I::Ty: TypeVisitable<I>,
sourcefn visit_with<V: TypeVisitor<I>>(
&self,
visitor: &mut V
) -> ControlFlow<V::BreakTy>
fn visit_with<V: TypeVisitor<I>>( &self, visitor: &mut V ) -> ControlFlow<V::BreakTy>
impl<I: Interner> Copy for TypeAndMut<I>
impl<I: Interner> Eq for TypeAndMut<I>