Struct rustdoc::core::DocContext
source · pub(crate) struct DocContext<'tcx> {Show 14 fields
pub(crate) tcx: TyCtxt<'tcx>,
pub(crate) param_env: ParamEnv<'tcx>,
pub(crate) external_traits: Rc<RefCell<FxHashMap<DefId, Trait>>>,
pub(crate) active_extern_traits: DefIdSet,
pub(crate) args: DefIdMap<GenericArg>,
pub(crate) current_type_aliases: DefIdMap<usize>,
pub(crate) impl_trait_bounds: FxHashMap<ImplTraitParam, Vec<GenericBound>>,
pub(crate) generated_synthetics: FxHashSet<(Ty<'tcx>, DefId)>,
pub(crate) auto_traits: Vec<DefId>,
pub(crate) render_options: RenderOptions,
pub(crate) cache: Cache,
pub(crate) inlined: FxHashSet<ItemId>,
pub(crate) output_format: OutputFormat,
pub(crate) show_coverage: bool,
}Fields
tcx: TyCtxt<'tcx>param_env: ParamEnv<'tcx>Used for normalization.
Most of this logic is copied from rustc_lint::late.
external_traits: Rc<RefCell<FxHashMap<DefId, Trait>>>Later on moved through clean::Crate into cache
active_extern_traits: DefIdSetUsed while populating external_traits to ensure we don’t process the same trait twice at
the same time.
args: DefIdMap<GenericArg>The current set of parameter instantiations for expanding type aliases at the HIR level.
Maps from the DefId of a lifetime or type parameter to the
generic argument it’s currently instantiated to in this context.
current_type_aliases: DefIdMap<usize>impl_trait_bounds: FxHashMap<ImplTraitParam, Vec<GenericBound>>Table synthetic type parameter for impl Trait in argument position -> bounds
generated_synthetics: FxHashSet<(Ty<'tcx>, DefId)>Auto-trait or blanket impls processed so far, as (self_ty, trait_def_id).
auto_traits: Vec<DefId>render_options: RenderOptionsThe options given to rustdoc that could be relevant to a pass.
cache: CacheThis same cache is used throughout rustdoc, including in crate::html::render.
inlined: FxHashSet<ItemId>Used by clean::inline to tell if an item has already been inlined.
output_format: OutputFormatUsed by calculate_doc_coverage.
show_coverage: boolUsed by strip_private.
Implementations
sourceimpl<'tcx> DocContext<'tcx>
impl<'tcx> DocContext<'tcx>
pub(crate) fn sess(&self) -> &'tcx Session
pub(crate) fn with_param_env<T, F: FnOnce(&mut Self) -> T>( &mut self, def_id: DefId, f: F ) -> T
sourcepub(crate) fn enter_alias<F, R>(
&mut self,
args: DefIdMap<GenericArg>,
def_id: DefId,
f: F
) -> R
pub(crate) fn enter_alias<F, R>( &mut self, args: DefIdMap<GenericArg>, def_id: DefId, f: F ) -> R
Call the closure with the given parameters set as the generic parameters for a type alias’ RHS.