struct ItemVars<'a> {
static_root_path: &'a str,
clipboard_svg: &'static StaticFile,
typ: &'a str,
name: &'a str,
item_type: &'a str,
path_components: Vec<PathComponent>,
stability_since_raw: &'a str,
src_href: Option<&'a str>,
}Fields
static_root_path: &'a strclipboard_svg: &'static StaticFiletyp: &'a strname: &'a stritem_type: &'a strpath_components: Vec<PathComponent>stability_since_raw: &'a strsrc_href: Option<&'a str>Trait Implementations
sourceimpl<'a> Template for ItemVars<'a>
impl<'a> Template for ItemVars<'a>
sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt buffersourceconst SIZE_HINT: usize = 409usize
const SIZE_HINT: usize = 409usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template