Struct rustdoc::html::render::type_layout::TypeLayoutSize
source · struct TypeLayoutSize {
is_unsized: bool,
is_uninhabited: bool,
size: u64,
}Fields
is_unsized: boolis_uninhabited: boolsize: u64Trait Implementations
sourceimpl Display for TypeLayoutSize
impl Display for TypeLayoutSize
sourceimpl Template for TypeLayoutSize
impl Template for TypeLayoutSize
sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt buffersourceconst SIZE_HINT: usize = 65usize
const SIZE_HINT: usize = 65usize
Provides a conservative estimate of the expanded length of the rendered template
sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template