Function rustfmt_nightly::lists::calculate_width
source · fn calculate_width<I, T>(items: I) -> (usize, usize)Expand description
Returns the count and total width of the list items.
fn calculate_width<I, T>(items: I) -> (usize, usize)Returns the count and total width of the list items.