Struct rustc::session::CrateDisambiguator
[−]
[src]
pub struct CrateDisambiguator(_);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Hash value constructed out of all the -C metadata arguments passed to the
compiler. Together with the crate-name forms a unique global identifier for
the crate.
Methods
impl CrateDisambiguator[src]
impl CrateDisambiguatorpub fn to_fingerprint(self) -> Fingerprint[src]
pub fn to_fingerprint(self) -> Fingerprint🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?