Type Alias stable_mir::abi::Scalar

source ·
type Scalar = Opaque;
We currently do not support Scalar, and use opaque instead.

Aliased Type

struct Scalar(pub(crate) String);

Fields

0: String

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 24 bytes