Function rustc::traits::coherence::overlap [−][src]
fn overlap<'cx, 'gcx, 'tcx>(
selcx: &mut SelectionContext<'cx, 'gcx, 'tcx>,
a_def_id: DefId,
b_def_id: DefId
) -> Option<OverlapResult<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Can both impl a and impl b be satisfied by a common type (including
where clauses)? If so, returns an ImplHeader that unifies the two impls.