Enum rustc::traits::Clause [−][src]
pub enum Clause<'tcx> {
Implies(ProgramClause<'tcx>),
ForAll(Binder<ProgramClause<'tcx>>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This matches the definition from Page 7 of "A Proof Procedure for the Logic of Hereditary Harrop Formulas".
Variants
Implies(ProgramClause<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ForAll(Binder<ProgramClause<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?