Enum rustc::traits::error_reporting::ArgKind [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Summarizes information
Variants
Arg(String, String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An argument of non-tuple type. Parameters are (name, ty)
Tuple(Option<Span>, Vec<(String, String)>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An argument of tuple type. For a "found" argument, the span is the locationo in the source of the pattern. For a "expected" argument, it will be None. The vector is a list of (name, ty) strings for the components of the tuple.
Methods
impl ArgKind[src]
impl ArgKindfn empty() -> ArgKind[src]
fn empty() -> ArgKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_expected_ty(t: Ty) -> ArgKind[src]
pub fn from_expected_ty(t: Ty) -> ArgKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates an ArgKind from the expected type of an
argument. This has no name (_) and no source spans..