Enum rustc::traits::object_safety::ObjectSafetyViolation [−][src]
pub enum ObjectSafetyViolation {
SizedSelf,
SupertraitSelf,
Method(Name, MethodViolationCode),
AssociatedConst(Name),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
SizedSelf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Self : Sized declared on the trait
SupertraitSelf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Supertrait reference references Self an in illegal location
(e.g. trait Foo : Bar<Self>)
Method(Name, MethodViolationCode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Method has something illegal
AssociatedConst(Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated const
Methods
impl ObjectSafetyViolation[src]
impl ObjectSafetyViolationpub fn error_msg(&self) -> Cow<'static, str>[src]
pub fn error_msg(&self) -> Cow<'static, str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?