Struct rustc::traits::on_unimplemented::OnUnimplementedFormatString [−][src]
pub struct OnUnimplementedFormatString(LocalInternedString);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> OnUnimplementedFormatString[src]
impl<'a, 'gcx, 'tcx> OnUnimplementedFormatStringpub fn try_parse(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_def_id: DefId,
from: LocalInternedString,
err_sp: Span
) -> Result<Self, ErrorReported>[src]
pub fn try_parse(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_def_id: DefId,
from: LocalInternedString,
err_sp: Span
) -> Result<Self, ErrorReported>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn verify(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_def_id: DefId,
span: Span
) -> Result<(), ErrorReported>[src]
fn verify(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_def_id: DefId,
span: Span
) -> Result<(), ErrorReported>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn format(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_ref: TraitRef<'tcx>
) -> String[src]
pub fn format(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
trait_ref: TraitRef<'tcx>
) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?