Enum rustc::traits::project::ProjectionTyCandidate [−][src]
enum ProjectionTyCandidate<'tcx> {
ParamEnv(PolyProjectionPredicate<'tcx>),
TraitDef(PolyProjectionPredicate<'tcx>),
Select(Selection<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
ParamEnv(PolyProjectionPredicate<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TraitDef(PolyProjectionPredicate<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Select(Selection<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?