Enum rustc::traits::project::ProjectionTyError [−][src]
pub enum ProjectionTyError<'tcx> {
TooManyCandidates,
TraitSelectionError(SelectionError<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When attempting to resolve <T as TraitRef>::Name ...
Variants
TooManyCandidates🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
...we found multiple sources of information and couldn't resolve the ambiguity.
TraitSelectionError(SelectionError<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
...an error occurred matching T : TraitRef