Enum rustc::traits::project::Reveal [−][src]
pub enum Reveal {
UserFacing,
All,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Depending on the stage of compilation, we want projection to be more or less conservative.
Variants
UserFacing🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
At type-checking time, we refuse to project any associated
type that is marked default. Non-default ("final") types
are always projected. This is necessary in general for
soundness of specialization. However, we could allow
projections in fully-monomorphic cases. We choose not to,
because we prefer for default type to force the type
definition to be treated abstractly by any consumers of the
impl. Concretely, that means that the following example will
fail to compile:
trait Assoc { type Output; } impl<T> Assoc for T { default type Output = bool; } fn main() { let <() as Assoc>::Output = true; }
All🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
At codegen time, all monomorphic projections will succeed.
Also, impl Trait is normalized to the concrete type,
which has to be already collected by type-checking.
NOTE: As impl Trait's concrete type should never
be observable directly by the user, Reveal::All
should not be used by checks which may expose
type equality or type contents to the user.
There are some exceptions, e.g. around OIBITS and
transmute-checking, which expose some details, but
not the whole concrete type of the impl Trait.