Struct rustc::traits::project::AssociatedTypeNormalizer [−][src]
struct AssociatedTypeNormalizer<'a, 'b: 'a, 'gcx: 'b + 'tcx, 'tcx: 'b> {
selcx: &'a mut SelectionContext<'b, 'gcx, 'tcx>,
param_env: ParamEnv<'tcx>,
cause: ObligationCause<'tcx>,
obligations: Vec<PredicateObligation<'tcx>>,
depth: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
selcx: &'a mut SelectionContext<'b, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
param_env: ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cause: ObligationCause<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
obligations: Vec<PredicateObligation<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
depth: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'b, 'gcx, 'tcx> AssociatedTypeNormalizer<'a, 'b, 'gcx, 'tcx>[src]
impl<'a, 'b, 'gcx, 'tcx> AssociatedTypeNormalizer<'a, 'b, 'gcx, 'tcx>fn new(
selcx: &'a mut SelectionContext<'b, 'gcx, 'tcx>,
param_env: ParamEnv<'tcx>,
cause: ObligationCause<'tcx>,
depth: usize
) -> AssociatedTypeNormalizer<'a, 'b, 'gcx, 'tcx>[src]
fn new(
selcx: &'a mut SelectionContext<'b, 'gcx, 'tcx>,
param_env: ParamEnv<'tcx>,
cause: ObligationCause<'tcx>,
depth: usize
) -> AssociatedTypeNormalizer<'a, 'b, 'gcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn fold<T: TypeFoldable<'tcx>>(&mut self, value: &T) -> T[src]
fn fold<T: TypeFoldable<'tcx>>(&mut self, value: &T) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?