Struct rustc::traits::project::Progress [−][src]
struct Progress<'tcx> {
ty: Ty<'tcx>,
obligations: Vec<PredicateObligation<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ty: Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
obligations: Vec<PredicateObligation<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> Progress<'tcx>[src]
impl<'tcx> Progress<'tcx>fn error<'a, 'gcx>(tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Self[src]
fn error<'a, 'gcx>(tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn with_addl_obligations(
self,
obligations: Vec<PredicateObligation<'tcx>>
) -> Self[src]
fn with_addl_obligations(
self,
obligations: Vec<PredicateObligation<'tcx>>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?