Struct rustc::traits::project::ProjectionCacheKey [−][src]
pub struct ProjectionCacheKey<'tcx> {
ty: ProjectionTy<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ty: ProjectionTy<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'cx, 'gcx, 'tcx> ProjectionCacheKey<'tcx>[src]
impl<'cx, 'gcx, 'tcx> ProjectionCacheKey<'tcx>pub fn from_poly_projection_predicate(
selcx: &mut SelectionContext<'cx, 'gcx, 'tcx>,
predicate: &PolyProjectionPredicate<'tcx>
) -> Option<Self>[src]
pub fn from_poly_projection_predicate(
selcx: &mut SelectionContext<'cx, 'gcx, 'tcx>,
predicate: &PolyProjectionPredicate<'tcx>
) -> Option<Self>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?