Enum rustc::traits::select::BuiltinImplConditions [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When does the builtin impl for T: Trait apply?
Variants
Where(Binder<Vec<Ty<'tcx>>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The impl is conditional on T1,T2,.. : Trait
None🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
There is no built-in impl. There may be some other candidate (a where-clause or user-defined impl).
Ambiguous🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
It is unknown whether there is an impl.