Enum rustc::traits::specialize::specialization_graph::Inserted [−][src]
enum Inserted {
BecameNewSibling(Option<OverlapError>),
ReplaceChild(DefId),
ShouldRecurseOn(DefId),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The result of attempting to insert an impl into a group of children.
Variants
BecameNewSibling(Option<OverlapError>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The impl was inserted as a new child in this group of children.
ReplaceChild(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The impl should replace an existing impl X, because the impl specializes X.
ShouldRecurseOn(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The impl is a specialization of an existing child.