Struct rustc::traits::specialize::specialization_graph::NodeItem [−][src]
pub struct NodeItem<T> {
pub node: Node,
pub item: T,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
node: Node
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
item: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> NodeItem<T>[src]
impl<T> NodeItem<T>pub fn map<U, F: FnOnce(T) -> U>(self, f: F) -> NodeItem<U>[src]
pub fn map<U, F: FnOnce(T) -> U>(self, f: F) -> NodeItem<U>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?