Struct rustc::traits::DerivedObligationCause [−][src]
pub struct DerivedObligationCause<'tcx> {
parent_trait_ref: PolyTraitRef<'tcx>,
parent_code: Rc<ObligationCauseCode<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
parent_trait_ref: PolyTraitRef<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The trait reference of the parent obligation that led to the current obligation. Note that only trait obligations lead to derived obligations, so we just store the trait reference here directly.
parent_code: Rc<ObligationCauseCode<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The parent trait had this cause