Struct rustc::traits::EvaluationCache [−][src]
pub struct EvaluationCache<'tcx> {
hashmap: RefCell<FxHashMap<PolyTraitRef<'tcx>, WithDepNode<EvaluationResult>>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
hashmap: RefCell<FxHashMap<PolyTraitRef<'tcx>, WithDepNode<EvaluationResult>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> EvaluationCache<'tcx>[src]
impl<'tcx> EvaluationCache<'tcx>pub fn new() -> EvaluationCache<'tcx>[src]
pub fn new() -> EvaluationCache<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&self)[src]
pub fn clear(&self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?