[−][src]Struct rustc::traits::FulfillmentContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The fulfillment context is used to drive trait resolution. It
consists of a list of obligations that must be (eventually)
satisfied. The job is to track which are satisfied, which yielded
errors, and which are still pending. At any point, users can call
select_where_possible, and the fulfillment context will try to do
selection, retaining only those obligations that remain
ambiguous. This may be helpful in pushing type inference
along. Once all type inference constraints have been generated, the
method select_all_or_error can be used to report any remaining
ambiguous cases as errors.
Fields
predicates: ObligationForest<PendingPredicateObligation<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
register_region_obligations: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> FulfillmentContext<'tcx>[src]
impl<'a, 'gcx, 'tcx> FulfillmentContext<'tcx>pub fn new() -> FulfillmentContext<'tcx>[src]
pub fn new() -> FulfillmentContext<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a new fulfillment context.
pub fn new_ignoring_regions() -> FulfillmentContext<'tcx>[src]
pub fn new_ignoring_regions() -> FulfillmentContext<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn select(
&mut self,
selcx: &mut SelectionContext<'a, 'gcx, 'tcx>
) -> Result<(), Vec<FulfillmentError<'tcx>>>[src]
fn select(
&mut self,
selcx: &mut SelectionContext<'a, 'gcx, 'tcx>
) -> Result<(), Vec<FulfillmentError<'tcx>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Attempts to select obligations using selcx.