Struct rustc::traits::MismatchedProjectionTypes
[−]
[src]
pub struct MismatchedProjectionTypes<'tcx> {
pub err: TypeError<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
err: TypeError<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?