Struct rustc::traits::ObligationCause [−][src]
pub struct ObligationCause<'tcx> {
pub span: Span,
pub body_id: NodeId,
pub code: ObligationCauseCode<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Why did we incur this obligation? Used for error reporting.
Fields
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
body_id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
code: ObligationCauseCode<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> ObligationCause<'tcx>[src]
impl<'tcx> ObligationCause<'tcx>fn as_failure_code(&self, terr: &TypeError<'tcx>) -> FailureCode[src]
fn as_failure_code(&self, terr: &TypeError<'tcx>) -> FailureCode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn as_requirement_str(&self) -> &'static str[src]
fn as_requirement_str(&self) -> &'static str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> ObligationCause<'tcx>[src]
impl<'tcx> ObligationCause<'tcx>pub fn span<'a, 'gcx>(&self, tcx: &TyCtxt<'a, 'gcx, 'tcx>) -> Span[src]
pub fn span<'a, 'gcx>(&self, tcx: &TyCtxt<'a, 'gcx, 'tcx>) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> ObligationCause<'tcx>[src]
impl<'tcx> ObligationCause<'tcx>pub fn new(
span: Span,
body_id: NodeId,
code: ObligationCauseCode<'tcx>
) -> ObligationCause<'tcx>[src]
pub fn new(
span: Span,
body_id: NodeId,
code: ObligationCauseCode<'tcx>
) -> ObligationCause<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn misc(span: Span, body_id: NodeId) -> ObligationCause<'tcx>[src]
pub fn misc(span: Span, body_id: NodeId) -> ObligationCause<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn dummy() -> ObligationCause<'tcx>[src]
pub fn dummy() -> ObligationCause<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?