Struct rustc::traits::VtableGeneratorData [−][src]
pub struct VtableGeneratorData<'tcx, N> {
pub generator_def_id: DefId,
pub substs: GeneratorSubsts<'tcx>,
pub nested: Vec<N>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
generator_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
substs: GeneratorSubsts<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
nested: Vec<N>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Nested obligations. This can be non-empty if the generator signature contains associated types.