Enum rustc::ty::adjustment::Adjust [−][src]
pub enum Adjust<'tcx> {
NeverToAny,
ReifyFnPointer,
UnsafeFnPointer,
ClosureFnPointer,
MutToConstPointer,
Deref(Option<OverloadedDeref<'tcx>>),
Borrow(AutoBorrow<'tcx>),
Unsize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
NeverToAny🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Go from ! to any type.
ReifyFnPointer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Go from a fn-item type to a fn-pointer type.
UnsafeFnPointer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Go from a safe fn pointer to an unsafe fn pointer.
ClosureFnPointer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Go from a non-capturing closure to an fn pointer.
MutToConstPointer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Go from a mut raw pointer to a const raw pointer.
Deref(Option<OverloadedDeref<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Dereference once, producing a place.
Borrow(AutoBorrow<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Take the address and produce either a & or * pointer.
Unsize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Unsize a pointer/reference value, e.g. &[T; n] to
&[T]. Note that the source could be a thin or fat pointer.
This will do things like convert thin pointers to fat
pointers, or convert structs containing thin pointers to
structs containing fat pointers, or convert between fat
pointers. We don't store the details of how the transform is
done (in fact, we don't know that, because it might depend on
the precise type parameters). We just store the target
type. Codegen backends and miri figure out what has to be done
based on the precise source/target type at hand.