Enum rustc::ty::adjustment::AutoBorrow [−][src]
pub enum AutoBorrow<'tcx> {
Ref(Region<'tcx>, AutoBorrowMutability),
RawPtr(Mutability),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Ref(Region<'tcx>, AutoBorrowMutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from T to &T.
RawPtr(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from T to *T.