Enum rustc::ty::adjustment::CustomCoerceUnsized [−][src]
pub enum CustomCoerceUnsized {
Struct(usize),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Struct(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Records the index of the field being coerced.