Enum rustc::ty::binding::BindingMode [−][src]
pub enum BindingMode {
BindByReference(Mutability),
BindByValue(Mutability),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
BindByReference(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
BindByValue(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl BindingMode[src]
impl BindingModepub fn convert(ba: BindingAnnotation) -> BindingMode[src]
pub fn convert(ba: BindingAnnotation) -> BindingMode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?