Struct rustc::ty::context::LocalTableInContextMut [−][src]
pub struct LocalTableInContextMut<'a, V: 'a> {
local_id_root: Option<DefId>,
data: &'a mut ItemLocalMap<V>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
local_id_root: Option<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
data: &'a mut ItemLocalMap<V>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, V> LocalTableInContextMut<'a, V>[src]
impl<'a, V> LocalTableInContextMut<'a, V>pub fn get_mut(&mut self, id: HirId) -> Option<&mut V>[src]
pub fn get_mut(&mut self, id: HirId) -> Option<&mut V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn entry(&mut self, id: HirId) -> Entry<ItemLocalId, V>[src]
pub fn entry(&mut self, id: HirId) -> Entry<ItemLocalId, V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn insert(&mut self, id: HirId, val: V) -> Option<V>[src]
pub fn insert(&mut self, id: HirId, val: V) -> Option<V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove(&mut self, id: HirId) -> Option<V>[src]
pub fn remove(&mut self, id: HirId) -> Option<V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?