[−][src]Trait rustc::ty::context::InternIteratorElement
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type Output
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output
iter: I,
f: F
) -> Self::Output
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'a, T, R> InternIteratorElement<T, R> for &'a T where
T: Clone + 'a, [src]
impl<'a, T, R> InternIteratorElement<T, R> for &'a T where
T: Clone + 'a, type Output = R
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output[src]
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T, R, E> InternIteratorElement<T, R> for Result<T, E>[src]
impl<T, R, E> InternIteratorElement<T, R> for Result<T, E>type Output = Result<R, E>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output[src]
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<T, R> InternIteratorElement<T, R> for T[src]
impl<T, R> InternIteratorElement<T, R> for Ttype Output = R
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output[src]
fn intern_with<I: Iterator<Item = Self>, F: FnOnce(&[T]) -> R>(
iter: I,
f: F
) -> Self::Output🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?