Enum rustc::ty::InstanceDef
[−]
[src]
pub enum InstanceDef<'tcx> {
Item(DefId),
Intrinsic(DefId),
FnPtrShim(DefId, Ty<'tcx>),
Virtual(DefId, usize),
ClosureOnceShim {
call_once: DefId,
},
DropGlue(DefId, Option<Ty<'tcx>>),
CloneShim(DefId, Ty<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Item(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Intrinsic(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
FnPtrShim(DefId, Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
<fn() as FnTrait>::call_* def-id is FnTrait::call_*
Virtual(DefId, usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ClosureOnceShim🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
<[mut closure] as FnOnce>::call_once
Fields of ClosureOnceShim
call_once: DefId | 🔬 This is a nightly-only experimental API. ( |
DropGlue(DefId, Option<Ty<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
drop_in_place::
CloneShim(DefId, Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
<T as Clone>::clone shim.
Methods
impl<'tcx> InstanceDef<'tcx>[src]
impl<'tcx> InstanceDef<'tcx>pub fn def_id(&self) -> DefId[src]
pub fn def_id(&self) -> DefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn attrs<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> Attributes<'tcx>[src]
pub fn attrs<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> Attributes<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_inline<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> bool[src]
pub fn is_inline<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn requires_local<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> bool[src]
pub fn requires_local<'a>(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?