[−][src]Enum rustc::ty::TyKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NB: If you change this, you'll probably want to change the corresponding AST structure in libsyntax/ast.rs as well.
Variants
Bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The primitive boolean type. Written as bool.
Char🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The primitive character type; holds a Unicode scalar value
(a non-surrogate code point). Written as char.
Int(IntTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A primitive signed integer type. For example, i32.
Uint(UintTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A primitive unsigned integer type. For example, u32.
Float(FloatTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A primitive floating-point type. For example, f64.
Adt(&'tcx AdtDef, &'tcx Substs<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Structures, enumerations and unions.
Substs here, possibly against intuition, may contain Params.
That is, even after substitution it is possible that there are type
variables. This happens when the Adt corresponds to an ADT
definition and not a concrete use of it.
Foreign(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The pointee of a string slice. Written as str.
Array(Ty<'tcx>, &'tcx Const<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An array with the given length. Written as [T; n].
Slice(Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The pointee of an array slice. Written as [T].
RawPtr(TypeAndMut<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A raw pointer. Written as *mut T or *const T
Ref(Region<'tcx>, Ty<'tcx>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A reference; a pointer with an associated lifetime. Written as
&'a mut T or &'a T.
FnDef(DefId, &'tcx Substs<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The anonymous type of a function declaration/definition. Each function has a unique type.
FnPtr(PolyFnSig<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A pointer to a function. Written as fn() -> i32.
Dynamic(Binder<&'tcx List<ExistentialPredicate<'tcx>>>, Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A trait, defined with trait.
Closure(DefId, ClosureSubsts<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The anonymous type of a closure. Used to represent the type of
|a| a.
Generator(DefId, GeneratorSubsts<'tcx>, GeneratorMovability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The anonymous type of a generator. Used to represent the type of
|a| yield a.
GeneratorWitness(Binder<&'tcx List<Ty<'tcx>>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A type representin the types stored inside a generator. This should only appear in GeneratorInteriors.
Never🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The never type !
Tuple(&'tcx List<Ty<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A tuple type. For example, (i32, bool).
Projection(ProjectionTy<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The projection of an associated type. For example,
<T as Trait<..>>::N.
Opaque(DefId, &'tcx Substs<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Opaque (impl Trait) type found in a return type.
The DefId comes either from
- the
impl Traitast::Ty node, - or the
existential typedeclaration The substitutions are for the generics of the function in question. After typeck, the concrete type can be found in thetypesmap.
Param(ParamTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A type parameter; for example, T in `fn f
Infer(InferTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A type variable used during type-checking.
Error🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A placeholder for a type which could not be computed; this is propagated to avoid useless error messages.