Enum rustc::ty::UpvarCapture [−][src]
pub enum UpvarCapture<'tcx> {
ByValue,
ByRef(UpvarBorrow<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Information describing the capture of an upvar. This is computed
during typeck, specifically by regionck.
Variants
ByValue🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Upvar is captured by value. This is always true when the
closure is labeled move, but can also be true in other cases
depending on inference.
ByRef(UpvarBorrow<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Upvar is captured by reference.