Enum rustc::ty::UpvarSubsts [−][src]
pub enum UpvarSubsts<'tcx> {
Closure(ClosureSubsts<'tcx>),
Generator(GeneratorSubsts<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Closure(ClosureSubsts<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Generator(GeneratorSubsts<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> UpvarSubsts<'tcx>[src]
impl<'tcx> UpvarSubsts<'tcx>pub fn upvar_tys(
self,
def_id: DefId,
tcx: TyCtxt
) -> impl Iterator<Item = Ty<'tcx>> + 'tcx[src]
pub fn upvar_tys(
self,
def_id: DefId,
tcx: TyCtxt
) -> impl Iterator<Item = Ty<'tcx>> + 'tcx🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?