Enum rustc::ty::VariantDiscr
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Explicit(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Explicit value for this variant, i.e. X = 123.
The DefId corresponds to the embedded constant.
Relative(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The previous variant's discriminant plus one.
For efficiency reasons, the distance from the
last Explicit discriminant is being stored,
or 0 for the first variant, if it has none.