Struct rustc::ty::fold::RegionReplacer [−][src]
struct RegionReplacer<'a, 'gcx: 'a + 'tcx, 'tcx: 'a> {
tcx: TyCtxt<'a, 'gcx, 'tcx>,
current_depth: u32,
fld_r: &'a mut (FnMut(BoundRegion) -> Region<'tcx> + 'a),
map: LazyBTreeMap<BoundRegion, Region<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
current_depth: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fld_r: &'a mut (FnMut(BoundRegion) -> Region<'tcx> + 'a)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
map: LazyBTreeMap<BoundRegion, Region<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> RegionReplacer<'a, 'gcx, 'tcx>[src]
impl<'a, 'gcx, 'tcx> RegionReplacer<'a, 'gcx, 'tcx>fn new<F>(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
fld_r: &'a mut F
) -> RegionReplacer<'a, 'gcx, 'tcx> where
F: FnMut(BoundRegion) -> Region<'tcx>, [src]
fn new<F>(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
fld_r: &'a mut F
) -> RegionReplacer<'a, 'gcx, 'tcx> where
F: FnMut(BoundRegion) -> Region<'tcx>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?