Enum rustc::ty::layout::call::PassMode [−][src]
pub enum PassMode {
Ignore,
Direct(ArgAttributes),
Pair(ArgAttributes, ArgAttributes),
Cast(CastTarget),
Indirect(ArgAttributes),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Ignore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ignore the argument (useful for empty struct).
Direct(ArgAttributes)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pass the argument directly.
Pair(ArgAttributes, ArgAttributes)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pass a pair's elements directly in two arguments.
Cast(CastTarget)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pass the argument after casting it, to either a single uniform or a pair of registers.
Indirect(ArgAttributes)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pass the argument indirectly via a hidden pointer.