pub struct Uniform {
pub unit: Reg,
pub total: Size,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An argument passed entirely registers with the
same kind (e.g. HFA / HVA on PPC64 and AArch64).
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The total size of the argument, which can be:
- equal to
unit.size (one scalar/vector)
- a multiple of
unit.size (an array of scalar/vectors)
- if
unit.kind is Integer, the last element
can be shorter, i.e. { i64, i64, i32 } for
64-bit integers with a total size of 20 bytes
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.