Enum rustc::ty::layout::Integer [−][src]
pub enum Integer {
I8,
I16,
I32,
I64,
I128,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Integers, also used for enum discriminants.
Variants
I8🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
I16🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
I32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
I64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
I128🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Integer[src]
impl Integerpub fn size(&self) -> Size[src]
pub fn size(&self) -> Size🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn align<C>(&self, cx: C) -> Align where
C: HasDataLayout, [src]
pub fn align<C>(&self, cx: C) -> Align where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn fit_signed(x: i128) -> Integer[src]
pub fn fit_signed(x: i128) -> Integer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the smallest Integer type which can represent the signed value.
pub fn fit_unsigned(x: u128) -> Integer[src]
pub fn fit_unsigned(x: u128) -> Integer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the smallest Integer type which can represent the unsigned value.
pub fn for_abi_align<C>(cx: C, align: Align) -> Option<Integer> where
C: HasDataLayout, [src]
pub fn for_abi_align<C>(cx: C, align: Align) -> Option<Integer> where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the smallest integer with the given alignment.
pub fn approximate_abi_align<C>(cx: C, align: Align) -> Integer where
C: HasDataLayout, [src]
pub fn approximate_abi_align<C>(cx: C, align: Align) -> Integer where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the largest integer with the given alignment or less.