[−][src]Enum rustc::ty::layout::Primitive
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fundamental unit of memory access and layout.
Variants
Int(Integer, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The bool is the signedness of the Integer type.
One would think we would not care about such details this low down, but some ABIs are described in terms of C types and ISAs where the integer arithmetic is done on {sign,zero}-extended registers, e.g. a negative integer passed by zero-extension will appear positive in the callee, and most operations on it will produce the wrong values.
Float(FloatTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pointer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> Primitive[src]
impl<'a, 'tcx> Primitivepub fn size<C>(self, cx: C) -> Size where
C: HasDataLayout, [src]
pub fn size<C>(self, cx: C) -> Size where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn align<C>(self, cx: C) -> Align where
C: HasDataLayout, [src]
pub fn align<C>(self, cx: C) -> Align where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_float(self) -> bool[src]
pub fn is_float(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_int(self) -> bool[src]
pub fn is_int(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?