Struct rustc::ty::layout::Align
[−]
[src]
pub struct Align { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Alignment of a type in bytes, both ABI-mandated and preferred. Each field is a power of two, giving the alignment a maximum value of 2(28 - 1), which is limited by LLVM to a i32, with a maximum capacity of 231 - 1 or 2147483647.
Methods
impl Align[src]
impl Alignpub fn from_bits(abi: u64, pref: u64) -> Result<Align, String>[src]
pub fn from_bits(abi: u64, pref: u64) -> Result<Align, String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_bytes(abi: u64, pref: u64) -> Result<Align, String>[src]
pub fn from_bytes(abi: u64, pref: u64) -> Result<Align, String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn abi(self) -> u64[src]
pub fn abi(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn pref(self) -> u64[src]
pub fn pref(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn abi_bits(self) -> u64[src]
pub fn abi_bits(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn pref_bits(self) -> u64[src]
pub fn pref_bits(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn min(self, other: Align) -> Align[src]
pub fn min(self, other: Align) -> Align🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn max(self, other: Align) -> Align[src]
pub fn max(self, other: Align) -> Align🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?