Struct rustc::ty::layout::Size [−][src]
pub struct Size {
raw: u64,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Size of a type in bytes.
Fields
raw: u64
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Size[src]
impl Sizepub const ZERO: Size
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ZERO: Size = <Self>::from_bytes(0)
pub fn from_bits(bits: u64) -> Size[src]
pub fn from_bits(bits: u64) -> Size🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub const fn from_bytes(bytes: u64) -> Size[src]
pub const fn from_bytes(bytes: u64) -> Size🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn bytes(self) -> u64[src]
pub fn bytes(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn bits(self) -> u64[src]
pub fn bits(self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn abi_align(self, align: Align) -> Size[src]
pub fn abi_align(self, align: Align) -> Size🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_abi_aligned(self, align: Align) -> bool[src]
pub fn is_abi_aligned(self, align: Align) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn checked_add<C>(self, offset: Size, cx: C) -> Option<Size> where
C: HasDataLayout, [src]
pub fn checked_add<C>(self, offset: Size, cx: C) -> Option<Size> where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn checked_mul<C>(self, count: u64, cx: C) -> Option<Size> where
C: HasDataLayout, [src]
pub fn checked_mul<C>(self, count: u64, cx: C) -> Option<Size> where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?