[−][src]Trait rustc::ty::layout::LayoutOf
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type Ty
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type TyLayout
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn layout_of(self, ty: Self::Ty) -> Self::TyLayout
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<'a, 'tcx> LayoutOf for &'a LateContext<'a, 'tcx>[src]
impl<'a, 'tcx> LayoutOf for &'a LateContext<'a, 'tcx>type Ty = Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type TyLayout = Result<TyLayout<'tcx>, LayoutError<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout[src]
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx> LayoutOf for LayoutCx<'tcx, TyCtxtAt<'a, 'tcx, 'tcx>>[src]
impl<'a, 'tcx> LayoutOf for LayoutCx<'tcx, TyCtxtAt<'a, 'tcx, 'tcx>>type Ty = Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type TyLayout = Result<TyLayout<'tcx>, LayoutError<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout[src]
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Computes the layout of a type. Note that this implicitly executes in "reveal all" mode.
impl<'a, 'tcx> LayoutOf for LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>[src]
impl<'a, 'tcx> LayoutOf for LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>type Ty = Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type TyLayout = Result<TyLayout<'tcx>, LayoutError<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout[src]
fn layout_of(self, ty: Ty<'tcx>) -> Self::TyLayout🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Computes the layout of a type. Note that this implicitly executes in "reveal all" mode.