[−][src]Trait rustc::ty::layout::MaybeResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn from_ok(x: T) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F: FnOnce(T) -> T>(self, f: F) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<T, E> MaybeResult<T> for Result<T, E>[src]
impl<T, E> MaybeResult<T> for Result<T, E>fn from_ok(x: T) -> Self[src]
fn from_ok(x: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F: FnOnce(T) -> T>(self, f: F) -> Self[src]
fn map_same<F: FnOnce(T) -> T>(self, f: F) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<T> MaybeResult<T> for T[src]
impl<T> MaybeResult<T> for Tfn from_ok(x: T) -> Self[src]
fn from_ok(x: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F: FnOnce(T) -> T>(self, f: F) -> Self[src]
fn map_same<F: FnOnce(T) -> T>(self, f: F) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?