Struct rustc::ty::maps::on_disk_cache::Footer [−][src]
struct Footer {
file_index_to_stable_id: FxHashMap<FileMapIndex, StableFilemapId>,
prev_cnums: Vec<(u32, String, CrateDisambiguator)>,
query_result_index: Vec<(SerializedDepNodeIndex, AbsoluteBytePos)>,
diagnostics_index: Vec<(SerializedDepNodeIndex, AbsoluteBytePos)>,
interpret_alloc_index: Vec<AbsoluteBytePos>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
file_index_to_stable_id: FxHashMap<FileMapIndex, StableFilemapId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
prev_cnums: Vec<(u32, String, CrateDisambiguator)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
query_result_index: Vec<(SerializedDepNodeIndex, AbsoluteBytePos)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
diagnostics_index: Vec<(SerializedDepNodeIndex, AbsoluteBytePos)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
interpret_alloc_index: Vec<AbsoluteBytePos>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?