Struct rustc::ty::maps::queries::maybe_unused_extern_crates [−][src]
pub struct maybe_unused_extern_crates<'tcx> {
data: PhantomData<&'tcx ()>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
data: PhantomData<&'tcx ()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx, 'lcx> maybe_unused_extern_crates<'tcx>[src]
impl<'a, 'tcx, 'lcx> maybe_unused_extern_crates<'tcx>pub fn ensure(tcx: TyCtxt<'a, 'tcx, 'lcx>, key: CrateNum)[src]
pub fn ensure(tcx: TyCtxt<'a, 'tcx, 'lcx>, key: CrateNum)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ensure that either this query has all green inputs or been executed. Executing query::ensure(D) is considered a read of the dep-node D.
This function is particularly useful when executing passes for their side-effects -- e.g., in order to report errors for erroneous programs.
Note: The optimization is only available during incr. comp.