Struct rustc::ty::maps::Providers [−][src]
pub struct Providers<'tcx> {
pub type_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Ty<'tcx>,
pub generics_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Generics,
pub predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>,
pub explicit_predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>,
pub super_predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>,
pub type_param_predicates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, DefId)) -> GenericPredicates<'tcx>,
pub trait_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx TraitDef,
pub adt_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx AdtDef,
pub adt_destructor: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Destructor>,
pub adt_sized_constraint: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx [Ty<'tcx>],
pub adt_dtorck_constraint: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Result<DtorckConstraint<'tcx>, NoSolution>,
pub is_const_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub is_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub crate_variances: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CrateVariancesMap>,
pub variances_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Variance>>,
pub inferred_outlives_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Predicate<'tcx>>>,
pub inferred_outlives_crate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CratePredicatesMap<'tcx>>,
pub associated_item_def_ids: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<DefId>>,
pub associated_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> AssociatedItem,
pub impl_trait_ref: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<TraitRef<'tcx>>,
pub impl_polarity: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> ImplPolarity,
pub inherent_impls: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<DefId>>,
pub mir_keys: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdSet>,
pub mir_const_qualif: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> (u8, Lrc<IdxSetBuf<Local>>),
pub mir_built: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>,
pub mir_const: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>,
pub mir_validated: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>,
pub optimized_mir: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Mir<'tcx>,
pub unsafety_check_result: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> UnsafetyCheckResult,
pub unsafe_derive_on_repr_packed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId),
pub fn_sig: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> PolyFnSig<'tcx>,
pub coerce_unsized_info: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> CoerceUnsizedInfo,
pub typeck_item_bodies: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CompileResult,
pub typeck_tables_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx TypeckTables<'tcx>,
pub used_trait_imports: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<DefIdSet>,
pub has_typeck_tables: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub coherent_trait: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId),
pub borrowck: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<BorrowCheckResult>,
pub mir_borrowck: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> BorrowCheckResult<'tcx>,
pub crate_inherent_impls: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CrateInherentImpls,
pub crate_inherent_impls_overlap_check: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum),
pub const_eval: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, GlobalId<'tcx>>) -> EvalResult<'tcx>,
pub check_match: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Result<(), ErrorReported>,
pub privacy_access_levels: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<AccessLevels>,
pub reachable_set: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> ReachableSet,
pub region_scope_tree: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<ScopeTree>,
pub mir_shims: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InstanceDef<'tcx>) -> &'tcx Mir<'tcx>,
pub def_symbol_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> SymbolName,
pub symbol_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: Instance<'tcx>) -> SymbolName,
pub describe_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Def>,
pub def_span: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Span,
pub lookup_stability: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<&'tcx Stability>,
pub lookup_deprecation_entry: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DeprecationEntry>,
pub item_attrs: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<[Attribute]>,
pub trans_fn_attrs: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> TransFnAttrs,
pub fn_arg_names: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Vec<Name>,
pub rendered_const: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> String,
pub impl_parent: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DefId>,
pub trait_of_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DefId>,
pub const_is_rvalue_promotable_to_static: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub rvalue_promotable_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<ItemLocalSet>,
pub is_mir_available: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub vtable_methods: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: PolyTraitRef<'tcx>) -> Lrc<Vec<Option<(DefId, &'tcx Substs<'tcx>)>>>,
pub trans_fulfill_obligation: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (ParamEnv<'tcx>, PolyTraitRef<'tcx>)) -> Vtable<'tcx, ()>,
pub trait_impls_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<TraitImpls>,
pub specialization_graph_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Graph>,
pub is_object_safe: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub param_env: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> ParamEnv<'tcx>,
pub is_copy_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool,
pub is_sized_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool,
pub is_freeze_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool,
pub needs_drop_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool,
pub layout_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> Result<&'tcx LayoutDetails, LayoutError<'tcx>>,
pub dylib_dependency_formats: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(CrateNum, LinkagePreference)>>,
pub is_panic_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub is_compiler_builtins: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub has_global_allocator: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub is_sanitizer_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub is_profiler_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub panic_strategy: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> PanicStrategy,
pub is_no_builtins: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub extern_crate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Option<ExternCrate>>,
pub specializes: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, DefId)) -> bool,
pub in_scope_traits_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Lrc<StableVec<TraitCandidate>>>>>,
pub module_exports: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<Vec<Export>>>,
pub lint_levels: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<LintLevelMap>,
pub impl_defaultness: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Defaultness,
pub check_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId),
pub check_trait_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId),
pub check_impl_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId),
pub reachable_non_generics: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<SymbolExportLevel>>,
pub is_reachable_non_generic: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub is_unreachable_local_definition: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub upstream_monomorphizations: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<Lrc<FxHashMap<&'tcx Substs<'tcx>, CrateNum>>>>,
pub upstream_monomorphizations_for: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<FxHashMap<&'tcx Substs<'tcx>, CrateNum>>>,
pub native_libraries: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<NativeLibrary>>,
pub foreign_modules: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<ForeignModule>>,
pub plugin_registrar_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Option<DefId>,
pub derive_registrar_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Option<DefId>,
pub crate_disambiguator: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CrateDisambiguator,
pub crate_hash: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Svh,
pub original_crate_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Symbol,
pub extra_filename: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> String,
pub implementations_of_trait: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (CrateNum, DefId)) -> Lrc<Vec<DefId>>,
pub all_trait_implementations: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>,
pub dllimport_foreign_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashSet<DefId>>,
pub is_dllimport_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub is_statically_included_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub native_library_kind: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<NativeLibraryKind>,
pub link_args: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<String>>,
pub resolve_lifetimes: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<ResolveLifetimes>,
pub named_region_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Region>>>,
pub is_late_bound_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashSet<ItemLocalId>>>,
pub object_lifetime_defaults_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Lrc<Vec<ObjectLifetimeDefault>>>>>,
pub visibility: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Visibility,
pub dep_kind: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> DepKind,
pub crate_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Symbol,
pub item_children: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Export>>,
pub extern_mod_stmt_cnum: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<CrateNum>,
pub get_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<LanguageItems>,
pub defined_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(DefId, usize)>>,
pub missing_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<LangItem>>,
pub visible_parent_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<DefId>>,
pub missing_extern_crate_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool,
pub used_crate_source: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CrateSource>,
pub postorder_cnums: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<CrateNum>>,
pub freevars: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<Vec<Freevar>>>,
pub maybe_unused_trait_import: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub maybe_unused_extern_crates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(DefId, Span)>>,
pub stability_index: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Index<'tcx>>,
pub all_crate_nums: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<CrateNum>>,
pub all_traits: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>,
pub exported_symbols: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Arc<Vec<(ExportedSymbol<'tcx>, SymbolExportLevel)>>,
pub collect_and_partition_translation_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> (Arc<DefIdSet>, Arc<Vec<Arc<CodegenUnit<'tcx>>>>),
pub is_translated_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool,
pub codegen_unit: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InternedString) -> Arc<CodegenUnit<'tcx>>,
pub compile_codegen_unit: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InternedString) -> Stats,
pub output_filenames: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Arc<OutputFilenames>,
pub erase_regions_ty: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: Ty<'tcx>) -> Ty<'tcx>,
pub normalize_projection_ty: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalProjectionGoal<'tcx>) -> Result<Lrc<Canonical<'tcx, QueryResult<'tcx, NormalizationResult<'tcx>>>>, NoSolution>,
pub normalize_ty_after_erasing_regions: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> Ty<'tcx>,
pub dropck_outlives: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalTyGoal<'tcx>) -> Result<Lrc<Canonical<'tcx, QueryResult<'tcx, DropckOutlivesResult<'tcx>>>>, NoSolution>,
pub evaluate_obligation: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalPredicateGoal<'tcx>) -> Result<EvaluationResult, OverflowError>,
pub substitute_normalize_and_test_predicates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, &'tcx Substs<'tcx>)) -> bool,
pub target_features_whitelist: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashMap<String, Option<String>>>,
pub instance_def_size_estimate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InstanceDef<'tcx>) -> usize,
pub features_query: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Features>,
pub program_clauses_for: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Clauses<'tcx>,
pub program_clauses_for_env: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnv<'tcx>) -> Clauses<'tcx>,
pub wasm_custom_sections: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>,
pub wasm_import_module_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashMap<DefId, String>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
type_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
generics_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Generics
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
explicit_predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
super_predicates_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> GenericPredicates<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type_param_predicates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, DefId)) -> GenericPredicates<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trait_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx TraitDef
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
adt_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx AdtDef
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
adt_destructor: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Destructor>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
adt_sized_constraint: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx [Ty<'tcx>]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
adt_dtorck_constraint: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Result<DtorckConstraint<'tcx>, NoSolution>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_const_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_variances: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CrateVariancesMap>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
variances_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Variance>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
inferred_outlives_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Predicate<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
inferred_outlives_crate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CratePredicatesMap<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
associated_item_def_ids: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
associated_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> AssociatedItem
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl_trait_ref: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<TraitRef<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl_polarity: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> ImplPolarity
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
inherent_impls: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_keys: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdSet>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_const_qualif: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> (u8, Lrc<IdxSetBuf<Local>>)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_built: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_const: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_validated: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Steal<Mir<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
optimized_mir: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unsafety_check_result: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> UnsafetyCheckResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unsafe_derive_on_repr_packed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn_sig: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> PolyFnSig<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
coerce_unsized_info: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> CoerceUnsizedInfo
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
typeck_item_bodies: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CompileResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
typeck_tables_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> &'tcx TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
used_trait_imports: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<DefIdSet>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
has_typeck_tables: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
coherent_trait: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
borrowck: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<BorrowCheckResult>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_borrowck: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> BorrowCheckResult<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_inherent_impls: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CrateInherentImpls
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_inherent_impls_overlap_check: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
const_eval: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, GlobalId<'tcx>>) -> EvalResult<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
check_match: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Result<(), ErrorReported>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
privacy_access_levels: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<AccessLevels>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
reachable_set: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> ReachableSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_scope_tree: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<ScopeTree>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_shims: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InstanceDef<'tcx>) -> &'tcx Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def_symbol_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> SymbolName
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
symbol_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: Instance<'tcx>) -> SymbolName
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
describe_def: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Def>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def_span: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lookup_stability: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<&'tcx Stability>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lookup_deprecation_entry: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DeprecationEntry>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
item_attrs: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<[Attribute]>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trans_fn_attrs: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> TransFnAttrs
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn_arg_names: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Vec<Name>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
rendered_const: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl_parent: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trait_of_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
const_is_rvalue_promotable_to_static: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
rvalue_promotable_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<ItemLocalSet>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_mir_available: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
vtable_methods: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: PolyTraitRef<'tcx>) -> Lrc<Vec<Option<(DefId, &'tcx Substs<'tcx>)>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trans_fulfill_obligation: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (ParamEnv<'tcx>, PolyTraitRef<'tcx>)) -> Vtable<'tcx, ()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trait_impls_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<TraitImpls>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
specialization_graph_of: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Graph>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_object_safe: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
param_env: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_copy_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_sized_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_freeze_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
needs_drop_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
layout_raw: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> Result<&'tcx LayoutDetails, LayoutError<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dylib_dependency_formats: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(CrateNum, LinkagePreference)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_panic_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_compiler_builtins: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
has_global_allocator: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_sanitizer_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_profiler_runtime: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
panic_strategy: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> PanicStrategy
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_no_builtins: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
extern_crate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Option<ExternCrate>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
specializes: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, DefId)) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
in_scope_traits_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Lrc<StableVec<TraitCandidate>>>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
module_exports: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<Vec<Export>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lint_levels: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<LintLevelMap>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl_defaultness: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Defaultness
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
check_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
check_trait_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
check_impl_item_well_formed: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
reachable_non_generics: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<SymbolExportLevel>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_reachable_non_generic: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_unreachable_local_definition: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
upstream_monomorphizations: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<Lrc<FxHashMap<&'tcx Substs<'tcx>, CrateNum>>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
upstream_monomorphizations_for: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<FxHashMap<&'tcx Substs<'tcx>, CrateNum>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
native_libraries: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<NativeLibrary>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
foreign_modules: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<ForeignModule>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
plugin_registrar_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Option<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
derive_registrar_fn: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Option<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_disambiguator: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> CrateDisambiguator
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_hash: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Svh
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
original_crate_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Symbol
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
extra_filename: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
implementations_of_trait: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (CrateNum, DefId)) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
all_trait_implementations: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dllimport_foreign_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashSet<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_dllimport_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_statically_included_foreign_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
native_library_kind: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<NativeLibraryKind>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
link_args: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<String>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
resolve_lifetimes: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<ResolveLifetimes>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
named_region_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Region>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_late_bound_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashSet<ItemLocalId>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
object_lifetime_defaults_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefIndex) -> Option<Lrc<FxHashMap<ItemLocalId, Lrc<Vec<ObjectLifetimeDefault>>>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
visibility: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Visibility
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dep_kind: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> DepKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
crate_name: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Symbol
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
item_children: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Lrc<Vec<Export>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
extern_mod_stmt_cnum: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<CrateNum>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
get_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<LanguageItems>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
defined_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(DefId, usize)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
missing_lang_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<LangItem>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
visible_parent_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<DefIdMap<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
missing_extern_crate_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
used_crate_source: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<CrateSource>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
postorder_cnums: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<CrateNum>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
freevars: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Option<Lrc<Vec<Freevar>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
maybe_unused_trait_import: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
maybe_unused_extern_crates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<(DefId, Span)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
stability_index: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Index<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
all_crate_nums: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<CrateNum>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
all_traits: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
exported_symbols: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Arc<Vec<(ExportedSymbol<'tcx>, SymbolExportLevel)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
collect_and_partition_translation_items: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> (Arc<DefIdSet>, Arc<Vec<Arc<CodegenUnit<'tcx>>>>)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_translated_item: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
codegen_unit: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InternedString) -> Arc<CodegenUnit<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
compile_codegen_unit: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InternedString) -> Stats
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
output_filenames: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Arc<OutputFilenames>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
erase_regions_ty: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: Ty<'tcx>) -> Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
normalize_projection_ty: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalProjectionGoal<'tcx>) -> Result<Lrc<Canonical<'tcx, QueryResult<'tcx, NormalizationResult<'tcx>>>>, NoSolution>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
normalize_ty_after_erasing_regions: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnvAnd<'tcx, Ty<'tcx>>) -> Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dropck_outlives: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalTyGoal<'tcx>) -> Result<Lrc<Canonical<'tcx, QueryResult<'tcx, DropckOutlivesResult<'tcx>>>>, NoSolution>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
evaluate_obligation: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CanonicalPredicateGoal<'tcx>) -> Result<EvaluationResult, OverflowError>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
substitute_normalize_and_test_predicates: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: (DefId, &'tcx Substs<'tcx>)) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
target_features_whitelist: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashMap<String, Option<String>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
instance_def_size_estimate: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: InstanceDef<'tcx>) -> usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
features_query: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Features>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
program_clauses_for: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: DefId) -> Clauses<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
program_clauses_for_env: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: ParamEnv<'tcx>) -> Clauses<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
wasm_custom_sections: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
wasm_import_module_map: fn'a(_: TyCtxt<'a, 'tcx, 'tcx>, _: CrateNum) -> Lrc<FxHashMap<DefId, String>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?