Struct rustc::ty::query::on_disk_cache::AbsoluteBytePos [−][src]
struct AbsoluteBytePos(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl AbsoluteBytePos[src]
impl AbsoluteBytePosfn new(pos: usize) -> AbsoluteBytePos[src]
fn new(pos: usize) -> AbsoluteBytePos🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_usize(self) -> usize[src]
fn to_usize(self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?