[−][src]Struct rustc::ty::query::queries::program_clauses_for_env
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
data: PhantomData<&'tcx ()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx, 'lcx> program_clauses_for_env<'tcx>[src]
impl<'a, 'tcx, 'lcx> program_clauses_for_env<'tcx>pub fn ensure(tcx: TyCtxt<'a, 'tcx, 'lcx>, key: ParamEnv<'tcx>)[src]
pub fn ensure(tcx: TyCtxt<'a, 'tcx, 'lcx>, key: ParamEnv<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ensure that either this query has all green inputs or been executed. Executing query::ensure(D) is considered a read of the dep-node D.
This function is particularly useful when executing passes for their side-effects -- e.g., in order to report errors for erroneous programs.
Note: The optimization is only available during incr. comp.