[−][src]Struct rustc::ty::AdtDef
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The definition of an abstract data type - a struct or enum.
These are all interned (by intern_adt_def) into the adt_defs table.
Fields
did: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
variants: Vec<VariantDef>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
flags: AdtFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
repr: ReprOptions
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> AdtDef[src]
impl<'a, 'gcx, 'tcx> AdtDeffn uninhabited_from(
&self,
visited: &mut FxHashMap<DefId, FxHashSet<&'tcx Substs<'tcx>>>,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
substs: &'tcx Substs<'tcx>
) -> DefIdForest[src]
fn uninhabited_from(
&self,
visited: &mut FxHashMap<DefId, FxHashSet<&'tcx Substs<'tcx>>>,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
substs: &'tcx Substs<'tcx>
) -> DefIdForest🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Calculate the forest of DefIds from which this adt is visibly uninhabited.
impl<'a, 'gcx, 'tcx> AdtDef[src]
impl<'a, 'gcx, 'tcx> AdtDeffn new(
tcx: TyCtxt,
did: DefId,
kind: AdtKind,
variants: Vec<VariantDef>,
repr: ReprOptions
) -> Self[src]
fn new(
tcx: TyCtxt,
did: DefId,
kind: AdtKind,
variants: Vec<VariantDef>,
repr: ReprOptions
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_struct(&self) -> bool[src]
pub fn is_struct(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_union(&self) -> bool[src]
pub fn is_union(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_enum(&self) -> bool[src]
pub fn is_enum(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_variant_list_non_exhaustive(&self) -> bool[src]
pub fn is_variant_list_non_exhaustive(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn adt_kind(&self) -> AdtKind[src]
pub fn adt_kind(&self) -> AdtKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the kind of the ADT - Struct or Enum.
pub fn descr(&self) -> &'static str[src]
pub fn descr(&self) -> &'static str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn variant_descr(&self) -> &'static str[src]
pub fn variant_descr(&self) -> &'static str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_fundamental(&self) -> bool[src]
pub fn is_fundamental(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns whether this type is #[fundamental] for the purposes of coherence checking.
pub fn is_phantom_data(&self) -> bool[src]
pub fn is_phantom_data(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this is PhantomData
pub fn is_box(&self) -> bool[src]
pub fn is_box(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this is Box
pub fn has_dtor(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> bool[src]
pub fn has_dtor(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns whether this type has a destructor.
pub fn non_enum_variant(&self) -> &VariantDef[src]
pub fn non_enum_variant(&self) -> &VariantDef🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Asserts this is a struct or union and returns its unique variant.
pub fn predicates(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> GenericPredicates<'gcx>[src]
pub fn predicates(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> GenericPredicates<'gcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn all_fields<'s>(
&'s self
) -> impl Iterator<Item = &'s FieldDef>[src]
pub fn all_fields<'s>(
&'s self
) -> impl Iterator<Item = &'s FieldDef>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an iterator over all fields contained by this ADT.
pub fn is_payloadfree(&self) -> bool[src]
pub fn is_payloadfree(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn variant_with_id(&self, vid: DefId) -> &VariantDef[src]
pub fn variant_with_id(&self, vid: DefId) -> &VariantDef🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn variant_index_with_id(&self, vid: DefId) -> usize[src]
pub fn variant_index_with_id(&self, vid: DefId) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn variant_of_def(&self, def: Def) -> &VariantDef[src]
pub fn variant_of_def(&self, def: Def) -> &VariantDef🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn eval_explicit_discr(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
expr_did: DefId
) -> Option<Discr<'tcx>>[src]
pub fn eval_explicit_discr(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
expr_did: DefId
) -> Option<Discr<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn discriminants(
&'a self,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> impl Iterator<Item = Discr<'tcx>> + Captures<'gcx> + 'a[src]
pub fn discriminants(
&'a self,
tcx: TyCtxt<'a, 'gcx, 'tcx>
) -> impl Iterator<Item = Discr<'tcx>> + Captures<'gcx> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn discriminant_for_variant(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
variant_index: usize
) -> Discr<'tcx>[src]
pub fn discriminant_for_variant(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
variant_index: usize
) -> Discr<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compute the discriminant value used by a specific variant.
Unlike discriminants, this is (amortized) constant-time,
only doing at most one query for evaluating an explicit
discriminant (the last one before the requested variant),
assuming there are no constant-evaluation errors there.
pub fn discriminant_def_for_variant(
&self,
variant_index: usize
) -> (Option<DefId>, usize)[src]
pub fn discriminant_def_for_variant(
&self,
variant_index: usize
) -> (Option<DefId>, usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Yields a DefId for the discriminant and an offset to add to it Alternatively, if there is no explicit discriminant, returns the inferred discriminant directly
pub fn destructor(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Option<Destructor>[src]
pub fn destructor(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Option<Destructor>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn sized_constraint(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> &'tcx [Ty<'tcx>][src]
pub fn sized_constraint(&self, tcx: TyCtxt<'a, 'gcx, 'tcx>) -> &'tcx [Ty<'tcx>]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns a list of types such that Self: Sized if and only
if that type is Sized, or TyErr if this type is recursive.
Oddly enough, checking that the sized-constraint is Sized is actually more expressive than checking all members: the Sized trait is inductive, so an associated type that references Self would prevent its containing ADT from being Sized.
Due to normalization being eager, this applies even if the associated type is behind a pointer, e.g. issue #31299.
fn sized_constraint_for_ty(
&self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
ty: Ty<'tcx>
) -> Vec<Ty<'tcx>>[src]
fn sized_constraint_for_ty(
&self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
ty: Ty<'tcx>
) -> Vec<Ty<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?