[−][src]Struct rustc::ty::ClosureSubsts
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A closure can be modeled as a struct that looks like:
struct Closure<'l0...'li, T0...Tj, CK, CS, U0...Uk> { upvar0: U0, ... upvark: Uk }
where:
- 'l0...'li and T0...Tj are the lifetime and type parameters in scope on the function that defined the closure,
- CK represents the closure kind (Fn vs FnMut vs FnOnce). This
is rather hackily encoded via a scalar type. See
TyS::to_opt_closure_kindfor details. - CS represents the closure signature, representing as a
fn()type. For example,fn(u32, u32) -> u32would mean that the closure implementsCK<(u32, u32), Output = u32>, whereCKis the trait specified above. - U0...Uk are type parameters representing the types of its upvars
(borrowed, if appropriate; that is, if Ui represents a by-ref upvar,
and the up-var has the type
Foo, thenUi = &Foo).
So, for example, given this function:
fn foo<'a, T>(data: &'a mut T) { do(|| data.count += 1) }
the type of the closure would be something like:
struct Closure<'a, T, U0> { data: U0 }
Note that the type of the upvar is not specified in the struct. You may wonder how the impl would then be able to use the upvar, if it doesn't know it's type? The answer is that the impl is (conceptually) not fully generic over Closure but rather tied to instances with the expected upvar types:
impl<'b, 'a, T> FnMut() for Closure<'a, T, &'b mut &'a mut T> { ... }
You can see that the impl fully specified the type of the upvar
and thus knows full well that data has type &'b mut &'a mut T.
(Here, I am assuming that data is mut-borrowed.)
Now, the last question you may ask is: Why include the upvar types
as extra type parameters? The reason for this design is that the
upvar types can reference lifetimes that are internal to the
creating function. In my example above, for example, the lifetime
'b represents the scope of the closure itself; this is some
subset of foo, probably just the scope of the call to the to
do(). If we just had the lifetime/type parameters from the
enclosing function, we couldn't name this lifetime 'b. Note that
there can also be lifetimes in the types of the upvars themselves,
if one of them happens to be a reference to something that the
creating fn owns.
OK, you say, so why not create a more minimal set of parameters that just includes the extra lifetime parameters? The answer is primarily that it would be hard --- we don't know at the time when we create the closure type what the full types of the upvars are, nor do we know which are borrowed and which are not. In this design, we can just supply a fresh type parameter and figure that out later.
All right, you say, but why include the type parameters from the
original function then? The answer is that codegen may need them
when monomorphizing, and they may not appear in the upvars. A
closure could capture no variables but still make use of some
in-scope type parameter with a bound (e.g., if our example above
had an extra U: Default, and the closure called U::default()).
There is another reason. This design (implicitly) prohibits closures from capturing themselves (except via a trait object). This simplifies closure inference considerably, since it means that when we infer the kind of a closure or its upvars, we don't have to handle cycles where the decisions we make for closure C wind up influencing the decisions we ought to make for closure C (which would then require fixed point iteration to handle). Plus it fixes an ICE. :P
Generators
Perhaps surprisingly, ClosureSubsts are also used for
generators. In that case, what is written above is only half-true
-- the set of type parameters is similar, but the role of CK and
CS are different. CK represents the "yield type" and CS
represents the "return type" of the generator.
It'd be nice to split this struct into ClosureSubsts and GeneratorSubsts, I believe. -nmatsakis
Fields
substs: &'tcx Substs<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Lifetime and type parameters from the enclosing function, concatenated with the types of the upvars.
These are separated out because codegen wants to pass them around when monomorphizing.
Methods
impl<'tcx> ClosureSubsts<'tcx>[src]
impl<'tcx> ClosureSubsts<'tcx>fn split(self, def_id: DefId, tcx: TyCtxt) -> SplitClosureSubsts<'tcx>[src]
fn split(self, def_id: DefId, tcx: TyCtxt) -> SplitClosureSubsts<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Divides the closure substs into their respective components. Single source of truth with respect to the ordering.
pub fn upvar_tys(
self,
def_id: DefId,
tcx: TyCtxt
) -> impl Iterator<Item = Ty<'tcx>> + 'tcx[src]
pub fn upvar_tys(
self,
def_id: DefId,
tcx: TyCtxt
) -> impl Iterator<Item = Ty<'tcx>> + 'tcx🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn closure_kind_ty(self, def_id: DefId, tcx: TyCtxt) -> Ty<'tcx>[src]
pub fn closure_kind_ty(self, def_id: DefId, tcx: TyCtxt) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the closure kind for this closure; may return a type
variable during inference. To get the closure kind during
inference, use infcx.closure_kind(def_id, substs).
pub fn closure_sig_ty(self, def_id: DefId, tcx: TyCtxt) -> Ty<'tcx>[src]
pub fn closure_sig_ty(self, def_id: DefId, tcx: TyCtxt) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the type representing the closure signature for this
closure; may contain type variables during inference. To get
the closure signature during inference, use
infcx.fn_sig(def_id).
pub fn closure_kind(
self,
def_id: DefId,
tcx: TyCtxt<'_, 'tcx, 'tcx>
) -> ClosureKind[src]
pub fn closure_kind(
self,
def_id: DefId,
tcx: TyCtxt<'_, 'tcx, 'tcx>
) -> ClosureKind🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the closure kind for this closure; only usable outside of an inference context, because in that context we know that there are no type variables.
If you have an inference context, use infcx.closure_kind().
pub fn closure_sig(
self,
def_id: DefId,
tcx: TyCtxt<'_, 'tcx, 'tcx>
) -> PolyFnSig<'tcx>[src]
pub fn closure_sig(
self,
def_id: DefId,
tcx: TyCtxt<'_, 'tcx, 'tcx>
) -> PolyFnSig<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extracts the signature from the closure; only usable outside of an inference context, because in that context we know that there are no type variables.
If you have an inference context, use infcx.closure_sig().