Struct rustc::ty::CrateInherentImpls
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A map for the local crate mapping each type to a vector of its
inherent impls. This is not meant to be used outside of coherence;
rather, you should request the vector for a specific type via
tcx.inherent_impls(def_id) so as to minimize your dependencies
(constructing this map requires touching the entire crate).
Fields
inherent_impls: DefIdMap<Lrc<Vec<DefId>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?