[−][src]Struct rustc::ty::ExistentialProjection
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A ProjectionPredicate for an ExistentialTraitRef.
Fields
item_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
substs: &'tcx Substs<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ty: Ty<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx, 'gcx> ExistentialProjection<'tcx>[src]
impl<'a, 'tcx, 'gcx> ExistentialProjection<'tcx>pub fn trait_ref(&self, tcx: TyCtxt) -> ExistentialTraitRef<'tcx>[src]
pub fn trait_ref(&self, tcx: TyCtxt) -> ExistentialTraitRef<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extracts the underlying existential trait reference from this projection.
For example, if this is a projection of exists T. <T as Iterator>::Item == X,
then this function would return a exists T. T: Iterator existential trait
reference.
pub fn with_self_ty(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
self_ty: Ty<'tcx>
) -> ProjectionPredicate<'tcx>[src]
pub fn with_self_ty(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
self_ty: Ty<'tcx>
) -> ProjectionPredicate<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?