Struct rustc::ty::GlobalArenas
[−]
[src]
pub struct GlobalArenas<'tcx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Internal storage
Methods
impl<'tcx> GlobalArenas<'tcx>[src]
impl<'tcx> GlobalArenas<'tcx>pub fn new() -> GlobalArenas<'tcx>[src]
pub fn new() -> GlobalArenas<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?