[−][src]Struct rustc::ty::ParamEnv
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When type checking, we use the ParamEnv to track
details about the set of where-clauses that are in scope at this
particular point.
Fields
caller_bounds: &'tcx List<Predicate<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Obligations that the caller must satisfy. This is basically the set of bounds on the in-scope type parameters, translated into Obligations, and elaborated and normalized.
reveal: Reveal
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Typically, this is Reveal::UserFacing, but during codegen we
want Reveal::All -- note that this is always paired with an
empty environment. To get that, use ParamEnv::reveal().
Methods
impl<'tcx> ParamEnv<'tcx>[src]
impl<'tcx> ParamEnv<'tcx>pub fn can_type_implement_copy<'a>(
self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
self_type: Ty<'tcx>
) -> Result<(), CopyImplementationError<'tcx>>[src]
pub fn can_type_implement_copy<'a>(
self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
self_type: Ty<'tcx>
) -> Result<(), CopyImplementationError<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> ParamEnv<'tcx>[src]
impl<'tcx> ParamEnv<'tcx>pub fn empty() -> Self[src]
pub fn empty() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Construct a trait environment suitable for contexts where
there are no where clauses in scope. Hidden types (like impl Trait) are left hidden, so this is suitable for ordinary
type-checking.
pub fn reveal_all() -> Self[src]
pub fn reveal_all() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Construct a trait environment with no where clauses in scope
where the values of all impl Trait and other hidden types
are revealed. This is suitable for monomorphized, post-typeck
environments like codegen or doing optimizations.
NB. If you want to have predicates in scope, use ParamEnv::new,
or invoke param_env.with_reveal_all().
pub fn new(caller_bounds: &'tcx List<Predicate<'tcx>>, reveal: Reveal) -> Self[src]
pub fn new(caller_bounds: &'tcx List<Predicate<'tcx>>, reveal: Reveal) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Construct a trait environment with the given set of predicates.
pub fn with_reveal_all(self) -> Self[src]
pub fn with_reveal_all(self) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns a new parameter environment with the same clauses, but
which "reveals" the true results of projections in all cases
(even for associated types that are specializable). This is
the desired behavior during codegen and certain other special
contexts; normally though we want to use Reveal::UserFacing,
which is the default.
pub fn without_caller_bounds(self) -> Self[src]
pub fn without_caller_bounds(self) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns this same environment but with no caller bounds.
pub fn and<T: TypeFoldable<'tcx>>(self, value: T) -> ParamEnvAnd<'tcx, T>[src]
pub fn and<T: TypeFoldable<'tcx>>(self, value: T) -> ParamEnvAnd<'tcx, T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a suitable environment in which to perform trait
queries on the given value. When type-checking, this is simply
the pair of the environment plus value. But when reveal is set to
All, then if value does not reference any type parameters, we will
pair it with the empty environment. This improves caching and is generally
invisible.
NB: We preserve the environment when type-checking because it
is possible for the user to have wacky where-clauses like
where Box<u32>: Copy, which are clearly never
satisfiable. We generally want to behave as if they were true,
although the surrounding function is never reachable.