[−][src]Struct rustc::ty::TraitPredicate
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
trait_ref: TraitRef<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> TraitPredicate<'tcx>[src]
impl<'tcx> TraitPredicate<'tcx>pub fn def_id(&self) -> DefId[src]
pub fn def_id(&self) -> DefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn input_types<'a>(
&'a self
) -> impl DoubleEndedIterator<Item = Ty<'tcx>> + 'a[src]
pub fn input_types<'a>(
&'a self
) -> impl DoubleEndedIterator<Item = Ty<'tcx>> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn self_ty(&self) -> Ty<'tcx>[src]
pub fn self_ty(&self) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?