Struct rustc::ty::TypeFlags [−]
pub struct TypeFlags {
bits: u32,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bits: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl TypeFlags
impl TypeFlagspub const HAS_PARAMS: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_PARAMS: TypeFlags = TypeFlags{bits: 1 << 0,}
pub const HAS_SELF: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_SELF: TypeFlags = TypeFlags{bits: 1 << 1,}
pub const HAS_TY_INFER: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_TY_INFER: TypeFlags = TypeFlags{bits: 1 << 2,}
pub const HAS_RE_INFER: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_RE_INFER: TypeFlags = TypeFlags{bits: 1 << 3,}
pub const HAS_RE_SKOL: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_RE_SKOL: TypeFlags = TypeFlags{bits: 1 << 4,}
pub const HAS_RE_EARLY_BOUND: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_RE_EARLY_BOUND: TypeFlags = TypeFlags{bits: 1 << 5,}
Does this have any ReEarlyBound regions? Used to
determine whether substitition is required, since those
represent regions that are bound in a ty::Generics and
hence may be substituted.
pub const HAS_FREE_REGIONS: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_FREE_REGIONS: TypeFlags = TypeFlags{bits: 1 << 6,}
Does this have any region that "appears free" in the type?
Basically anything but ReLateBound and ReErased.
pub const HAS_TY_ERR: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_TY_ERR: TypeFlags = TypeFlags{bits: 1 << 7,}
Is an error type reachable?
pub const HAS_PROJECTION: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_PROJECTION: TypeFlags = TypeFlags{bits: 1 << 8,}
pub const HAS_TY_CLOSURE: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_TY_CLOSURE: TypeFlags = TypeFlags{bits: 1 << 9,}
pub const HAS_FREE_LOCAL_NAMES: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_FREE_LOCAL_NAMES: TypeFlags = TypeFlags{bits: 1 << 10,}
pub const KEEP_IN_LOCAL_TCX: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
KEEP_IN_LOCAL_TCX: TypeFlags = TypeFlags{bits: 1 << 11,}
pub const HAS_NORMALIZABLE_PROJECTION: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_NORMALIZABLE_PROJECTION: TypeFlags = TypeFlags{bits: 1 << 12,}
pub const HAS_CANONICAL_VARS: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_CANONICAL_VARS: TypeFlags = TypeFlags{bits: 1 << 13,}
pub const HAS_RE_LATE_BOUND: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
HAS_RE_LATE_BOUND: TypeFlags = TypeFlags{bits: 1 << 14,}
Does this have any ReLateBound regions? Used to check
if a global bound is safe to evaluate.
pub const NEEDS_SUBST: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NEEDS_SUBST: TypeFlags = TypeFlags{bits: <TypeFlags>::HAS_PARAMS.bits | <TypeFlags>::HAS_SELF.bits | <TypeFlags>::HAS_RE_EARLY_BOUND.bits,}
pub const NOMINAL_FLAGS: TypeFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NOMINAL_FLAGS: TypeFlags = TypeFlags{bits: <TypeFlags>::HAS_PARAMS.bits | <TypeFlags>::HAS_SELF.bits | <TypeFlags>::HAS_TY_INFER.bits | <TypeFlags>::HAS_RE_INFER.bits | <TypeFlags>::HAS_RE_SKOL.bits | <TypeFlags>::HAS_RE_EARLY_BOUND.bits | <TypeFlags>::HAS_FREE_REGIONS.bits | <TypeFlags>::HAS_TY_ERR.bits | <TypeFlags>::HAS_PROJECTION.bits | <TypeFlags>::HAS_TY_CLOSURE.bits | <TypeFlags>::HAS_FREE_LOCAL_NAMES.bits | <TypeFlags>::KEEP_IN_LOCAL_TCX.bits | <TypeFlags>::HAS_CANONICAL_VARS.bits | <TypeFlags>::HAS_RE_LATE_BOUND.bits,}
pub fn empty() -> TypeFlags
pub fn empty() -> TypeFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an empty set of flags.
pub fn all() -> TypeFlags
pub fn all() -> TypeFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<TypeFlags>
pub fn from_bits(bits: u32) -> Option<TypeFlags>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> TypeFlags
pub fn from_bits_truncate(bits: u32) -> TypeFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if all flags are currently set.
pub fn intersects(&self, other: TypeFlags) -> bool
pub fn intersects(&self, other: TypeFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: TypeFlags) -> bool
pub fn contains(&self, other: TypeFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: TypeFlags)
pub fn insert(&mut self, other: TypeFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts the specified flags in-place.
pub fn remove(&mut self, other: TypeFlags)
pub fn remove(&mut self, other: TypeFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes the specified flags in-place.
pub fn toggle(&mut self, other: TypeFlags)
pub fn toggle(&mut self, other: TypeFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Toggles the specified flags in-place.
pub fn set(&mut self, other: TypeFlags, value: bool)
pub fn set(&mut self, other: TypeFlags, value: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts or removes the specified flags depending on the passed value.