Struct rustc::ty::UpvarBorrow [−][src]
pub struct UpvarBorrow<'tcx> {
pub kind: BorrowKind,
pub region: Region<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
kind: BorrowKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The kind of borrow: by-ref upvars have access to shared immutable borrows, which are not part of the normal language syntax.
region: Region<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Region of the resulting reference.