[−]Struct rustc::ty::VariantFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bits: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl VariantFlags
impl VariantFlagspub const NO_VARIANT_FLAGS: VariantFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub const IS_FIELD_LIST_NON_EXHAUSTIVE: VariantFlags
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates whether the field list of this variant is #[non_exhaustive].
pub fn empty() -> VariantFlags
pub fn empty() -> VariantFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an empty set of flags.
pub fn all() -> VariantFlags
pub fn all() -> VariantFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<VariantFlags>
pub fn from_bits(bits: u32) -> Option<VariantFlags>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> VariantFlags
pub fn from_bits_truncate(bits: u32) -> VariantFlags🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if all flags are currently set.
pub fn intersects(&self, other: VariantFlags) -> bool
pub fn intersects(&self, other: VariantFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: VariantFlags) -> bool
pub fn contains(&self, other: VariantFlags) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: VariantFlags)
pub fn insert(&mut self, other: VariantFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts the specified flags in-place.
pub fn remove(&mut self, other: VariantFlags)
pub fn remove(&mut self, other: VariantFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes the specified flags in-place.
pub fn toggle(&mut self, other: VariantFlags)
pub fn toggle(&mut self, other: VariantFlags)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Toggles the specified flags in-place.
pub fn set(&mut self, other: VariantFlags, value: bool)
pub fn set(&mut self, other: VariantFlags, value: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts or removes the specified flags depending on the passed value.