Struct rustc::ty::sty::DebruijnIndex [−]
pub struct DebruijnIndex(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DebruijnIndex[src]
impl DebruijnIndex#[must_use]
pub const fn shifted_in(self, amount: u32) -> DebruijnIndex[src]
#[must_use]
pub const fn shifted_in(self, amount: u32) -> DebruijnIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the resulting index when this value is moved into
amount number of new binders. So e.g. if you had
for<'a> fn(&'a x)
and you wanted to change to
for<'a> fn(for<'b> fn(&'a x))
you would need to shift the index for 'a into 1 new binder.
pub fn shift_in(&mut self, amount: u32)[src]
pub fn shift_in(&mut self, amount: u32)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Update this index in place by shifting it "in" through
amount number of binders.
#[must_use]
pub const fn shifted_out(self, amount: u32) -> DebruijnIndex[src]
#[must_use]
pub const fn shifted_out(self, amount: u32) -> DebruijnIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the resulting index when this value is moved out from
amount number of new binders.
pub fn shift_out(&mut self, amount: u32)[src]
pub fn shift_out(&mut self, amount: u32)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Update in place by shifting out from amount binders.
pub fn shifted_out_to_binder(self, to_binder: DebruijnIndex) -> Self[src]
pub fn shifted_out_to_binder(self, to_binder: DebruijnIndex) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adjusts any Debruijn Indices so as to make to_binder the
innermost binder. That is, if we have something bound at to_binder,
it will now be bound at INNERMOST. This is an appropriate thing to do
when moving a region out from inside binders:
for<'a> fn(for<'b> for<'c> fn(&'a u32), _)
// Binder: D3 D2 D1 ^^
Here, the region 'a would have the debruijn index D3,
because it is the bound 3 binders out. However, if we wanted
to refer to that region 'a in the second argument (the _),
those two binders would not be in scope. In that case, we
might invoke shift_out_to_binder(D3). This would adjust the
debruijn index of 'a to D1 (the innermost binder).
If we invoke shift_out_to_binder and the region is in fact
bound by one of the binders we are shifting out of, that is an
error (and should fail an assertion failure).