Struct rustc::ty::sty::FreeRegion [−][src]
pub struct FreeRegion {
pub scope: DefId,
pub bound_region: BoundRegion,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A "free" region fr can be interpreted as "some region
at least as big as the scope fr.scope".
Fields
scope: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bound_region: BoundRegion
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?