Type Definition rustc::ty::PolyFnSig [−][src]
type PolyFnSig<'tcx> = Binder<FnSig<'tcx>>;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> PolyFnSig<'tcx>[src]
impl<'tcx> PolyFnSig<'tcx>pub fn inputs(&self) -> Binder<&'tcx [Ty<'tcx>]>[src]
pub fn inputs(&self) -> Binder<&'tcx [Ty<'tcx>]>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn input(&self, index: usize) -> Binder<Ty<'tcx>>[src]
pub fn input(&self, index: usize) -> Binder<Ty<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn inputs_and_output(&self) -> Binder<&'tcx Slice<Ty<'tcx>>>[src]
pub fn inputs_and_output(&self) -> Binder<&'tcx Slice<Ty<'tcx>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn output(&self) -> Binder<Ty<'tcx>>[src]
pub fn output(&self) -> Binder<Ty<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn variadic(&self) -> bool[src]
pub fn variadic(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn unsafety(&self) -> Unsafety[src]
pub fn unsafety(&self) -> Unsafety🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn abi(&self) -> Abi[src]
pub fn abi(&self) -> Abi🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?