Struct rustc::ty::util::TypeIdHasher
[−]
[src]
pub struct TypeIdHasher<'a, 'gcx: 'a + 'tcx, 'tcx: 'a, W> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx, W> TypeIdHasher<'a, 'gcx, 'tcx, W> where
W: StableHasherResult, [src]
impl<'a, 'gcx, 'tcx, W> TypeIdHasher<'a, 'gcx, 'tcx, W> where
W: StableHasherResult, pub fn new(tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Self[src]
pub fn new(tcx: TyCtxt<'a, 'gcx, 'tcx>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn finish(self) -> W[src]
pub fn finish(self) -> W🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn hash<T: Hash>(&mut self, x: T)[src]
pub fn hash<T: Hash>(&mut self, x: T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?