Struct rustc::util::common::Indenter [−][src]
pub struct Indenter {
_cannot_construct_outside_of_this_module: (),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
_cannot_construct_outside_of_this_module: ()
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?