Trait rustc::util::common::CellUsizeExt
[−]
[src]
pub trait CellUsizeExt {
fn increment(&self);
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn increment(&self)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl CellUsizeExt for Cell<usize>[src]
impl CellUsizeExt for Cell<usize>