Struct rustc::util::ppaux::PrintContext [−][src]
pub struct PrintContext {
is_debug: bool,
is_verbose: bool,
identify_regions: bool,
used_region_names: Option<FxHashSet<InternedString>>,
region_index: usize,
binder_depth: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
is_debug: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_verbose: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
identify_regions: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
used_region_names: Option<FxHashSet<InternedString>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_index: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
binder_depth: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl PrintContext[src]
impl PrintContextfn new() -> Self[src]
fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn prepare_late_bound_region_info<'tcx, T>(&mut self, value: &Binder<T>) where
T: TypeFoldable<'tcx>, [src]
fn prepare_late_bound_region_info<'tcx, T>(&mut self, value: &Binder<T>) where
T: TypeFoldable<'tcx>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PrintContext[src]
impl PrintContextfn fn_sig<F: Write>(
&mut self,
f: &mut F,
inputs: &[Ty],
variadic: bool,
output: Ty
) -> Result[src]
fn fn_sig<F: Write>(
&mut self,
f: &mut F,
inputs: &[Ty],
variadic: bool,
output: Ty
) -> Result🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn parameterized<F: Write>(
&mut self,
f: &mut F,
substs: &Substs,
did: DefId,
projections: &[ProjectionPredicate]
) -> Result[src]
fn parameterized<F: Write>(
&mut self,
f: &mut F,
substs: &Substs,
did: DefId,
projections: &[ProjectionPredicate]
) -> Result🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn in_binder<'a, 'gcx, 'tcx, T, U, F>(
&mut self,
f: &mut F,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
original: &Binder<T>,
lifted: Option<Binder<U>>
) -> Result where
T: Print,
U: Print + TypeFoldable<'tcx>,
F: Write, [src]
fn in_binder<'a, 'gcx, 'tcx, T, U, F>(
&mut self,
f: &mut F,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
original: &Binder<T>,
lifted: Option<Binder<U>>
) -> Result where
T: Print,
U: Print + TypeFoldable<'tcx>,
F: Write, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn is_name_used(&self, name: &InternedString) -> bool[src]
fn is_name_used(&self, name: &InternedString) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?