Struct rustc::util::time_graph::TimeGraph [−][src]
pub struct TimeGraph {
data: Arc<Mutex<HashMap<TimelineId, PerThread>>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
data: Arc<Mutex<HashMap<TimelineId, PerThread>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl TimeGraph[src]
impl TimeGraphpub fn new() -> TimeGraph[src]
pub fn new() -> TimeGraph🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn start(
&self,
timeline: TimelineId,
work_package_kind: WorkPackageKind,
name: &str
) -> Timeline[src]
pub fn start(
&self,
timeline: TimelineId,
work_package_kind: WorkPackageKind,
name: &str
) -> Timeline🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn end(&self, timeline: TimelineId, events: Vec<(String, Instant)>)[src]
fn end(&self, timeline: TimelineId, events: Vec<(String, Instant)>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn dump(&self, output_filename: &str)[src]
pub fn dump(&self, output_filename: &str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?