Struct rustc::util::time_graph::Timeline [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
token: Option<RaiiToken>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Timeline[src]
impl Timelinepub fn noop() -> Timeline[src]
pub fn noop() -> Timeline🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn record(&mut self, name: &str)[src]
pub fn record(&mut self, name: &str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Record an event which happened at this moment on this timeline.
Events are displayed in the eventual HTML output where you can click on a particular timeline and it'll expand to all of the events that happened on that timeline. This can then be used to drill into a particular timeline and see what events are happening and taking the most time.