Function rustc_apfloat::ieee::sig::extract [−][src]
pub(super) fn extract(
dst: &mut [u128],
src: &[u128],
src_bits: usize,
src_lsb: usize
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Copy the bit vector of width src_bits from src, starting at bit SRC_LSB,
to dst, such that the bit SRC_LSB becomes the least significant bit of dst.
All high bits above src_bits in dst are zero-filled.