Struct rustc_apfloat::StatusAnd [−][src]
#[must_use]pub struct StatusAnd<T> { pub status: Status, pub value: T, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
status: Status
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
value: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> StatusAnd<T>[src]
impl<T> StatusAnd<T>pub fn map<F: FnOnce(T) -> U, U>(self, f: F) -> StatusAnd<U>[src]
pub fn map<F: FnOnce(T) -> U, U>(self, f: F) -> StatusAnd<U>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?