Enum rustc_borrowck::borrowck::LoanPathElem [−][src]
pub enum LoanPathElem<'tcx> {
LpDeref(PointerKind<'tcx>),
LpInterior(Option<DefId>, InteriorKind),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
LpDeref(PointerKind<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LpInterior(Option<DefId>, InteriorKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?