Enum rustc_borrowck::borrowck::LoanPathKind [−][src]
pub enum LoanPathKind<'tcx> {
LpVar(NodeId),
LpUpvar(UpvarId),
LpDowncast(Rc<LoanPath<'tcx>>, DefId),
LpExtend(Rc<LoanPath<'tcx>>, MutabilityCategory, LoanPathElem<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
LpVar(NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LpUpvar(UpvarId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LpDowncast(Rc<LoanPath<'tcx>>, DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LpExtend(Rc<LoanPath<'tcx>>, MutabilityCategory, LoanPathElem<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?