Enum rustc_borrowck::borrowck::bckerr_code [−][src]
pub enum bckerr_code<'tcx> {
err_mutbl,
err_out_of_scope(Region<'tcx>, Region<'tcx>, LoanCause),
err_borrowed_pointer_too_short(Region<'tcx>, Region<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
err_mutbl🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
err_out_of_scope(Region<'tcx>, Region<'tcx>, LoanCause)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
superscope, subscope, loan cause
err_borrowed_pointer_too_short(Region<'tcx>, Region<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?