Function rustc_borrowck::borrowck::opt_loan_path [−][src]
pub fn opt_loan_path<'tcx>(cmt: &cmt_<'tcx>) -> Option<Rc<LoanPath<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Computes the LoanPath (if any) for a cmt.
Note that this logic is somewhat duplicated in
the method compute() found in gather_loans::restrictions,
which allows it to share common loan path pieces as it
traverses the CMT.