Struct rustc_borrowck::borrowck::gather_loans::lifetime::GuaranteeLifetimeContext [−][src]
struct GuaranteeLifetimeContext<'a, 'tcx: 'a> {
bccx: &'a BorrowckCtxt<'a, 'tcx>,
item_scope: Scope,
span: Span,
cause: LoanCause,
loan_region: Region<'tcx>,
cmt_original: &'a cmt_<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bccx: &'a BorrowckCtxt<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
item_scope: Scope
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cause: LoanCause
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
loan_region: Region<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cmt_original: &'a cmt_<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> GuaranteeLifetimeContext<'a, 'tcx>[src]
impl<'a, 'tcx> GuaranteeLifetimeContext<'a, 'tcx>fn check(&self, cmt: &cmt_<'tcx>, discr_scope: Option<NodeId>) -> Result<(), ()>[src]
fn check(&self, cmt: &cmt_<'tcx>, discr_scope: Option<NodeId>) -> Result<(), ()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Main routine. Walks down cmt until we find the
"guarantor". Reports an error if self.loan_region is
larger than scope of cmt.
fn check_scope(&self, max_scope: Region<'tcx>) -> Result<(), ()>[src]
fn check_scope(&self, max_scope: Region<'tcx>) -> Result<(), ()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Reports an error if loan_region is larger than max_scope
fn scope(&self, cmt: &cmt_<'tcx>) -> Region<'tcx>[src]
fn scope(&self, cmt: &cmt_<'tcx>) -> Region<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the maximal region scope for the which the
place cmt is guaranteed to be valid without any
rooting etc, and presuming cmt is not mutated.
fn report_error(&self, code: bckerr_code<'tcx>)[src]
fn report_error(&self, code: bckerr_code<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?