Struct rustc_borrowck::borrowck::gather_loans::restrictions::RestrictionsContext [−][src]
struct RestrictionsContext<'a, 'tcx: 'a> {
bccx: &'a BorrowckCtxt<'a, 'tcx>,
span: Span,
loan_region: Region<'tcx>,
cause: LoanCause,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bccx: &'a BorrowckCtxt<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
loan_region: Region<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cause: LoanCause
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> RestrictionsContext<'a, 'tcx>[src]
impl<'a, 'tcx> RestrictionsContext<'a, 'tcx>fn restrict(&self, cmt: &cmt_<'tcx>) -> RestrictionResult<'tcx>[src]
fn restrict(&self, cmt: &cmt_<'tcx>) -> RestrictionResult<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn extend(
&self,
result: RestrictionResult<'tcx>,
cmt: &cmt_<'tcx>,
elem: LoanPathElem<'tcx>
) -> RestrictionResult<'tcx>[src]
fn extend(
&self,
result: RestrictionResult<'tcx>,
cmt: &cmt_<'tcx>,
elem: LoanPathElem<'tcx>
) -> RestrictionResult<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?