Struct rustc_borrowck::borrowck::move_data::FlowedMoveData [−][src]
pub struct FlowedMoveData<'a, 'tcx: 'a> {
pub move_data: MoveData<'tcx>,
pub dfcx_moves: DataFlowContext<'a, 'tcx, MoveDataFlowOperator>,
pub dfcx_assign: DataFlowContext<'a, 'tcx, AssignDataFlowOperator>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
move_data: MoveData<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dfcx_moves: DataFlowContext<'a, 'tcx, MoveDataFlowOperator>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dfcx_assign: DataFlowContext<'a, 'tcx, AssignDataFlowOperator>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> FlowedMoveData<'a, 'tcx>[src]
impl<'a, 'tcx> FlowedMoveData<'a, 'tcx>pub fn new(
move_data: MoveData<'tcx>,
bccx: &BorrowckCtxt<'a, 'tcx>,
cfg: &CFG,
id_range: IdRange,
body: &Body
) -> FlowedMoveData<'a, 'tcx>[src]
pub fn new(
move_data: MoveData<'tcx>,
bccx: &BorrowckCtxt<'a, 'tcx>,
cfg: &CFG,
id_range: IdRange,
body: &Body
) -> FlowedMoveData<'a, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn kind_of_move_of_path(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>
) -> Option<MoveKind>[src]
pub fn kind_of_move_of_path(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>
) -> Option<MoveKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the kind of a move of loan_path by id, if one exists.
pub fn each_move_of<F>(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>,
f: F
) -> bool where
F: FnMut(&Move, &LoanPath<'tcx>) -> bool, [src]
pub fn each_move_of<F>(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>,
f: F
) -> bool where
F: FnMut(&Move, &LoanPath<'tcx>) -> bool, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates through each move of loan_path (or some base path of loan_path) that may
have occurred on entry to id without an intervening assignment. In other words, any moves
that would invalidate a reference to loan_path at location id.
pub fn each_assignment_of<F>(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>,
f: F
) -> bool where
F: FnMut(&Assignment) -> bool, [src]
pub fn each_assignment_of<F>(
&self,
id: ItemLocalId,
loan_path: &Rc<LoanPath<'tcx>>,
f: F
) -> bool where
F: FnMut(&Assignment) -> bool, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates through every assignment to loan_path that may have occurred on entry to id.
loan_path must be a single variable.