Struct rustc_borrowck::borrowck::move_data::MovePath [−][src]
pub struct MovePath<'tcx> {
pub loan_path: Rc<LoanPath<'tcx>>,
pub parent: MovePathIndex,
pub first_move: MoveIndex,
pub first_child: MovePathIndex,
pub next_sibling: MovePathIndex,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
loan_path: Rc<LoanPath<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Loan path corresponding to this move path
parent: MovePathIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parent pointer, InvalidMovePathIndex if root
first_move: MoveIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Head of linked list of moves to this path,
InvalidMoveIndex if not moved
first_child: MovePathIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
First node in linked list of children, InvalidMovePathIndex if leaf
next_sibling: MovePathIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Next node in linked list of parent's children (siblings),
InvalidMovePathIndex if none.