Struct rustc_borrowck::borrowck::move_data::MovePathIndex [−][src]
pub struct MovePathIndex(usize);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Index into MoveData.paths, used like a pointer
Methods
impl MovePathIndex[src]
impl MovePathIndexfn get(&self) -> usize[src]
fn get(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?