[−][src]Struct rustc_borrowck::borrowck::BorrowckCtxt
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tables: &'a TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_scope_tree: Lrc<ScopeTree>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
owner_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
body: &'tcx Body
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
used_mut_nodes: RefCell<FxHashSet<HirId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
signalled_any_error: Cell<SignalledError>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx: 'a> BorrowckCtxt<'a, 'tcx>[src]
impl<'a, 'tcx: 'a> BorrowckCtxt<'a, 'tcx>fn signal_error(&self)[src]
fn signal_error(&self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx> BorrowckCtxt<'a, 'tcx>[src]
impl<'a, 'tcx> BorrowckCtxt<'a, 'tcx>pub fn is_subregion_of(&self, r_sub: Region<'tcx>, r_sup: Region<'tcx>) -> bool[src]
pub fn is_subregion_of(&self, r_sub: Region<'tcx>, r_sup: Region<'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn report(&self, err: BckError<'a, 'tcx>)[src]
pub fn report(&self, err: BckError<'a, 'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn report_use_of_moved_value(
&self,
use_span: Span,
use_kind: MovedValueUseKind,
lp: &LoanPath<'tcx>,
the_move: &Move,
moved_lp: &LoanPath<'tcx>
)[src]
pub fn report_use_of_moved_value(
&self,
use_span: Span,
use_kind: MovedValueUseKind,
lp: &LoanPath<'tcx>,
the_move: &Move,
moved_lp: &LoanPath<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn report_partial_reinitialization_of_uninitialized_structure(
&self,
span: Span,
lp: &LoanPath<'tcx>
)[src]
pub fn report_partial_reinitialization_of_uninitialized_structure(
&self,
span: Span,
lp: &LoanPath<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn report_reassigned_immutable_variable(
&self,
span: Span,
lp: &LoanPath<'tcx>,
assign: &Assignment
)[src]
pub fn report_reassigned_immutable_variable(
&self,
span: Span,
lp: &LoanPath<'tcx>,
assign: &Assignment
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn report_bckerr(&self, err: &BckError<'a, 'tcx>)[src]
fn report_bckerr(&self, err: &BckError<'a, 'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn report_aliasability_violation(
&self,
span: Span,
kind: AliasableViolationKind,
cause: AliasableReason,
cmt: &cmt_<'tcx>
)[src]
pub fn report_aliasability_violation(
&self,
span: Span,
kind: AliasableViolationKind,
cause: AliasableReason,
cmt: &cmt_<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn suggest_mut_for_immutable(
&self,
pty: &Ty,
is_implicit_self: bool
) -> Option<String>[src]
fn suggest_mut_for_immutable(
&self,
pty: &Ty,
is_implicit_self: bool
) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given a type, if it is an immutable reference, return a suggestion to make it mutable
fn local_binding_mode(&self, node_id: NodeId) -> BindingMode[src]
fn local_binding_mode(&self, node_id: NodeId) -> BindingMode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn local_ty(&self, node_id: NodeId) -> (Option<&Ty>, bool)[src]
fn local_ty(&self, node_id: NodeId) -> (Option<&Ty>, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn note_immutability_blame(
&self,
db: &mut DiagnosticBuilder,
blame: Option<ImmutabilityBlame>,
error_node_id: NodeId
)[src]
fn note_immutability_blame(
&self,
db: &mut DiagnosticBuilder,
blame: Option<ImmutabilityBlame>,
error_node_id: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn note_immutable_local(
&self,
db: &mut DiagnosticBuilder,
borrowed_node_id: NodeId,
binding_node_id: NodeId
)[src]
fn note_immutable_local(
&self,
db: &mut DiagnosticBuilder,
borrowed_node_id: NodeId,
binding_node_id: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn report_out_of_scope_escaping_closure_capture(
&self,
err: &BckError<'a, 'tcx>,
capture_span: Span
)[src]
fn report_out_of_scope_escaping_closure_capture(
&self,
err: &BckError<'a, 'tcx>,
capture_span: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn region_end_span(&self, region: Region<'tcx>) -> Option<Span>[src]
fn region_end_span(&self, region: Region<'tcx>) -> Option<Span>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn note_and_explain_mutbl_error(
&self,
db: &mut DiagnosticBuilder,
err: &BckError<'a, 'tcx>,
error_span: &Span
)[src]
fn note_and_explain_mutbl_error(
&self,
db: &mut DiagnosticBuilder,
err: &BckError<'a, 'tcx>,
error_span: &Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn append_loan_path_to_string(
&self,
loan_path: &LoanPath<'tcx>,
out: &mut String
)[src]
pub fn append_loan_path_to_string(
&self,
loan_path: &LoanPath<'tcx>,
out: &mut String
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn append_autoderefd_loan_path_to_string(
&self,
loan_path: &LoanPath<'tcx>,
out: &mut String
)[src]
pub fn append_autoderefd_loan_path_to_string(
&self,
loan_path: &LoanPath<'tcx>,
out: &mut String
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn loan_path_to_string(&self, loan_path: &LoanPath<'tcx>) -> String[src]
pub fn loan_path_to_string(&self, loan_path: &LoanPath<'tcx>) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn cmt_to_string(&self, cmt: &cmt_<'tcx>) -> String[src]
pub fn cmt_to_string(&self, cmt: &cmt_<'tcx>) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn cmt_to_path_or_string(&self, cmt: &cmt_<'tcx>) -> String[src]
pub fn cmt_to_path_or_string(&self, cmt: &cmt_<'tcx>) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?