[−][src]Enum rustc_borrowck::dataflow::KillFrom
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Flag used by add_kill to indicate whether the provided kill
takes effect only when control flows directly through the node in
question, or if the kill's effect is associated with any
control-flow directly through or indirectly over the node.
Variants
ScopeEnd🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A ScopeEnd kill is one that takes effect when any control
flow goes over the node. A kill associated with the end of the
scope of a variable declaration let x; is an example of a
ScopeEnd kill.
Execution🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An Execution kill is one that takes effect only when control
flow goes through the node to completion. A kill associated
with an assignment statement x = expr; is an example of an
Execution kill.