[−][src]Trait rustc_borrowck::dataflow::DataFlowOperator
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parameterization for the precise form of data flow that is used.
Required Methods
fn initial_value(&self) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Specifies the initial value for each bit in the on_entry set
Implementors
impl DataFlowOperator for AssignDataFlowOperator[src]
impl DataFlowOperator for AssignDataFlowOperatorfn initial_value(&self) -> bool[src]
fn initial_value(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl DataFlowOperator for MoveDataFlowOperator[src]
impl DataFlowOperator for MoveDataFlowOperatorfn initial_value(&self) -> bool[src]
fn initial_value(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl DataFlowOperator for LoanDataFlowOperator[src]
impl DataFlowOperator for LoanDataFlowOperatorfn initial_value(&self) -> bool[src]
fn initial_value(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?