Struct rustc_borrowck::graphviz::DataflowLabeller [−][src]
pub struct DataflowLabeller<'a, 'tcx: 'a> {
pub inner: LabelledCFG<'a, 'tcx>,
pub variants: Vec<Variant>,
pub borrowck_ctxt: &'a BorrowckCtxt<'a, 'tcx>,
pub analysis_data: &'a AnalysisData<'a, 'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
inner: LabelledCFG<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
variants: Vec<Variant>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
borrowck_ctxt: &'a BorrowckCtxt<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
analysis_data: &'a AnalysisData<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> DataflowLabeller<'a, 'tcx>[src]
impl<'a, 'tcx> DataflowLabeller<'a, 'tcx>fn dataflow_for(&self, e: EntryOrExit, n: &Node<'a>) -> String[src]
fn dataflow_for(&self, e: EntryOrExit, n: &Node<'a>) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dataflow_for_variant(&self, e: EntryOrExit, n: &Node, v: Variant) -> String[src]
fn dataflow_for_variant(&self, e: EntryOrExit, n: &Node, v: Variant) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_set<O: DataFlowOperator, F>(
&self,
e: EntryOrExit,
cfgidx: CFGIndex,
dfcx: &DataFlowContext<'a, 'tcx, O>,
to_lp: F
) -> String where
F: FnMut(usize) -> Rc<LoanPath<'tcx>>, [src]
fn build_set<O: DataFlowOperator, F>(
&self,
e: EntryOrExit,
cfgidx: CFGIndex,
dfcx: &DataFlowContext<'a, 'tcx, O>,
to_lp: F
) -> String where
F: FnMut(usize) -> Rc<LoanPath<'tcx>>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dataflow_loans_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String[src]
fn dataflow_loans_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dataflow_moves_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String[src]
fn dataflow_moves_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dataflow_assigns_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String[src]
fn dataflow_assigns_for(&self, e: EntryOrExit, cfgidx: CFGIndex) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?