[−][src]Trait rustc_codegen_llvm::abi::ArgAttributesExt
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn apply_llfn(&self, idx: AttributePlace, llfn: &Value)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn apply_callsite(&self, idx: AttributePlace, callsite: &Value)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl ArgAttributesExt for ArgAttributes[src]
impl ArgAttributesExt for ArgAttributesfn apply_llfn(&self, idx: AttributePlace, llfn: &Value)[src]
fn apply_llfn(&self, idx: AttributePlace, llfn: &Value)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn apply_callsite(&self, idx: AttributePlace, callsite: &Value)[src]
fn apply_callsite(&self, idx: AttributePlace, callsite: &Value)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?