[−][src]Trait rustc_codegen_llvm::abi::LlvmType
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn llvm_type<'ll>(&self, cx: &CodegenCx<'ll, '_>) -> &'ll Type
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl LlvmType for CastTarget[src]
impl LlvmType for CastTargetfn llvm_type<'ll>(&self, cx: &CodegenCx<'ll, '_>) -> &'ll Type[src]
fn llvm_type<'ll>(&self, cx: &CodegenCx<'ll, '_>) -> &'ll Type🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl LlvmType for Reg[src]
impl LlvmType for Reg