[−][src]Struct rustc_codegen_llvm::mir::FunctionCx
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Master context for codegenning from MIR.
Fields
instance: Instance<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir: &'a Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
debug_context: FunctionDebugContext<'ll>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
llfn: &'ll Value
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cx: &'a CodegenCx<'ll, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn_ty: FnType<'tcx, Ty<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
personality_slot: Option<PlaceRef<'ll, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When unwinding is initiated, we have to store this personality value somewhere so that we can load it and re-use it in the resume instruction. The personality is (afaik) some kind of value used for C++ unwinding, which must filter by type: we don't really care about it very much. Anyway, this value contains an alloca into which the personality is stored and then later loaded when generating the DIVERGE_BLOCK.
blocks: IndexVec<BasicBlock, &'ll BasicBlock>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Block for each MIR BasicBlock
cleanup_kinds: IndexVec<BasicBlock, CleanupKind>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The funclet status of each basic block
funclets: &'a IndexVec<BasicBlock, Option<Funclet<'ll>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When targeting MSVC, this stores the cleanup info for each funclet BB. This is initialized as we compute the funclets' head block in RPO.
landing_pads: IndexVec<BasicBlock, Option<&'ll BasicBlock>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This stores the landing-pad block for a given BB, computed lazily on GNU and eagerly on MSVC.
unreachable_block: Option<&'ll BasicBlock>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Cached unreachable block
locals: IndexVec<Local, LocalRef<'ll, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The location where each MIR arg/var/tmp/ret is stored. This is
usually an PlaceRef representing an alloca, but not always:
sometimes we can skip the alloca and just store the value
directly using an OperandRef, which makes for tighter LLVM
IR. The conditions for using an OperandRef are as follows:
- the type of the local must be judged "immediate" by
is_llvm_immediate - the operand must never be referenced indirectly
- we should not take its address using the
&operator - nor should it appear in a place path like
tmp.a
- we should not take its address using the
- the operand must be defined by an rvalue that can generate immediate values
Avoiding allocs can also be important for certain intrinsics,
notably expect.
scopes: IndexVec<SourceScope, MirDebugScope<'ll>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Debug information for MIR scopes.
param_substs: &'tcx Substs<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this function is being monomorphized, this contains the type substitutions used.
Methods
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>pub fn codegen_block(&mut self, bb: BasicBlock)[src]
pub fn codegen_block(&mut self, bb: BasicBlock)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn codegen_terminator(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
bb: BasicBlock,
terminator: &Terminator<'tcx>
)[src]
fn codegen_terminator(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
bb: BasicBlock,
terminator: &Terminator<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn codegen_argument(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: OperandRef<'ll, 'tcx>,
llargs: &mut Vec<&'ll Value>,
arg: &ArgType<'tcx, Ty<'tcx>>
)[src]
fn codegen_argument(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: OperandRef<'ll, 'tcx>,
llargs: &mut Vec<&'ll Value>,
arg: &ArgType<'tcx, Ty<'tcx>>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn codegen_arguments_untupled(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
operand: &Operand<'tcx>,
llargs: &mut Vec<&'ll Value>,
args: &[ArgType<'tcx, Ty<'tcx>>]
)[src]
fn codegen_arguments_untupled(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
operand: &Operand<'tcx>,
llargs: &mut Vec<&'ll Value>,
args: &[ArgType<'tcx, Ty<'tcx>>]
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_personality_slot(
&mut self,
bx: &Builder<'a, 'll, 'tcx>
) -> PlaceRef<'ll, 'tcx>[src]
fn get_personality_slot(
&mut self,
bx: &Builder<'a, 'll, 'tcx>
) -> PlaceRef<'ll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn landing_pad_to(&mut self, target_bb: BasicBlock) -> &'ll BasicBlock[src]
fn landing_pad_to(&mut self, target_bb: BasicBlock) -> &'ll BasicBlock🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the landingpad wrapper around the given basic block
No-op in MSVC SEH scheme.
fn landing_pad_uncached(
&mut self,
target_bb: &'ll BasicBlock
) -> &'ll BasicBlock[src]
fn landing_pad_uncached(
&mut self,
target_bb: &'ll BasicBlock
) -> &'ll BasicBlock🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn landing_pad_type(&self) -> &'ll Type[src]
fn landing_pad_type(&self) -> &'ll Type🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn unreachable_block(&mut self) -> &'ll BasicBlock[src]
fn unreachable_block(&mut self) -> &'ll BasicBlock🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_block(&self, name: &str) -> Builder<'a, 'll, 'tcx>[src]
pub fn new_block(&self, name: &str) -> Builder<'a, 'll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn build_block(&self, bb: BasicBlock) -> Builder<'a, 'll, 'tcx>[src]
pub fn build_block(&self, bb: BasicBlock) -> Builder<'a, 'll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn make_return_dest(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
dest: &Place<'tcx>,
fn_ret: &ArgType<'tcx, Ty<'tcx>>,
llargs: &mut Vec<&'ll Value>,
is_intrinsic: bool
) -> ReturnDest<'ll, 'tcx>[src]
fn make_return_dest(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
dest: &Place<'tcx>,
fn_ret: &ArgType<'tcx, Ty<'tcx>>,
llargs: &mut Vec<&'ll Value>,
is_intrinsic: bool
) -> ReturnDest<'ll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn codegen_transmute(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
src: &Operand<'tcx>,
dst: &Place<'tcx>
)[src]
fn codegen_transmute(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
src: &Operand<'tcx>,
dst: &Place<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn codegen_transmute_into(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
src: &Operand<'tcx>,
dst: PlaceRef<'ll, 'tcx>
)[src]
fn codegen_transmute_into(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
src: &Operand<'tcx>,
dst: PlaceRef<'ll, 'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn store_return(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
dest: ReturnDest<'ll, 'tcx>,
ret_ty: &ArgType<'tcx, Ty<'tcx>>,
llval: &'ll Value
)[src]
fn store_return(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
dest: ReturnDest<'ll, 'tcx>,
ret_ty: &ArgType<'tcx, Ty<'tcx>>,
llval: &'ll Value
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>fn fully_evaluate(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
constant: &'tcx Const<'tcx>
) -> Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>[src]
fn fully_evaluate(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
constant: &'tcx Const<'tcx>
) -> Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn eval_mir_constant(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
constant: &Constant<'tcx>
) -> Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>[src]
pub fn eval_mir_constant(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
constant: &Constant<'tcx>
) -> Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn simd_shuffle_indices(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
span: Span,
ty: Ty<'tcx>,
constant: Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>
) -> (&'ll Value, Ty<'tcx>)[src]
pub fn simd_shuffle_indices(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
span: Span,
ty: Ty<'tcx>,
constant: Result<&'tcx Const<'tcx>, Lrc<ConstEvalErr<'tcx>>>
) -> (&'ll Value, Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
process constant containing SIMD shuffle indices
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>pub fn codegen_place(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> PlaceRef<'ll, 'tcx>[src]
pub fn codegen_place(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> PlaceRef<'ll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn monomorphized_place_ty(&self, place: &Place<'tcx>) -> Ty<'tcx>[src]
pub fn monomorphized_place_ty(&self, place: &Place<'tcx>) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>fn maybe_codegen_consume_direct(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> Option<OperandRef<'ll, 'tcx>>[src]
fn maybe_codegen_consume_direct(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> Option<OperandRef<'ll, 'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_consume(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> OperandRef<'ll, 'tcx>[src]
pub fn codegen_consume(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> OperandRef<'ll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_operand(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
operand: &Operand<'tcx>
) -> OperandRef<'ll, 'tcx>[src]
pub fn codegen_operand(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
operand: &Operand<'tcx>
) -> OperandRef<'ll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>pub fn codegen_rvalue(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
dest: PlaceRef<'ll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> Builder<'a, 'll, 'tcx>[src]
pub fn codegen_rvalue(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
dest: PlaceRef<'ll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> Builder<'a, 'll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_rvalue_unsized(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
indirect_dest: PlaceRef<'ll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> Builder<'a, 'll, 'tcx>[src]
pub fn codegen_rvalue_unsized(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
indirect_dest: PlaceRef<'ll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> Builder<'a, 'll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_rvalue_operand(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> (Builder<'a, 'll, 'tcx>, OperandRef<'ll, 'tcx>)[src]
pub fn codegen_rvalue_operand(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
rvalue: &Rvalue<'tcx>
) -> (Builder<'a, 'll, 'tcx>, OperandRef<'ll, 'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn evaluate_array_len(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> &'ll Value[src]
fn evaluate_array_len(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
place: &Place<'tcx>
) -> &'ll Value🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_scalar_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs: &'ll Value,
rhs: &'ll Value,
input_ty: Ty<'tcx>
) -> &'ll Value[src]
pub fn codegen_scalar_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs: &'ll Value,
rhs: &'ll Value,
input_ty: Ty<'tcx>
) -> &'ll Value🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_fat_ptr_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs_addr: &'ll Value,
lhs_extra: &'ll Value,
rhs_addr: &'ll Value,
rhs_extra: &'ll Value,
_input_ty: Ty<'tcx>
) -> &'ll Value[src]
pub fn codegen_fat_ptr_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs_addr: &'ll Value,
lhs_extra: &'ll Value,
rhs_addr: &'ll Value,
rhs_extra: &'ll Value,
_input_ty: Ty<'tcx>
) -> &'ll Value🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn codegen_scalar_checked_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs: &'ll Value,
rhs: &'ll Value,
input_ty: Ty<'tcx>
) -> OperandValue<'ll>[src]
pub fn codegen_scalar_checked_binop(
&mut self,
bx: &Builder<'a, 'll, 'tcx>,
op: BinOp,
lhs: &'ll Value,
rhs: &'ll Value,
input_ty: Ty<'tcx>
) -> OperandValue<'ll>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn rvalue_creates_operand(&self, rvalue: &Rvalue<'tcx>) -> bool[src]
pub fn rvalue_creates_operand(&self, rvalue: &Rvalue<'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>pub fn codegen_statement(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
statement: &Statement<'tcx>
) -> Builder<'a, 'll, 'tcx>[src]
pub fn codegen_statement(
&mut self,
bx: Builder<'a, 'll, 'tcx>,
statement: &Statement<'tcx>
) -> Builder<'a, 'll, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>[src]
impl<'a, 'll, 'tcx> FunctionCx<'a, 'll, 'tcx>pub fn monomorphize<T>(&self, value: &T) -> T where
T: TypeFoldable<'tcx>, [src]
pub fn monomorphize<T>(&self, value: &T) -> T where
T: TypeFoldable<'tcx>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_debug_loc(
&mut self,
bx: &Builder<'_, 'll, '_>,
source_info: SourceInfo
)[src]
pub fn set_debug_loc(
&mut self,
bx: &Builder<'_, 'll, '_>,
source_info: SourceInfo
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn debug_loc(
&mut self,
source_info: SourceInfo
) -> (Option<&'ll DIScope>, Span)[src]
pub fn debug_loc(
&mut self,
source_info: SourceInfo
) -> (Option<&'ll DIScope>, Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn scope_metadata_for_loc(
&self,
scope_id: SourceScope,
pos: BytePos
) -> Option<&'ll DIScope>[src]
fn scope_metadata_for_loc(
&self,
scope_id: SourceScope,
pos: BytePos
) -> Option<&'ll DIScope>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?