Struct rustc_const_math::ConstFloat
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ty: FloatTy
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bits: u128
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ConstFloat[src]
impl ConstFloatpub fn description(&self) -> &'static str[src]
pub fn description(&self) -> &'static str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Description of the type, not the value
pub fn try_cmp(self, rhs: Self) -> Result<Option<Ordering>, ConstMathErr>[src]
pub fn try_cmp(self, rhs: Self) -> Result<Option<Ordering>, ConstMathErr>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compares the values if they are of the same type
pub fn from_i128(input: i128, ty: FloatTy) -> Self[src]
pub fn from_i128(input: i128, ty: FloatTy) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_u128(input: u128, ty: FloatTy) -> Self[src]
pub fn from_u128(input: u128, ty: FloatTy) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_str(num: &str, ty: FloatTy) -> Result<Self, ParseFloatError>[src]
pub fn from_str(num: &str, ty: FloatTy) -> Result<Self, ParseFloatError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_i128(self, width: usize) -> Option<i128>[src]
pub fn to_i128(self, width: usize) -> Option<i128>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_u128(self, width: usize) -> Option<u128>[src]
pub fn to_u128(self, width: usize) -> Option<u128>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn convert(self, to: FloatTy) -> Self[src]
pub fn convert(self, to: FloatTy) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?