Struct rustc_data_structures::bitvec::BitVector [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A very simple BitVector type.
Fields
data: Vec<u128>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl BitVector[src]
impl BitVectorpub fn new(num_bits: usize) -> BitVector[src]
pub fn new(num_bits: usize) -> BitVector🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn count(&self) -> usize[src]
pub fn count(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains(&self, bit: usize) -> bool[src]
pub fn contains(&self, bit: usize) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn insert(&mut self, bit: usize) -> bool[src]
pub fn insert(&mut self, bit: usize) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the bit has changed.
pub fn remove(&mut self, bit: usize) -> bool[src]
pub fn remove(&mut self, bit: usize) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the bit has changed.
pub fn insert_all(&mut self, all: &BitVector) -> bool[src]
pub fn insert_all(&mut self, all: &BitVector) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn grow(&mut self, num_bits: usize)[src]
pub fn grow(&mut self, num_bits: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for BitVectorIter<'a>pub fn iter<'a>(&'a self) -> BitVectorIter<'a>[src]
pub fn iter<'a>(&'a self) -> BitVectorIter<'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over indexes of set bits in a sorted order