[−][src]Struct rustc_data_structures::bitvec::SparseBitMatrix
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A moderately sparse bit matrix, in which rows are instantiated lazily.
Initially, every row has no explicit representation. If any bit within a
row is set, the entire row is instantiated as
Some(<full-column-width-BitArray>). Furthermore, any previously
uninstantiated rows prior to it will be instantiated as None. Those prior
rows may themselves become fully instantiated later on if any of their bits
are set.
Fields
num_columns: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
rows: IndexVec<R, Option<BitArray<C>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<R: Idx, C: Idx> SparseBitMatrix<R, C>[src]
impl<R: Idx, C: Idx> SparseBitMatrix<R, C>pub fn new(num_columns: usize) -> Self[src]
pub fn new(num_columns: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new empty sparse bit matrix with no rows or columns.
fn ensure_row(&mut self, row: R) -> &mut BitArray<C>[src]
fn ensure_row(&mut self, row: R) -> &mut BitArray<C>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add(&mut self, row: R, column: C) -> bool[src]
pub fn add(&mut self, row: R, column: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets the cell at (row, column) to true. Put another way, insert
column to the bitset for row.
Returns true if this changed the matrix, and false otherwise.
pub fn contains(&self, row: R, column: C) -> bool[src]
pub fn contains(&self, row: R, column: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Do the bits from row contain column? Put another way, is
the matrix cell at (row, column) true? Put yet another way,
if the matrix represents (transitive) reachability, can
row reach column?
pub fn merge(&mut self, read: R, write: R) -> bool[src]
pub fn merge(&mut self, read: R, write: R) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add the bits from row read to the bits from row write,
return true if anything changed.
This is used when computing transitive reachability because if
you have an edge write -> read, because in that case
write can reach everything that read can (and
potentially more).
pub fn merge_into(&mut self, into: R, from: &BitArray<C>) -> bool[src]
pub fn merge_into(&mut self, into: R, from: &BitArray<C>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Merge a row, from, into the into row.
pub fn add_all(&mut self, row: R)[src]
pub fn add_all(&mut self, row: R)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add all bits to the given row.
pub fn rows(
&self
) -> impl Iterator<Item = R>[src]
pub fn rows(
&self
) -> impl Iterator<Item = R>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter<'a>(
&'a self,
row: R
) -> impl Iterator<Item = C> + 'a[src]
pub fn iter<'a>(
&'a self,
row: R
) -> impl Iterator<Item = C> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates through all the columns set to true in a given row of the matrix.
pub fn row(&self, row: R) -> Option<&BitArray<C>>[src]
pub fn row(&self, row: R) -> Option<&BitArray<C>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?