Struct rustc_data_structures::bitvec::SparseChunk
[−]
[src]
pub struct SparseChunk<I> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<I: Idx> SparseChunk<I>[src]
impl<I: Idx> SparseChunk<I>pub fn one(index: I) -> Self[src]
pub fn one(index: I) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn any(&self) -> bool[src]
pub fn any(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter(
&self
) -> impl Iterator<Item = I>[src]
pub fn iter(
&self
) -> impl Iterator<Item = I>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?