[−][src]Struct rustc_data_structures::fingerprint::Fingerprint
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Fingerprint[src]
impl Fingerprintpub const ZERO: Fingerprint[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_smaller_hash(hash: u64) -> Fingerprint[src]
pub fn from_smaller_hash(hash: u64) -> Fingerprint🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_smaller_hash(&self) -> u64[src]
pub fn to_smaller_hash(&self) -> u64🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_value(&self) -> (u64, u64)[src]
pub fn as_value(&self) -> (u64, u64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn combine(self, other: Fingerprint) -> Fingerprint[src]
pub fn combine(self, other: Fingerprint) -> Fingerprint🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn combine_commutative(self, other: Fingerprint) -> Fingerprint[src]
pub fn combine_commutative(self, other: Fingerprint) -> Fingerprint🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_hex(&self) -> String[src]
pub fn to_hex(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn encode_opaque(&self, encoder: &mut Encoder) -> EncodeResult[src]
pub fn encode_opaque(&self, encoder: &mut Encoder) -> EncodeResult🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn decode_opaque<'a>(
decoder: &mut Decoder<'a>
) -> Result<Fingerprint, String>[src]
pub fn decode_opaque<'a>(
decoder: &mut Decoder<'a>
) -> Result<Fingerprint, String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?