Struct rustc_data_structures::fx::FxHasher [−]
pub struct FxHasher {
hash: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A speedy hash algorithm for use within rustc. The hashmap in liballoc by default uses SipHash which isn't quite as speedy as we want. In the compiler we're not really worried about DOS attempts, so we use a fast non-cryptographic hash.
This is the same as the algorithm used by Firefox -- which is a homespun one not based on any widely-known algorithm -- though modified to produce 64-bit hash values instead of 32-bit hash values. It consistently out-performs an FNV-based hash within rustc itself -- the collision rate is similar or slightly worse than FNV, but the speed of the hash function itself is much higher because it works on up to 8 bytes at a time.
Fields
hash: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl FxHasher
impl FxHasherTrait Implementations
impl Default for FxHasher
impl Default for FxHasherimpl Hasher for FxHasher
impl Hasher for FxHasherfn write(&mut self, bytes: &[u8])
fn write(&mut self, bytes: &[u8])Writes some data into this Hasher. Read more
fn write_u8(&mut self, i: u8)
fn write_u8(&mut self, i: u8)Writes a single u8 into this hasher.
fn write_u16(&mut self, i: u16)
fn write_u16(&mut self, i: u16)Writes a single u16 into this hasher.
fn write_u32(&mut self, i: u32)
fn write_u32(&mut self, i: u32)Writes a single u32 into this hasher.
fn write_u64(&mut self, i: u64)
fn write_u64(&mut self, i: u64)Writes a single u64 into this hasher.
fn write_usize(&mut self, i: usize)
fn write_usize(&mut self, i: usize)Writes a single usize into this hasher.
fn finish(&self) -> u64
fn finish(&self) -> u64Returns the hash value for the values written so far. Read more
fn write_u128(&mut self, i: u128)1.26.0[src]
fn write_u128(&mut self, i: u128)Writes a single u128 into this hasher.
fn write_i8(&mut self, i: i8)1.3.0[src]
fn write_i8(&mut self, i: i8)Writes a single i8 into this hasher.
fn write_i16(&mut self, i: i16)1.3.0[src]
fn write_i16(&mut self, i: i16)Writes a single i16 into this hasher.
fn write_i32(&mut self, i: i32)1.3.0[src]
fn write_i32(&mut self, i: i32)Writes a single i32 into this hasher.
fn write_i64(&mut self, i: i64)1.3.0[src]
fn write_i64(&mut self, i: i64)Writes a single i64 into this hasher.
fn write_i128(&mut self, i: i128)1.26.0[src]
fn write_i128(&mut self, i: i128)Writes a single i128 into this hasher.
fn write_isize(&mut self, i: isize)1.3.0[src]
fn write_isize(&mut self, i: isize)Writes a single isize into this hasher.