Struct rustc_data_structures::graph::dominators::Dominators [−][src]
pub struct Dominators<N: Idx> { post_order_rank: IndexVec<N, usize>, immediate_dominators: IndexVec<N, Option<N>>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
post_order_rank: IndexVec<N, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
immediate_dominators: IndexVec<N, Option<N>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<Node: Idx> Dominators<Node>[src]
impl<Node: Idx> Dominators<Node>pub fn is_reachable(&self, node: Node) -> bool[src]
pub fn is_reachable(&self, node: Node) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn immediate_dominator(&self, node: Node) -> Node[src]
pub fn immediate_dominator(&self, node: Node) -> Node🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Iter<'dom, Node>pub fn dominators(&self, node: Node) -> Iter<Node>[src]
pub fn dominators(&self, node: Node) -> Iter<Node>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_dominated_by(&self, node: Node, dom: Node) -> bool[src]
pub fn is_dominated_by(&self, node: Node, dom: Node) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?