Struct rustc_data_structures::graph::implementation::Graph [−][src]
pub struct Graph<N, E> {
nodes: SnapshotVec<Node<N>>,
edges: SnapshotVec<Edge<E>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
nodes: SnapshotVec<Node<N>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
edges: SnapshotVec<Edge<E>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<N: Debug, E: Debug> Graph<N, E>[src]
impl<N: Debug, E: Debug> Graph<N, E>pub fn new() -> Graph<N, E>[src]
pub fn new() -> Graph<N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_capacity(nodes: usize, edges: usize) -> Graph<N, E>[src]
pub fn with_capacity(nodes: usize, edges: usize) -> Graph<N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn all_nodes(&self) -> &[Node<N>][src]
pub fn all_nodes(&self) -> &[Node<N>]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn len_nodes(&self) -> usize[src]
pub fn len_nodes(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn all_edges(&self) -> &[Edge<E>][src]
pub fn all_edges(&self) -> &[Edge<E>]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn len_edges(&self) -> usize[src]
pub fn len_edges(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn next_node_index(&self) -> NodeIndex[src]
pub fn next_node_index(&self) -> NodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_node(&mut self, data: N) -> NodeIndex[src]
pub fn add_node(&mut self, data: N) -> NodeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Wpub fn mut_node_data(&mut self, idx: NodeIndex) -> &mut N[src]
pub fn mut_node_data(&mut self, idx: NodeIndex) -> &mut N🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Wpub fn node_data(&self, idx: NodeIndex) -> &N[src]
pub fn node_data(&self, idx: NodeIndex) -> &N🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn node(&self, idx: NodeIndex) -> &Node<N>[src]
pub fn node(&self, idx: NodeIndex) -> &Node<N>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn next_edge_index(&self) -> EdgeIndex[src]
pub fn next_edge_index(&self) -> EdgeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_edge(
&mut self,
source: NodeIndex,
target: NodeIndex,
data: E
) -> EdgeIndex[src]
pub fn add_edge(
&mut self,
source: NodeIndex,
target: NodeIndex,
data: E
) -> EdgeIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn edge(&self, idx: EdgeIndex) -> &Edge<E>[src]
pub fn edge(&self, idx: EdgeIndex) -> &Edge<E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn enumerated_nodes(&self) -> [src]
pub fn enumerated_nodes(&self) -> 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn enumerated_edges(&self) -> [src]
pub fn enumerated_edges(&self) -> 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn each_node<'a>(
&'a self,
f: impl FnMut(NodeIndex, &'a Node<N>) -> bool
) -> bool[src]
pub fn each_node<'a>(
&'a self,
f: impl FnMut(NodeIndex, &'a Node<N>) -> bool
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over all edges defined in the graph.
pub fn each_edge<'a>(
&'a self,
f: impl FnMut(EdgeIndex, &'a Edge<E>) -> bool
) -> bool[src]
pub fn each_edge<'a>(
&'a self,
f: impl FnMut(EdgeIndex, &'a Edge<E>) -> bool
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over all edges defined in the graph
ⓘImportant traits for AdjacentEdges<'g, N, E>pub fn outgoing_edges(&self, source: NodeIndex) -> AdjacentEdges<N, E>[src]
pub fn outgoing_edges(&self, source: NodeIndex) -> AdjacentEdges<N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for AdjacentEdges<'g, N, E>pub fn incoming_edges(&self, source: NodeIndex) -> AdjacentEdges<N, E>[src]
pub fn incoming_edges(&self, source: NodeIndex) -> AdjacentEdges<N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for AdjacentEdges<'g, N, E>pub fn adjacent_edges(
&self,
source: NodeIndex,
direction: Direction
) -> AdjacentEdges<N, E>[src]
pub fn adjacent_edges(
&self,
source: NodeIndex,
direction: Direction
) -> AdjacentEdges<N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn successor_nodes<'a>(&'a self, source: NodeIndex) -> <'a>[src]
pub fn successor_nodes<'a>(&'a self, source: NodeIndex) -> <'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn predecessor_nodes<'a>(&'a self, target: NodeIndex) -> <'a>[src]
pub fn predecessor_nodes<'a>(&'a self, target: NodeIndex) -> <'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for DepthFirstTraversal<'g, N, E>pub fn depth_traverse<'a>(
&'a self,
start: NodeIndex,
direction: Direction
) -> DepthFirstTraversal<'a, N, E>[src]
pub fn depth_traverse<'a>(
&'a self,
start: NodeIndex,
direction: Direction
) -> DepthFirstTraversal<'a, N, E>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn nodes_in_postorder<'a>(
&'a self,
direction: Direction,
entry_node: NodeIndex
) -> Vec<NodeIndex>[src]
pub fn nodes_in_postorder<'a>(
&'a self,
direction: Direction,
entry_node: NodeIndex
) -> Vec<NodeIndex>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?