Struct rustc_data_structures::graph::scc::SccData [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ranges: IndexVec<S, Range<usize>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each SCC, the range of all_successors where its
successors can be found.
all_successors: Vec<S>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contains the succcessors for all the Sccs, concatenated. The range of indices corresponding to a given SCC is found in its SccData.
Methods
impl<S: Idx> SccData<S>[src]
impl<S: Idx> SccData<S>fn len(&self) -> usize[src]
fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Number of SCCs,
fn successors(&self, scc: S) -> &[S][src]
fn successors(&self, scc: S) -> &[S]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the successors of the given SCC.
fn create_scc(
&mut self,
successors: impl IntoIterator<Item = S>
) -> S[src]
fn create_scc(
&mut self,
successors: impl IntoIterator<Item = S>
) -> S🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a new SCC with successors as its successors and
returns the resulting index.