[−][src]Struct rustc_data_structures::graph::scc::Sccs
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Strongly connected components (SCC) of a graph. The type N is
the index type for the graph nodes and S is the index type for
the SCCs. We can map from each node to the SCC that it
participates in, and we also have the successors of each SCC.
Fields
scc_indices: IndexVec<N, S>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each node, what is the SCC index of the SCC to which it belongs.
scc_data: SccData<S>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Data about each SCC.
Methods
impl<N: Idx, S: Idx> Sccs<N, S>[src]
impl<N: Idx, S: Idx> Sccs<N, S>pub fn new(
graph: &impl DirectedGraph<Node = N> + WithNumNodes + WithSuccessors
) -> Self[src]
pub fn new(
graph: &impl DirectedGraph<Node = N> + WithNumNodes + WithSuccessors
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn num_sccs(&self) -> usize[src]
pub fn num_sccs(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the number of SCCs in the graph.
pub fn all_sccs(
&self
) -> impl Iterator<Item = S>[src]
pub fn all_sccs(
&self
) -> impl Iterator<Item = S>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an iterator over the SCCs in the graph.
pub fn scc(&self, r: N) -> S[src]
pub fn scc(&self, r: N) -> S🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the SCC to which a node r belongs.
pub fn successors(&self, scc: S) -> &[S][src]
pub fn successors(&self, scc: S) -> &[S]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the successors of the given SCC.