Struct rustc_data_structures::graph::NodeIndex
[−]
[src]
pub struct NodeIndex(pub usize);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl NodeIndex[src]
impl NodeIndexpub fn node_id(&self) -> usize[src]
pub fn node_id(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns unique id (unique with respect to the graph holding associated node).