Trait rustc_data_structures::graph::DirectedGraph [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type Node: Idx
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'graph, G: DirectedGraph> DirectedGraph for &'graph G[src]
impl<'graph, G: DirectedGraph> DirectedGraph for &'graph G