Trait rustc_data_structures::graph::WithStartNode [−][src]
pub trait WithStartNode: DirectedGraph { fn start_node(&self) -> Self::Node; }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn start_node(&self) -> Self::Node
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'graph, G: WithStartNode> WithStartNode for &'graph G[src]
impl<'graph, G: WithStartNode> WithStartNode for &'graph Gfn start_node(&self) -> Self::Node[src]
fn start_node(&self) -> Self::Node🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?