[−][src]Enum rustc_data_structures::indexed_set::HybridIdxSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Like IdxSet, but with a hybrid representation: sparse when there are few
elements in the set, but dense when there are many. It's especially
efficient for sets that typically have a small number of elements, but a
large domain_size, and are cleared frequently.
Variants
Sparse(SparseIdxSet<T>, usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Dense(IdxSet<T>, usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: Idx> HybridIdxSet<T>[src]
impl<T: Idx> HybridIdxSet<T>pub fn new_empty(domain_size: usize) -> Self[src]
pub fn new_empty(domain_size: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains(&self, elem: &T) -> bool[src]
pub fn contains(&self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true iff set self contains elem.
pub fn add(&mut self, elem: &T) -> bool[src]
pub fn add(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds elem to the set self.
pub fn remove(&mut self, elem: &T) -> bool[src]
pub fn remove(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes elem from the set self.
pub fn to_dense(self) -> IdxSet<T>[src]
pub fn to_dense(self) -> IdxSet<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts to a dense set, consuming itself in the process.
ⓘImportant traits for HybridIter<'a, T>pub fn iter(&self) -> HybridIter<T>[src]
pub fn iter(&self) -> HybridIter<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iteration order is unspecified.