[−][src]Struct rustc_data_structures::indexed_set::IdxSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a set of some element type E, where each E is identified by some
unique index type T.
In other words, T is the type used to index into the bitvector
this type uses to represent the set of object it holds.
The representation is dense, using one bit per possible element.
Methods
impl<T: Idx> IdxSet<T>[src]
impl<T: Idx> IdxSet<T>pub fn new_empty(domain_size: usize) -> Self[src]
pub fn new_empty(domain_size: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates set holding no elements.
pub fn new_filled(domain_size: usize) -> Self[src]
pub fn new_filled(domain_size: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates set holding every element whose index falls in range 0..domain_size.
pub fn to_hybrid(&self) -> HybridIdxSet<T>[src]
pub fn to_hybrid(&self) -> HybridIdxSet<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Duplicates as a hybrid set.
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes all elements
pub fn set_up_to(&mut self, domain_size: usize)[src]
pub fn set_up_to(&mut self, domain_size: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets all elements up to domain_size
pub fn remove(&mut self, elem: &T) -> bool[src]
pub fn remove(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes elem from the set self; returns true iff this changed self.
pub fn add(&mut self, elem: &T) -> bool[src]
pub fn add(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds elem to the set self; returns true iff this changed self.
pub fn contains(&self, elem: &T) -> bool[src]
pub fn contains(&self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true iff set self contains elem.
pub fn words(&self) -> &[Word][src]
pub fn words(&self) -> &[Word]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn words_mut(&mut self) -> &mut [Word][src]
pub fn words_mut(&mut self) -> &mut [Word]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn overwrite(&mut self, other: &IdxSet<T>)[src]
pub fn overwrite(&mut self, other: &IdxSet<T>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Efficiently overwrite self with other. Panics if self and other
don't have the same length.
pub fn union(
&mut self,
other: &impl UnionIntoIdxSet<T>
) -> bool[src]
pub fn union(
&mut self,
other: &impl UnionIntoIdxSet<T>
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Set self = self | other and return true if self changed
(i.e., if new bits were added).
pub fn subtract(
&mut self,
other: &impl SubtractFromIdxSet<T>
) -> bool[src]
pub fn subtract(
&mut self,
other: &impl SubtractFromIdxSet<T>
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Set self = self - other and return true if self changed.
(i.e., if any bits were removed).
pub fn intersect(&mut self, other: &IdxSet<T>) -> bool[src]
pub fn intersect(&mut self, other: &IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Set self = self & other and return true if self changed.
(i.e., if any bits were removed).
ⓘImportant traits for BitIter<'a, C>pub fn iter(&self) -> BitIter<T>[src]
pub fn iter(&self) -> BitIter<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?