[−][src]Trait rustc_data_structures::indexed_set::SubtractFromIdxSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is implemented by all the index sets so that IdxSet::subtract() can be passed any type of index set.
Required Methods
fn subtract_from(&self, other: &mut IdxSet<T>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<T: Idx> SubtractFromIdxSet<T> for HybridIdxSet<T>[src]
impl<T: Idx> SubtractFromIdxSet<T> for HybridIdxSet<T>fn subtract_from(&self, other: &mut IdxSet<T>) -> bool[src]
fn subtract_from(&self, other: &mut IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Idx> SubtractFromIdxSet<T> for IdxSet<T>[src]
impl<T: Idx> SubtractFromIdxSet<T> for IdxSet<T>fn subtract_from(&self, other: &mut IdxSet<T>) -> bool[src]
fn subtract_from(&self, other: &mut IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Idx> SubtractFromIdxSet<T> for SparseIdxSet<T>[src]
impl<T: Idx> SubtractFromIdxSet<T> for SparseIdxSet<T>fn subtract_from(&self, other: &mut IdxSet<T>) -> bool[src]
fn subtract_from(&self, other: &mut IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?