[−][src]Struct rustc_data_structures::indexed_vec::IndexVec
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
raw: Vec<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
_marker: PhantomData<fn(_: &I)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<I: Idx, T> IndexVec<I, T>[src]
impl<I: Idx, T> IndexVec<I, T>pub fn new() -> Self[src]
pub fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_raw(raw: Vec<T>) -> Self[src]
pub fn from_raw(raw: Vec<T>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_capacity(capacity: usize) -> Self[src]
pub fn with_capacity(capacity: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_elem<S>(elem: T, universe: &IndexVec<I, S>) -> Self where
T: Clone, [src]
pub fn from_elem<S>(elem: T, universe: &IndexVec<I, S>) -> Self where
T: Clone, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_elem_n(elem: T, n: usize) -> Self where
T: Clone, [src]
pub fn from_elem_n(elem: T, n: usize) -> Self where
T: Clone, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push(&mut self, d: T) -> I[src]
pub fn push(&mut self, d: T) -> I🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn pop(&mut self) -> Option<T>[src]
pub fn pop(&mut self) -> Option<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for IntoIter<T>pub fn into_iter(self) -> IntoIter<T>[src]
pub fn into_iter(self) -> IntoIter<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn into_iter_enumerated(self) -> Enumerated<I, IntoIter<T>>[src]
pub fn into_iter_enumerated(self) -> Enumerated<I, IntoIter<T>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Iter<'a, T>pub fn iter(&self) -> Iter<T>[src]
pub fn iter(&self) -> Iter<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter_enumerated(&self) -> Enumerated<I, Iter<T>>[src]
pub fn iter_enumerated(&self) -> Enumerated<I, Iter<T>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Map<I, F>pub fn indices(&self) -> Map<Range<usize>, IntoIdx<I>>[src]
pub fn indices(&self) -> Map<Range<usize>, IntoIdx<I>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for IterMut<'a, T>pub fn iter_mut(&mut self) -> IterMut<T>[src]
pub fn iter_mut(&mut self) -> IterMut<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter_enumerated_mut(&mut self) -> Enumerated<I, IterMut<T>>[src]
pub fn iter_enumerated_mut(&mut self) -> Enumerated<I, IterMut<T>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn drain<'a, R: RangeBounds<usize>>(
&'a mut self,
range: R
) -> impl Iterator<Item = T> + 'a[src]
pub fn drain<'a, R: RangeBounds<usize>>(
&'a mut self,
range: R
) -> impl Iterator<Item = T> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn drain_enumerated<'a, R: RangeBounds<usize>>(
&'a mut self,
range: R
) -> impl Iterator<Item = (I, T)> + 'a[src]
pub fn drain_enumerated<'a, R: RangeBounds<usize>>(
&'a mut self,
range: R
) -> impl Iterator<Item = (I, T)> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn last(&self) -> Option<I>[src]
pub fn last(&self) -> Option<I>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn shrink_to_fit(&mut self)[src]
pub fn shrink_to_fit(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn swap(&mut self, a: I, b: I)[src]
pub fn swap(&mut self, a: I, b: I)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn truncate(&mut self, a: usize)[src]
pub fn truncate(&mut self, a: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, index: I) -> Option<&T>[src]
pub fn get(&self, index: I) -> Option<&T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_mut(&mut self, index: I) -> Option<&mut T>[src]
pub fn get_mut(&mut self, index: I) -> Option<&mut T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn pick2_mut(&mut self, a: I, b: I) -> (&mut T, &mut T)[src]
pub fn pick2_mut(&mut self, a: I, b: I) -> (&mut T, &mut T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return mutable references to two distinct elements, a and b. Panics if a == b.
pub fn convert_index_type<Ix: Idx>(self) -> IndexVec<Ix, T>[src]
pub fn convert_index_type<Ix: Idx>(self) -> IndexVec<Ix, T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<I: Idx, T: Clone> IndexVec<I, T>[src]
impl<I: Idx, T: Clone> IndexVec<I, T>pub fn ensure_contains_elem(
&mut self,
elem: I,
fill_value: impl FnMut() -> T
)[src]
pub fn ensure_contains_elem(
&mut self,
elem: I,
fill_value: impl FnMut() -> T
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Grows the index vector so that it contains an entry for
elem; if that is already true, then has no
effect. Otherwise, inserts new values as needed by invoking
fill_value.
pub fn resize(&mut self, new_len: usize, value: T)[src]
pub fn resize(&mut self, new_len: usize, value: T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn resize_to_elem(
&mut self,
elem: I,
fill_value: impl FnMut() -> T
)[src]
pub fn resize_to_elem(
&mut self,
elem: I,
fill_value: impl FnMut() -> T
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<I: Idx, T: Ord> IndexVec<I, T>[src]
impl<I: Idx, T: Ord> IndexVec<I, T>pub fn binary_search(&self, value: &T) -> Result<I, I>[src]
pub fn binary_search(&self, value: &T) -> Result<I, I>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?