[−][src]Enum rustc_data_structures::obligation_forest::NodeState
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The state of one node in some tree within the forest. This
represents the current state of processing for the obligation (of
type O) associated with this node.
Outside of ObligationForest methods, nodes should be either Pending or Waiting.
Variants
Pending🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Obligations for which selection had not yet returned a non-ambiguous result.
Success🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This obligation was selected successfully, but may or may not have subobligations.
Waiting🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This obligation was selected successfully, but it has a pending subobligation.
Done🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This obligation, along with its subobligations, are complete, and will be removed in the next collection.
Error🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This obligation was resolved to an error. Error nodes are removed from the vector by the compression step.
OnDfsStack🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is a temporary state used in DFS loops to detect cycles, it should not exist outside of these DFSes.