Struct rustc_data_structures::obligation_forest::Node [−][src]
struct Node<O> {
obligation: O,
state: Cell<NodeState>,
dependents: Vec<NodeIndex>,
parent: Option<NodeIndex>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
obligation: O
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
state: Cell<NodeState>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dependents: Vec<NodeIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Obligations that depend on this obligation for their completion. They must all be in a non-pending state.
parent: Option<NodeIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The parent of a node - the original obligation of
which it is a subobligation. Except for error reporting,
this is just another member of dependents.
Methods
impl<O> Node<O>[src]
impl<O> Node<O>fn new(parent: Option<NodeIndex>, obligation: O) -> Node<O>[src]
fn new(parent: Option<NodeIndex>, obligation: O) -> Node<O>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?