Trait rustc_data_structures::owning_ref::ToHandle [−][src]
pub trait ToHandle {
type Handle: Deref;
unsafe fn to_handle(x: *const Self) -> Self::Handle;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Trait to implement the conversion of owner to handle for common types.
Associated Types
type Handle: Deref
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The type of handle to be encapsulated by the OwningHandle.
Required Methods
unsafe fn to_handle(x: *const Self) -> Self::Handle
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given an appropriately-long-lived pointer to ourselves, create a
handle to be encapsulated by the OwningHandle.
Implementations on Foreign Types
impl<T: 'static> ToHandle for RefCell<T>[src]
impl<T: 'static> ToHandle for RefCell<T>type Handle = Ref<'static, T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unsafe fn to_handle(x: *const Self) -> Self::Handle[src]
unsafe fn to_handle(x: *const Self) -> Self::Handle🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?