Struct rustc_data_structures::sip128::Sip24Rounds [−][src]
struct Sip24Rounds;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Sip24Rounds[src]
impl Sip24Roundsfn c_rounds(state: &mut State)[src]
fn c_rounds(state: &mut State)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn d_rounds(state: &mut State)[src]
fn d_rounds(state: &mut State)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?