Struct rustc_data_structures::snapshot_map::SnapshotMap [−][src]
pub struct SnapshotMap<K, V> where
K: Hash + Clone + Eq, { map: FxHashMap<K, V>, undo_log: Vec<UndoLog<K, V>>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
map: FxHashMap<K, V>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
undo_log: Vec<UndoLog<K, V>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<K, V> SnapshotMap<K, V> where
K: Hash + Clone + Eq, [src]
impl<K, V> SnapshotMap<K, V> where
K: Hash + Clone + Eq, pub fn new() -> Self[src]
pub fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn insert(&mut self, key: K, value: V) -> bool[src]
pub fn insert(&mut self, key: K, value: V) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove(&mut self, key: K) -> bool[src]
pub fn remove(&mut self, key: K) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, key: &K) -> Option<&V>[src]
pub fn get(&self, key: &K) -> Option<&V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn snapshot(&mut self) -> Snapshot[src]
pub fn snapshot(&mut self) -> Snapshot🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn assert_open_snapshot(&self, snapshot: &Snapshot)[src]
fn assert_open_snapshot(&self, snapshot: &Snapshot)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn commit(&mut self, snapshot: Snapshot)[src]
pub fn commit(&mut self, snapshot: Snapshot)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn partial_rollback<F>(
&mut self,
snapshot: &Snapshot,
should_revert_key: &F
) where
F: Fn(&K) -> bool, [src]
pub fn partial_rollback<F>(
&mut self,
snapshot: &Snapshot,
should_revert_key: &F
) where
F: Fn(&K) -> bool, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn rollback_to(&mut self, snapshot: Snapshot)[src]
pub fn rollback_to(&mut self, snapshot: Snapshot)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn reverse(&mut self, entry: UndoLog<K, V>)[src]
fn reverse(&mut self, entry: UndoLog<K, V>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?