Trait rustc_data_structures::stable_hasher::StableHasherResult [−][src]
pub trait StableHasherResult: Sized { fn finish(hasher: StableHasher<Self>) -> Self; }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn finish(hasher: StableHasher<Self>) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl StableHasherResult for u128[src]
impl StableHasherResult for u128fn finish(hasher: StableHasher<Self>) -> Self[src]
fn finish(hasher: StableHasher<Self>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl StableHasherResult for u64[src]
impl StableHasherResult for u64fn finish(hasher: StableHasher<Self>) -> Self[src]
fn finish(hasher: StableHasher<Self>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?