[−][src]Struct rustc_data_structures::OnDrop
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<F: Fn()> OnDrop<F>[src]
impl<F: Fn()> OnDrop<F>pub fn disable(self)[src]
pub fn disable(self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Forgets the function which prevents it from running. Ensure that the function owns no memory, otherwise it will be leaked.