Struct rustc_data_structures::sync::MTLock [−][src]
pub struct MTLock<T>(T);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> MTLock<T>[src]
impl<T> MTLock<T>pub fn new(inner: T) -> Self[src]
pub fn new(inner: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn into_inner(self) -> T[src]
pub fn into_inner(self) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Wpub fn get_mut(&mut self) -> &mut T[src]
pub fn get_mut(&mut self) -> &mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Wpub fn lock(&self) -> &T[src]
pub fn lock(&self) -> &T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Wpub fn lock_mut(&mut self) -> &mut T[src]
pub fn lock_mut(&mut self) -> &mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?