Struct rustc_data_structures::sync::RwLock
[−]
[src]
pub struct RwLock<T>(_);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> RwLock<T>[src]
impl<T> RwLock<T>pub fn new(inner: T) -> Self[src]
pub fn new(inner: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn into_inner(self) -> T[src]
pub fn into_inner(self) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Rpub fn get_mut(&mut self) -> &mut T[src]
pub fn get_mut(&mut self) -> &mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn read(&self) -> ReadGuard<T>[src]
pub fn read(&self) -> ReadGuard<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_read_lock<F: FnOnce(&T) -> R, R>(&self, f: F) -> R[src]
pub fn with_read_lock<F: FnOnce(&T) -> R, R>(&self, f: F) -> R🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn write(&self) -> WriteGuard<T>[src]
pub fn write(&self) -> WriteGuard<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_write_lock<F: FnOnce(&mut T) -> R, R>(&self, f: F) -> R[src]
pub fn with_write_lock<F: FnOnce(&mut T) -> R, R>(&self, f: F) -> R🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn borrow(&self) -> ReadGuard<T>[src]
pub fn borrow(&self) -> ReadGuard<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn borrow_mut(&self) -> WriteGuard<T>[src]
pub fn borrow_mut(&self) -> WriteGuard<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?