Struct rustc_data_structures::sync::SerialScope [−][src]
pub struct SerialScope;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SerialScope[src]
impl SerialScopepub fn spawn<F>(&self, f: F) where
F: FnOnce(&SerialScope), [src]
pub fn spawn<F>(&self, f: F) where
F: FnOnce(&SerialScope), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?