[−][src]Struct rustc_data_structures::sync::WorkerLocal
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T> WorkerLocal<T>[src]
impl<T> WorkerLocal<T>pub fn new<F: FnMut(usize) -> T>(f: F) -> WorkerLocal<T>[src]
pub fn new<F: FnMut(usize) -> T>(f: F) -> WorkerLocal<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a new worker local where the initial closure computes the
value this worker local should take for each thread in the thread pool.
pub fn into_inner(self) -> Vec<T>[src]
pub fn into_inner(self) -> Vec<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the worker-local value for each thread