[−]Struct rustc_data_structures::unify::InPlace
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Backing store for an in-place unification table. Not typically used directly.
Fields
values: SnapshotVec<Delegate<K>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?