[−]Struct rustc_data_structures::unify::Snapshot
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
At any time, users may snapshot a unification table. The changes made during the snapshot may either be committed or rolled back.
Fields
marker: PhantomData<S>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
snapshot: <S as UnificationStore>::Snapshot
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?