[−][src]Trait rustc_data_structures::vec_linked_list::Links
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type LinkIndex: Copy
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn next(links: &Self, index: Self::LinkIndex) -> Option<Self::LinkIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<Ls, '_> Links for &'_ Ls where
Ls: Links, [src]
impl<Ls, '_> Links for &'_ Ls where
Ls: Links, type LinkIndex = Ls::LinkIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn next(links: &Self, index: Ls::LinkIndex) -> Option<Ls::LinkIndex>[src]
fn next(links: &Self, index: Ls::LinkIndex) -> Option<Ls::LinkIndex>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<L, E> Links for IndexVec<L, E> where
E: LinkElem<LinkIndex = L>,
L: Idx, [src]
impl<L, E> Links for IndexVec<L, E> where
E: LinkElem<LinkIndex = L>,
L: Idx, type LinkIndex = L
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn next(links: &Self, index: L) -> Option<L>[src]
fn next(links: &Self, index: L) -> Option<L>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?