[−][src]Trait rustc_driver::pretty::HirPrinterSupport
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn sess<'a>(&'a self) -> &'a Session
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provides a uniform interface for re-extracting a reference to a
Session from a value that now owns it.
fn hir_map<'a>(&'a self) -> Option<&'a Map<'hir>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provides a uniform interface for re-extracting a reference to an
hir_map::Map from a value that now owns it.
fn pp_ann<'a>(&'a self) -> &'a PpAnn
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Produces the pretty-print annotation object.
(Rust does not yet support upcasting from a trait object to an object for one of its super-traits.)
Provided Methods
fn node_path(&self, id: NodeId) -> Option<String>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Computes an user-readable representation of a path, if possible.
Implementors
impl<'b, 'tcx> HirPrinterSupport<'tcx> for TypedAnnotation<'b, 'tcx>[src]
impl<'b, 'tcx> HirPrinterSupport<'tcx> for TypedAnnotation<'b, 'tcx>fn sess<'a>(&'a self) -> &'a Session[src]
fn sess<'a>(&'a self) -> &'a Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn hir_map<'a>(&'a self) -> Option<&'a Map<'tcx>>[src]
fn hir_map<'a>(&'a self) -> Option<&'a Map<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann<'a>(&'a self) -> &'a PpAnn[src]
fn pp_ann<'a>(&'a self) -> &'a PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn node_path(&self, id: NodeId) -> Option<String>[src]
fn node_path(&self, id: NodeId) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'hir> HirPrinterSupport<'hir> for IdentifiedAnnotation<'hir>[src]
impl<'hir> HirPrinterSupport<'hir> for IdentifiedAnnotation<'hir>fn sess<'a>(&'a self) -> &'a Session[src]
fn sess<'a>(&'a self) -> &'a Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn hir_map<'a>(&'a self) -> Option<&'a Map<'hir>>[src]
fn hir_map<'a>(&'a self) -> Option<&'a Map<'hir>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann<'a>(&'a self) -> &'a PpAnn[src]
fn pp_ann<'a>(&'a self) -> &'a PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn node_path(&self, id: NodeId) -> Option<String>[src]
fn node_path(&self, id: NodeId) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'hir> HirPrinterSupport<'hir> for NoAnn<'hir>[src]
impl<'hir> HirPrinterSupport<'hir> for NoAnn<'hir>fn sess<'a>(&'a self) -> &'a Session[src]
fn sess<'a>(&'a self) -> &'a Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn hir_map<'a>(&'a self) -> Option<&'a Map<'hir>>[src]
fn hir_map<'a>(&'a self) -> Option<&'a Map<'hir>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann<'a>(&'a self) -> &'a PpAnn[src]
fn pp_ann<'a>(&'a self) -> &'a PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn node_path(&self, id: NodeId) -> Option<String>[src]
fn node_path(&self, id: NodeId) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?