[−][src]Trait rustc_driver::pretty::PrinterSupport
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn sess<'a>(&'a self) -> &'a Session
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provides a uniform interface for re-extracting a reference to a
Session from a value that now owns it.
fn pp_ann<'a>(&'a self) -> &'a PpAnn
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Produces the pretty-print annotation object.
(Rust does not yet support upcasting from a trait object to an object for one of its super-traits.)
Implementors
impl<'a> PrinterSupport for HygieneAnnotation<'a>[src]
impl<'a> PrinterSupport for HygieneAnnotation<'a>fn sess(&self) -> &Session[src]
fn sess(&self) -> &Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann(&self) -> &PpAnn[src]
fn pp_ann(&self) -> &PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'hir> PrinterSupport for IdentifiedAnnotation<'hir>[src]
impl<'hir> PrinterSupport for IdentifiedAnnotation<'hir>fn sess<'a>(&'a self) -> &'a Session[src]
fn sess<'a>(&'a self) -> &'a Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann<'a>(&'a self) -> &'a PpAnn[src]
fn pp_ann<'a>(&'a self) -> &'a PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'hir> PrinterSupport for NoAnn<'hir>[src]
impl<'hir> PrinterSupport for NoAnn<'hir>fn sess<'a>(&'a self) -> &'a Session[src]
fn sess<'a>(&'a self) -> &'a Session🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pp_ann<'a>(&'a self) -> &'a PpAnn[src]
fn pp_ann<'a>(&'a self) -> &'a PpAnn🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?