Enum rustc_errors::snippet::AnnotationType [−][src]
pub enum AnnotationType {
Singleline,
Multiline(MultilineAnnotation),
MultilineStart(usize),
MultilineEnd(usize),
MultilineLine(usize),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Singleline🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Annotation under a single line of code
Multiline(MultilineAnnotation)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Annotation enclosing the first and last character of a multiline span
MultilineStart(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Annotation marking the first character of a fully shown multiline span
MultilineEnd(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Annotation marking the last character of a fully shown multiline span
MultilineLine(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Line at the left enclosing the lines of a fully shown multiline span