[−][src]Struct rustc_errors::CodeSuggestion
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
substitutions: Vec<Substitution>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Each substitute can have multiple variants due to multiple applicable suggestions
foo.bar might be replaced with a.b or x.y by replacing
foo and bar on their own:
vec![ Substitution { parts: vec![(0..3, "a"), (4..7, "b")] }, Substitution { parts: vec![(0..3, "x"), (4..7, "y")] }, ]
or by replacing the entire span:
vec![ Substitution { parts: vec![(0..7, "a.b")] }, Substitution { parts: vec![(0..7, "x.y")] }, ]
msg: String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
show_code_when_inline: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
applicability: Applicability
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether or not the suggestion is approximate
Sometimes we may show suggestions with placeholders, which are useful for users but not useful for tools like rustfix
Methods
impl CodeSuggestion[src]
impl CodeSuggestionpub fn splice_lines(
&self,
cm: &SourceMapperDyn
) -> Vec<(String, Vec<SubstitutionPart>)>[src]
pub fn splice_lines(
&self,
cm: &SourceMapperDyn
) -> Vec<(String, Vec<SubstitutionPart>)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the assembled code suggestions and whether they should be shown with an underline.