Struct rustc_errors::FatalError [−][src]
#[must_use]pub struct FatalError;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used as a return value to signify a fatal error occurred. (It is also used as the argument to panic at the moment, but that will eventually not be true.)
Methods
impl FatalError[src]
impl FatalErrorpub fn raise(self) -> ![src]
pub fn raise(self) -> !🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?