[−][src]Struct rustc_errors::styled_buffer::StyledBuffer
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
text: Vec<Vec<char>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
styles: Vec<Vec<Style>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl StyledBuffer[src]
impl StyledBufferpub fn new() -> StyledBuffer[src]
pub fn new() -> StyledBuffer🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn replace_tabs(&mut self)[src]
fn replace_tabs(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn render(&mut self) -> Vec<Vec<StyledString>>[src]
pub fn render(&mut self) -> Vec<Vec<StyledString>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn ensure_lines(&mut self, line: usize)[src]
fn ensure_lines(&mut self, line: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn putc(&mut self, line: usize, col: usize, chr: char, style: Style)[src]
pub fn putc(&mut self, line: usize, col: usize, chr: char, style: Style)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn puts(&mut self, line: usize, col: usize, string: &str, style: Style)[src]
pub fn puts(&mut self, line: usize, col: usize, string: &str, style: Style)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn prepend(&mut self, line: usize, string: &str, style: Style)[src]
pub fn prepend(&mut self, line: usize, string: &str, style: Style)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn append(&mut self, line: usize, string: &str, style: Style)[src]
pub fn append(&mut self, line: usize, string: &str, style: Style)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn num_lines(&self) -> usize[src]
pub fn num_lines(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_style_range(
&mut self,
line: usize,
col_start: usize,
col_end: usize,
style: Style,
overwrite: bool
)[src]
pub fn set_style_range(
&mut self,
line: usize,
col_start: usize,
col_end: usize,
style: Style,
overwrite: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_style(
&mut self,
line: usize,
col: usize,
style: Style,
overwrite: bool
)[src]
pub fn set_style(
&mut self,
line: usize,
col: usize,
style: Style,
overwrite: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?