Struct rustc_incremental::assert_module_sources::AssertModuleSource [−][src]
struct AssertModuleSource<'a, 'tcx: 'a> {
tcx: TyCtxt<'a, 'tcx, 'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> AssertModuleSource<'a, 'tcx>[src]
impl<'a, 'tcx> AssertModuleSource<'a, 'tcx>fn check_attr(&self, attr: &Attribute)[src]
fn check_attr(&self, attr: &Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn field(&self, attr: &Attribute, name: &str) -> Name[src]
fn field(&self, attr: &Attribute, name: &str) -> Name🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_config(&self, attr: &Attribute) -> bool[src]
fn check_config(&self, attr: &Attribute) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Scan for a cfg="foo" attribute and check whether we have a
cfg flag called foo.