Struct rustc_incremental::persist::data::SerializedWorkProduct [−][src]
pub struct SerializedWorkProduct {
pub id: WorkProductId,
pub work_product: WorkProduct,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
id: WorkProductId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
node that produced the work-product
work_product: WorkProduct
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
work-product data itself