[−][src]Function rustc_incremental::persist::dirty_clean::check_config
fn check_config(tcx: TyCtxt, attr: &Attribute) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given a #[rustc_dirty] or #[rustc_clean] attribute, scan
for a cfg="foo" attribute and check whether we have a cfg
flag called foo.
Also make sure that the label and except fields do not
both exist.