Struct rustc_incremental::persist::dirty_clean::DirtyCleanVisitor [−][src]
pub struct DirtyCleanVisitor<'a, 'tcx: 'a> {
tcx: TyCtxt<'a, 'tcx, 'tcx>,
checked_attrs: FxHashSet<AttrId>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
checked_attrs: FxHashSet<AttrId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> DirtyCleanVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> DirtyCleanVisitor<'a, 'tcx>fn assertion_maybe(
&mut self,
item_id: NodeId,
attr: &Attribute
) -> Option<Assertion>[src]
fn assertion_maybe(
&mut self,
item_id: NodeId,
attr: &Attribute
) -> Option<Assertion>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Possibly "deserialize" the attribute into a clean/dirty assertion
fn assertion_auto(
&mut self,
item_id: NodeId,
attr: &Attribute,
is_clean: bool
) -> Assertion[src]
fn assertion_auto(
&mut self,
item_id: NodeId,
attr: &Attribute,
is_clean: bool
) -> Assertion🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Get the "auto" assertion on pre-validated attr, along with the except labels
fn labels(&self, attr: &Attribute) -> Option<HashSet<String>>[src]
fn labels(&self, attr: &Attribute) -> Option<HashSet<String>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn except(&self, attr: &Attribute) -> HashSet<String>[src]
fn except(&self, attr: &Attribute) -> HashSet<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
except= attribute value
fn auto_labels(
&mut self,
item_id: NodeId,
attr: &Attribute
) -> (&'static str, HashSet<String>)[src]
fn auto_labels(
&mut self,
item_id: NodeId,
attr: &Attribute
) -> (&'static str, HashSet<String>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return all DepNode labels that should be asserted for this item. index=0 is the "name" used for error messages
fn resolve_labels(&self, item: &NestedMetaItem, value: &str) -> HashSet<String>[src]
fn resolve_labels(&self, item: &NestedMetaItem, value: &str) -> HashSet<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dep_nodes(&self, labels: &HashSet<String>, def_id: DefId) -> Vec<DepNode>[src]
fn dep_nodes(&self, labels: &HashSet<String>, def_id: DefId) -> Vec<DepNode>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dep_node_str(&self, dep_node: &DepNode) -> String[src]
fn dep_node_str(&self, dep_node: &DepNode) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn assert_dirty(&self, item_span: Span, dep_node: DepNode)[src]
fn assert_dirty(&self, item_span: Span, dep_node: DepNode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn assert_clean(&self, item_span: Span, dep_node: DepNode)[src]
fn assert_clean(&self, item_span: Span, dep_node: DepNode)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_item(&mut self, item_id: NodeId, item_span: Span)[src]
fn check_item(&mut self, item_id: NodeId, item_span: Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?