Struct rustc_lint::bad_style::NonSnakeCase [−][src]
pub struct NonSnakeCase;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl NonSnakeCase[src]
impl NonSnakeCasefn to_snake_case(str: &str) -> String[src]
fn to_snake_case(str: &str) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_snake_case(
&self,
cx: &LateContext,
sort: &str,
name: &str,
span: Option<Span>
)[src]
fn check_snake_case(
&self,
cx: &LateContext,
sort: &str,
name: &str,
span: Option<Span>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?