Enum rustc_lint::builtin::BuiltinLintDiagnostics [−][src]
pub enum BuiltinLintDiagnostics {
Normal,
BareTraitObject(Span, bool),
AbsPathWithModule(Span),
DuplicatedMacroExports(Ident, Span, Span),
ProcMacroDeriveResolutionFallback(Span),
ElidedLifetimesInPaths(usize, Span, bool, Span, String),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Normal🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
BareTraitObject(Span, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
AbsPathWithModule(Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
DuplicatedMacroExports(Ident, Span, Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ProcMacroDeriveResolutionFallback(Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ElidedLifetimesInPaths(usize, Span, bool, Span, String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl BuiltinLintDiagnostics[src]
impl BuiltinLintDiagnosticspub fn run(self, sess: &Session, db: &mut DiagnosticBuilder)[src]
pub fn run(self, sess: &Session, db: &mut DiagnosticBuilder)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?