Struct rustc_lint::builtin::AnonymousParameters [−][src]
pub struct AnonymousParameters;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Checks for use of anonymous parameters (RFC 1685)