Struct rustc_lint::builtin::TypeAliasBounds [−][src]
pub struct TypeAliasBounds;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Lint for trait and lifetime bounds in type aliases being mostly ignored: They are relevant when using associated types, but otherwise neither checked at definition site nor enforced at use site.
Methods
impl TypeAliasBounds[src]
impl TypeAliasBoundsfn is_type_variable_assoc(qpath: &QPath) -> bool[src]
fn is_type_variable_assoc(qpath: &QPath) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn suggest_changing_assoc_types(ty: &Ty, err: &mut DiagnosticBuilder)[src]
fn suggest_changing_assoc_types(ty: &Ty, err: &mut DiagnosticBuilder)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?