Struct rustc_lint::builtin::UnreachablePub [−][src]
pub struct UnreachablePub;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Lint for items marked pub that aren't reachable from other crates
Methods
impl UnreachablePub[src]
impl UnreachablePubfn perform_lint(
&self,
cx: &LateContext,
what: &str,
id: NodeId,
vis: &Visibility,
span: Span,
exportable: bool,
applicability: Applicability
)[src]
fn perform_lint(
&self,
cx: &LateContext,
what: &str,
id: NodeId,
vis: &Visibility,
span: Span,
exportable: bool,
applicability: Applicability
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?