Struct rustc_lint::types::ImproperCTypesVisitor [−][src]
struct ImproperCTypesVisitor<'a, 'tcx: 'a> {
cx: &'a LateContext<'a, 'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
cx: &'a LateContext<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> ImproperCTypesVisitor<'a, 'tcx>[src]
impl<'a, 'tcx> ImproperCTypesVisitor<'a, 'tcx>fn check_type_for_ffi(
&self,
cache: &mut FxHashSet<Ty<'tcx>>,
ty: Ty<'tcx>
) -> FfiResult<'tcx>[src]
fn check_type_for_ffi(
&self,
cache: &mut FxHashSet<Ty<'tcx>>,
ty: Ty<'tcx>
) -> FfiResult<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if the given type is "ffi-safe" (has a stable, well-defined representation which can be exported to C code).
fn check_type_for_ffi_and_report_errors(&mut self, sp: Span, ty: Ty<'tcx>)[src]
fn check_type_for_ffi_and_report_errors(&mut self, sp: Span, ty: Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_fn(&mut self, id: NodeId, decl: &FnDecl)[src]
fn check_foreign_fn(&mut self, id: NodeId, decl: &FnDecl)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_foreign_static(&mut self, id: NodeId, span: Span)[src]
fn check_foreign_static(&mut self, id: NodeId, span: Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?