[−][src]Struct rustc_lint::unused::UnusedParens
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl UnusedParens[src]
impl UnusedParensfn check_unused_parens_core(
&self,
cx: &EarlyContext,
value: &Expr,
msg: &str,
struct_lit_needs_parens: bool
)[src]
fn check_unused_parens_core(
&self,
cx: &EarlyContext,
value: &Expr,
msg: &str,
struct_lit_needs_parens: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?