[−][src]Function rustc_llvm::initialize_available_targets
pub fn initialize_available_targets()
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Initialize targets enabled by the build script via cfg(llvm_component = "...").
NB: this function can't be moved to rustc_codegen_llvm because of the cfgs.