Enum rustc_metadata::creader::PMDSource [−][src]
enum PMDSource {
Registered(Lrc<CrateMetadata>),
Owned(Library),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Registered(Lrc<CrateMetadata>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Owned(Library)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods from Deref<Target = MetadataBlob>
pub fn is_compatible(&self) -> bool[src]
pub fn is_compatible(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_rustc_version(&self) -> String[src]
pub fn get_rustc_version(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_root(&self) -> CrateRoot[src]
pub fn get_root(&self) -> CrateRoot🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn list_crate_metadata(&self, out: &mut Write) -> Result<()>[src]
pub fn list_crate_metadata(&self, out: &mut Write) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?