Struct rustc_metadata::cstore::CStore [−][src]
pub struct CStore {
metas: RwLock<IndexVec<CrateNum, Option<Lrc<CrateMetadata>>>>,
extern_mod_crate_map: Lock<NodeMap<CrateNum>>,
pub metadata_loader: Box<MetadataLoader + Sync>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
metas: RwLock<IndexVec<CrateNum, Option<Lrc<CrateMetadata>>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
extern_mod_crate_map: Lock<NodeMap<CrateNum>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Map from NodeId's of local extern crate statements to crate numbers
metadata_loader: Box<MetadataLoader + Sync>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CStore[src]
impl CStorepub fn new(metadata_loader: Box<MetadataLoader + Sync>) -> CStore[src]
pub fn new(metadata_loader: Box<MetadataLoader + Sync>) -> CStore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn next_crate_num(&self) -> CrateNum[src]
pub fn next_crate_num(&self) -> CrateNum🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
You cannot use this function to allocate a CrateNum in a thread-safe manner. It is currently only used in CrateLoader which is single-threaded code.
pub fn get_crate_data(&self, cnum: CrateNum) -> Lrc<CrateMetadata>[src]
pub fn get_crate_data(&self, cnum: CrateNum) -> Lrc<CrateMetadata>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_crate_data(&self, cnum: CrateNum, data: Lrc<CrateMetadata>)[src]
pub fn set_crate_data(&self, cnum: CrateNum, data: Lrc<CrateMetadata>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter_crate_data<I>(&self, i: I) where
I: FnMut(CrateNum, &Lrc<CrateMetadata>), [src]
pub fn iter_crate_data<I>(&self, i: I) where
I: FnMut(CrateNum, &Lrc<CrateMetadata>), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn crate_dependencies_in_rpo(&self, krate: CrateNum) -> Vec<CrateNum>[src]
pub fn crate_dependencies_in_rpo(&self, krate: CrateNum) -> Vec<CrateNum>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_dependencies_in_postorder(
&self,
ordering: &mut Vec<CrateNum>,
krate: CrateNum
)[src]
pub fn push_dependencies_in_postorder(
&self,
ordering: &mut Vec<CrateNum>,
krate: CrateNum
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn do_postorder_cnums_untracked(&self) -> Vec<CrateNum>[src]
pub fn do_postorder_cnums_untracked(&self) -> Vec<CrateNum>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_extern_mod_stmt_cnum(&self, emod_id: NodeId, cnum: CrateNum)[src]
pub fn add_extern_mod_stmt_cnum(&self, emod_id: NodeId, cnum: CrateNum)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn do_extern_mod_stmt_cnum(&self, emod_id: NodeId) -> Option<CrateNum>[src]
pub fn do_extern_mod_stmt_cnum(&self, emod_id: NodeId) -> Option<CrateNum>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?