[−][src]Struct rustc_metadata::encoder::EncodeContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
opaque: Encoder
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lazy_state: LazyState
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
type_shorthands: FxHashMap<Ty<'tcx>, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
predicate_shorthands: FxHashMap<Predicate<'tcx>, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
interpret_allocs: FxHashMap<AllocId, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
interpret_allocs_inverse: Vec<AllocId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
source_file_cache: Lrc<SourceFile>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> EncodeContext<'a, 'tcx>[src]
impl<'a, 'tcx> EncodeContext<'a, 'tcx>fn emit_node<F: FnOnce(&mut Self, usize) -> R, R>(&mut self, f: F) -> R[src]
fn emit_node<F: FnOnce(&mut Self, usize) -> R, R>(&mut self, f: F) -> R🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn emit_lazy_distance(
&mut self,
position: usize,
min_size: usize
) -> Result<(), Self::Error>[src]
fn emit_lazy_distance(
&mut self,
position: usize,
min_size: usize
) -> Result<(), Self::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn lazy<T: Encodable>(&mut self, value: &T) -> Lazy<T>[src]
pub fn lazy<T: Encodable>(&mut self, value: &T) -> Lazy<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn lazy_seq<I, T>(&mut self, iter: I) -> LazySeq<T> where
I: IntoIterator<Item = T>,
T: Encodable, [src]
pub fn lazy_seq<I, T>(&mut self, iter: I) -> LazySeq<T> where
I: IntoIterator<Item = T>,
T: Encodable, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn lazy_seq_ref<'b, I, T>(&mut self, iter: I) -> LazySeq<T> where
I: IntoIterator<Item = &'b T>,
T: 'b + Encodable, [src]
pub fn lazy_seq_ref<'b, I, T>(&mut self, iter: I) -> LazySeq<T> where
I: IntoIterator<Item = &'b T>,
T: 'b + Encodable, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn tracked<'x, DATA, R>(
&'x mut self,
op: fn(_: &mut IsolatedEncoder<'x, 'a, 'tcx>, _: DATA) -> R,
data: DATA
) -> R[src]
pub fn tracked<'x, DATA, R>(
&'x mut self,
op: fn(_: &mut IsolatedEncoder<'x, 'a, 'tcx>, _: DATA) -> R,
data: DATA
) -> R🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn encode_info_for_items(&mut self) -> Index[src]
fn encode_info_for_items(&mut self) -> Index🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn encode_def_path_table(&mut self) -> Lazy<DefPathTable>[src]
fn encode_def_path_table(&mut self) -> Lazy<DefPathTable>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn encode_source_map(&mut self) -> LazySeq<SourceFile>[src]
fn encode_source_map(&mut self) -> LazySeq<SourceFile>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn encode_crate_root(&mut self) -> Lazy<CrateRoot>[src]
fn encode_crate_root(&mut self) -> Lazy<CrateRoot>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?