Enum rustc_metadata::schema::LazyState [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Encoding / decoding state for Lazy and LazySeq.
Variants
NoNode🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Outside of a metadata node.
NodeStart(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inside a metadata node, and before any Lazy or LazySeq.
The position is that of the node itself.
Previous(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inside a metadata node, with a previous Lazy or LazySeq.
The position is a conservative estimate of where that
previous Lazy / LazySeq would end (see their comments).