[−][src]Struct rustc_metadata::schema::LazySeq
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A sequence of type T referred to by its absolute position
in the metadata and length, and which can be decoded lazily.
The sequence is a single node for the purposes of Lazy.
Unlike Lazy<Vec<T>>, the length is encoded next to the
position, not at the position, which means that the length
doesn't need to be known before encoding all the elements.
If the length is 0, no position is encoded, but otherwise,
the encoding is that of Lazy, with the distinction that
the minimal distance the length of the sequence, i.e.
it's assumed there's no 0-byte element in the sequence.
Fields
len: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
position: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
_marker: PhantomData<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> LazySeq<Index>[src]
impl<'tcx> LazySeq<Index>pub fn lookup(
&self,
bytes: &[u8],
def_index: DefIndex
) -> Option<Lazy<Entry<'tcx>>>[src]
pub fn lookup(
&self,
bytes: &[u8],
def_index: DefIndex
) -> Option<Lazy<Entry<'tcx>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given the metadata, extract out the offset of a particular DefIndex (if any).
impl<'a, 'tcx: 'a, T: Decodable> LazySeq<T>[src]
impl<'a, 'tcx: 'a, T: Decodable> LazySeq<T>pub fn decode<M: Metadata<'a, 'tcx>>(
self,
meta: M
) -> impl Iterator<Item = T> + Captures<'tcx> + 'a[src]
pub fn decode<M: Metadata<'a, 'tcx>>(
self,
meta: M
) -> impl Iterator<Item = T> + Captures<'tcx> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T> LazySeq<T>[src]
impl<T> LazySeq<T>pub fn empty() -> LazySeq<T>[src]
pub fn empty() -> LazySeq<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_position_and_length(position: usize, len: usize) -> LazySeq<T>[src]
pub fn with_position_and_length(position: usize, len: usize) -> LazySeq<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn min_size(length: usize) -> usize[src]
pub fn min_size(length: usize) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the minimum encoded size of length values of type T.