Struct rustc_metadata::schema::RenderedConst [−][src]
pub struct RenderedConst(pub String);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contains a constant which has been rendered to a String. Used by rustdoc.