Struct rustc_mir::borrow_check::borrow_set::GatherBorrows [−][src]
struct GatherBorrows<'a, 'gcx: 'tcx, 'tcx: 'a> {
tcx: TyCtxt<'a, 'gcx, 'tcx>,
mir: &'a Mir<'tcx>,
idx_vec: IndexVec<BorrowIndex, BorrowData<'tcx>>,
location_map: FxHashMap<Location, BorrowIndex>,
activation_map: FxHashMap<Location, Vec<BorrowIndex>>,
region_map: FxHashMap<Region<'tcx>, FxHashSet<BorrowIndex>>,
local_map: FxHashMap<Local, FxHashSet<BorrowIndex>>,
pending_activations: FxHashMap<Local, BorrowIndex>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir: &'a Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
idx_vec: IndexVec<BorrowIndex, BorrowData<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
location_map: FxHashMap<Location, BorrowIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
activation_map: FxHashMap<Location, Vec<BorrowIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_map: FxHashMap<Region<'tcx>, FxHashSet<BorrowIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
local_map: FxHashMap<Local, FxHashSet<BorrowIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pending_activations: FxHashMap<Local, BorrowIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When we encounter a 2-phase borrow statement, it will always be assigning into a temporary TEMP:
TEMP = &foo
We add TEMP into this map with b, where b is the index of
the borrow. When we find a later use of this activation, we
remove from the map (and add to the "tombstone" set below).
Methods
impl<'a, 'gcx, 'tcx> GatherBorrows<'a, 'gcx, 'tcx>[src]
impl<'a, 'gcx, 'tcx> GatherBorrows<'a, 'gcx, 'tcx>fn allow_two_phase_borrow(&self, kind: BorrowKind) -> bool[src]
fn allow_two_phase_borrow(&self, kind: BorrowKind) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the borrow represented by kind is
allowed to be split into separate Reservation and
Activation phases.
fn insert_as_pending_if_two_phase(
&mut self,
start_location: Location,
assigned_place: &Place<'tcx>,
region: Region<'tcx>,
kind: BorrowKind,
borrow_index: BorrowIndex
)[src]
fn insert_as_pending_if_two_phase(
&mut self,
start_location: Location,
assigned_place: &Place<'tcx>,
region: Region<'tcx>,
kind: BorrowKind,
borrow_index: BorrowIndex
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this is a two-phase borrow, then we will record it as "pending" until we find the activating use.