enum LocalMutationIsAllowed {
Yes,
ExceptUpvars,
No,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When checking permissions for a place access, this flag is used to indicate that an immutable
local place can be mutated.
FIXME: @nikomatsakis suggested that this flag could be removed with the following modifications:
- Merge
check_access_permissions() and check_if_reassignment_to_immutable_state()
- Split
is_mutable() into is_assignable() (can be directly assigned) and
is_declared_mutable()
- Take flow state into consideration in
is_assignable() for local variables
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We want use of immutable upvars to cause a "write to immutable upvar"
error, not an "reassignment" error.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Performs copy-assignment from source. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Formats the value using the given formatter. Read more