[−][src]Enum rustc_mir::borrow_check::ReadOrWrite
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Kind of access to a value: read or write (For informational purposes only)
Variants
Read(ReadKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
From the RFC: "A read means that the existing data may be read, but will not be changed."
Write(WriteKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
From the RFC: "A write means that the data may be mutated to new values or otherwise invalidated (for example, it could be de-initialized, as in a move operation).
Reservation(WriteKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For two-phase borrows, we distinguish a reservation (which is treated like a Read) from an activation (which is treated like a write), and each of those is furthermore distinguished from Reads/Writes above.
Activation(WriteKind, BorrowIndex)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?