Struct rustc_mir::borrow_check::location::LocationIndex [−]
pub struct LocationIndex(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LocationIndex[src]
impl LocationIndexfn is_start(&self) -> bool[src]
fn is_start(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?