Struct rustc_mir::borrow_check::nll::constraints::graph::ConstraintGraph [−][src]
pub(crate) struct ConstraintGraph {
first_constraints: IndexVec<RegionVid, Option<ConstraintIndex>>,
next_constraints: IndexVec<ConstraintIndex, Option<ConstraintIndex>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
first_constraints: IndexVec<RegionVid, Option<ConstraintIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
next_constraints: IndexVec<ConstraintIndex, Option<ConstraintIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ConstraintGraph[src]
impl ConstraintGraphpub(crate) fn new(set: &ConstraintSet, num_region_vars: usize) -> Self[src]
pub(crate) fn new(set: &ConstraintSet, num_region_vars: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a "dependency graph" where each region constraint R1: R2 is treated as an edge R1 -> R2. We use this graph to
construct SCCs for region inference but also for error
reporting.
ⓘImportant traits for Edges<'s>pub(crate) fn outgoing_edges(&self, region_sup: RegionVid) -> Edges[src]
pub(crate) fn outgoing_edges(&self, region_sup: RegionVid) -> Edges🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given a region R, iterate over all constraints R: R1.