Struct rustc_mir::borrow_check::nll::constraints::graph::RegionGraph [−][src]
pub(crate) struct RegionGraph<'s> {
set: &'s ConstraintSet,
constraint_graph: &'s ConstraintGraph,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
set: &'s ConstraintSet
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
constraint_graph: &'s ConstraintGraph
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'s> RegionGraph<'s>[src]
impl<'s> RegionGraph<'s>pub(crate) fn new(
set: &'s ConstraintSet,
constraint_graph: &'s ConstraintGraph
) -> Self[src]
pub(crate) fn new(
set: &'s ConstraintSet,
constraint_graph: &'s ConstraintGraph
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a "dependency graph" where each region constraint R1: R2 is treated as an edge R1 -> R2. We use this graph to
construct SCCs for region inference but also for error
reporting.
ⓘImportant traits for Successors<'s>pub(crate) fn sub_regions(&self, region_sup: RegionVid) -> Successors[src]
pub(crate) fn sub_regions(&self, region_sup: RegionVid) -> Successors🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given a region R, iterate over all regions R1 such that
there exists a constraint R: R1.