[−][src]Trait rustc_mir::borrow_check::nll::constraints::graph::ConstraintGraphDirecton
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Marker trait that controls whether a R1: R2 constraint
represents an edge R1 -> R2 or R2 -> R1.
Required Methods
fn start_region(c: &OutlivesConstraint) -> RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn end_region(c: &OutlivesConstraint) -> RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn is_normal() -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl ConstraintGraphDirecton for Normal[src]
impl ConstraintGraphDirecton for Normalfn start_region(c: &OutlivesConstraint) -> RegionVid[src]
fn start_region(c: &OutlivesConstraint) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn end_region(c: &OutlivesConstraint) -> RegionVid[src]
fn end_region(c: &OutlivesConstraint) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn is_normal() -> bool[src]
fn is_normal() -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl ConstraintGraphDirecton for Reverse[src]
impl ConstraintGraphDirecton for Reversefn start_region(c: &OutlivesConstraint) -> RegionVid[src]
fn start_region(c: &OutlivesConstraint) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn end_region(c: &OutlivesConstraint) -> RegionVid[src]
fn end_region(c: &OutlivesConstraint) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn is_normal() -> bool[src]
fn is_normal() -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?