Struct rustc_mir::borrow_check::nll::facts::AllFacts [−][src]
struct AllFacts {
borrow_region: Vec<(RegionVid, BorrowIndex, LocationIndex)>,
universal_region: Vec<RegionVid>,
cfg_edge: Vec<(LocationIndex, LocationIndex)>,
killed: Vec<(BorrowIndex, LocationIndex)>,
outlives: Vec<(RegionVid, RegionVid, LocationIndex)>,
region_live_at: Vec<(RegionVid, LocationIndex)>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The "facts" which are the basis of the NLL borrow analysis.
Fields
borrow_region: Vec<(RegionVid, BorrowIndex, LocationIndex)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
universal_region: Vec<RegionVid>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cfg_edge: Vec<(LocationIndex, LocationIndex)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
killed: Vec<(BorrowIndex, LocationIndex)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
outlives: Vec<(RegionVid, RegionVid, LocationIndex)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_live_at: Vec<(RegionVid, LocationIndex)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl AllFacts[src]
impl AllFactsfn write_to_dir(
&self,
dir: impl AsRef<Path>,
location_table: &LocationTable
) -> Result<(), Box<Error>>[src]
fn write_to_dir(
&self,
dir: impl AsRef<Path>,
location_table: &LocationTable
) -> Result<(), Box<Error>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?