Trait rustc_mir::borrow_check::nll::facts::FactCell [−][src]
trait FactCell {
fn to_string(&self, location_table: &LocationTable) -> String;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn to_string(&self, location_table: &LocationTable) -> String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<A: Debug> FactCell for Aimpl FactCell for LocationIndex