Struct rustc_mir::borrow_check::nll::liveness_map::NllLivenessMap [−][src]
pub(crate) struct NllLivenessMap {
pub from_local: IndexVec<Local, Option<LocalWithRegion>>,
pub to_local: IndexVec<LocalWithRegion, Local>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Map between Local and LocalWithRegion indices: this map is supplied to the liveness code so that it will only analyze those variables whose types contain regions.
Fields
from_local: IndexVec<Local, Option<LocalWithRegion>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each local variable, contains either None (if the type has no regions) or Some(i) with a suitable index.
to_local: IndexVec<LocalWithRegion, Local>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each LocalWithRegion, maps back to the original Local index.
Methods
impl NllLivenessMap[src]
impl NllLivenessMappub fn compute(mir: &Mir) -> Self[src]
pub fn compute(mir: &Mir) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over the variables in Mir and assigns each Local whose type contains regions a LocalWithRegion index. Returns a map for converting back and forth.