Enum rustc_mir::borrow_check::nll::region_infer::Cause [−][src]
enum Cause {
LiveVar(Local, Location),
DropVar(Local, Location),
LiveOther(Location),
UniversalRegion(RegionVid),
Outlives {
original_cause: Rc<Cause>,
constraint_location: Location,
constraint_span: Span,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NB: The variants in Cause are intentionally ordered. Lower
values are preferred when it comes to error messages. Do not
reorder willy nilly.
Variants
LiveVar(Local, Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
point inserted because Local was live at the given Location
DropVar(Local, Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
point inserted because Local was dropped at the given Location
LiveOther(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
point inserted because the type was live at the given Location, but not as part of some local variable
UniversalRegion(RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
part of the initial set of values for a universally quantified region
Outlives🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Element E was added to R because there was some
outlives obligation R: R1 @ P and R1 contained E.
Fields of Outlives
original_cause: Rc<Cause> | 🔬 This is a nightly-only experimental API. ( |
constraint_location: Location | 🔬 This is a nightly-only experimental API. ( |
constraint_span: Span | 🔬 This is a nightly-only experimental API. ( |
Methods
impl Cause[src]
impl Causefn root_cause(&self) -> &Cause[src]
fn root_cause(&self) -> &Cause🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?