Struct rustc_mir::borrow_check::nll::region_infer::OutlivesConstraint [−][src]
pub struct OutlivesConstraint {
pub sup: RegionVid,
pub sub: RegionVid,
pub point: Location,
pub next: Option<ConstraintIndex>,
pub span: Span,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
sup: RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The region SUP must outlive SUB...
sub: RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Region that must be outlived.
point: Location
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
At this location.
next: Option<ConstraintIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Later on, we thread the constraints onto a linked list
grouped by their sub field. So if you had:
| Index | Constraint | Next Field |
|---|---|---|
| 0 | 'a: 'b | Some(2) |
| 1 | 'b: 'c | None |
| 2 | 'c: 'b | None |
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Where did this constraint arise?