Struct rustc_mir::borrow_check::nll::region_infer::RegionCausalInfo [−][src]
struct RegionCausalInfo {
inferred_values: RegionValues,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
inferred_values: RegionValues
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl RegionCausalInfo[src]
impl RegionCausalInfofn why_region_contains_point<R>(&self, r: R, p: Location) -> Option<Rc<Cause>> where
R: ToRegionVid, [src]
fn why_region_contains_point<R>(&self, r: R, p: Location) -> Option<Rc<Cause>> where
R: ToRegionVid, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the reason that the region r contains the given point.