[−][src]Struct rustc_mir::borrow_check::nll::region_infer::RegionDefinition
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
origin: NLLRegionVariableOrigin
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
What kind of variable is this -- a free region? existential
variable? etc. (See the NLLRegionVariableOrigin for more
info.)
universe: UniverseIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Which universe is this region variable defined in? This is
most often ty::UniverseIndex::ROOT, but when we encounter
forall-quantifiers like for<'a> { 'a = 'b }, we would create
the variable for 'a in a subuniverse.
external_name: Option<Region<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this is 'static or an early-bound region, then this is
Some(X) where X is the name of the region.
Methods
impl<'tcx> RegionDefinition<'tcx>[src]
impl<'tcx> RegionDefinition<'tcx>fn new(universe: UniverseIndex, rv_origin: RegionVariableOrigin) -> Self[src]
fn new(universe: UniverseIndex, rv_origin: RegionVariableOrigin) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?