Enum rustc_mir::borrow_check::nll::region_infer::values::RegionElement [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An individual element in a region value -- the value of a particular region variable consists of a set of these elements.
Variants
Location(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A point in the control-flow graph.
UniversalRegion(RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An in-scope, universally quantified region (e.g., a lifetime parameter).