Struct rustc_mir::borrow_check::nll::region_infer::values::RegionValueElements [−][src]
struct RegionValueElements {
statements_before_block: IndexVec<BasicBlock, usize>,
num_points: usize,
num_universal_regions: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps between the various kinds of elements of a region value to the internal indices that w use.
Fields
statements_before_block: IndexVec<BasicBlock, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each basic block, how many points are contained within?
num_points: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
num_universal_regions: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl RegionValueElements[src]
impl RegionValueElementsfn new(mir: &Mir, num_universal_regions: usize) -> Self[src]
fn new(mir: &Mir, num_universal_regions: usize) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn num_elements(&self) -> usize[src]
fn num_elements(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Total number of element indices that exist.
fn index<T: ToElementIndex>(&self, elem: T) -> RegionElementIndex[src]
fn index<T: ToElementIndex>(&self, elem: T) -> RegionElementIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts an element of a region value into a RegionElementIndex.
fn all_point_indices<'a>(
&'a self
) -> impl Iterator<Item = RegionElementIndex> + 'a[src]
fn all_point_indices<'a>(
&'a self
) -> impl Iterator<Item = RegionElementIndex> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over the RegionElementIndex for all points in the CFG.
fn all_universal_region_indices(
&self
) -> impl Iterator<Item = RegionElementIndex>[src]
fn all_universal_region_indices(
&self
) -> impl Iterator<Item = RegionElementIndex>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over the RegionElementIndex for all points in the CFG.
fn to_element(&self, i: RegionElementIndex) -> RegionElement[src]
fn to_element(&self, i: RegionElementIndex) -> RegionElement🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a particular RegionElementIndex to the RegionElement it represents.
fn to_universal_region(&self, i: RegionElementIndex) -> Option<RegionVid>[src]
fn to_universal_region(&self, i: RegionElementIndex) -> Option<RegionVid>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a particular RegionElementIndex to a universal
region, if that is what it represents. Returns None
otherwise.