[−][src]Struct rustc_mir::borrow_check::nll::region_infer::values::RegionValues
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stores the full values for a set of regions (in contrast to
LivenessValues, which only stores those points in the where a
region is live). The full value for a region may contain points in
the CFG, but also free regions as well as bound universe
placeholders.
Example:
fn foo(x: &'a u32) -> &'a u32 {
let y: &'0 u32 = x; // let's call this `'0`
y
}
Here, the variable '0 would contain the free region 'a,
because (since it is returned) it must live for at least 'a. But
it would also contain various points from within the function.
Fields
elements: Rc<RegionValueElements>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
points: SparseBitMatrix<N, PointIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
free_regions: SparseBitMatrix<N, RegionVid>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
placeholders: SparseBitMatrix<N, PlaceholderIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Placeholders represent bound regions -- so something like 'a
in for<'a> fn(&'a u32)`.
Methods
impl<N: Idx> RegionValues<N>[src]
impl<N: Idx> RegionValues<N>pub(crate) fn new(
elements: &Rc<RegionValueElements>,
num_universal_regions: usize,
max_universe: UniverseIndex
) -> Self[src]
pub(crate) fn new(
elements: &Rc<RegionValueElements>,
num_universal_regions: usize,
max_universe: UniverseIndex
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a new set of "region values" that tracks causal information. Each of the regions in num_region_variables will be initialized with an empty set of points and no causal information.
pub(crate) fn add_element(
&mut self,
r: N,
elem: impl ToElementIndex
) -> bool[src]
pub(crate) fn add_element(
&mut self,
r: N,
elem: impl ToElementIndex
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds the given element to the value for the given region. Returns true if the element is newly added (i.e., was not already present).
pub(crate) fn add_all_points(&mut self, r: N)[src]
pub(crate) fn add_all_points(&mut self, r: N)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds all the control-flow points to the values for r.
pub(crate) fn add_region(&mut self, r_to: N, r_from: N) -> bool[src]
pub(crate) fn add_region(&mut self, r_to: N, r_from: N) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add all elements in r_from to r_to (because e.g. r_to: r_from).
pub(crate) fn contains(
&self,
r: N,
elem: impl ToElementIndex
) -> bool[src]
pub(crate) fn contains(
&self,
r: N,
elem: impl ToElementIndex
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if the region r contains the given element.
pub(crate) fn merge_liveness<M: Idx>(
&mut self,
to: N,
from: M,
values: &LivenessValues<M>
)[src]
pub(crate) fn merge_liveness<M: Idx>(
&mut self,
to: N,
from: M,
values: &LivenessValues<M>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
self[to] |= values[from], essentially: that is, take all the
elements for the region from from values and add them to
the region to in self.
pub(crate) fn contains_points(&self, sup_region: N, sub_region: N) -> bool[src]
pub(crate) fn contains_points(&self, sup_region: N, sub_region: N) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if sup_region contains all the CFG points that
sub_region contains. Ignores universal regions.
pub(crate) fn locations_outlived_by<'a>(
&'a self,
r: N
) -> impl Iterator<Item = Location> + 'a[src]
pub(crate) fn locations_outlived_by<'a>(
&'a self,
r: N
) -> impl Iterator<Item = Location> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the locations contained within a given region r.
pub(crate) fn universal_regions_outlived_by<'a>(
&'a self,
r: N
) -> impl Iterator<Item = RegionVid> + 'a[src]
pub(crate) fn universal_regions_outlived_by<'a>(
&'a self,
r: N
) -> impl Iterator<Item = RegionVid> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns just the universal regions that are contained in a given region's value.
pub(crate) fn subuniverses_contained_in<'a>(
&'a self,
r: N
) -> impl Iterator<Item = UniverseIndex> + 'a[src]
pub(crate) fn subuniverses_contained_in<'a>(
&'a self,
r: N
) -> impl Iterator<Item = UniverseIndex> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns all the elements contained in a given region's value.
pub(crate) fn elements_contained_in<'a>(
&'a self,
r: N
) -> impl Iterator<Item = RegionElement> + 'a[src]
pub(crate) fn elements_contained_in<'a>(
&'a self,
r: N
) -> impl Iterator<Item = RegionElement> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns all the elements contained in a given region's value.
pub(crate) fn region_value_str(&self, r: N) -> String[src]
pub(crate) fn region_value_str(&self, r: N) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns a "pretty" string value of the region. Meant for debugging.