[−][src]Trait rustc_mir::borrow_check::nll::ToRegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Right now, we piggy back on the ReVar to store our NLL inference
regions. These are indexed with RegionVid. This method will
assert that the region is a ReVar and extract its internal index.
This is reasonable because in our MIR we replace all universal regions
with inference variables.
Required Methods
fn to_region_vid(self) -> RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'tcx> ToRegionVid for &'tcx RegionKind[src]
impl<'tcx> ToRegionVid for &'tcx RegionKindfn to_region_vid(self) -> RegionVid[src]
fn to_region_vid(self) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl ToRegionVid for RegionVid[src]
impl ToRegionVid for RegionVidfn to_region_vid(self) -> RegionVid[src]
fn to_region_vid(self) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?