Struct rustc_mir::borrow_check::nll::type_check::free_region_relations::UniversalRegionRelationsBuilder [−][src]
struct UniversalRegionRelationsBuilder<'this, 'gcx: 'tcx, 'tcx: 'this> {
infcx: &'this InferCtxt<'this, 'gcx, 'tcx>,
mir_def_id: DefId,
mir_node_id: NodeId,
param_env: ParamEnv<'tcx>,
location_table: &'this LocationTable,
universal_regions: Rc<UniversalRegions<'tcx>>,
implicit_region_bound: Option<Region<'tcx>>,
constraints: &'this mut MirTypeckRegionConstraints<'tcx>,
all_facts: &'this mut Option<PoloniusAllFacts<RegionVid, BorrowIndex, LocationIndex>>,
relations: UniversalRegionRelations<'tcx>,
region_bound_pairs: Vec<(Region<'tcx>, GenericKind<'tcx>)>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
infcx: &'this InferCtxt<'this, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir_node_id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
param_env: ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
location_table: &'this LocationTable
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
universal_regions: Rc<UniversalRegions<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
implicit_region_bound: Option<Region<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
constraints: &'this mut MirTypeckRegionConstraints<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
all_facts: &'this mut Option<PoloniusAllFacts<RegionVid, BorrowIndex, LocationIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
relations: UniversalRegionRelations<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
region_bound_pairs: Vec<(Region<'tcx>, GenericKind<'tcx>)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'cx, 'gcx, 'tcx> UniversalRegionRelationsBuilder<'cx, 'gcx, 'tcx>[src]
impl<'cx, 'gcx, 'tcx> UniversalRegionRelationsBuilder<'cx, 'gcx, 'tcx>pub(crate) fn create(self) -> CreateResult<'tcx>[src]
pub(crate) fn create(self) -> CreateResult<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn add_implied_bounds(&mut self, ty: Ty<'tcx>)[src]
fn add_implied_bounds(&mut self, ty: Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Update the type of a single local, which should represent either the return type of the MIR or one of its arguments. At the same time, compute and add any implied bounds that come from this local.
fn add_outlives_bounds<I>(&mut self, outlives_bounds: I) where
I: IntoIterator<Item = OutlivesBound<'tcx>>, [src]
fn add_outlives_bounds<I>(&mut self, outlives_bounds: I) where
I: IntoIterator<Item = OutlivesBound<'tcx>>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Registers the OutlivesBound items from outlives_bounds in
the outlives relation as well as the region-bound pairs
listing.