[−][src]Type Definition rustc_mir::borrow_check::nll::type_check::free_region_relations::RegionBoundPairs
type RegionBoundPairs<'tcx> = Vec<(Region<'tcx>, GenericKind<'tcx>)>;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Each RBP ('a, GK) indicates that GK: 'a can be assumed to
be true. These encode relationships like T: 'a that are
added via implicit bounds.
Each region here is guaranteed to be a key in the indices
map. We use the "original" regions (i.e., the keys from the
map, and not the values) because the code in
process_registered_region_obligations has some special-cased
logic expecting to see (e.g.) ReStatic, and if we supplied
our special inference variable there, we would mess that up.