[−][src]Struct rustc_mir::borrow_check::nll::type_check::liveness::trace::LivenessContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contextual state for the type-liveness generator.
Fields
typeck: &'me mut TypeChecker<'typeck, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Current type-checker, giving us our inference context etc.
elements: &'me RegionValueElements
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Defines the PointIndex mapping
mir: &'me Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
MIR we are analyzing.
move_data: &'me MoveData<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Mapping to/from the various indices used for initialization tracking.
drop_data: FxHashMap<Ty<'tcx>, DropData<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Cache for the results of dropck_outlives query.
flow_inits: &'me mut FlowAtLocation<MaybeInitializedPlaces<'flow, 'gcx, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Results of dataflow tracking which variables (and paths) have been initialized.
local_use_map: &'me LocalUseMap<'me>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Index indicating where each variable is assigned, used, or dropped.
liveness_map: &'me NllLivenessMap
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Map tracking which variables need liveness computation.
Methods
impl<'_, '_, '_, '_, 'tcx> LivenessContext<'_, '_, '_, '_, 'tcx>[src]
impl<'_, '_, '_, '_, 'tcx> LivenessContext<'_, '_, '_, '_, 'tcx>fn initialized_at_terminator(
&mut self,
block: BasicBlock,
mpi: MovePathIndex
) -> bool[src]
fn initialized_at_terminator(
&mut self,
block: BasicBlock,
mpi: MovePathIndex
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if the local variable (or some part of it) is initialized in
the terminator of block. We need to check this to determine if a
DROP of some local variable will have an effect -- note that
drops, as they may unwind, are always terminators.
fn initialized_at_exit(&mut self, block: BasicBlock, mpi: MovePathIndex) -> bool[src]
fn initialized_at_exit(&mut self, block: BasicBlock, mpi: MovePathIndex) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if the path mpi (or some part of it) is initialized at
the exit of block.
Warning: Does not account for the result of Call
instructions.
fn add_use_live_facts_for(
&mut self,
value: impl TypeFoldable<'tcx>,
live_at: &BitArray<PointIndex>
)[src]
fn add_use_live_facts_for(
&mut self,
value: impl TypeFoldable<'tcx>,
live_at: &BitArray<PointIndex>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Store the result that all regions in value are live for the
points live_at.
fn add_drop_live_facts_for(
&mut self,
dropped_local: Local,
dropped_ty: Ty<'tcx>,
drop_locations: &[Location],
live_at: &BitArray<PointIndex>
)[src]
fn add_drop_live_facts_for(
&mut self,
dropped_local: Local,
dropped_ty: Ty<'tcx>,
drop_locations: &[Location],
live_at: &BitArray<PointIndex>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Some variable with type live_ty is "drop live" at location
-- i.e., it may be dropped later. This means that some of
the regions in its type must be live at location. The
precise set will depend on the dropck constraints, and in
particular this takes #[may_dangle] into account.
fn make_all_regions_live(
elements: &RegionValueElements,
typeck: &mut TypeChecker<'_, '_, 'tcx>,
value: impl TypeFoldable<'tcx>,
live_at: &BitArray<PointIndex>
)[src]
fn make_all_regions_live(
elements: &RegionValueElements,
typeck: &mut TypeChecker<'_, '_, 'tcx>,
value: impl TypeFoldable<'tcx>,
live_at: &BitArray<PointIndex>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn compute_drop_data<'gcx>(
typeck: &mut TypeChecker<'_, 'gcx, 'tcx>,
dropped_ty: Ty<'tcx>
) -> DropData<'tcx>[src]
fn compute_drop_data<'gcx>(
typeck: &mut TypeChecker<'_, 'gcx, 'tcx>,
dropped_ty: Ty<'tcx>
) -> DropData<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?