[−][src]Struct rustc_mir::borrow_check::nll::type_check::liveness::trace::LivenessResults
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
cx: LivenessContext<'me, 'typeck, 'flow, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
defs: BitArray<PointIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Set of points that define the current local.
use_live_at: BitArray<PointIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Points where the current variable is "use live" -- meaning that there is a future "full use" that may use its value.
drop_live_at: BitArray<PointIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Points where the current variable is "drop live" -- meaning that there is no future "full use" that may use its value, but there is a future drop.
drop_locations: Vec<Location>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Locations where drops may occur.
stack: Vec<PointIndex>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stack used when doing (reverse) DFS.
Methods
impl<'me, 'typeck, 'flow, 'gcx, 'tcx> LivenessResults<'me, 'typeck, 'flow, 'gcx, 'tcx>[src]
impl<'me, 'typeck, 'flow, 'gcx, 'tcx> LivenessResults<'me, 'typeck, 'flow, 'gcx, 'tcx>fn new(cx: LivenessContext<'me, 'typeck, 'flow, 'gcx, 'tcx>) -> Self[src]
fn new(cx: LivenessContext<'me, 'typeck, 'flow, 'gcx, 'tcx>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn compute_for_all_locals(&mut self)[src]
fn compute_for_all_locals(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn reset_local_state(&mut self)[src]
fn reset_local_state(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Clear the value of fields that are "per local variable".
fn add_defs_for(&mut self, live_local: LiveVar)[src]
fn add_defs_for(&mut self, live_local: LiveVar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds the definitions of local into self.defs.
fn compute_use_live_points_for(&mut self, live_local: LiveVar)[src]
fn compute_use_live_points_for(&mut self, live_local: LiveVar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compute all points where local is "use live" -- meaning its
current value may be used later (except by a drop). This is
done by walking backwards from each use of live_local until we
find a def of local.
Requires add_defs_for(live_local) to have been executed.
fn compute_drop_live_points_for(&mut self, live_local: LiveVar)[src]
fn compute_drop_live_points_for(&mut self, live_local: LiveVar)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compute all points where local is "drop live" -- meaning its
current value may be dropped later (but not used). This is
done by iterating over the drops of local where local (or
some subpart of local) is initialized. For each such drop,
we walk backwards until we find a point where local is
either defined or use-live.
Requires compute_use_live_points_for and add_defs_for to
have been executed.
fn compute_drop_live_points_for_block(
&mut self,
mpi: MovePathIndex,
term_point: PointIndex
)[src]
fn compute_drop_live_points_for_block(
&mut self,
mpi: MovePathIndex,
term_point: PointIndex
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Executes one iteration of the drop-live analysis loop.
The parameter mpi is the MovePathIndex of the local variable
we are currently analyzing.
The point term_point represents some terminator in the MIR,
where the local mpi is drop-live on entry to that terminator.
This method adds all drop-live points within the block and --
where applicable -- pushes the terminators of preceding blocks
onto self.stack.