Struct rustc_mir::borrow_check::nll::type_check::relate_tys::BoundRegionScope [−][src]
struct BoundRegionScope {
map: FxHashMap<BoundRegion, RegionVid>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
map: FxHashMap<BoundRegion, RegionVid>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?