[−][src]Struct rustc_mir::borrow_check::nll::type_check::relate_tys::ScopeInstantiator
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When we encounter a binder like for<..> fn(..), we actually have
to walk the fn value to find all the values bound by the for
(these are not explicitly present in the ty representation right
now). This visitor handles that: it descends the type, tracking
binder depth, and finds late-bound regions targeting the
for<..>. For each of those, it creates an entry in
bound_region_scope.
Fields
infcx: &'cx InferCtxt<'cx, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
target_index: DebruijnIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
universally_quantified: UniversallyQuantified
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bound_region_scope: &'cx mut BoundRegionScope
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?