Struct rustc_mir::borrow_check::nll::type_check::relate_tys::ScopesAndKind [−][src]
struct ScopesAndKind<'tcx> {
scopes: Vec<BoundRegionScope>,
kind: Kind<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
scopes: Vec<BoundRegionScope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
kind: Kind<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?