[−][src]Struct rustc_mir::borrow_check::nll::type_check::relate_tys::TypeGeneralizer
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The "type generalize" is used when handling inference variables.
The basic strategy for handling a constraint like ?A <: B is to
apply a "generalization strategy" to the type B -- this replaces
all the lifetimes in the type B with fresh inference
variables. (You can read more about the strategy in this blog
post.)
As an example, if we had ?A <: &'x u32, we would generalize &'x u32 to &'0 u32 where '0 is a fresh variable. This becomes the
value of A. Finally, we relate &'0 u32 <: &'x u32, which
establishes '0: 'x as a constraint.
As a side-effect of this generalization procedure, we also replace all the bound regions that we have traversed with concrete values, so that the resulting generalized type is independent from the scopes.
Fields
type_rel: &'me TypeRelating<'me, 'bccx, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ambient_variance: Variance
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
After we generalize this type, we are going to relative it to some other type. What will be the variance at this point?
first_free_index: DebruijnIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
universe: UniverseIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?