Struct rustc_mir::borrow_check::nll::type_check::relate_tys::UniversallyQuantified [−][src]
struct UniversallyQuantified(bool);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?