Struct rustc_mir::borrow_check::nll::type_check::OutlivesSet [−][src]
pub struct OutlivesSet<'tcx> {
pub locations: Locations,
pub data: RegionConstraintData<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Outlives relationships between regions and types created at a particular point within the control-flow graph.
Fields
locations: Locations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The locations associated with these constraints.
data: RegionConstraintData<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Constraints generated. In terms of the NLL RFC, when you have
a constraint R1: R2 @ P, the data in there specifies things
like R1: R2.