Trait rustc_mir::borrow_check::nll::type_check::AtLocation [−][src]
trait AtLocation {
fn at_self(self) -> Locations;
fn at_successor_within_block(self) -> Locations;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn at_self(self) -> Locations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a Locations where self is both the from-location
and the at-location. This means that any required region
relationships must hold upon entering the statement/terminator
indicated by self. This is typically used when processing
"inputs" to the given location.
fn at_successor_within_block(self) -> Locations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Creates a Locations where self is the from-location and
its successor within the block is the at-location. This means
that any required region relationships must hold only upon
exiting the statement/terminator indicated by self. This
is for example used when you have a place = rv statement: it
indicates that the typeof(rv) <: typeof(place) as of the
next statement.
Implementations on Foreign Types
impl AtLocation for Location[src]
impl AtLocation for Locationfn at_self(self) -> Locations[src]
fn at_self(self) -> Locations🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn at_successor_within_block(self) -> Locations[src]
fn at_successor_within_block(self) -> Locations🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?