Struct rustc_mir::borrow_check::nll::universal_regions::UniversalRegionRelations [−][src]
struct UniversalRegionRelations {
outlives: TransitiveRelation<RegionVid>,
inverse_outlives: TransitiveRelation<RegionVid>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
outlives: TransitiveRelation<RegionVid>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stores the outlives relations that are known to hold from the implied bounds, in-scope where clauses, and that sort of thing.
inverse_outlives: TransitiveRelation<RegionVid>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is the <= relation; that is, if a: b, then b <= a,
and we store that here. This is useful when figuring out how
to express some local region in terms of external regions our
caller will understand.
Methods
impl UniversalRegionRelations[src]
impl UniversalRegionRelationsfn relate_universal_regions(&mut self, fr_a: RegionVid, fr_b: RegionVid)[src]
fn relate_universal_regions(&mut self, fr_a: RegionVid, fr_b: RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Records in the outlives_relation (and
inverse_outlives_relation) that fr_a: fr_b.