Function rustc_mir::borrow_check::places_conflict::unroll_place [−][src]
fn unroll_place<'tcx, R>(
place: &Place<'tcx>,
next: Option<&PlaceComponents<'_, 'tcx>>,
op: impl FnOnce(PlaceComponentsIter<'_, 'tcx>) -> R
) -> R
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Recursively "unroll" a place into a PlaceComponents list,
invoking op with a PlaceComponentsIter.