Struct rustc_mir::borrow_check::places_conflict::PlaceComponentsIter [−][src]
struct PlaceComponentsIter<'p, 'tcx: 'p> {
value: Option<&'p PlaceComponents<'p, 'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterator over components; see PlaceComponents::iter for more
information.
NB: This is not a true Rust iterator -- the code above just
manually invokes next. This is because we (sometimes) want to
keep executing even after None has been returned.
Fields
value: Option<&'p PlaceComponents<'p, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'p, 'tcx> PlaceComponentsIter<'p, 'tcx>[src]
impl<'p, 'tcx> PlaceComponentsIter<'p, 'tcx>fn next(&mut self) -> Option<&'p Place<'tcx>>[src]
fn next(&mut self) -> Option<&'p Place<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?