Trait rustc_mir::borrow_check::prefixes::IsPrefixOf [−][src]
pub trait IsPrefixOf<'tcx> {
fn is_prefix_of(&self, other: &Place<'tcx>) -> bool;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn is_prefix_of(&self, other: &Place<'tcx>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'tcx> IsPrefixOf<'tcx> for Place<'tcx>[src]
impl<'tcx> IsPrefixOf<'tcx> for Place<'tcx>fn is_prefix_of(&self, other: &Place<'tcx>) -> bool[src]
fn is_prefix_of(&self, other: &Place<'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?