Enum rustc_mir::build::ForGuard [−][src]
enum ForGuard {
ValWithinGuard(usize),
RefWithinGuard,
OutsideGuard,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ForGuard indicates whether we are talking about:
- the temp for a local binding used solely within guard expressions,
- the temp that holds reference to (1.), which is actually what the guard expressions see, or
- the temp for use outside of guard expressions.
Variants
ValWithinGuard(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The usize identifies for which candidate pattern we want the
local binding. We keep a temp per-candidate to accommodate
two-phase borrows (see LocalsForNode documentation).
RefWithinGuard🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
OutsideGuard🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?