enum LocalsForNode {
One(Local),
ForGuard {
vals_for_guard: Vec<Local>,
ref_for_guard: Local,
for_arm_body: Local,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
In the usual case, a node-id for an identifier maps to at most
one Local declaration.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The exceptional case is identifiers in a match arm's pattern
that are referenced in a guard of that match arm. For these,
we can have 2+k Locals, where k is the number of candidate
patterns (separated by |) in the arm.
-
for_arm_body is the Local used in the arm body (which is
just like the One case above),
-
ref_for_guard is the Local used in the arm's guard (which
is a reference to a temp that is an alias of
for_arm_body).
-
vals_for_guard is the k Locals; at most one of them will
get initialized by the arm's execution, and after it is
initialized, ref_for_guard will be assigned a reference to
it.
There reason we have k Locals rather than just 1 is to
accommodate some restrictions imposed by two-phase borrows,
which apply when we have a ref mut pattern.
Fields of ForGuard
vals_for_guard: Vec<Local> | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
ref_for_guard: Local | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
for_arm_body: Local | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an error for a missing method specialization. Defaults to panicking with type, trait & method names. S is the encoder/decoder state type, T is the type being encoded/decoded, and the arguments are the names of the trait and method that should've been overridden. Read more
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?