Enum rustc_mir::build::expr::category::Category [−][src]
pub enum Category {
Place,
Constant,
Rvalue(RvalueFunc),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Place🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Constant🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Rvalue(RvalueFunc)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Category[src]
impl CategoryDetermines the category for a given expression. Note that scope and paren expressions have no category.
pub fn of<'tcx>(ek: &ExprKind<'tcx>) -> Option<Category>[src]
pub fn of<'tcx>(ek: &ExprKind<'tcx>) -> Option<Category>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?