Struct rustc_mir::build::matches::ArmHasGuard [−][src]
pub(crate) struct ArmHasGuard(pub bool);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ArmHasGuard is isomorphic to a boolean flag. It indicates whether a match arm has a guard expression attached to it.