Struct rustc_mir::build::scope::BreakableScope [−][src]
pub struct BreakableScope<'tcx> {
pub region_scope: Scope,
pub continue_block: Option<BasicBlock>,
pub break_block: BasicBlock,
pub break_destination: Place<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
region_scope: Scope
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Region scope of the loop
continue_block: Option<BasicBlock>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Where the body of the loop begins. None if block
break_block: BasicBlock
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Block to branch into when the loop or block terminates (either by being break-en out
from, or by having its condition to become false)
break_destination: Place<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The destination of the loop/block expression itself (i.e. where to put the result of a
break expression)