Struct rustc_mir::build::CFG [−][src]
struct CFG<'tcx> {
basic_blocks: IndexVec<BasicBlock, BasicBlockData<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
basic_blocks: IndexVec<BasicBlock, BasicBlockData<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> CFG<'tcx>[src]
impl<'tcx> CFG<'tcx>pub fn block_data(&self, blk: BasicBlock) -> &BasicBlockData<'tcx>[src]
pub fn block_data(&self, blk: BasicBlock) -> &BasicBlockData<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn block_data_mut(&mut self, blk: BasicBlock) -> &mut BasicBlockData<'tcx>[src]
pub fn block_data_mut(&mut self, blk: BasicBlock) -> &mut BasicBlockData<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn start_new_block(&mut self) -> BasicBlock[src]
pub fn start_new_block(&mut self) -> BasicBlock🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn start_new_cleanup_block(&mut self) -> BasicBlock[src]
pub fn start_new_cleanup_block(&mut self) -> BasicBlock🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push(&mut self, block: BasicBlock, statement: Statement<'tcx>)[src]
pub fn push(&mut self, block: BasicBlock, statement: Statement<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_end_region<'a, 'gcx: 'a + 'tcx>(
&mut self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
block: BasicBlock,
source_info: SourceInfo,
region_scope: Scope
)[src]
pub fn push_end_region<'a, 'gcx: 'a + 'tcx>(
&mut self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
block: BasicBlock,
source_info: SourceInfo,
region_scope: Scope
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_assign(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
place: &Place<'tcx>,
rvalue: Rvalue<'tcx>
)[src]
pub fn push_assign(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
place: &Place<'tcx>,
rvalue: Rvalue<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_assign_constant(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
temp: &Place<'tcx>,
constant: Constant<'tcx>
)[src]
pub fn push_assign_constant(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
temp: &Place<'tcx>,
constant: Constant<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_assign_unit(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
place: &Place<'tcx>
)[src]
pub fn push_assign_unit(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
place: &Place<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn terminate(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
kind: TerminatorKind<'tcx>
)[src]
pub fn terminate(
&mut self,
block: BasicBlock,
source_info: SourceInfo,
kind: TerminatorKind<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?