Struct rustc_mir::build::GuardFrame [−][src]
struct GuardFrame {
locals: Vec<GuardFrameLocal>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
locals: Vec<GuardFrameLocal>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
These are the id's of names that are bound by patterns of the arm of this guard.
(Frames higher up the stack will have the id's bound in arms further out, such as in a case like:
match E1 { P1(id1) if (... (match E2 { P2(id2) if ... => B2 })) => B1, }
here, when building for FIXME