[−][src]Trait rustc_mir::build::BlockAndExtension
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn and<T>(self, v: T) -> BlockAnd<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn unit(self) -> BlockAnd<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl BlockAndExtension for BasicBlock[src]
impl BlockAndExtension for BasicBlockfn and<T>(self, v: T) -> BlockAnd<T>[src]
fn and<T>(self, v: T) -> BlockAnd<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn unit(self) -> BlockAnd<()>[src]
fn unit(self) -> BlockAnd<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?