[−][src]Struct rustc_mir::dataflow::impls::borrows::Borrows
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Borrows stores the data used in the analyses that track the flow
of borrows.
It uniquely identifies every borrow (Rvalue::Ref) by a
BorrowIndex, and maps each such index to a BorrowData
describing the borrow. These indexes are used for representing the
borrows in compact bitvectors.
Fields
tcx: TyCtxt<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir: &'a Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
scope_tree: Lrc<ScopeTree>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
root_scope: Option<Scope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
borrow_set: Rc<BorrowSet<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
borrows_out_of_scope_at_location: FxHashMap<Location, Vec<BorrowIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
_nonlexical_regioncx: Rc<RegionInferenceContext<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NLL region inference context with which NLL queries should be resolved
Methods
impl<'a, 'gcx, 'tcx> Borrows<'a, 'gcx, 'tcx>[src]
impl<'a, 'gcx, 'tcx> Borrows<'a, 'gcx, 'tcx>pub(crate) fn new(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
mir: &'a Mir<'tcx>,
nonlexical_regioncx: Rc<RegionInferenceContext<'tcx>>,
def_id: DefId,
body_id: Option<BodyId>,
borrow_set: &Rc<BorrowSet<'tcx>>
) -> Self[src]
pub(crate) fn new(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
mir: &'a Mir<'tcx>,
nonlexical_regioncx: Rc<RegionInferenceContext<'tcx>>,
def_id: DefId,
body_id: Option<BodyId>,
borrow_set: &Rc<BorrowSet<'tcx>>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn borrows(&self) -> &IndexVec<BorrowIndex, BorrowData<'tcx>>[src]
pub(crate) fn borrows(&self) -> &IndexVec<BorrowIndex, BorrowData<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn scope_tree(&self) -> &Lrc<ScopeTree>[src]
pub fn scope_tree(&self) -> &Lrc<ScopeTree>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn location(&self, idx: BorrowIndex) -> &Location[src]
pub fn location(&self, idx: BorrowIndex) -> &Location🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn kill_loans_out_of_scope_at_location(
&self,
sets: &mut BlockSets<BorrowIndex>,
location: Location
)[src]
fn kill_loans_out_of_scope_at_location(
&self,
sets: &mut BlockSets<BorrowIndex>,
location: Location
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add all borrows to the kill set, if those borrows are out of scope at location.
That means either they went out of either a nonlexical scope, if we care about those
at the moment, or the location represents a lexical EndRegion
fn kill_borrows_on_local(
&self,
sets: &mut BlockSets<BorrowIndex>,
local: &Local
)[src]
fn kill_borrows_on_local(
&self,
sets: &mut BlockSets<BorrowIndex>,
local: &Local
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?