Trait rustc_mir::dataflow::move_paths::abs_domain::Lift [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type Abstract
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn lift(&self) -> Self::Abstract
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'tcx> Lift for Operand<'tcx>[src]
impl<'tcx> Lift for Operand<'tcx>type Abstract = AbstractOperand
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lift(&self) -> Self::Abstract[src]
fn lift(&self) -> Self::Abstract🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Lift for Local[src]
impl Lift for Localtype Abstract = AbstractOperand
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lift(&self) -> Self::Abstract[src]
fn lift(&self) -> Self::Abstract🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> Lift for Ty<'tcx>[src]
impl<'tcx> Lift for Ty<'tcx>type Abstract = AbstractType
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lift(&self) -> Self::Abstract[src]
fn lift(&self) -> Self::Abstract🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'tcx> Lift for PlaceElem<'tcx>[src]
impl<'tcx> Lift for PlaceElem<'tcx>type Abstract = ProjectionElem<'tcx, AbstractOperand, AbstractType>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lift(&self) -> Self::Abstract[src]
fn lift(&self) -> Self::Abstract🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?