pub(crate) enum IllegalMoveOriginKind<'tcx> {
Static,
BorrowedContent {
target_place: Place<'tcx>,
},
InteriorOfTypeWithDestructor {
container_ty: Ty<'tcx>,
},
InteriorOfSliceOrArray {
ty: Ty<'tcx>,
is_index: bool,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from static variable.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from behind a reference.
Fields of BorrowedContent
target_place: Place<'tcx> | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The place the reference refers to: if erroneous code was trying to
move from (*x).f this will be *x.
|
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from field of an ADT that
implements Drop. Rust maintains invariant that all Drop
ADT's remain fully-initialized so that user-defined destructor
can safely read from all of the ADT's fields.
Fields of InteriorOfTypeWithDestructor
container_ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move out of a slice or array.
Fields of InteriorOfSliceOrArray
ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
is_index: bool | 🔬 This is a nightly-only experimental API. (rustc_private)this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
|
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an error for a missing method specialization. Defaults to panicking with type, trait & method names. S is the encoder/decoder state type, T is the type being encoded/decoded, and the arguments are the names of the trait and method that should've been overridden. Read more
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?