Enum rustc_mir::dataflow::move_paths::InitKind [−][src]
pub enum InitKind {
Deep,
Shallow,
NonPanicPathOnly,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Additional information about the initialization.
Variants
Deep🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Deep init, even on panic
Shallow🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Only does a shallow init
NonPanicPathOnly🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This doesn't initialize the variabe on panic (and a panic is possible).