Enum rustc_mir::dataflow::move_paths::MoveError [−][src]
pub enum MoveError<'tcx> {
IllegalMove {
cannot_move_out_of: IllegalMoveOrigin<'tcx>,
},
UnionMove {
path: MovePathIndex,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
IllegalMove🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of IllegalMove
cannot_move_out_of: IllegalMoveOrigin<'tcx> | 🔬 This is a nightly-only experimental API. ( |
UnionMove🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of UnionMove
path: MovePathIndex | 🔬 This is a nightly-only experimental API. ( |
Methods
impl<'tcx> MoveError<'tcx>[src]
impl<'tcx> MoveError<'tcx>fn cannot_move_out_of(
location: Location,
kind: IllegalMoveOriginKind<'tcx>
) -> Self[src]
fn cannot_move_out_of(
location: Location,
kind: IllegalMoveOriginKind<'tcx>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?