Struct rustc_mir::dataflow::move_paths::indexes::MoveOutIndex [−][src]
pub struct MoveOutIndex(NonZeroUsize);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl MoveOutIndex[src]
impl MoveOutIndexpub fn move_path_index(&self, move_data: &MoveData) -> MovePathIndex[src]
pub fn move_path_index(&self, move_data: &MoveData) -> MovePathIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?