Struct rustc_mir::dataflow::move_paths::LocationMap [−][src]
pub struct LocationMap<T> {
map: IndexVec<BasicBlock, Vec<T>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
map: IndexVec<BasicBlock, Vec<T>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Location-indexed (BasicBlock for outer index, index within BB for inner index) map.
Methods
impl<T> LocationMap<T> where
T: Default + Clone, [src]
impl<T> LocationMap<T> where
T: Default + Clone, fn new(mir: &Mir) -> Self[src]
fn new(mir: &Mir) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?