Struct rustc_mir::dataflow::move_paths::MoveOut [−][src]
pub struct MoveOut {
pub path: MovePathIndex,
pub source: Location,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
MoveOut represents a point in a program that moves out of some
L-value; i.e., "creates" uninitialized memory.
With respect to dataflow analysis:
- Generated by moves and declaration of uninitialized variables.
- Killed by assignments to the memory.
Fields
path: MovePathIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
path being moved
source: Location
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
location of move