Struct rustc_mir::dataflow::Bits [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps each block to a set of bits
Fields
bits: IdxSetBuf<E>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<E: Idx> Bits<E>[src]
impl<E: Idx> Bits<E>fn new(bits: IdxSetBuf<E>) -> Self[src]
fn new(bits: IdxSetBuf<E>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?