[−][src]Struct rustc_mir::dataflow::DataflowAnalysis
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
flow_state: DataflowState<O>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
dead_unwinds: &'a IdxSet<BasicBlock>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir: &'a Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx: 'tcx, 'tcx: 'a, BD> DataflowAnalysis<'a, 'tcx, BD> where
BD: BitDenotation, [src]
impl<'a, 'gcx: 'tcx, 'tcx: 'a, BD> DataflowAnalysis<'a, 'tcx, BD> where
BD: BitDenotation, pub(crate) fn run<P>(
self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
node_id: NodeId,
attributes: &[Attribute],
p: P
) -> DataflowResults<BD> where
P: Fn(&BD, BD::Idx) -> DebugFormatted, [src]
pub(crate) fn run<P>(
self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
node_id: NodeId,
attributes: &[Attribute],
p: P
) -> DataflowResults<BD> where
P: Fn(&BD, BD::Idx) -> DebugFormatted, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx: 'a, BD> DataflowAnalysis<'a, 'tcx, BD> where
BD: BitDenotation, [src]
impl<'a, 'tcx: 'a, BD> DataflowAnalysis<'a, 'tcx, BD> where
BD: BitDenotation, fn propagate(&mut self)[src]
fn propagate(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_sets(&mut self)[src]
fn build_sets(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx: 'a, O> DataflowAnalysis<'a, 'tcx, O> where
O: BitDenotation, [src]
impl<'a, 'tcx: 'a, O> DataflowAnalysis<'a, 'tcx, O> where
O: BitDenotation, pub fn results(self) -> DataflowResults<O>[src]
pub fn results(self) -> DataflowResults<O>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn mir(&self) -> &'a Mir<'tcx>[src]
pub fn mir(&self) -> &'a Mir<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx, D> DataflowAnalysis<'a, 'tcx, D> where
D: BitDenotation, [src]
impl<'a, 'tcx, D> DataflowAnalysis<'a, 'tcx, D> where
D: BitDenotation, pub fn new(
mir: &'a Mir<'tcx>,
dead_unwinds: &'a IdxSet<BasicBlock>,
denotation: D
) -> Self where
D: InitialFlow, [src]
pub fn new(
mir: &'a Mir<'tcx>,
dead_unwinds: &'a IdxSet<BasicBlock>,
denotation: D
) -> Self where
D: InitialFlow, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_from_sets(
mir: &'a Mir<'tcx>,
dead_unwinds: &'a IdxSet<BasicBlock>,
sets: AllSets<D::Idx>,
denotation: D
) -> Self[src]
pub fn new_from_sets(
mir: &'a Mir<'tcx>,
dead_unwinds: &'a IdxSet<BasicBlock>,
sets: AllSets<D::Idx>,
denotation: D
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx: 'a, D> DataflowAnalysis<'a, 'tcx, D> where
D: BitDenotation, [src]
impl<'a, 'tcx: 'a, D> DataflowAnalysis<'a, 'tcx, D> where
D: BitDenotation, fn propagate_bits_into_graph_successors_of(
&mut self,
in_out: &mut IdxSet<D::Idx>,
(bb, bb_data): (BasicBlock, &BasicBlockData),
dirty_list: &mut WorkQueue<BasicBlock>
)[src]
fn propagate_bits_into_graph_successors_of(
&mut self,
in_out: &mut IdxSet<D::Idx>,
(bb, bb_data): (BasicBlock, &BasicBlockData),
dirty_list: &mut WorkQueue<BasicBlock>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Propagates the bits of in_out into all the successors of bb,
using bitwise operator denoted by self.operator.
For most blocks, this is entirely uniform. However, for blocks that end with a call terminator, the effect of the call on the dataflow state may depend on whether the call returned successfully or unwound.
To reflect this, the propagate_call_return method of the
BitDenotation mutates in_out when propagating in_out via
a call terminator; such mutation is performed last, to
ensure its side-effects do not leak elsewhere (e.g. into
unwind target).
fn propagate_bits_into_entry_set_for(
&mut self,
in_out: &IdxSet<D::Idx>,
bb: BasicBlock,
dirty_queue: &mut WorkQueue<BasicBlock>
)[src]
fn propagate_bits_into_entry_set_for(
&mut self,
in_out: &IdxSet<D::Idx>,
bb: BasicBlock,
dirty_queue: &mut WorkQueue<BasicBlock>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?