[−][src]Trait rustc_mir::dataflow::Dataflow
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn build_sets(&mut self)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets up the entry, gen, and kill sets for this instance of a dataflow problem.
fn propagate(&mut self)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Finds a fixed-point solution to this instance of a dataflow problem.
Provided Methods
fn dataflow<P>(&mut self, p: P) where
P: Fn(&BD, BD::Idx) -> DebugFormatted,
P: Fn(&BD, BD::Idx) -> DebugFormatted,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets up and runs the dataflow problem, using p to render results if
implementation so chooses.
Implementors
impl<'a, 'tcx: 'a, BD> Dataflow<BD> for DataflowBuilder<'a, 'tcx, BD> where
BD: BitDenotation, [src]
impl<'a, 'tcx: 'a, BD> Dataflow<BD> for DataflowBuilder<'a, 'tcx, BD> where
BD: BitDenotation, fn dataflow<P>(&mut self, p: P) where
P: Fn(&BD, BD::Idx) -> DebugFormatted, [src]
fn dataflow<P>(&mut self, p: P) where
P: Fn(&BD, BD::Idx) -> DebugFormatted, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_sets(&mut self)[src]
fn build_sets(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn propagate(&mut self)[src]
fn propagate(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?