Enum rustc_mir::hair::pattern::_match::Constructor [−][src]
pub enum Constructor<'tcx> {
Single,
Variant(DefId),
ConstantValue(&'tcx Const<'tcx>),
ConstantRange(&'tcx Const<'tcx>, &'tcx Const<'tcx>, RangeEnd),
Slice(u64),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Single🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The constructor of all patterns that don't vary by constructor, e.g. struct patterns and fixed-length arrays.
Variant(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Enum variants.
ConstantValue(&'tcx Const<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Literal values.
ConstantRange(&'tcx Const<'tcx>, &'tcx Const<'tcx>, RangeEnd)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Ranges of literal values (2...5 and 2..5).
Slice(u64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Array patterns of length n.
Methods
impl<'tcx> Constructor<'tcx>[src]
impl<'tcx> Constructor<'tcx>fn variant_index_for_adt(&self, adt: &'tcx AdtDef) -> usize[src]
fn variant_index_for_adt(&self, adt: &'tcx AdtDef) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?