Enum rustc_mir::interpret::Place [−][src]
pub enum Place {
Ptr {
ptr: Pointer,
align: Align,
extra: PlaceExtra,
},
Local {
frame: usize,
local: Local,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Ptr🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A place referring to a value allocated in the Memory system.
Fields of Ptr
ptr: Pointer | 🔬 This is a nightly-only experimental API. ( |
align: Align | 🔬 This is a nightly-only experimental API. ( |
extra: PlaceExtra | 🔬 This is a nightly-only experimental API. ( |
Local🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A place referring to a value on the stack. Represented by a stack frame index paired with a Mir local index.
Fields of Local
frame: usize | 🔬 This is a nightly-only experimental API. ( |
local: Local | 🔬 This is a nightly-only experimental API. ( |
Methods
impl<'tcx> Place[src]
impl<'tcx> Placepub fn undef() -> Self[src]
pub fn undef() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Produces a Place that will error if attempted to be read from
pub fn from_primval_ptr(ptr: Pointer, align: Align) -> Self[src]
pub fn from_primval_ptr(ptr: Pointer, align: Align) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_ptr(ptr: MemoryPointer, align: Align) -> Self[src]
pub fn from_ptr(ptr: MemoryPointer, align: Align) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr_align_extra(self) -> (Pointer, Align, PlaceExtra)[src]
pub fn to_ptr_align_extra(self) -> (Pointer, Align, PlaceExtra)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr_align(self) -> (Pointer, Align)[src]
pub fn to_ptr_align(self) -> (Pointer, Align)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr(self) -> EvalResult<'tcx, MemoryPointer>[src]
pub fn to_ptr(self) -> EvalResult<'tcx, MemoryPointer>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn elem_ty_and_len(self, ty: Ty<'tcx>) -> (Ty<'tcx>, u64)[src]
fn elem_ty_and_len(self, ty: Ty<'tcx>) -> (Ty<'tcx>, u64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?