[−][src]Enum rustc_mir::interpret::Value
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Value represents a single immediate self-contained Rust value.
For optimization of a few very common cases, there is also a representation for a pair of
primitive values (ScalarPair). It allows Miri to avoid making allocations for checked binary
operations and fat pointers. This idea was taken from rustc's codegen.
In particular, thanks to ScalarPair, arithmetic operations and casts can be entirely
defined on Value, and do not have to work with a Place.
Variants
Scalar(ScalarMaybeUndef<Id>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ScalarPair(ScalarMaybeUndef<Id>, ScalarMaybeUndef<Id>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> Value[src]
impl<'tcx> Valuepub fn new_slice(
val: Scalar,
len: u64,
cx: impl HasDataLayout
) -> Self[src]
pub fn new_slice(
val: Scalar,
len: u64,
cx: impl HasDataLayout
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_dyn_trait(val: Scalar, vtable: Pointer) -> Self[src]
pub fn new_dyn_trait(val: Scalar, vtable: Pointer) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar_or_undef(self) -> ScalarMaybeUndef[src]
pub fn to_scalar_or_undef(self) -> ScalarMaybeUndef🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar(self) -> EvalResult<'tcx, Scalar>[src]
pub fn to_scalar(self) -> EvalResult<'tcx, Scalar>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar_pair(self) -> EvalResult<'tcx, (Scalar, Scalar)>[src]
pub fn to_scalar_pair(self) -> EvalResult<'tcx, (Scalar, Scalar)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar_ptr(self) -> EvalResult<'tcx, Scalar>[src]
pub fn to_scalar_ptr(self) -> EvalResult<'tcx, Scalar>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert the value into a pointer (or a pointer-sized integer). Throws away the second half of a ScalarPair!