[−][src]Struct rustc_mir::interpret::place::MemPlace
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ptr: Scalar<Id>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A place may have an integral pointer for ZSTs, and since it might be turned back into a reference before ever being dereferenced. However, it may never be undef.
align: Align
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
extra: Option<Scalar<Id>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Metadata for unsized places. Interpretation is up to the type.
Must not be present for sized types, but can be missing for unsized types
(e.g. extern type).
Methods
impl MemPlace[src]
impl MemPlacepub fn from_scalar_ptr(ptr: Scalar, align: Align) -> Self[src]
pub fn from_scalar_ptr(ptr: Scalar, align: Align) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_ptr(ptr: Pointer, align: Align) -> Self[src]
pub fn from_ptr(ptr: Pointer, align: Align) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_scalar_ptr_align(self) -> (Scalar, Align)[src]
pub fn to_scalar_ptr_align(self) -> (Scalar, Align)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr<'tcx>(self) -> EvalResult<'tcx, Pointer>[src]
pub fn to_ptr<'tcx>(self) -> EvalResult<'tcx, Pointer>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extract the ptr part of the mplace
pub fn to_ref(self) -> Value[src]
pub fn to_ref(self) -> Value🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Turn a mplace into a (thin or fat) pointer, as a reference, pointing to the same space.
This is the inverse of ref_to_mplace.