Struct rustc_mir::monomorphize::collector::InliningMap
[−]
[src]
pub struct InliningMap<'tcx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps every mono item to all mono items it references in its body.
Methods
impl<'tcx> InliningMap<'tcx>[src]
impl<'tcx> InliningMap<'tcx>pub fn with_inlining_candidates<F>(&self, source: MonoItem<'tcx>, f: F) where
F: FnMut(MonoItem<'tcx>), [src]
pub fn with_inlining_candidates<F>(&self, source: MonoItem<'tcx>, f: F) where
F: FnMut(MonoItem<'tcx>), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter_accesses<F>(&self, f: F) where
F: FnMut(MonoItem<'tcx>, &[MonoItem<'tcx>]), [src]
pub fn iter_accesses<F>(&self, f: F) where
F: FnMut(MonoItem<'tcx>, &[MonoItem<'tcx>]), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?