Enum rustc_mir::monomorphize::partitioning::PartitioningStrategy
[−]
[src]
pub enum PartitioningStrategy {
PerModule,
FixedUnitCount(usize),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
PerModule🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Generate one codegen unit per source-level module.
FixedUnitCount(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Partition the whole crate into a fixed number of codegen units.