Struct rustc_mir::monomorphize::partitioning::CodegenUnit [−][src]
pub struct CodegenUnit<'tcx> {
name: InternedString,
items: HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>,
size_estimate: Option<usize>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
name: InternedString
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A name for this CGU. Incremental compilation requires that name be unique amongst all crates. Therefore, it should contain something unique to this crate (e.g., a module path) as well as the crate name and disambiguator.
items: HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
size_estimate: Option<usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> CodegenUnit<'tcx>[src]
impl<'tcx> CodegenUnit<'tcx>pub fn new(name: InternedString) -> CodegenUnit<'tcx>[src]
pub fn new(name: InternedString) -> CodegenUnit<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn name(&self) -> &InternedString[src]
pub fn name(&self) -> &InternedString🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_name(&mut self, name: InternedString)[src]
pub fn set_name(&mut self, name: InternedString)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn items(
&self
) -> &HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>[src]
pub fn items(
&self
) -> &HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn items_mut(
&mut self
) -> &mut HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>[src]
pub fn items_mut(
&mut self
) -> &mut HashMap<MonoItem<'tcx>, (Linkage, Visibility), BuildHasherDefault<FxHasher>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn mangle_name(human_readable_name: &str) -> String[src]
pub fn mangle_name(human_readable_name: &str) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn estimate_size(&mut self, tcx: &TyCtxt<'a, 'tcx, 'tcx>)[src]
pub fn estimate_size(&mut self, tcx: &TyCtxt<'a, 'tcx, 'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn size_estimate(&self) -> usize[src]
pub fn size_estimate(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modify_size_estimate(&mut self, delta: usize)[src]
pub fn modify_size_estimate(&mut self, delta: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?