Struct rustc_mir::monomorphize::Instance [−][src]
pub struct Instance<'tcx> {
pub def: InstanceDef<'tcx>,
pub substs: &'tcx Slice<Kind<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
def: InstanceDef<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
substs: &'tcx Slice<Kind<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> Instance<'tcx>[src]
impl<'a, 'tcx> Instance<'tcx>pub fn ty(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> &'tcx TyS<'tcx>[src]
pub fn ty(&self, tcx: TyCtxt<'a, 'tcx, 'tcx>) -> &'tcx TyS<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'b, 'tcx> Instance<'tcx>[src]
impl<'a, 'b, 'tcx> Instance<'tcx>pub fn new(def_id: DefId, substs: &'tcx Slice<Kind<'tcx>>) -> Instance<'tcx>[src]
pub fn new(def_id: DefId, substs: &'tcx Slice<Kind<'tcx>>) -> Instance<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn mono(tcx: TyCtxt<'a, 'tcx, 'b>, def_id: DefId) -> Instance<'tcx>[src]
pub fn mono(tcx: TyCtxt<'a, 'tcx, 'b>, def_id: DefId) -> Instance<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn def_id(&self) -> DefId[src]
pub fn def_id(&self) -> DefId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn resolve(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
param_env: ParamEnv<'tcx>,
def_id: DefId,
substs: &'tcx Slice<Kind<'tcx>>
) -> Option<Instance<'tcx>>[src]
pub fn resolve(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
param_env: ParamEnv<'tcx>,
def_id: DefId,
substs: &'tcx Slice<Kind<'tcx>>
) -> Option<Instance<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Resolve a (def_id, substs) pair to an (optional) instance -- most commonly, this is used to find the precise code that will run for a trait method invocation, if known.
Returns None if we cannot resolve Instance to a specific instance.
For example, in a context like this,
fn foo<T: Debug>(t: T) { ... }
trying to resolve Debug::fmt applied to T will yield None, because we do not
know what code ought to run. (Note that this setting is also affected by the
RevealMode in the parameter environment.)
Presuming that coherence and type-check have succeeded, if this method is invoked
in a monomorphic context (i.e., like during codegen), then it is guaranteed to return
Some.
pub fn resolve_closure(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
def_id: DefId,
substs: ClosureSubsts<'tcx>,
requested_kind: ClosureKind
) -> Instance<'tcx>[src]
pub fn resolve_closure(
tcx: TyCtxt<'a, 'tcx, 'tcx>,
def_id: DefId,
substs: ClosureSubsts<'tcx>,
requested_kind: ClosureKind
) -> Instance<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?