Enum rustc_mir::transform::add_call_guards::AddCallGuards
[−]
[src]
pub enum AddCallGuards {
AllCallEdges,
CriticalCallEdges,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
AllCallEdges🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
CriticalCallEdges🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl AddCallGuards[src]
impl AddCallGuardspub fn add_call_guards(&self, mir: &mut Mir)[src]
pub fn add_call_guards(&self, mir: &mut Mir)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?