Struct rustc_mir::transform::const_prop::ConstPropagator [−][src]
struct ConstPropagator<'b, 'a, 'tcx: 'a + 'b> {
ecx: EvalContext<'a, 'b, 'tcx, CompileTimeEvaluator>,
mir: &'b Mir<'tcx>,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
source: MirSource,
places: IndexVec<Local, Option<(Value, TyLayout<'tcx>, Span)>>,
can_const_prop: IndexVec<Local, bool>,
param_env: ParamEnv<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Finds optimization opportunities on the MIR.
Fields
ecx: EvalContext<'a, 'b, 'tcx, CompileTimeEvaluator>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
mir: &'b Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
source: MirSource
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
places: IndexVec<Local, Option<(Value, TyLayout<'tcx>, Span)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
can_const_prop: IndexVec<Local, bool>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
param_env: ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'b, 'a, 'tcx: 'b> ConstPropagator<'b, 'a, 'tcx>[src]
impl<'b, 'a, 'tcx: 'b> ConstPropagator<'b, 'a, 'tcx>fn new(
mir: &'b Mir<'tcx>,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
source: MirSource
) -> ConstPropagator<'b, 'a, 'tcx>[src]
fn new(
mir: &'b Mir<'tcx>,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
source: MirSource
) -> ConstPropagator<'b, 'a, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn use_ecx<F, T>(&mut self, source_info: SourceInfo, f: F) -> Option<T> where
F: FnOnce(&mut Self) -> EvalResult<'tcx, T>, [src]
fn use_ecx<F, T>(&mut self, source_info: SourceInfo, f: F) -> Option<T> where
F: FnOnce(&mut Self) -> EvalResult<'tcx, T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn eval_constant(
&mut self,
c: &Constant<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>[src]
fn eval_constant(
&mut self,
c: &Constant<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn eval_place(
&mut self,
place: &Place<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>[src]
fn eval_place(
&mut self,
place: &Place<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn eval_operand(
&mut self,
op: &Operand<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>[src]
fn eval_operand(
&mut self,
op: &Operand<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn const_prop(
&mut self,
rvalue: &Rvalue<'tcx>,
place_layout: TyLayout<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>[src]
fn const_prop(
&mut self,
rvalue: &Rvalue<'tcx>,
place_layout: TyLayout<'tcx>,
source_info: SourceInfo
) -> Option<(Value, TyLayout<'tcx>, Span)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?