Struct rustc_mir::transform::inline::Inliner [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
source: MirSource
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> Inliner<'a, 'tcx>[src]
impl<'a, 'tcx> Inliner<'a, 'tcx>fn run_pass(&self, caller_mir: &mut Mir<'tcx>)[src]
fn run_pass(&self, caller_mir: &mut Mir<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_inline(
&self,
callsite: CallSite<'tcx>,
callee_mir: &Mir<'tcx>
) -> bool[src]
fn should_inline(
&self,
callsite: CallSite<'tcx>,
callee_mir: &Mir<'tcx>
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn inline_call(
&self,
callsite: CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>,
callee_mir: Mir<'tcx>
) -> bool[src]
fn inline_call(
&self,
callsite: CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>,
callee_mir: Mir<'tcx>
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn make_call_args(
&self,
args: Vec<Operand<'tcx>>,
callsite: &CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>
) -> Vec<Local>[src]
fn make_call_args(
&self,
args: Vec<Operand<'tcx>>,
callsite: &CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>
) -> Vec<Local>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn create_temp_if_necessary(
&self,
arg: Operand<'tcx>,
callsite: &CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>
) -> Local[src]
fn create_temp_if_necessary(
&self,
arg: Operand<'tcx>,
callsite: &CallSite<'tcx>,
caller_mir: &mut Mir<'tcx>
) -> Local🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If arg is already a temporary, returns it. Otherwise, introduces a fresh
temporary T and an instruction T = arg, and returns T.