Struct rustc_mir::transform::lower_128bit::Lower128Bit [−][src]
pub struct Lower128Bit;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Lower128Bit[src]
impl Lower128Bitfn lower_128bit_ops<'a, 'tcx>(
&self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
mir: &mut Mir<'tcx>
)[src]
fn lower_128bit_ops<'a, 'tcx>(
&self,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
mir: &mut Mir<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?