Enum rustc_mir::transform::promote_consts::TempState
[−]
[src]
pub enum TempState {
Undefined,
Defined {
location: Location,
uses: usize,
},
Unpromotable,
PromotedOut,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
State of a temporary during collection and promotion.
Variants
Undefined🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
No references to this temp.
Defined🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
One direct assignment and any number of direct uses. A borrow of this temp is promotable if the assigned value is qualified as constant.
Fields of Defined
location: Location | 🔬 This is a nightly-only experimental API. ( |
uses: usize | 🔬 This is a nightly-only experimental API. ( |
Unpromotable🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Any other combination of assignments/uses.
PromotedOut🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This temp was part of an rvalue which got extracted during promotion and needs cleanup.
Methods
impl TempState[src]
impl TempStatepub fn is_promotable(&self) -> bool[src]
pub fn is_promotable(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?