Struct rustc_mir::transform::qualify_consts::Qualif [−]
struct Qualif {
bits: u8,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bits: u8
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Qualif
impl Qualifpub const MUTABLE_INTERIOR: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
MUTABLE_INTERIOR: Qualif = Qualif{bits: 1 << 0,}
pub const NEEDS_DROP: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NEEDS_DROP: Qualif = Qualif{bits: 1 << 1,}
pub const FN_ARGUMENT: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
FN_ARGUMENT: Qualif = Qualif{bits: 1 << 2,}
pub const NOT_CONST: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NOT_CONST: Qualif = Qualif{bits: 1 << 3,}
pub const NOT_PROMOTABLE: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NOT_PROMOTABLE: Qualif = Qualif{bits: 1 << 4,}
pub const CONST_ERROR: Qualif
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
CONST_ERROR: Qualif = Qualif{bits: !<Qualif>::MUTABLE_INTERIOR.bits & !<Qualif>::NOT_PROMOTABLE.bits,}
pub fn empty() -> Qualif
pub fn empty() -> Qualif🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns an empty set of flags.
pub fn all() -> Qualif
pub fn all() -> Qualif🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the set containing all flags.
pub fn bits(&self) -> u8
pub fn bits(&self) -> u8🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<Qualif>
pub fn from_bits(bits: u8) -> Option<Qualif>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u8) -> Qualif
pub fn from_bits_truncate(bits: u8) -> Qualif🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if all flags are currently set.
pub fn intersects(&self, other: Qualif) -> bool
pub fn intersects(&self, other: Qualif) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: Qualif) -> bool
pub fn contains(&self, other: Qualif) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: Qualif)
pub fn insert(&mut self, other: Qualif)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts the specified flags in-place.
pub fn remove(&mut self, other: Qualif)
pub fn remove(&mut self, other: Qualif)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes the specified flags in-place.
pub fn toggle(&mut self, other: Qualif)
pub fn toggle(&mut self, other: Qualif)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Toggles the specified flags in-place.
pub fn set(&mut self, other: Qualif, value: bool)
pub fn set(&mut self, other: Qualif, value: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts or removes the specified flags depending on the passed value.
impl<'a, 'tcx> Qualif[src]
impl<'a, 'tcx> Qualiffn restrict(
&mut self,
ty: Ty<'tcx>,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
param_env: ParamEnv<'tcx>
)[src]
fn restrict(
&mut self,
ty: Ty<'tcx>,
tcx: TyCtxt<'a, 'tcx, 'tcx>,
param_env: ParamEnv<'tcx>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Remove flags which are impossible for the given type.