Struct rustc_mir::transform::remove_noop_landing_pads::RemoveNoopLandingPads
[−]
[src]
pub struct RemoveNoopLandingPads;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A pass that removes no-op landing pads and replaces jumps to them with
None. This is important because otherwise LLVM generates terrible
code for these.