Struct rustc_mir::transform::simplify_branches::SimplifyBranches
[−]
[src]
pub struct SimplifyBranches { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SimplifyBranches[src]
impl SimplifyBranchespub fn new(label: &str) -> Self[src]
pub fn new(label: &str) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?