Struct rustc_mir::util::def_use::DefUseAnalysis [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
info: IndexVec<Local, Info<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> DefUseAnalysis<'tcx>[src]
impl<'tcx> DefUseAnalysis<'tcx>pub fn new(mir: &Mir<'tcx>) -> DefUseAnalysis<'tcx>[src]
pub fn new(mir: &Mir<'tcx>) -> DefUseAnalysis<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn analyze(&mut self, mir: &Mir<'tcx>)[src]
pub fn analyze(&mut self, mir: &Mir<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn clear(&mut self)[src]
fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn local_info(&self, local: Local) -> &Info<'tcx>[src]
pub fn local_info(&self, local: Local) -> &Info<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mutate_defs_and_uses<F>(
&self,
local: Local,
mir: &mut Mir<'tcx>,
callback: F
) where
F: for<'a> FnMut(&'a mut Local, PlaceContext<'tcx>, Location), [src]
fn mutate_defs_and_uses<F>(
&self,
local: Local,
mir: &mut Mir<'tcx>,
callback: F
) where
F: for<'a> FnMut(&'a mut Local, PlaceContext<'tcx>, Location), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn replace_all_defs_and_uses_with(
&self,
local: Local,
mir: &mut Mir<'tcx>,
new_local: Local
)[src]
pub fn replace_all_defs_and_uses_with(
&self,
local: Local,
mir: &mut Mir<'tcx>,
new_local: Local
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
FIXME(pcwalton): This should update the def-use chains.