[−][src]Trait rustc_mir::util::elaborate_drops::DropElaborator
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Types
type Path: Copy + Debug
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn patch(&mut self) -> &mut MirPatch<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mir(&self) -> &'a Mir<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn tcx(&self) -> TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn param_env(&self) -> ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn drop_style(&self, path: Self::Path, mode: DropFlagMode) -> DropStyle
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_drop_flag(&mut self, path: Self::Path) -> Option<Operand<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn clear_drop_flag(
&mut self,
location: Location,
path: Self::Path,
mode: DropFlagMode
)
&mut self,
location: Location,
path: Self::Path,
mode: DropFlagMode
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn field_subpath(&self, path: Self::Path, field: Field) -> Option<Self::Path>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn deref_subpath(&self, path: Self::Path) -> Option<Self::Path>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn downcast_subpath(
&self,
path: Self::Path,
variant: usize
) -> Option<Self::Path>
&self,
path: Self::Path,
variant: usize
) -> Option<Self::Path>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn array_subpath(
&self,
path: Self::Path,
index: u32,
size: u32
) -> Option<Self::Path>
&self,
path: Self::Path,
index: u32,
size: u32
) -> Option<Self::Path>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<'a, 'b, 'tcx> DropElaborator<'a, 'tcx> for Elaborator<'a, 'b, 'tcx>[src]
impl<'a, 'b, 'tcx> DropElaborator<'a, 'tcx> for Elaborator<'a, 'b, 'tcx>type Path = MovePathIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn patch(&mut self) -> &mut MirPatch<'tcx>[src]
fn patch(&mut self) -> &mut MirPatch<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mir(&self) -> &'a Mir<'tcx>[src]
fn mir(&self) -> &'a Mir<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn tcx(&self) -> TyCtxt<'a, 'tcx, 'tcx>[src]
fn tcx(&self) -> TyCtxt<'a, 'tcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn param_env(&self) -> ParamEnv<'tcx>[src]
fn param_env(&self) -> ParamEnv<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn drop_style(&self, path: Self::Path, mode: DropFlagMode) -> DropStyle[src]
fn drop_style(&self, path: Self::Path, mode: DropFlagMode) -> DropStyle🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn clear_drop_flag(
&mut self,
loc: Location,
path: Self::Path,
mode: DropFlagMode
)[src]
fn clear_drop_flag(
&mut self,
loc: Location,
path: Self::Path,
mode: DropFlagMode
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn field_subpath(&self, path: Self::Path, field: Field) -> Option<Self::Path>[src]
fn field_subpath(&self, path: Self::Path, field: Field) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn array_subpath(
&self,
path: Self::Path,
index: u32,
size: u32
) -> Option<Self::Path>[src]
fn array_subpath(
&self,
path: Self::Path,
index: u32,
size: u32
) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn deref_subpath(&self, path: Self::Path) -> Option<Self::Path>[src]
fn deref_subpath(&self, path: Self::Path) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn downcast_subpath(
&self,
path: Self::Path,
variant: usize
) -> Option<Self::Path>[src]
fn downcast_subpath(
&self,
path: Self::Path,
variant: usize
) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_drop_flag(&mut self, path: Self::Path) -> Option<Operand<'tcx>>[src]
fn get_drop_flag(&mut self, path: Self::Path) -> Option<Operand<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx> DropElaborator<'a, 'tcx> for DropShimElaborator<'a, 'tcx>[src]
impl<'a, 'tcx> DropElaborator<'a, 'tcx> for DropShimElaborator<'a, 'tcx>type Path = ()
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn patch(&mut self) -> &mut MirPatch<'tcx>[src]
fn patch(&mut self) -> &mut MirPatch<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn mir(&self) -> &'a Mir<'tcx>[src]
fn mir(&self) -> &'a Mir<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn tcx(&self) -> TyCtxt<'a, 'tcx, 'tcx>[src]
fn tcx(&self) -> TyCtxt<'a, 'tcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn param_env(&self) -> ParamEnv<'tcx>[src]
fn param_env(&self) -> ParamEnv<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn drop_style(&self, _path: Self::Path, mode: DropFlagMode) -> DropStyle[src]
fn drop_style(&self, _path: Self::Path, mode: DropFlagMode) -> DropStyle🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_drop_flag(&mut self, _path: Self::Path) -> Option<Operand<'tcx>>[src]
fn get_drop_flag(&mut self, _path: Self::Path) -> Option<Operand<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn clear_drop_flag(
&mut self,
_location: Location,
_path: Self::Path,
_mode: DropFlagMode
)[src]
fn clear_drop_flag(
&mut self,
_location: Location,
_path: Self::Path,
_mode: DropFlagMode
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn field_subpath(&self, _path: Self::Path, _field: Field) -> Option<Self::Path>[src]
fn field_subpath(&self, _path: Self::Path, _field: Field) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn deref_subpath(&self, _path: Self::Path) -> Option<Self::Path>[src]
fn deref_subpath(&self, _path: Self::Path) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn downcast_subpath(
&self,
_path: Self::Path,
_variant: usize
) -> Option<Self::Path>[src]
fn downcast_subpath(
&self,
_path: Self::Path,
_variant: usize
) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn array_subpath(
&self,
_path: Self::Path,
_index: u32,
_size: u32
) -> Option<Self::Path>[src]
fn array_subpath(
&self,
_path: Self::Path,
_index: u32,
_size: u32
) -> Option<Self::Path>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?