Enum rustc_mir::util::PassWhere [−][src]
pub enum PassWhere {
BeforeCFG,
AfterCFG,
BeforeBlock(BasicBlock),
BeforeLocation(Location),
AfterLocation(Location),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An indication of where we are in the control flow graph. Used for printing
extra information in dump_mir
Variants
BeforeCFG🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We have not started dumping the control flow graph, but we are about to.
AfterCFG🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We just finished dumping the control flow graph. This is right before EOF
BeforeBlock(BasicBlock)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We are about to start dumping the given basic block.
BeforeLocation(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We are just about to dump the given statement or terminator.
AfterLocation(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We just dumped the given statement or terminator.