Function rustc_mir::util::dump_mir
[−]
[src]
pub fn dump_mir<'a, 'gcx, 'tcx, F>(
tcx: TyCtxt<'a, 'gcx, 'tcx>,
pass_num: Option<&Display>,
pass_name: &str,
disambiguator: &Display,
source: MirSource,
mir: &Mir<'tcx>,
extra_data: F
) where
F: FnMut(PassWhere, &mut Write) -> Result<()>,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the session is properly configured, dumps a human-readable representation of the mir into:
rustc.node<node_id>.<pass_num>.<pass_name>.<disambiguator>
Output from this function is controlled by passing -Z dump-mir=<filter>,
where <filter> takes the following forms:
all-- dump MIR for all fns, all passes, all everything- a filter defined by a set of substrings combined with
&and|(&has higher precedence). At least one of the|-separated groups must match; an|-separated group matches if all of its&-separated substrings are matched.
Example:
nll== match ifnllappears in the namefoo & nll== match iffooandnllboth appear in the namefoo & nll | typeck== match iffooandnllboth appear in the name ortypeckappears in the name.foo & nll | bar & typeck== match iffooandnllboth appear in the name ortypeckandbarboth appear in the name.