Struct rustc_mir::util::liveness::DefsUsesVisitor [−][src]
struct DefsUsesVisitor<'lv, V, M> where
V: Idx,
M: LiveVariableMap<LiveVar = V> + 'lv, { mode: LivenessMode, map: &'lv M, defs_uses: DefsUses<V>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
mode: LivenessMode
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
map: &'lv M
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
defs_uses: DefsUses<V>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'lv, V, M> DefsUsesVisitor<'lv, V, M> where
V: Idx,
M: LiveVariableMap<LiveVar = V>, [src]
impl<'lv, V, M> DefsUsesVisitor<'lv, V, M> where
V: Idx,
M: LiveVariableMap<LiveVar = V>, fn update_bits_and_do_callback<'tcx, OP>(
&mut self,
location: Location,
value: &impl MirVisitable<'tcx>,
bits: &mut LiveVarSet<V>,
callback: &mut OP
) where
OP: FnMut(Location, &LiveVarSet<V>), [src]
fn update_bits_and_do_callback<'tcx, OP>(
&mut self,
location: Location,
value: &impl MirVisitable<'tcx>,
bits: &mut LiveVarSet<V>,
callback: &mut OP
) where
OP: FnMut(Location, &LiveVarSet<V>), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Update bits with the effects of value and call callback. We
should always visit in reverse order. This method assumes that we have
not visited anything before; if you have, clear bits first.