Struct rustc_mir::util::liveness::LivenessMode [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
include_regular_use: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If true, then we will consider "regular uses" of a variable to be live.
For example, if the user writes foo(x), then this is a regular use of
the variable x.
include_drops: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If true, then we will consider (implicit) drops of a variable
to be live. For example, if the user writes { let x = vec![...]; .. }, then the drop at the end of the block is an
implicit drop.
NB. Despite its name, a call like ::std::mem::drop(x) is
not considered a drop for this purposes, but rather a
regular use.