[−][src]Struct rustc_mir::util::liveness::LivenessResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This gives the result of the liveness analysis at the boundary of basic blocks.
The V type defines the set of variables that we computed
liveness for. This is often Local, in which case we computed
liveness for all variables -- but it can also be some other type,
which indicates a subset of the variables within the graph.
Fields
outs: IndexVec<BasicBlock, LiveVarSet<V>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Live variables on exit to each basic block. This is equal to
the union of the ins for each successor.