Struct rustc_passes::ast_validation::AstValidator [−][src]
struct AstValidator<'a> {
session: &'a Session,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
session: &'a Session
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> AstValidator<'a>[src]
impl<'a> AstValidator<'a>fn err_handler(&self) -> &Handler[src]
fn err_handler(&self) -> &Handler🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_lifetime(&self, ident: Ident)[src]
fn check_lifetime(&self, ident: Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_label(&self, ident: Ident)[src]
fn check_label(&self, ident: Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn invalid_non_exhaustive_attribute(&self, variant: &Variant)[src]
fn invalid_non_exhaustive_attribute(&self, variant: &Variant)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn invalid_visibility(&self, vis: &Visibility, note: Option<&str>)[src]
fn invalid_visibility(&self, vis: &Visibility, note: Option<&str>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_decl_no_pat<ReportFn: Fn(Span, bool)>(
&self,
decl: &FnDecl,
report_err: ReportFn
)[src]
fn check_decl_no_pat<ReportFn: Fn(Span, bool)>(
&self,
decl: &FnDecl,
report_err: ReportFn
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_trait_fn_not_const(&self, constness: Spanned<Constness>)[src]
fn check_trait_fn_not_const(&self, constness: Spanned<Constness>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn no_questions_in_bounds(
&self,
bounds: &TyParamBounds,
where_: &str,
is_trait: bool
)[src]
fn no_questions_in_bounds(
&self,
bounds: &TyParamBounds,
where_: &str,
is_trait: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_expr_within_pat(&self, expr: &Expr, allow_paths: bool)[src]
fn check_expr_within_pat(&self, expr: &Expr, allow_paths: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
matches '-' lit | lit (cf. parser::Parser::parse_literal_maybe_minus), or path for ranges.
FIXME: do we want to allow expr -> pattern conversion to create path expressions? That means making this work:
struct S;
macro_rules! m {
($a:expr) => {
let $a = S;
}
}
m!(S);
fn check_late_bound_lifetime_defs(&self, params: &Vec<GenericParam>)[src]
fn check_late_bound_lifetime_defs(&self, params: &Vec<GenericParam>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?