Struct rustc_passes::hir_stats::StatCollector [−][src]
struct StatCollector<'k> {
krate: Option<&'k Crate>,
data: FxHashMap<&'static str, NodeData>,
seen: FxHashSet<Id>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
krate: Option<&'k Crate>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
data: FxHashMap<&'static str, NodeData>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
seen: FxHashSet<Id>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'k> StatCollector<'k>[src]
impl<'k> StatCollector<'k>fn record<T>(&mut self, label: &'static str, id: Id, node: &T)[src]
fn record<T>(&mut self, label: &'static str, id: Id, node: &T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn print(&self, title: &str)[src]
fn print(&self, title: &str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?