Struct rustc_plugin::load::PluginLoader [−][src]
struct PluginLoader<'a> {
sess: &'a Session,
reader: CrateLoader<'a>,
plugins: Vec<PluginRegistrar>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
sess: &'a Session
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
reader: CrateLoader<'a>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
plugins: Vec<PluginRegistrar>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> PluginLoader<'a>[src]
impl<'a> PluginLoader<'a>fn new(sess: &'a Session, cstore: &'a CStore, crate_name: &str) -> Self[src]
fn new(sess: &'a Session, cstore: &'a CStore, crate_name: &str) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn load_plugin(&mut self, span: Span, name: &str, args: Vec<NestedMetaItem>)[src]
fn load_plugin(&mut self, span: Span, name: &str, args: Vec<NestedMetaItem>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn dylink_registrar(
&mut self,
span: Span,
path: PathBuf,
symbol: String
) -> PluginRegistrarFun[src]
fn dylink_registrar(
&mut self,
span: Span,
path: PathBuf,
symbol: String
) -> PluginRegistrarFun🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?