Struct rustc_plugin::load::PluginRegistrar [−][src]
pub struct PluginRegistrar {
pub fun: PluginRegistrarFun,
pub args: Vec<NestedMetaItem>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
fun: PluginRegistrarFun
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
args: Vec<NestedMetaItem>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?