Enum rustc_resolve::CrateLint [−][src]
enum CrateLint {
No,
SimplePath(NodeId),
UsePath {
root_id: NodeId,
root_span: Span,
},
QPathTrait {
qpath_id: NodeId,
qpath_span: Span,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
No🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Do not issue the lint
SimplePath(NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This lint applies to some random path like impl ::foo::Bar
or whatever. In this case, we can take the span of that path.
UsePath🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This lint comes from a use statement. In this case, what we
care about really is the root use statement; e.g., if we
have nested things like use a::{b, c}, we care about the
use a part.
Fields of UsePath
root_id: NodeId | 🔬 This is a nightly-only experimental API. ( |
root_span: Span | 🔬 This is a nightly-only experimental API. ( |
QPathTrait🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is the "trait item" from a fully qualified path. For example,
we might be resolving X::Y::Z from a path like <T as X::Y>::Z.
The path_span is the span of the to the trait itself (X::Y).
Fields of QPathTrait
qpath_id: NodeId | 🔬 This is a nightly-only experimental API. ( |
qpath_span: Span | 🔬 This is a nightly-only experimental API. ( |
Methods
impl CrateLint[src]
impl CrateLintfn node_id(&self) -> Option<NodeId>[src]
fn node_id(&self) -> Option<NodeId>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?