Enum rustc_resolve::LexicalScopeBinding [−][src]
enum LexicalScopeBinding<'a> {
Item(&'a NameBinding<'a>),
Def(Def),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An intermediate resolution result.
This refers to the thing referred by a name. The difference between Def and Item is that
items are visible in their whole block, while defs only from the place they are defined
forward.
Variants
Item(&'a NameBinding<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Def(Def)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> LexicalScopeBinding<'a>[src]
impl<'a> LexicalScopeBinding<'a>fn item(self) -> Option<&'a NameBinding<'a>>[src]
fn item(self) -> Option<&'a NameBinding<'a>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn def(self) -> Def[src]
fn def(self) -> Def🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?