[−][src]Enum rustc_resolve::ModuleKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Block(NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An anonymous module, eg. just a block.
fn main() { fn f() {} // (1) { // This is an anonymous module f(); // This resolves to (2) as we are inside the block. fn f() {} // (2) } f(); // Resolves to (1) }
Def(Def, Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Any module with a name.
This could be:
- A normal module ‒ either
mod from_file;ormod from_block { }. - A trait or an enum (it implicitly contains associated types, methods and variant constructors).