Struct rustc_resolve::macros::InvocationData [−][src]
pub struct InvocationData<'a> {
pub module: Cell<&'a ModuleData<'a>>,
pub def_index: DefIndex,
pub const_expr: bool,
pub legacy_scope: Cell<LegacyScope<'a>>,
pub expansion: Cell<LegacyScope<'a>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
module: Cell<&'a ModuleData<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def_index: DefIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
const_expr: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
legacy_scope: Cell<LegacyScope<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
expansion: Cell<LegacyScope<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> InvocationData<'a>[src]
impl<'a> InvocationData<'a>pub fn root(graph_root: &'a ModuleData<'a>) -> Self[src]
pub fn root(graph_root: &'a ModuleData<'a>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?