Enum rustc_resolve::resolve_imports::ImportDirectiveSubclass [−][src]
pub enum ImportDirectiveSubclass<'a> {
SingleImport {
target: Ident,
source: Ident,
result: PerNS<Cell<Result<&'a NameBinding<'a>, Determinacy>>>,
type_ns_only: bool,
},
GlobImport {
is_prelude: bool,
max_vis: Cell<Visibility>,
},
ExternCrate(Option<Name>),
MacroUse,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contains data for specific types of import directives.
Variants
SingleImport🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of SingleImport
target: Ident | 🔬 This is a nightly-only experimental API. ( |
source: Ident | 🔬 This is a nightly-only experimental API. ( |
result: PerNS<Cell<Result<&'a NameBinding<'a>, Determinacy>>> | 🔬 This is a nightly-only experimental API. ( |
type_ns_only: bool | 🔬 This is a nightly-only experimental API. ( |
GlobImport🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of GlobImport
is_prelude: bool | 🔬 This is a nightly-only experimental API. ( |
max_vis: Cell<Visibility> | 🔬 This is a nightly-only experimental API. ( |
ExternCrate(Option<Name>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
MacroUse🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?