Enum rustc_resolve::resolve_imports::SingleImports [−][src]
enum SingleImports<'a> {
None,
MaybeOne(&'a ImportDirective<'a>),
MaybeTwo(&'a ImportDirective<'a>, &'a ImportDirective<'a>),
AtLeastOne,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
None🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
No single imports can define the name in the namespace.
MaybeOne(&'a ImportDirective<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Only the given single import can define the name in the namespace.
MaybeTwo(&'a ImportDirective<'a>, &'a ImportDirective<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Only one of these two single imports can define the name in the namespace.
AtLeastOne🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
At least one single import will define the name in the namespace.
Methods
impl<'a> SingleImports<'a>[src]
impl<'a> SingleImports<'a>fn add_directive(
&mut self,
directive: &'a ImportDirective<'a>,
use_extern_macros: bool
)[src]
fn add_directive(
&mut self,
directive: &'a ImportDirective<'a>,
use_extern_macros: bool
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn directive_failed(&mut self, dir: &'a ImportDirective<'a>)[src]
fn directive_failed(&mut self, dir: &'a ImportDirective<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?