Struct rustc_resolve::resolve_imports::NameResolution [−][src]
pub struct NameResolution<'a> {
single_imports: SingleImports<'a>,
pub binding: Option<&'a NameBinding<'a>>,
shadows_glob: Option<&'a NameBinding<'a>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Records information about the resolution of a name in a namespace of a module.
Fields
single_imports: SingleImports<'a>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The single imports that define the name in the namespace.
binding: Option<&'a NameBinding<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The least shadowable known binding for this name, or None if there are no known bindings.
shadows_glob: Option<&'a NameBinding<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> NameResolution<'a>[src]
impl<'a> NameResolution<'a>fn binding(&self) -> Option<&'a NameBinding<'a>>[src]
fn binding(&self) -> Option<&'a NameBinding<'a>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?