Struct rustc_resolve::ImportSuggestion [−][src]
struct ImportSuggestion {
path: Path,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A free importable items suggested in case of resolution failure.
Fields
path: Path
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?