Struct rustc_resolve::PrimitiveTypeTable [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Interns the names of the primitive types.
All other types are defined somewhere and possibly imported, but the primitive ones need special handling, since they have no place of origin.
Fields
primitive_types: FxHashMap<Name, PrimTy>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl PrimitiveTypeTable[src]
impl PrimitiveTypeTablefn new() -> PrimitiveTypeTable[src]
fn new() -> PrimitiveTypeTable🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn intern(&mut self, string: &str, primitive_type: PrimTy)[src]
fn intern(&mut self, string: &str, primitive_type: PrimTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?