[−][src]Trait rustc_save_analysis::sig::Sig
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn make(
&self,
offset: usize,
id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>
&self,
offset: usize,
id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl Sig for Ty[src]
impl Sig for Tyfn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for Item[src]
impl Sig for Itemfn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for Path[src]
impl Sig for Pathfn make(
&self,
offset: usize,
id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for Generics[src]
impl Sig for Genericsfn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for StructField[src]
impl Sig for StructFieldfn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for Variant_[src]
impl Sig for Variant_fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Sig for ForeignItem[src]
impl Sig for ForeignItemfn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>[src]
fn make(
&self,
offset: usize,
_parent_id: Option<NodeId>,
scx: &SaveContext
) -> Result<Signature, &'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?