Struct rustc_save_analysis::SaveContext [−][src]
pub struct SaveContext<'l, 'tcx: 'l> {
tcx: TyCtxt<'l, 'tcx, 'tcx>,
tables: &'l TypeckTables<'tcx>,
analysis: &'l CrateAnalysis,
span_utils: SpanUtils<'tcx>,
config: Config,
impl_counter: Cell<u32>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'l, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tables: &'l TypeckTables<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
analysis: &'l CrateAnalysis
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span_utils: SpanUtils<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
config: Config
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl_counter: Cell<u32>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'l, 'tcx: 'l> SaveContext<'l, 'tcx>[src]
impl<'l, 'tcx: 'l> SaveContext<'l, 'tcx>fn span_from_span(&self, span: Span) -> SpanData[src]
fn span_from_span(&self, span: Span) -> SpanData🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_external_crates(&self) -> Vec<ExternalCrateData>[src]
pub fn get_external_crates(&self) -> Vec<ExternalCrateData>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_extern_item_data(&self, item: &ForeignItem) -> Option<Data>[src]
pub fn get_extern_item_data(&self, item: &ForeignItem) -> Option<Data>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_item_data(&self, item: &Item) -> Option<Data>[src]
pub fn get_item_data(&self, item: &Item) -> Option<Data>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_field_data(&self, field: &StructField, scope: NodeId) -> Option<Def>[src]
pub fn get_field_data(&self, field: &StructField, scope: NodeId) -> Option<Def>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_method_data(&self, id: NodeId, name: Name, span: Span) -> Option<Def>[src]
pub fn get_method_data(&self, id: NodeId, name: Name, span: Span) -> Option<Def>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_trait_ref_data(&self, trait_ref: &TraitRef) -> Option<Ref>[src]
pub fn get_trait_ref_data(&self, trait_ref: &TraitRef) -> Option<Ref>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_expr_data(&self, expr: &Expr) -> Option<Data>[src]
pub fn get_expr_data(&self, expr: &Expr) -> Option<Data>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_path_def(&self, id: NodeId) -> HirDef[src]
pub fn get_path_def(&self, id: NodeId) -> HirDef🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_path_data(&self, id: NodeId, path: &Path) -> Option<Ref>[src]
pub fn get_path_data(&self, id: NodeId, path: &Path) -> Option<Ref>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_field_ref_data(
&self,
field_ref: &Field,
variant: &VariantDef
) -> Option<Ref>[src]
pub fn get_field_ref_data(
&self,
field_ref: &Field,
variant: &VariantDef
) -> Option<Ref>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_macro_use_data(&self, span: Span) -> Option<MacroRef>[src]
pub fn get_macro_use_data(&self, span: Span) -> Option<MacroRef>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Attempt to return MacroRef for any AST node.
For a given piece of AST defined by the supplied Span and NodeId, returns None if the node is not macro-generated or the span is malformed, else uses the expansion callsite and callee to return some MacroRef.
fn lookup_ref_id(&self, ref_id: NodeId) -> Option<DefId>[src]
fn lookup_ref_id(&self, ref_id: NodeId) -> Option<DefId>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn docs_for_attrs(&self, attrs: &[Attribute]) -> String[src]
fn docs_for_attrs(&self, attrs: &[Attribute]) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn next_impl_id(&self) -> u32[src]
fn next_impl_id(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?