[−][src]Struct rustc_target::abi::Scalar
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Information about one scalar component of a Rust type.
Fields
value: Primitive
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
valid_range: RangeInclusive<u128>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inclusive wrap-around range of valid values, that is, if
start > end, it represents start..=max_value(),
followed by 0..=end.
That is, for an i8 primitive, a range of 254..=2 means following
sequence:
254 (-2), 255 (-1), 0, 1, 2
This is intended specifically to mirror LLVM’s !range metadata,
semantics.
Methods
impl Scalar[src]
impl Scalarpub fn is_bool(&self) -> bool[src]
pub fn is_bool(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn valid_range_exclusive<C: HasDataLayout>(&self, cx: C) -> Range<u128>[src]
pub fn valid_range_exclusive<C: HasDataLayout>(&self, cx: C) -> Range<u128>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the valid range as a x..y range.
If x and y are equal, the range is full, not empty.