[−][src]Trait rustc_target::abi::HasDataLayout
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn data_layout(&self) -> &TargetDataLayout
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<'a> HasDataLayout for &'a TargetDataLayout[src]
impl<'a> HasDataLayout for &'a TargetDataLayoutfn data_layout(&self) -> &TargetDataLayout[src]
fn data_layout(&self) -> &TargetDataLayout🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?