Trait rustc_traits::lowering::IntoFromEnvGoal [−][src]
trait IntoFromEnvGoal {
fn into_from_env_goal(self) -> Self;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Transforms an existing goal into a FromEnv goal.
Used for lowered where clauses (see rustc guide).
Required Methods
fn into_from_env_goal(self) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<'tcx> IntoFromEnvGoal for DomainGoal<'tcx>[src]
impl<'tcx> IntoFromEnvGoal for DomainGoal<'tcx>fn into_from_env_goal(self) -> DomainGoal<'tcx>[src]
fn into_from_env_goal(self) -> DomainGoal<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?