[−][src]Trait rustc_traits::lowering::IntoWellFormedGoal
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used for well-formedness related rules (see rustc guide).
Required Methods
fn into_well_formed_goal(self) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Transforms an existing goal into a WellFormed goal.
Implementations on Foreign Types
impl<'tcx> IntoWellFormedGoal for DomainGoal<'tcx>[src]
impl<'tcx> IntoWellFormedGoal for DomainGoal<'tcx>fn into_well_formed_goal(self) -> DomainGoal<'tcx>[src]
fn into_well_formed_goal(self) -> DomainGoal<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?