Enum rustc_trans::middle::ty::BorrowKindExperimental
[-]
[+]
[src]
pub enum BorrowKind {
ImmBorrow,
UniqueImmBorrow,
MutBorrow,
}Variants
Methods
impl BorrowKind
fn from_mutbl(m: Mutability) -> BorrowKind
fn to_mutbl_lossy(self) -> Mutability
Returns a mutability m such that an &m T pointer could be used to obtain this borrow
kind. Because borrow kinds are richer than mutabilities, we sometimes have to pick a
mutability that is stronger than necessary so that it at least would permit the borrow in
question.