Struct rustc_trans::middle::ty::CrateAnalysisExperimental
[-]
[+]
[src]
pub struct CrateAnalysis<'tcx> {
pub export_map: HashMap<u32, Vec<Export>, FnvHasher>,
pub exported_items: HashSet<u32, FnvHasher>,
pub public_items: HashSet<u32, FnvHasher>,
pub ty_cx: ctxt<'tcx>,
pub reachable: HashSet<u32, FnvHasher>,
pub name: String,
pub glob_map: Option<HashMap<u32, HashSet<Name, RandomSipHasher>, RandomSipHasher>>,
}The complete set of all analyses described in this module. This is produced by the driver and fed to trans and later passes.
Fields
export_map | |
exported_items | |
public_items | |
ty_cx | |
reachable | |
name | |
glob_map |