Struct rustc_trans::middle::ty::ItemSubstsExperimental
[-]
[+]
[src]
pub struct ItemSubsts<'tcx> {
pub substs: Substs<'tcx>,
}Records the substitutions used to translate the polytype for an item into the monotype of an item reference.
Fields
substs |