Struct rustc_trans::middle::ty::ParamBoundsExperimental
[-]
[+]
[src]
pub struct ParamBounds<'tcx> {
pub region_bounds: Vec<Region>,
pub builtin_bounds: EnumSet<BuiltinBound>,
pub trait_bounds: Vec<Binder<Rc<TraitRef<'tcx>>>>,
pub projection_bounds: Vec<Binder<ProjectionPredicate<'tcx>>>,
}Bounds suitable for a named type parameter like A in fn foo<A>
as well as the existential type parameter in an object type.
Fields
region_bounds | |
builtin_bounds | |
trait_bounds | |
projection_bounds |