Struct rustc_typeck::astconv::Bounds [−][src]
pub struct Bounds<'tcx> {
pub region_bounds: Vec<Region<'tcx>>,
pub implicitly_sized: bool,
pub trait_bounds: Vec<PolyTraitRef<'tcx>>,
pub projection_bounds: Vec<PolyProjectionPredicate<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
region_bounds: Vec<Region<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
implicitly_sized: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trait_bounds: Vec<PolyTraitRef<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
projection_bounds: Vec<PolyProjectionPredicate<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> Bounds<'tcx>[src]
impl<'a, 'gcx, 'tcx> Bounds<'tcx>pub fn predicates(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
param_ty: Ty<'tcx>
) -> Vec<Predicate<'tcx>>[src]
pub fn predicates(
&self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
param_ty: Ty<'tcx>
) -> Vec<Predicate<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?