Enum rustc_typeck::check::Expectation [−][src]
pub enum Expectation<'tcx> {
NoExpectation,
ExpectIfCondition,
ExpectHasType(Ty<'tcx>),
ExpectCastableToType(Ty<'tcx>),
ExpectRvalueLikeUnsized(Ty<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When type-checking an expression, we propagate downward
whatever type hint we are able in the form of an Expectation.
Variants
NoExpectation🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We know nothing about what type this expression should have.
ExpectIfCondition🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This expression is an if condition, it must resolve to bool.
ExpectHasType(Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This expression should have the type given (or some subtype)
ExpectCastableToType(Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This expression will be cast to the Ty
ExpectRvalueLikeUnsized(Ty<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This rvalue expression will be wrapped in & or Box and coerced
to &Ty or Box<Ty>, respectively. Ty is [A] or Trait.
Methods
impl<'a, 'gcx, 'tcx> Expectation<'tcx>[src]
impl<'a, 'gcx, 'tcx> Expectation<'tcx>fn adjust_for_branches(&self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Expectation<'tcx>[src]
fn adjust_for_branches(&self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Expectation<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn rvalue_hint(fcx: &FnCtxt<'a, 'gcx, 'tcx>, ty: Ty<'tcx>) -> Expectation<'tcx>[src]
fn rvalue_hint(fcx: &FnCtxt<'a, 'gcx, 'tcx>, ty: Ty<'tcx>) -> Expectation<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provide an expectation for an rvalue expression given an optional
hint, which is not required for type safety (the resulting type might
be checked higher up, as is the case with &expr and box expr), but
is useful in determining the concrete type.
The primary use case is where the expected type is a fat pointer,
like &[isize]. For example, consider the following statement:
let x: &[isize] = &[1, 2, 3];
In this case, the expected type for the &[1, 2, 3] expression is
&[isize]. If however we were to say that [1, 2, 3] has the
expectation ExpectHasType([isize]), that would be too strong --
[1, 2, 3] does not have the type [isize] but rather [isize; 3].
It is only the &[1, 2, 3] expression as a whole that can be coerced
to the type &[isize]. Therefore, we propagate this more limited hint,
which still is useful, because it informs integer literals and the like.
See the test case test/run-pass/coerce-expect-unsized.rs and #20169
for examples of where this comes up,.
fn resolve(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Expectation<'tcx>[src]
fn resolve(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Expectation<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_option(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Option<Ty<'tcx>>[src]
fn to_option(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Option<Ty<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn only_has_type(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Option<Ty<'tcx>>[src]
fn only_has_type(self, fcx: &FnCtxt<'a, 'gcx, 'tcx>) -> Option<Ty<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
It sometimes happens that we want to turn an expectation into
a hard constraint (i.e., something that must be satisfied
for the program to type-check). only_has_type will return
such a constraint, if it exists.
fn coercion_target_type(
self,
fcx: &FnCtxt<'a, 'gcx, 'tcx>,
span: Span
) -> Ty<'tcx>[src]
fn coercion_target_type(
self,
fcx: &FnCtxt<'a, 'gcx, 'tcx>,
span: Span
) -> Ty<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Like only_has_type, but instead of returning None if no
hard constraint exists, creates a fresh type variable.