Enum rustc_typeck::check::TupleArgumentsFlag [−][src]
enum TupleArgumentsFlag {
DontTupleArguments,
TupleArguments,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Controls whether the arguments are tupled. This is used for the call operator.
Tupling means that all call-side arguments are packed into a tuple and passed as a single parameter. For example, if tupling is enabled, this function:
fn f(x: (isize, isize))
Can be called as:
f(1, 2);
Instead of:
f((1, 2));
Variants
DontTupleArguments🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TupleArguments🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?