Enum rustc_typeck::check::method::probe::CandidateKind [−][src]
enum CandidateKind<'tcx> {
InherentImplCandidate(&'tcx Substs<'tcx>, Vec<PredicateObligation<'tcx>>),
ObjectCandidate,
TraitCandidate(TraitRef<'tcx>),
WhereClauseCandidate(PolyTraitRef<'tcx>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
InherentImplCandidate(&'tcx Substs<'tcx>, Vec<PredicateObligation<'tcx>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ObjectCandidate🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TraitCandidate(TraitRef<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
WhereClauseCandidate(PolyTraitRef<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?