Struct rustc_typeck::check::method::probe::IsSuggestion [−][src]
pub struct IsSuggestion(pub bool);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Boolean flag used to indicate if this search is for a suggestion or not. If true, we can allow ambiguity and so forth.