Struct rustc_typeck::check::EnclosingBreakables [−][src]
pub struct EnclosingBreakables<'gcx: 'tcx, 'tcx> {
stack: Vec<BreakableCtxt<'gcx, 'tcx>>,
by_id: NodeMap<usize>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
stack: Vec<BreakableCtxt<'gcx, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
by_id: NodeMap<usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'gcx, 'tcx> EnclosingBreakables<'gcx, 'tcx>[src]
impl<'gcx, 'tcx> EnclosingBreakables<'gcx, 'tcx>fn find_breakable(
&mut self,
target_id: NodeId
) -> &mut BreakableCtxt<'gcx, 'tcx>[src]
fn find_breakable(
&mut self,
target_id: NodeId
) -> &mut BreakableCtxt<'gcx, 'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?