Struct rustc_typeck::check::MaybeInProgressTables [−][src]
struct MaybeInProgressTables<'a, 'tcx: 'a> {
maybe_tables: Option<&'a RefCell<TypeckTables<'tcx>>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A wrapper for InferCtxt's in_progress_tables field.
Fields
maybe_tables: Option<&'a RefCell<TypeckTables<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> MaybeInProgressTables<'a, 'tcx>[src]
impl<'a, 'tcx> MaybeInProgressTables<'a, 'tcx>fn borrow(self) -> Ref<'a, TypeckTables<'tcx>>[src]
fn borrow(self) -> Ref<'a, TypeckTables<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn borrow_mut(self) -> RefMut<'a, TypeckTables<'tcx>>[src]
fn borrow_mut(self) -> RefMut<'a, TypeckTables<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?