[−][src]Struct rustc_typeck::check::upvar::InferBorrowKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
fcx: &'a FnCtxt<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
closure_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
current_closure_kind: ClosureKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
current_origin: Option<(Span, Name)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
adjust_upvar_captures: UpvarCaptureMap<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'gcx, 'tcx> InferBorrowKind<'a, 'gcx, 'tcx>[src]
impl<'a, 'gcx, 'tcx> InferBorrowKind<'a, 'gcx, 'tcx>fn adjust_upvar_borrow_kind_for_consume(
&mut self,
cmt: &cmt_<'tcx>,
mode: ConsumeMode
)[src]
fn adjust_upvar_borrow_kind_for_consume(
&mut self,
cmt: &cmt_<'tcx>,
mode: ConsumeMode
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn adjust_upvar_borrow_kind_for_mut(&mut self, cmt: &cmt_<'tcx>)[src]
fn adjust_upvar_borrow_kind_for_mut(&mut self, cmt: &cmt_<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates that cmt is being directly mutated (e.g., assigned
to). If cmt contains any by-ref upvars, this implies that
those upvars must be borrowed using an &mut borrow.
fn adjust_upvar_borrow_kind_for_unique(&mut self, cmt: &cmt_<'tcx>)[src]
fn adjust_upvar_borrow_kind_for_unique(&mut self, cmt: &cmt_<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn try_adjust_upvar_deref(
&mut self,
cmt: &cmt_<'tcx>,
borrow_kind: BorrowKind
) -> bool[src]
fn try_adjust_upvar_deref(
&mut self,
cmt: &cmt_<'tcx>,
borrow_kind: BorrowKind
) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn adjust_upvar_borrow_kind(&mut self, upvar_id: UpvarId, kind: BorrowKind)[src]
fn adjust_upvar_borrow_kind(&mut self, upvar_id: UpvarId, kind: BorrowKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
We infer the borrow_kind with which to borrow upvars in a stack closure.
The borrow_kind basically follows a lattice of imm < unique-imm < mut,
moving from left to right as needed (but never right to left).
Here the argument mutbl is the borrow_kind that is required by
some particular use.
fn adjust_closure_kind(
&mut self,
closure_id: LocalDefId,
new_kind: ClosureKind,
upvar_span: Span,
var_name: Name
)[src]
fn adjust_closure_kind(
&mut self,
closure_id: LocalDefId,
new_kind: ClosureKind,
upvar_span: Span,
var_name: Name
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?