Struct rustc_typeck::coherence::builtin::Checker [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: TyCtxt<'a, 'tcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
trait_def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> Checker<'a, 'tcx>[src]
impl<'a, 'tcx> Checker<'a, 'tcx>ⓘImportant traits for &'a mut Wfn check<F>(&self, trait_def_id: Option<DefId>, f: F) -> &Self where
F: FnMut(TyCtxt<'a, 'tcx, 'tcx>, DefId, DefId), [src]
ⓘImportant traits for &'a mut W
fn check<F>(&self, trait_def_id: Option<DefId>, f: F) -> &Self where
F: FnMut(TyCtxt<'a, 'tcx, 'tcx>, DefId, DefId), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?