Function rustc_typeck::constrained_type_params::parameters_for [−][src]
pub fn parameters_for<'tcx, T>(
t: &T,
include_nonconstraining: bool
) -> Vec<Parameter> where
T: TypeFoldable<'tcx>,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If include_projections is false, returns the list of parameters that are
constrained by t - i.e. the value of each parameter in the list is
uniquely determined by t (see RFC 447). If it is true, return the list
of parameters whose values are needed in order to constrain ty - these
differ, with the latter being a superset, in the presence of projections.