Struct rustc_typeck::middle::ty::FnSigExperimental
[-]
[+]
[src]
pub struct FnSig<'tcx> {
pub inputs: Vec<&'tcx TyS<'tcx>>,
pub output: FnOutput<'tcx>,
pub variadic: bool,
}Signature of a function type, which I have arbitrarily decided to use to refer to the input/output types.
inputsis the list of arguments and their modes.outputis the return type.variadicindicates whether this is a varidic function. (only true for foreign fns)
Fields
inputs | |
output | |
variadic |