Struct rustc_typeck::variance::constraints::CurrentItem [−][src]
pub struct CurrentItem {
inferred_start: InferredIndex,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
To build constraints, we visit one item (type, trait) at a time and look at its contents. So e.g. if we have
struct Foo<T> { b: Bar<T> }
then while we are visiting Bar<T>, the CurrentItem would have
the def-id and the start of Foo's inferreds.
Fields
inferred_start: InferredIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?