Struct rustc_typeck::variance::solve::SolveContext [−][src]
struct SolveContext<'a, 'tcx: 'a> {
terms_cx: TermsContext<'a, 'tcx>,
constraints: Vec<Constraint<'a>>,
solutions: Vec<Variance>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
terms_cx: TermsContext<'a, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
constraints: Vec<Constraint<'a>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
solutions: Vec<Variance>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> SolveContext<'a, 'tcx>[src]
impl<'a, 'tcx> SolveContext<'a, 'tcx>fn solve(&mut self)[src]
fn solve(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn create_map(&self) -> FxHashMap<DefId, Lrc<Vec<Variance>>>[src]
fn create_map(&self) -> FxHashMap<DefId, Lrc<Vec<Variance>>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn evaluate(&self, term: &'a VarianceTerm<'a>) -> Variance[src]
fn evaluate(&self, term: &'a VarianceTerm<'a>) -> Variance🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?