[−][src]Struct rustdoc::clean::auto_trait::AutoTraitFinder
Fields
cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>
f: AutoTraitFinder<'a, 'tcx>
Methods
impl<'a, 'tcx, 'rcx, 'cstore> AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>[src]
impl<'a, 'tcx, 'rcx, 'cstore> AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>pub fn new(cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>) -> Self[src]
pub fn new(cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>) -> Selfpub fn get_with_def_id(&self, def_id: DefId) -> Vec<Item>[src]
pub fn get_with_def_id(&self, def_id: DefId) -> Vec<Item>pub fn get_with_node_id(&self, id: NodeId, name: String) -> Vec<Item>[src]
pub fn get_with_node_id(&self, id: NodeId, name: String) -> Vec<Item>pub fn get_auto_trait_impls<F>(
&self,
def_id: DefId,
def_ctor: &F,
name: Option<String>
) -> Vec<Item> where
F: Fn(DefId) -> Def, [src]
pub fn get_auto_trait_impls<F>(
&self,
def_id: DefId,
def_ctor: &F,
name: Option<String>
) -> Vec<Item> where
F: Fn(DefId) -> Def, fn get_auto_trait_impl_for<F>(
&self,
def_id: DefId,
name: Option<String>,
generics: Generics,
def_ctor: &F,
trait_def_id: DefId
) -> Option<Item> where
F: Fn(DefId) -> Def, [src]
fn get_auto_trait_impl_for<F>(
&self,
def_id: DefId,
name: Option<String>,
generics: Generics,
def_ctor: &F,
trait_def_id: DefId
) -> Option<Item> where
F: Fn(DefId) -> Def, fn find_auto_trait_generics(
&self,
did: DefId,
trait_did: DefId,
generics: &Generics
) -> AutoTraitResult[src]
fn find_auto_trait_generics(
&self,
did: DefId,
trait_did: DefId,
generics: &Generics
) -> AutoTraitResultfn get_lifetime(
&self,
region: Region,
names_map: &FxHashMap<String, Lifetime>
) -> Lifetime[src]
fn get_lifetime(
&self,
region: Region,
names_map: &FxHashMap<String, Lifetime>
) -> Lifetimefn region_name(&self, region: Region) -> Option<String>[src]
fn region_name(&self, region: Region) -> Option<String>fn handle_lifetimes<'cx>(
&self,
regions: &RegionConstraintData<'cx>,
names_map: &FxHashMap<String, Lifetime>
) -> Vec<WherePredicate>[src]
fn handle_lifetimes<'cx>(
&self,
regions: &RegionConstraintData<'cx>,
names_map: &FxHashMap<String, Lifetime>
) -> Vec<WherePredicate>fn extract_for_generics<'b, 'c, 'd>(
&self,
tcx: TyCtxt<'b, 'c, 'd>,
pred: Predicate<'d>
) -> FxHashSet<GenericParamDef>[src]
fn extract_for_generics<'b, 'c, 'd>(
&self,
tcx: TyCtxt<'b, 'c, 'd>,
pred: Predicate<'d>
) -> FxHashSet<GenericParamDef>fn make_final_bounds<'b, 'c, 'cx>(
&self,
ty_to_bounds: FxHashMap<Type, FxHashSet<GenericBound>>,
ty_to_fn: FxHashMap<Type, (Option<PolyTrait>, Option<Type>)>,
lifetime_to_bounds: FxHashMap<Lifetime, FxHashSet<GenericBound>>
) -> Vec<WherePredicate>[src]
fn make_final_bounds<'b, 'c, 'cx>(
&self,
ty_to_bounds: FxHashMap<Type, FxHashSet<GenericBound>>,
ty_to_fn: FxHashMap<Type, (Option<PolyTrait>, Option<Type>)>,
lifetime_to_bounds: FxHashMap<Lifetime, FxHashSet<GenericBound>>
) -> Vec<WherePredicate>fn param_env_to_generics<'b, 'c, 'cx>(
&self,
tcx: TyCtxt<'b, 'c, 'cx>,
did: DefId,
param_env: ParamEnv<'cx>,
type_generics: Generics,
existing_predicates: Vec<WherePredicate>,
vid_to_region: FxHashMap<RegionVid, Region<'cx>>
) -> Generics[src]
fn param_env_to_generics<'b, 'c, 'cx>(
&self,
tcx: TyCtxt<'b, 'c, 'cx>,
did: DefId,
param_env: ParamEnv<'cx>,
type_generics: Generics,
existing_predicates: Vec<WherePredicate>,
vid_to_region: FxHashMap<RegionVid, Region<'cx>>
) -> Genericsfn sort_where_predicates(&self, predicates: &mut Vec<WherePredicate>)[src]
fn sort_where_predicates(&self, predicates: &mut Vec<WherePredicate>)fn sort_where_bounds(&self, bounds: &mut Vec<GenericBound>)[src]
fn sort_where_bounds(&self, bounds: &mut Vec<GenericBound>)fn unstable_debug_sort<T: Debug>(&self, vec: &mut Vec<T>)[src]
fn unstable_debug_sort<T: Debug>(&self, vec: &mut Vec<T>)fn is_fn_ty(&self, tcx: &TyCtxt, ty: &Type) -> bool[src]
fn is_fn_ty(&self, tcx: &TyCtxt, ty: &Type) -> boolAuto Trait Implementations
impl<'a, 'tcx, 'rcx, 'cstore> !Send for AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>
impl<'a, 'tcx, 'rcx, 'cstore> !Send for AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>impl<'a, 'tcx, 'rcx, 'cstore> !Sync for AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>
impl<'a, 'tcx, 'rcx, 'cstore> !Sync for AutoTraitFinder<'a, 'tcx, 'rcx, 'cstore>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>try_from)Performs the conversion.
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow(&self) -> &T[src]
fn borrow(&self) -> &TImmutably borrows from an owned value. Read more
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>try_from)Performs the conversion.
impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut TMutably borrows from an owned value. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Gets the TypeId of self. Read more
impl<E> SpecializationError for E[src]
impl<E> SpecializationError for Efn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, [src]
fn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an error for a missing method specialization. Defaults to panicking with type, trait & method names. S is the encoder/decoder state type, T is the type being encoded/decoded, and the arguments are the names of the trait and method that should've been overridden. Read more
impl<T> Erased for T[src]
impl<T> Erased for Timpl<T> Send for T where
T: ?Sized, [src]
impl<T> Send for T where
T: ?Sized, impl<T> Sync for T where
T: ?Sized, [src]
impl<T> Sync for T where
T: ?Sized, impl<T> Erased for T
impl<T> Erased for Timpl<T> MaybeResult for T[src]
impl<T> MaybeResult for Tfn from_ok(x: T) -> T[src]
fn from_ok(x: T) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, [src]
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, T> Captures for T where
T: ?Sized, [src]
impl<'a, T> Captures for T where
T: ?Sized,