Enum rustdoc::clean::GenericBound [−][src]
pub enum GenericBound {
TraitBound(PolyTrait, TraitBoundModifier),
Outlives(Lifetime),
}Variants
TraitBound(PolyTrait, TraitBoundModifier)Outlives(Lifetime)Methods
impl GenericBound[src]
impl GenericBoundfn maybe_sized(cx: &DocContext) -> GenericBound[src]
fn maybe_sized(cx: &DocContext) -> GenericBoundfn is_sized_bound(&self, cx: &DocContext) -> bool[src]
fn is_sized_bound(&self, cx: &DocContext) -> boolfn get_poly_trait(&self) -> Option<PolyTrait>[src]
fn get_poly_trait(&self) -> Option<PolyTrait>fn get_trait_type(&self) -> Option<Type>[src]
fn get_trait_type(&self) -> Option<Type>Trait Implementations
impl Clone for GenericBound[src]
impl Clone for GenericBoundfn clone(&self) -> GenericBound[src]
fn clone(&self) -> GenericBoundReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for GenericBound[src]
impl Encodable for GenericBoundfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for GenericBound[src]
impl Decodable for GenericBoundfn decode<__D: Decoder>(d: &mut __D) -> Result<GenericBound, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<GenericBound, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for GenericBound[src]
impl PartialEq for GenericBoundfn eq(&self, other: &GenericBound) -> bool[src]
fn eq(&self, other: &GenericBound) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &GenericBound) -> bool[src]
fn ne(&self, other: &GenericBound) -> boolThis method tests for !=.
impl Eq for GenericBound[src]
impl Eq for GenericBoundfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Debug for GenericBound[src]
impl Debug for GenericBoundfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for GenericBound[src]
impl Hash for GenericBoundfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Clean<GenericBound> for GenericBound[src]
impl Clean<GenericBound> for GenericBoundfn clean(&self, cx: &DocContext) -> GenericBound[src]
fn clean(&self, cx: &DocContext) -> GenericBoundimpl<'a, 'tcx> Clean<GenericBound> for (&'a TraitRef<'tcx>, Vec<TypeBinding>)[src]
impl<'a, 'tcx> Clean<GenericBound> for (&'a TraitRef<'tcx>, Vec<TypeBinding>)fn clean(&self, cx: &DocContext) -> GenericBound[src]
fn clean(&self, cx: &DocContext) -> GenericBoundimpl<'tcx> Clean<GenericBound> for TraitRef<'tcx>[src]
impl<'tcx> Clean<GenericBound> for TraitRef<'tcx>fn clean(&self, cx: &DocContext) -> GenericBound[src]
fn clean(&self, cx: &DocContext) -> GenericBoundimpl From<GenericBound> for SimpleBound[src]
impl From<GenericBound> for SimpleBoundfn from(bound: GenericBound) -> Self[src]
fn from(bound: GenericBound) -> SelfPerforms the conversion.
impl Display for GenericBound[src]
impl Display for GenericBoundAuto Trait Implementations
impl !Send for GenericBound
impl !Send for GenericBoundimpl !Sync for GenericBound
impl !Sync for GenericBound