Enum rustdoc::clean::GenericParamDef [−][src]
Variants
Lifetime(Lifetime)Type(TyParam)
Methods
impl GenericParamDef[src]
impl GenericParamDefpub fn is_synthetic_type_param(&self) -> bool[src]
pub fn is_synthetic_type_param(&self) -> boolTrait Implementations
impl Clone for GenericParamDef[src]
impl Clone for GenericParamDeffn clone(&self) -> GenericParamDef[src]
fn clone(&self) -> GenericParamDefReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for GenericParamDef[src]
impl Encodable for GenericParamDeffn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for GenericParamDef[src]
impl Decodable for GenericParamDeffn decode<__D: Decoder>(d: &mut __D) -> Result<GenericParamDef, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<GenericParamDef, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for GenericParamDef[src]
impl PartialEq for GenericParamDeffn eq(&self, other: &GenericParamDef) -> bool[src]
fn eq(&self, other: &GenericParamDef) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &GenericParamDef) -> bool[src]
fn ne(&self, other: &GenericParamDef) -> boolThis method tests for !=.
impl Eq for GenericParamDef[src]
impl Eq for GenericParamDeffn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Debug for GenericParamDef[src]
impl Debug for GenericParamDeffn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for GenericParamDef[src]
impl Hash for GenericParamDeffn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Clean<GenericParamDef> for GenericParam[src]
impl Clean<GenericParamDef> for GenericParamfn clean(&self, cx: &DocContext) -> GenericParamDef[src]
fn clean(&self, cx: &DocContext) -> GenericParamDefimpl Display for GenericParamDef[src]
impl Display for GenericParamDefAuto Trait Implementations
impl !Send for GenericParamDef
impl !Send for GenericParamDefimpl !Sync for GenericParamDef
impl !Sync for GenericParamDef