Enum rustdoc::clean::ImplPolarity [−][src]
pub enum ImplPolarity {
Positive,
Negative,
}Variants
PositiveNegativeTrait Implementations
impl Clone for ImplPolarity[src]
impl Clone for ImplPolarityfn clone(&self) -> ImplPolarity[src]
fn clone(&self) -> ImplPolarityReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for ImplPolarity[src]
impl Encodable for ImplPolarityfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for ImplPolarity[src]
impl Decodable for ImplPolarityfn decode<__D: Decoder>(d: &mut __D) -> Result<ImplPolarity, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<ImplPolarity, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for ImplPolarity[src]
impl PartialEq for ImplPolarityfn eq(&self, other: &ImplPolarity) -> bool[src]
fn eq(&self, other: &ImplPolarity) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for ImplPolarity[src]
impl Eq for ImplPolarityfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Copy for ImplPolarity[src]
impl Copy for ImplPolarityimpl Debug for ImplPolarity[src]
impl Debug for ImplPolarityfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for ImplPolarity[src]
impl Hash for ImplPolarityfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Clean<ImplPolarity> for ImplPolarity[src]
impl Clean<ImplPolarity> for ImplPolarityfn clean(&self, _: &DocContext) -> ImplPolarity[src]
fn clean(&self, _: &DocContext) -> ImplPolarityAuto Trait Implementations
impl Send for ImplPolarity
impl Send for ImplPolarityimpl Sync for ImplPolarity
impl Sync for ImplPolarity