Enum rustdoc::clean::PathKind [−][src]
enum PathKind {
Unknown,
Macro,
Value,
Type,
}Variants
Unknowncan be either value or type, not a macro
Macromacro
Valuevalues, functions, consts, statics, everything in the value namespace
Typetypes, traits, everything in the type namespace