Enum rustdoc::clean::PrimitiveType [−][src]
pub enum PrimitiveType {
Isize,
I8,
I16,
I32,
I64,
I128,
Usize,
U8,
U16,
U32,
U64,
U128,
F32,
F64,
Char,
Bool,
Str,
Slice,
Array,
Tuple,
Unit,
RawPointer,
Reference,
Fn,
Never,
}Variants
IsizeI8I16I32I64I128UsizeU8U16U32U64U128F32F64CharBoolStrSliceArrayTupleUnitRawPointerReferenceFnNever
Methods
impl PrimitiveType[src]
impl PrimitiveTypefn from_str(s: &str) -> Option<PrimitiveType>[src]
fn from_str(s: &str) -> Option<PrimitiveType>pub fn as_str(&self) -> &'static str[src]
pub fn as_str(&self) -> &'static strpub fn to_url_str(&self) -> &'static str[src]
pub fn to_url_str(&self) -> &'static strTrait Implementations
impl Clone for PrimitiveType[src]
impl Clone for PrimitiveTypefn clone(&self) -> PrimitiveType[src]
fn clone(&self) -> PrimitiveTypeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for PrimitiveType[src]
impl Encodable for PrimitiveTypefn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for PrimitiveType[src]
impl Decodable for PrimitiveTypefn decode<__D: Decoder>(d: &mut __D) -> Result<PrimitiveType, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<PrimitiveType, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for PrimitiveType[src]
impl PartialEq for PrimitiveTypefn eq(&self, other: &PrimitiveType) -> bool[src]
fn eq(&self, other: &PrimitiveType) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for PrimitiveType[src]
impl Eq for PrimitiveTypefn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Hash for PrimitiveType[src]
impl Hash for PrimitiveTypefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Copy for PrimitiveType[src]
impl Copy for PrimitiveTypeimpl Debug for PrimitiveType[src]
impl Debug for PrimitiveTypefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl From<IntTy> for PrimitiveType[src]
impl From<IntTy> for PrimitiveTypefn from(int_ty: IntTy) -> PrimitiveType[src]
fn from(int_ty: IntTy) -> PrimitiveTypePerforms the conversion.
impl From<UintTy> for PrimitiveType[src]
impl From<UintTy> for PrimitiveTypefn from(uint_ty: UintTy) -> PrimitiveType[src]
fn from(uint_ty: UintTy) -> PrimitiveTypePerforms the conversion.
impl From<FloatTy> for PrimitiveType[src]
impl From<FloatTy> for PrimitiveTypefn from(float_ty: FloatTy) -> PrimitiveType[src]
fn from(float_ty: FloatTy) -> PrimitiveTypePerforms the conversion.