Enum rustdoc::clean::SelfTy [−][src]
pub enum SelfTy {
SelfValue,
SelfBorrowed(Option<Lifetime>, Mutability),
SelfExplicit(Type),
}Variants
SelfValueSelfBorrowed(Option<Lifetime>, Mutability)SelfExplicit(Type)Trait Implementations
impl Clone for SelfTy[src]
impl Clone for SelfTyfn clone(&self) -> SelfTy[src]
fn clone(&self) -> SelfTyReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for SelfTy[src]
impl Encodable for SelfTyfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for SelfTy[src]
impl Decodable for SelfTyfn decode<__D: Decoder>(d: &mut __D) -> Result<SelfTy, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<SelfTy, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for SelfTy[src]
impl PartialEq for SelfTyfn eq(&self, other: &SelfTy) -> bool[src]
fn eq(&self, other: &SelfTy) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SelfTy) -> bool[src]
fn ne(&self, other: &SelfTy) -> boolThis method tests for !=.
impl Debug for SelfTy[src]
impl Debug for SelfTy