Enum rustdoc::clean::TyParamBound [−][src]
pub enum TyParamBound {
RegionBound(Lifetime),
TraitBound(PolyTrait, TraitBoundModifier),
}Variants
RegionBound(Lifetime)TraitBound(PolyTrait, TraitBoundModifier)
Methods
impl TyParamBound[src]
impl TyParamBoundfn maybe_sized(cx: &DocContext) -> TyParamBound[src]
fn maybe_sized(cx: &DocContext) -> TyParamBoundfn is_sized_bound(&self, cx: &DocContext) -> bool[src]
fn is_sized_bound(&self, cx: &DocContext) -> boolfn get_poly_trait(&self) -> Option<PolyTrait>[src]
fn get_poly_trait(&self) -> Option<PolyTrait>fn get_trait_type(&self) -> Option<Type>[src]
fn get_trait_type(&self) -> Option<Type>Trait Implementations
impl Clone for TyParamBound[src]
impl Clone for TyParamBoundfn clone(&self) -> TyParamBound[src]
fn clone(&self) -> TyParamBoundReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for TyParamBound[src]
impl Encodable for TyParamBoundfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for TyParamBound[src]
impl Decodable for TyParamBoundfn decode<__D: Decoder>(d: &mut __D) -> Result<TyParamBound, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<TyParamBound, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for TyParamBound[src]
impl PartialEq for TyParamBoundfn eq(&self, other: &TyParamBound) -> bool[src]
fn eq(&self, other: &TyParamBound) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TyParamBound) -> bool[src]
fn ne(&self, other: &TyParamBound) -> boolThis method tests for !=.
impl Eq for TyParamBound[src]
impl Eq for TyParamBoundfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Debug for TyParamBound[src]
impl Debug for TyParamBoundfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for TyParamBound[src]
impl Hash for TyParamBoundfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Clean<TyParamBound> for TyParamBound[src]
impl Clean<TyParamBound> for TyParamBoundfn clean(&self, cx: &DocContext) -> TyParamBound[src]
fn clean(&self, cx: &DocContext) -> TyParamBoundimpl<'a, 'tcx> Clean<TyParamBound> for (&'a TraitRef<'tcx>, Vec<TypeBinding>)[src]
impl<'a, 'tcx> Clean<TyParamBound> for (&'a TraitRef<'tcx>, Vec<TypeBinding>)fn clean(&self, cx: &DocContext) -> TyParamBound[src]
fn clean(&self, cx: &DocContext) -> TyParamBoundimpl<'tcx> Clean<TyParamBound> for TraitRef<'tcx>[src]
impl<'tcx> Clean<TyParamBound> for TraitRef<'tcx>fn clean(&self, cx: &DocContext) -> TyParamBound[src]
fn clean(&self, cx: &DocContext) -> TyParamBoundimpl From<TyParamBound> for SimpleBound[src]
impl From<TyParamBound> for SimpleBoundfn from(bound: TyParamBound) -> Self[src]
fn from(bound: TyParamBound) -> SelfPerforms the conversion.
impl Display for TyParamBound[src]
impl Display for TyParamBoundAuto Trait Implementations
impl !Send for TyParamBound
impl !Send for TyParamBoundimpl !Sync for TyParamBound
impl !Sync for TyParamBound