Enum rustdoc::clean::TypeExperimental
[-]
[+]
[src]
pub enum Type {
ResolvedPath {
path: Path,
typarams: Option<Vec<TyParamBound>>,
did: DefId,
},
TyParamBinder(NodeId),
Generic(String),
Primitive(PrimitiveType),
Closure(Box<ClosureDecl>),
Proc(Box<ClosureDecl>),
BareFunction(Box<BareFunctionDecl>),
Tuple(Vec<Type>),
Vector(Box<Type>),
FixedVector(Box<Type>, String),
Bottom,
Unique(Box<Type>),
RawPointer(Mutability, Box<Type>),
BorrowedRef {
lifetime: Option<Lifetime>,
mutability: Mutability,
type_: Box<Type>,
},
QPath {
name: String,
self_type: Box<Type>,
trait_: Box<Type>,
},
Infer,
PolyTraitRef(Vec<TyParamBound>),
}A representation of a Type suitable for hyperlinking purposes. Ideally one can get the original type out of the AST/ty::ctxt given one of these, if more information is needed. Most importantly it does not preserve mutability or boxes.