[−][src]Struct rustdoc::clean::Attributes
Fields
doc_strings: Vec<DocFragment>
other_attrs: Vec<Attribute>
cfg: Option<Arc<Cfg>>
span: Option<Span>
links: Vec<(String, Option<DefId>, Option<String>)>
map from Rust paths to resolved defs and potential URL fragments
inner_docs: bool
Methods
impl Attributes[src]
impl Attributesfn extract_cfg(mi: &MetaItem) -> Option<&MetaItem>[src]
fn extract_cfg(mi: &MetaItem) -> Option<&MetaItem>Extracts the content from an attribute #[doc(cfg(content))].
fn extract_include(mi: &MetaItem) -> Option<(String, String)>[src]
fn extract_include(mi: &MetaItem) -> Option<(String, String)>Reads a MetaItem from within an attribute, looks for whether it is a
#[doc(include="file")], and returns the filename and contents of the file as loaded from
its expansion.
pub fn has_doc_flag(&self, flag: &str) -> bool[src]
pub fn has_doc_flag(&self, flag: &str) -> boolpub fn from_ast(diagnostic: &Handler, attrs: &[Attribute]) -> Attributes[src]
pub fn from_ast(diagnostic: &Handler, attrs: &[Attribute]) -> Attributespub fn doc_value<'a>(&'a self) -> Option<&'a str>[src]
pub fn doc_value<'a>(&'a self) -> Option<&'a str>Finds the doc attribute as a NameValue and returns the corresponding
value found.
pub fn collapsed_doc_value(&self) -> Option<String>[src]
pub fn collapsed_doc_value(&self) -> Option<String>Finds all doc attributes as NameValues and returns their corresponding values, joined
with newlines.
pub fn links(&self, krate: &CrateNum) -> Vec<(String, String)>[src]
pub fn links(&self, krate: &CrateNum) -> Vec<(String, String)>Get links as a vector
Cache must be populated before call
impl Attributes[src]
impl Attributespub fn collapse_doc_comments(&mut self)[src]
pub fn collapse_doc_comments(&mut self)impl Attributes[src]
impl Attributespub fn unindent_doc_comments(&mut self)[src]
pub fn unindent_doc_comments(&mut self)Trait Implementations
impl Clone for Attributes[src]
impl Clone for Attributesfn clone(&self) -> Attributes[src]
fn clone(&self) -> AttributesReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Encodable for Attributes[src]
impl Encodable for Attributesfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for Attributes[src]
impl Decodable for Attributesfn decode<__D: Decoder>(d: &mut __D) -> Result<Attributes, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<Attributes, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Debug for Attributes[src]
impl Debug for Attributesfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Default for Attributes[src]
impl Default for Attributesfn default() -> Attributes[src]
fn default() -> AttributesReturns the "default value" for a type. Read more
impl PartialEq for Attributes[src]
impl PartialEq for Attributesfn eq(&self, rhs: &Self) -> bool[src]
fn eq(&self, rhs: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Attributes[src]
impl Eq for Attributesfn assert_receiver_is_total_eq(&self)1.0.0[src]
fn assert_receiver_is_total_eq(&self)impl Hash for Attributes[src]
impl Hash for Attributesfn hash<H: Hasher>(&self, hasher: &mut H)[src]
fn hash<H: Hasher>(&self, hasher: &mut H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl AttributesExt for Attributes[src]
impl AttributesExt for AttributesⓘImportant traits for ListAttributesIter<'a>fn lists<'a>(&'a self, name: &'a str) -> ListAttributesIter<'a>[src]
fn lists<'a>(&'a self, name: &'a str) -> ListAttributesIter<'a>Finds an attribute as List and returns the list of attributes nested inside.
impl Clean<Attributes> for [Attribute][src]
impl Clean<Attributes> for [Attribute]fn clean(&self, cx: &DocContext) -> Attributes[src]
fn clean(&self, cx: &DocContext) -> AttributesAuto Trait Implementations
impl !Send for Attributes
impl !Send for Attributesimpl !Sync for Attributes
impl !Sync for AttributesBlanket Implementations
impl<T> ToOwned for T where
T: Clone, [src]
impl<T> ToOwned for T where
T: Clone, type Owned = T
fn to_owned(&self) -> T[src]
fn to_owned(&self) -> TCreates owned data from borrowed data, usually by cloning. Read more
fn clone_into(&self, target: &mut T)[src]
fn clone_into(&self, target: &mut T)🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>try_from)Performs the conversion.
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow(&self) -> &T[src]
fn borrow(&self) -> &TImmutably borrows from an owned value. Read more
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>try_from)Performs the conversion.
impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut TMutably borrows from an owned value. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Gets the TypeId of self. Read more
impl<T> Encodable for T where
T: UseSpecializedEncodable + ?Sized, [src]
impl<T> Encodable for T where
T: UseSpecializedEncodable + ?Sized, fn encode<E>(&self, e: &mut E) -> Result<(), <E as Encoder>::Error> where
E: Encoder, [src]
fn encode<E>(&self, e: &mut E) -> Result<(), <E as Encoder>::Error> where
E: Encoder, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T> Decodable for T where
T: UseSpecializedDecodable, [src]
impl<T> Decodable for T where
T: UseSpecializedDecodable, fn decode<D>(d: &mut D) -> Result<T, <D as Decoder>::Error> where
D: Decoder, [src]
fn decode<D>(d: &mut D) -> Result<T, <D as Decoder>::Error> where
D: Decoder, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<E> SpecializationError for E[src]
impl<E> SpecializationError for Efn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, [src]
fn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an error for a missing method specialization. Defaults to panicking with type, trait & method names. S is the encoder/decoder state type, T is the type being encoded/decoded, and the arguments are the names of the trait and method that should've been overridden. Read more
impl<T> Erased for T[src]
impl<T> Erased for Timpl<T> Send for T where
T: ?Sized, [src]
impl<T> Send for T where
T: ?Sized, impl<T> Sync for T where
T: ?Sized, [src]
impl<T> Sync for T where
T: ?Sized, impl<T> Erased for T
impl<T> Erased for Timpl<T> MaybeResult for T[src]
impl<T> MaybeResult for Tfn from_ok(x: T) -> T[src]
fn from_ok(x: T) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, [src]
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, T> Captures for T where
T: ?Sized, [src]
impl<'a, T> Captures for T where
T: ?Sized,