Struct rustdoc::clean::FnDecl [−][src]
pub struct FnDecl {
pub inputs: Arguments,
pub output: FunctionRetTy,
pub variadic: bool,
pub attrs: Attributes,
}Fields
inputs: Arguments
output: FunctionRetTy
variadic: bool
attrs: Attributes
Methods
impl FnDecl[src]
impl FnDeclTrait Implementations
impl Clone for FnDecl[src]
impl Clone for FnDeclfn clone(&self) -> FnDecl[src]
fn clone(&self) -> FnDeclReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for FnDecl[src]
impl Encodable for FnDeclfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for FnDecl[src]
impl Decodable for FnDeclfn decode<__D: Decoder>(d: &mut __D) -> Result<FnDecl, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<FnDecl, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for FnDecl[src]
impl PartialEq for FnDeclfn eq(&self, other: &FnDecl) -> bool[src]
fn eq(&self, other: &FnDecl) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &FnDecl) -> bool[src]
fn ne(&self, other: &FnDecl) -> boolThis method tests for !=.
impl Eq for FnDecl[src]
impl Eq for FnDeclfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Debug for FnDecl[src]
impl Debug for FnDeclfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for FnDecl[src]
impl Hash for FnDeclfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl<'a, A: Copy> Clean<FnDecl> for (&'a FnDecl, A) where
(&'a [Ty], A): Clean<Arguments>, [src]
impl<'a, A: Copy> Clean<FnDecl> for (&'a FnDecl, A) where
(&'a [Ty], A): Clean<Arguments>, fn clean(&self, cx: &DocContext) -> FnDecl[src]
fn clean(&self, cx: &DocContext) -> FnDeclimpl<'a, 'tcx> Clean<FnDecl> for (DefId, PolyFnSig<'tcx>)[src]
impl<'a, 'tcx> Clean<FnDecl> for (DefId, PolyFnSig<'tcx>)fn clean(&self, cx: &DocContext) -> FnDecl[src]
fn clean(&self, cx: &DocContext) -> FnDeclimpl Display for FnDecl[src]
impl Display for FnDecl