Struct rustdoc::clean::Path [−][src]
pub struct Path {
pub global: bool,
pub def: Def,
pub segments: Vec<PathSegment>,
}Fields
global: bool
def: Def
segments: Vec<PathSegment>
Methods
impl Path[src]
impl PathTrait Implementations
impl Clone for Path[src]
impl Clone for Pathfn clone(&self) -> Path[src]
fn clone(&self) -> PathReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Encodable for Path[src]
impl Encodable for Pathfn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>[src]
fn encode<__S: Encoder>(&self, s: &mut __S) -> Result<(), __S::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for Path[src]
impl Decodable for Pathfn decode<__D: Decoder>(d: &mut __D) -> Result<Path, __D::Error>[src]
fn decode<__D: Decoder>(d: &mut __D) -> Result<Path, __D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl PartialEq for Path[src]
impl PartialEq for Pathfn eq(&self, other: &Path) -> bool[src]
fn eq(&self, other: &Path) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Path) -> bool[src]
fn ne(&self, other: &Path) -> boolThis method tests for !=.
impl Eq for Path[src]
impl Eq for Pathfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl Debug for Path[src]
impl Debug for Pathfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for Path[src]
impl Hash for Pathfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Clean<Path> for Path[src]
impl Clean<Path> for Pathfn clean(&self, cx: &DocContext) -> Path[src]
fn clean(&self, cx: &DocContext) -> Pathimpl Display for Path[src]
impl Display for Path