Struct rustdoc::clean::StaticExperimental
[-]
[+]
[src]
pub struct Static {
pub type_: Type,
pub mutability: Mutability,
pub expr: String,
}Fields
type_ | |
mutability | |
expr | It's useful to have the value of a static documented, but I have no desire to represent expressions (that'd basically be all of the AST, which is huge!). So, have a string. |