Struct rustdoc::core::SearchPaths [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
paths: Vec<(PathKind, PathBuf)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SearchPaths[src]
impl SearchPathspub fn new() -> SearchPaths[src]
pub fn new() -> SearchPaths🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add_path(&mut self, path: &str, output: ErrorOutputType)[src]
pub fn add_path(&mut self, path: &str, output: ErrorOutputType)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Iter<'a>pub fn iter(&self, kind: PathKind) -> Iter[src]
pub fn iter(&self, kind: PathKind) -> Iter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?