Struct rustdoc::externalfiles::ExternalHtml [−][src]
pub struct ExternalHtml {
pub in_header: String,
pub before_content: String,
pub after_content: String,
}Fields
in_header: String
Content that will be included inline in the
section of a rendered Markdown file or generated documentationbefore_content: String
Content that will be included inline between
and the content of a rendered Markdown file or generated documentationafter_content: String
Content that will be included inline between the content and of a rendered Markdown file or generated documentation
Methods
impl ExternalHtml[src]
impl ExternalHtmlpub fn load(
in_header: &[String],
before_content: &[String],
after_content: &[String],
md_before_content: &[String],
md_after_content: &[String],
diag: &Handler
) -> Option<ExternalHtml>[src]
pub fn load(
in_header: &[String],
before_content: &[String],
after_content: &[String],
md_before_content: &[String],
md_after_content: &[String],
diag: &Handler
) -> Option<ExternalHtml>Trait Implementations
impl Clone for ExternalHtml[src]
impl Clone for ExternalHtmlfn clone(&self) -> ExternalHtml[src]
fn clone(&self) -> ExternalHtmlReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more