Enum rustdoc::html::item_type::ItemType [−][src]
pub enum ItemType {
Module,
ExternCrate,
Import,
Struct,
Enum,
Function,
Typedef,
Static,
Trait,
Impl,
TyMethod,
Method,
StructField,
Variant,
Macro,
Primitive,
AssociatedType,
Constant,
AssociatedConst,
Union,
ForeignType,
Keyword,
Existential,
}Item type. Corresponds to clean::ItemEnum variants.
The search index uses item types encoded as smaller numbers which equal to
discriminants. JavaScript then is used to decode them into the original value.
Consequently, every change to this type should be synchronized to
the itemTypes mapping table in static/main.js.
Variants
ModuleExternCrateImportStructEnumFunctionTypedefStaticTraitImplTyMethodMethodStructFieldVariantMacroPrimitiveAssociatedTypeConstantAssociatedConstUnionForeignTypeKeywordExistentialMethods
impl ItemType[src]
impl ItemTypeTrait Implementations
impl Copy for ItemType[src]
impl Copy for ItemTypeimpl PartialEq for ItemType[src]
impl PartialEq for ItemTypefn eq(&self, other: &ItemType) -> bool[src]
fn eq(&self, other: &ItemType) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Clone for ItemType[src]
impl Clone for ItemTypefn clone(&self) -> ItemType[src]
fn clone(&self) -> ItemTypeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for ItemType[src]
impl Debug for ItemTypefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<'a> From<&'a Item> for ItemType[src]
impl<'a> From<&'a Item> for ItemTypeimpl From<TypeKind> for ItemType[src]
impl From<TypeKind> for ItemTypeimpl Display for ItemType[src]
impl Display for ItemType