Struct rustdoc::html::render::ItemEntry [−][src]
Fields
url: String
name: String
Methods
impl ItemEntry[src]
impl ItemEntryTrait Implementations
impl Debug for ItemEntry[src]
impl Debug for ItemEntryfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for ItemEntry[src]
impl Eq for ItemEntryfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl PartialEq for ItemEntry[src]
impl PartialEq for ItemEntryfn eq(&self, other: &ItemEntry) -> bool[src]
fn eq(&self, other: &ItemEntry) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ItemEntry) -> bool[src]
fn ne(&self, other: &ItemEntry) -> boolThis method tests for !=.
impl Hash for ItemEntry[src]
impl Hash for ItemEntryfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Display for ItemEntry[src]
impl Display for ItemEntryfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialOrd for ItemEntry[src]
impl PartialOrd for ItemEntryfn partial_cmp(&self, other: &ItemEntry) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ItemEntry) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for ItemEntry[src]
impl Ord for ItemEntryfn cmp(&self, other: &ItemEntry) -> Ordering[src]
fn cmp(&self, other: &ItemEntry) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more