Struct rustdoc::html::toc::Toc [−][src]
A (recursive) table of contents
Fields
entries: Vec<TocEntry>
The levels are strictly decreasing, i.e.
entries[0].level >= entries[1].level >= ...
Normally they are equal, but can differ in cases like A and B,
both of which end up in the same Toc as they have the same
parent (Main).
# Main
### A
## B
Methods
impl Toc[src]
impl Tocfn count_entries_with_level(&self, level: u32) -> usize[src]
fn count_entries_with_level(&self, level: u32) -> usizeTrait Implementations
impl PartialEq for Toc[src]
impl PartialEq for Tocfn eq(&self, other: &Toc) -> bool[src]
fn eq(&self, other: &Toc) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Toc) -> bool[src]
fn ne(&self, other: &Toc) -> boolThis method tests for !=.
impl Debug for Toc[src]
impl Debug for Tocfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for Toc[src]
impl Display for Toc