[−][src]Enum rustdoc::passes::Pass
Represents a single pass.
Variants
EarlyPassAn "early pass" is run in the compiler context, and can gather information about types and traits and the like.
Fields of EarlyPass
name: &'static str | |
pass: fn(_: Crate, _: &DocContext) -> Crate | |
description: &'static str |
LatePassA "late pass" is run between crate cleaning and page generation.
Fields of LatePass
name: &'static str | |
pass: fn(_: Crate) -> Crate | |
description: &'static str |
Methods
impl Pass[src]
impl Passpub const fn early(
name: &'static str,
pass: fn(_: Crate, _: &DocContext) -> Crate,
description: &'static str
) -> Pass[src]
pub const fn early(
name: &'static str,
pass: fn(_: Crate, _: &DocContext) -> Crate,
description: &'static str
) -> PassConstructs a new early pass.
pub const fn late(
name: &'static str,
pass: fn(_: Crate) -> Crate,
description: &'static str
) -> Pass[src]
pub const fn late(
name: &'static str,
pass: fn(_: Crate) -> Crate,
description: &'static str
) -> PassConstructs a new late pass.
pub fn name(self) -> &'static str[src]
pub fn name(self) -> &'static strReturns the name of this pass.
pub fn description(self) -> &'static str[src]
pub fn description(self) -> &'static strReturns the description of this pass.
pub fn early_fn(self) -> Option<fn(_: Crate, _: &DocContext) -> Crate>[src]
pub fn early_fn(self) -> Option<fn(_: Crate, _: &DocContext) -> Crate>If this pass is an early pass, returns the pointer to its function.
pub fn late_fn(self) -> Option<fn(_: Crate) -> Crate>[src]
pub fn late_fn(self) -> Option<fn(_: Crate) -> Crate>If this pass is a late pass, returns the pointer to its function.