[−][src]Struct rustdoc::visit_ast::RustdocVisitor
Fields
module: Module
attrs: HirVec<Attribute>
cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>
view_item_stack: FxHashSet<NodeId>
inlining: bool
inside_public_path: bool
Is the current module and all of its parents public?
exact_paths: Option<FxHashMap<DefId, Vec<String>>>
Methods
impl<'a, 'tcx, 'rcx, 'cstore> RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>[src]
impl<'a, 'tcx, 'rcx, 'cstore> RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>pub fn new(
cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>
) -> RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>[src]
pub fn new(
cx: &'a DocContext<'a, 'tcx, 'rcx, 'cstore>
) -> RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>fn store_path(&mut self, did: DefId)[src]
fn store_path(&mut self, did: DefId)fn stability(&self, id: NodeId) -> Option<Stability>[src]
fn stability(&self, id: NodeId) -> Option<Stability>fn deprecation(&self, id: NodeId) -> Option<Deprecation>[src]
fn deprecation(&self, id: NodeId) -> Option<Deprecation>pub fn visit(&mut self, krate: &Crate)[src]
pub fn visit(&mut self, krate: &Crate)pub fn visit_variant_data(
&mut self,
item: &Item,
name: Name,
sd: &VariantData,
generics: &Generics
) -> Struct[src]
pub fn visit_variant_data(
&mut self,
item: &Item,
name: Name,
sd: &VariantData,
generics: &Generics
) -> Structpub fn visit_union_data(
&mut self,
item: &Item,
name: Name,
sd: &VariantData,
generics: &Generics
) -> Union[src]
pub fn visit_union_data(
&mut self,
item: &Item,
name: Name,
sd: &VariantData,
generics: &Generics
) -> Unionpub fn visit_enum_def(
&mut self,
it: &Item,
name: Name,
def: &EnumDef,
params: &Generics
) -> Enum[src]
pub fn visit_enum_def(
&mut self,
it: &Item,
name: Name,
def: &EnumDef,
params: &Generics
) -> Enumpub fn visit_fn(
&mut self,
item: &Item,
name: Name,
fd: &FnDecl,
header: FnHeader,
gen: &Generics,
body: BodyId
) -> Function[src]
pub fn visit_fn(
&mut self,
item: &Item,
name: Name,
fd: &FnDecl,
header: FnHeader,
gen: &Generics,
body: BodyId
) -> Functionpub fn visit_mod_contents(
&mut self,
span: Span,
attrs: HirVec<Attribute>,
vis: Visibility,
id: NodeId,
m: &Mod,
name: Option<Name>
) -> Module[src]
pub fn visit_mod_contents(
&mut self,
span: Span,
attrs: HirVec<Attribute>,
vis: Visibility,
id: NodeId,
m: &Mod,
name: Option<Name>
) -> Modulefn maybe_inline_local(
&mut self,
id: NodeId,
def: Def,
renamed: Option<Name>,
glob: bool,
om: &mut Module,
please_inline: bool
) -> bool[src]
fn maybe_inline_local(
&mut self,
id: NodeId,
def: Def,
renamed: Option<Name>,
glob: bool,
om: &mut Module,
please_inline: bool
) -> boolTries to resolve the target of a pub use statement and inlines the
target if it is defined locally and would not be documented otherwise,
or when it is specifically requested with please_inline.
(the latter is the case when the import is marked doc(inline))
Cross-crate inlining occurs later on during crate cleaning and follows different rules.
Returns true if the target has been inlined.
pub fn visit_item(
&mut self,
item: &Item,
renamed: Option<Name>,
om: &mut Module
)[src]
pub fn visit_item(
&mut self,
item: &Item,
renamed: Option<Name>,
om: &mut Module
)fn visit_local_macro(&self, def: &MacroDef) -> Macro[src]
fn visit_local_macro(&self, def: &MacroDef) -> MacroTrait Implementations
impl<'a, 'tcx, 'rcx, 'cstore> Clean<Crate> for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>[src]
impl<'a, 'tcx, 'rcx, 'cstore> Clean<Crate> for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>fn clean(&self, cx: &DocContext) -> Crate[src]
fn clean(&self, cx: &DocContext) -> CrateAuto Trait Implementations
impl<'a, 'tcx, 'rcx, 'cstore> !Send for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>
impl<'a, 'tcx, 'rcx, 'cstore> !Send for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>impl<'a, 'tcx, 'rcx, 'cstore> !Sync for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>
impl<'a, 'tcx, 'rcx, 'cstore> !Sync for RustdocVisitor<'a, 'tcx, 'rcx, 'cstore>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>try_from)Performs the conversion.
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow(&self) -> &T[src]
fn borrow(&self) -> &TImmutably borrows from an owned value. Read more
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>try_from)Performs the conversion.
impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, ⓘImportant traits for &'a mut Rfn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut TMutably borrows from an owned value. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Gets the TypeId of self. Read more
impl<E> SpecializationError for E[src]
impl<E> SpecializationError for Efn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, [src]
fn not_found<S, T>(trait_name: &'static str, method_name: &'static str) -> E where
T: ?Sized, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create an error for a missing method specialization. Defaults to panicking with type, trait & method names. S is the encoder/decoder state type, T is the type being encoded/decoded, and the arguments are the names of the trait and method that should've been overridden. Read more
impl<T> Erased for T[src]
impl<T> Erased for Timpl<T> Send for T where
T: ?Sized, [src]
impl<T> Send for T where
T: ?Sized, impl<T> Sync for T where
T: ?Sized, [src]
impl<T> Sync for T where
T: ?Sized, impl<T> Erased for T
impl<T> Erased for Timpl<T> MaybeResult for T[src]
impl<T> MaybeResult for Tfn from_ok(x: T) -> T[src]
fn from_ok(x: T) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, [src]
fn map_same<F>(self, f: F) -> T where
F: FnOnce(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, T> Captures for T where
T: ?Sized, [src]
impl<'a, T> Captures for T where
T: ?Sized,