Enum serialize::json::Json [−][src]
pub enum Json {
I64(i64),
U64(u64),
F64(f64),
String(String),
Boolean(bool),
Array(Array),
Object(Object),
Null,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a json value
Variants
I64(i64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
U64(u64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
F64(f64)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
String(String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Boolean(bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Array(Array)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Object(Object)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Null🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Json[src]
impl Jsonpub fn pretty(&self) -> PrettyJson[src]
pub fn pretty(&self) -> PrettyJson🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Borrow this json object as a pretty object to generate a pretty
representation for it via Display.
pub fn find<'a>(&'a self, key: &str) -> Option<&'a Json>[src]
pub fn find<'a>(&'a self, key: &str) -> Option<&'a Json>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is an Object, returns the value associated with the provided key. Otherwise, returns None.
pub fn find_path<'a>(&'a self, keys: &[&str]) -> Option<&'a Json>[src]
pub fn find_path<'a>(&'a self, keys: &[&str]) -> Option<&'a Json>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Attempts to get a nested Json Object for each key in keys.
If any key is found not to exist, find_path will return None.
Otherwise, it will return the Json value associated with the final key.
pub fn search<'a>(&'a self, key: &str) -> Option<&'a Json>[src]
pub fn search<'a>(&'a self, key: &str) -> Option<&'a Json>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is an Object, performs a depth-first search until a value associated with the provided key is found. If no value is found or the Json value is not an Object, returns None.
pub fn is_object(&self) -> bool[src]
pub fn is_object(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is an Object. Returns false otherwise.
pub fn as_object(&self) -> Option<&Object>[src]
pub fn as_object(&self) -> Option<&Object>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is an Object, returns the associated BTreeMap. Returns None otherwise.
pub fn is_array(&self) -> bool[src]
pub fn is_array(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is an Array. Returns false otherwise.
pub fn as_array(&self) -> Option<&Array>[src]
pub fn as_array(&self) -> Option<&Array>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is an Array, returns the associated vector. Returns None otherwise.
pub fn is_string(&self) -> bool[src]
pub fn is_string(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a String. Returns false otherwise.
pub fn as_string(&self) -> Option<&str>[src]
pub fn as_string(&self) -> Option<&str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a String, returns the associated str. Returns None otherwise.
pub fn is_number(&self) -> bool[src]
pub fn is_number(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a Number. Returns false otherwise.
pub fn is_i64(&self) -> bool[src]
pub fn is_i64(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a i64. Returns false otherwise.
pub fn is_u64(&self) -> bool[src]
pub fn is_u64(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a u64. Returns false otherwise.
pub fn is_f64(&self) -> bool[src]
pub fn is_f64(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a f64. Returns false otherwise.
pub fn as_i64(&self) -> Option<i64>[src]
pub fn as_i64(&self) -> Option<i64>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a number, return or cast it to a i64. Returns None otherwise.
pub fn as_u64(&self) -> Option<u64>[src]
pub fn as_u64(&self) -> Option<u64>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a number, return or cast it to a u64. Returns None otherwise.
pub fn as_f64(&self) -> Option<f64>[src]
pub fn as_f64(&self) -> Option<f64>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a number, return or cast it to a f64. Returns None otherwise.
pub fn is_boolean(&self) -> bool[src]
pub fn is_boolean(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a Boolean. Returns false otherwise.
pub fn as_boolean(&self) -> Option<bool>[src]
pub fn as_boolean(&self) -> Option<bool>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a Boolean, returns the associated bool. Returns None otherwise.
pub fn is_null(&self) -> bool[src]
pub fn is_null(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the Json value is a Null. Returns false otherwise.
pub fn as_null(&self) -> Option<()>[src]
pub fn as_null(&self) -> Option<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If the Json value is a Null, returns (). Returns None otherwise.