Struct serialize::json::Builder [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Builder consumes a json::Parser to create a generic Json structure.
Fields
parser: Parser<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
token: Option<JsonEvent>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: Iterator<Item = char>> Builder<T>[src]
impl<T: Iterator<Item = char>> Builder<T>pub fn new(src: T) -> Builder<T>[src]
pub fn new(src: T) -> Builder<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a JSON Builder.
pub fn build(&mut self) -> Result<Json, BuilderError>[src]
pub fn build(&mut self) -> Result<Json, BuilderError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn bump(&mut self)[src]
fn bump(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_value(&mut self) -> Result<Json, BuilderError>[src]
fn build_value(&mut self) -> Result<Json, BuilderError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_array(&mut self) -> Result<Json, BuilderError>[src]
fn build_array(&mut self) -> Result<Json, BuilderError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn build_object(&mut self) -> Result<Json, BuilderError>[src]
fn build_object(&mut self) -> Result<Json, BuilderError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?