Struct serialize::json::FormatShim [−][src]
struct FormatShim<'a, 'b: 'a> {
inner: &'a mut Formatter<'b>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
inner: &'a mut Formatter<'b>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?