[−][src]Struct serialize::opaque::Encoder
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
data: Vec<u8>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Encoder[src]
impl Encoderpub fn new(data: Vec<u8>) -> Encoder[src]
pub fn new(data: Vec<u8>) -> Encoder🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn into_inner(self) -> Vec<u8>[src]
pub fn into_inner(self) -> Vec<u8>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn emit_raw_bytes(&mut self, s: &[u8])[src]
pub fn emit_raw_bytes(&mut self, s: &[u8])🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Encoder[src]
impl Encoderpub fn position(&self) -> usize[src]
pub fn position(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?