[−][src]Trait serialize::serialize::Decodable
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn decode<D: Decoder>(d: &mut D) -> Result<Self, D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl Decodable for usize[src]
impl Decodable for usizefn decode<D: Decoder>(d: &mut D) -> Result<usize, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<usize, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for u8[src]
impl Decodable for u8fn decode<D: Decoder>(d: &mut D) -> Result<u8, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<u8, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for u16[src]
impl Decodable for u16fn decode<D: Decoder>(d: &mut D) -> Result<u16, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<u16, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for u32[src]
impl Decodable for u32fn decode<D: Decoder>(d: &mut D) -> Result<u32, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<u32, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for NonZeroU32[src]
impl Decodable for NonZeroU32fn decode<D: Decoder>(d: &mut D) -> Result<Self, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Self, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for u64[src]
impl Decodable for u64fn decode<D: Decoder>(d: &mut D) -> Result<u64, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<u64, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for u128[src]
impl Decodable for u128fn decode<D: Decoder>(d: &mut D) -> Result<u128, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<u128, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for isize[src]
impl Decodable for isizefn decode<D: Decoder>(d: &mut D) -> Result<isize, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<isize, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for i8[src]
impl Decodable for i8fn decode<D: Decoder>(d: &mut D) -> Result<i8, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<i8, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for i16[src]
impl Decodable for i16fn decode<D: Decoder>(d: &mut D) -> Result<i16, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<i16, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for i32[src]
impl Decodable for i32fn decode<D: Decoder>(d: &mut D) -> Result<i32, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<i32, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for i64[src]
impl Decodable for i64fn decode<D: Decoder>(d: &mut D) -> Result<i64, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<i64, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for i128[src]
impl Decodable for i128fn decode<D: Decoder>(d: &mut D) -> Result<i128, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<i128, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for String[src]
impl Decodable for Stringfn decode<D: Decoder>(d: &mut D) -> Result<String, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<String, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for f32[src]
impl Decodable for f32fn decode<D: Decoder>(d: &mut D) -> Result<f32, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<f32, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for f64[src]
impl Decodable for f64fn decode<D: Decoder>(d: &mut D) -> Result<f64, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<f64, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for bool[src]
impl Decodable for boolfn decode<D: Decoder>(d: &mut D) -> Result<bool, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<bool, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for char[src]
impl Decodable for charfn decode<D: Decoder>(d: &mut D) -> Result<char, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<char, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for ()[src]
impl Decodable for ()fn decode<D: Decoder>(d: &mut D) -> Result<(), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Box<T>[src]
impl<T: Decodable> Decodable for Box<T>fn decode<D: Decoder>(d: &mut D) -> Result<Box<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Box<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Box<[T]>[src]
impl<T: Decodable> Decodable for Box<[T]>fn decode<D: Decoder>(d: &mut D) -> Result<Box<[T]>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Box<[T]>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Rc<T>[src]
impl<T: Decodable> Decodable for Rc<T>fn decode<D: Decoder>(d: &mut D) -> Result<Rc<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Rc<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Vec<T>[src]
impl<T: Decodable> Decodable for Vec<T>fn decode<D: Decoder>(d: &mut D) -> Result<Vec<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Vec<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable + ToOwned> Decodable for Cow<'static, [T]> where
[T]: ToOwned<Owned = Vec<T>>, [src]
impl<T: Decodable + ToOwned> Decodable for Cow<'static, [T]> where
[T]: ToOwned<Owned = Vec<T>>, fn decode<D: Decoder>(d: &mut D) -> Result<Cow<'static, [T]>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Cow<'static, [T]>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Option<T>[src]
impl<T: Decodable> Decodable for Option<T>fn decode<D: Decoder>(d: &mut D) -> Result<Option<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Option<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T1: Decodable, T2: Decodable> Decodable for Result<T1, T2>[src]
impl<T1: Decodable, T2: Decodable> Decodable for Result<T1, T2>fn decode<D: Decoder>(d: &mut D) -> Result<Result<T1, T2>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Result<T1, T2>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T0: Decodable, T1: Decodable, T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)[src]
impl<T0: Decodable, T1: Decodable, T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T1: Decodable, T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)[src]
impl<T1: Decodable, T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)[src]
impl<T2: Decodable, T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T2, T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T3, T4, T5, T6, T7, T8, T9, T10, T11)[src]
impl<T3: Decodable, T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T3, T4, T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T3, T4, T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T4, T5, T6, T7, T8, T9, T10, T11)[src]
impl<T4: Decodable, T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T4, T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T4, T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T4, T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T5, T6, T7, T8, T9, T10, T11)[src]
impl<T5: Decodable, T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T5, T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(
d: &mut D
) -> Result<(T5, T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(
d: &mut D
) -> Result<(T5, T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T6, T7, T8, T9, T10, T11)[src]
impl<T6: Decodable, T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T6, T7, T8, T9, T10, T11)fn decode<D: Decoder>(d: &mut D) -> Result<(T6, T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T6, T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T7, T8, T9, T10, T11)[src]
impl<T7: Decodable, T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T7, T8, T9, T10, T11)fn decode<D: Decoder>(d: &mut D) -> Result<(T7, T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T7, T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T8, T9, T10, T11)[src]
impl<T8: Decodable, T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T8, T9, T10, T11)fn decode<D: Decoder>(d: &mut D) -> Result<(T8, T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T8, T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T9, T10, T11)[src]
impl<T9: Decodable, T10: Decodable, T11: Decodable> Decodable for (T9, T10, T11)fn decode<D: Decoder>(d: &mut D) -> Result<(T9, T10, T11), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T9, T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T10: Decodable, T11: Decodable> Decodable for (T10, T11)[src]
impl<T10: Decodable, T11: Decodable> Decodable for (T10, T11)fn decode<D: Decoder>(d: &mut D) -> Result<(T10, T11), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T10, T11), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T11: Decodable> Decodable for (T11,)[src]
impl<T11: Decodable> Decodable for (T11,)fn decode<D: Decoder>(d: &mut D) -> Result<(T11,), D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<(T11,), D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Decodable for PathBuf[src]
impl Decodable for PathBuffn decode<D: Decoder>(d: &mut D) -> Result<PathBuf, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<PathBuf, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable + Copy> Decodable for Cell<T>[src]
impl<T: Decodable + Copy> Decodable for Cell<T>fn decode<D: Decoder>(d: &mut D) -> Result<Cell<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Cell<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for RefCell<T>[src]
impl<T: Decodable> Decodable for RefCell<T>fn decode<D: Decoder>(d: &mut D) -> Result<RefCell<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<RefCell<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Arc<T>[src]
impl<T: Decodable> Decodable for Arc<T>fn decode<D: Decoder>(d: &mut D) -> Result<Arc<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Arc<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<A> Decodable for SmallVec<A> where
A: Array,
A::Item: Decodable, [src]
impl<A> Decodable for SmallVec<A> where
A: Array,
A::Item: Decodable, fn decode<D: Decoder>(d: &mut D) -> Result<SmallVec<A>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<SmallVec<A>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for LinkedList<T>[src]
impl<T: Decodable> Decodable for LinkedList<T>fn decode<D: Decoder>(d: &mut D) -> Result<LinkedList<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<LinkedList<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for VecDeque<T>[src]
impl<T: Decodable> Decodable for VecDeque<T>fn decode<D: Decoder>(d: &mut D) -> Result<VecDeque<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<VecDeque<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<K, V> Decodable for BTreeMap<K, V> where
K: Decodable + PartialEq + Ord,
V: Decodable, [src]
impl<K, V> Decodable for BTreeMap<K, V> where
K: Decodable + PartialEq + Ord,
V: Decodable, fn decode<D: Decoder>(d: &mut D) -> Result<BTreeMap<K, V>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<BTreeMap<K, V>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T> Decodable for BTreeSet<T> where
T: Decodable + PartialEq + Ord, [src]
impl<T> Decodable for BTreeSet<T> where
T: Decodable + PartialEq + Ord, fn decode<D: Decoder>(d: &mut D) -> Result<BTreeSet<T>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<BTreeSet<T>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<K, V, S> Decodable for HashMap<K, V, S> where
K: Decodable + Hash + Eq,
V: Decodable,
S: BuildHasher + Default, [src]
impl<K, V, S> Decodable for HashMap<K, V, S> where
K: Decodable + Hash + Eq,
V: Decodable,
S: BuildHasher + Default, fn decode<D: Decoder>(d: &mut D) -> Result<HashMap<K, V, S>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<HashMap<K, V, S>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T, S> Decodable for HashSet<T, S> where
T: Decodable + Hash + Eq,
S: BuildHasher + Default, [src]
impl<T, S> Decodable for HashSet<T, S> where
T: Decodable + Hash + Eq,
S: BuildHasher + Default, fn decode<D: Decoder>(d: &mut D) -> Result<HashSet<T, S>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<HashSet<T, S>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Rc<[T]>[src]
impl<T: Decodable> Decodable for Rc<[T]>fn decode<D: Decoder>(d: &mut D) -> Result<Rc<[T]>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Rc<[T]>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Decodable> Decodable for Arc<[T]>[src]
impl<T: Decodable> Decodable for Arc<[T]>fn decode<D: Decoder>(d: &mut D) -> Result<Arc<[T]>, D::Error>[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Arc<[T]>, D::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<T: UseSpecializedDecodable> Decodable for T[src]
impl<T: UseSpecializedDecodable> Decodable for T