[−][src]Trait serialize::serialize::UseSpecializedEncodable
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implement this trait on your type to get an Encodable
implementation which goes through SpecializedEncoder.
Provided Methods
fn default_encode<E: Encoder>(&self, _: &mut E) -> Result<(), E::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Defaults to returning an error (see SpecializationError).
Implementations on Foreign Types
impl<'a, T: ?Sized + Encodable> UseSpecializedEncodable for &'a T[src]
impl<'a, T: ?Sized + Encodable> UseSpecializedEncodable for &'a Tfn default_encode<E: Encoder>(&self, _: &mut E) -> Result<(), E::Error>[src]
fn default_encode<E: Encoder>(&self, _: &mut E) -> Result<(), E::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: ?Sized + Encodable> UseSpecializedEncodable for Box<T>[src]
impl<T: ?Sized + Encodable> UseSpecializedEncodable for Box<T>fn default_encode<E: Encoder>(&self, _: &mut E) -> Result<(), E::Error>[src]
fn default_encode<E: Encoder>(&self, _: &mut E) -> Result<(), E::Error>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?