Function std::char::is_digit_radixDeprecated
[-]
[+]
[src]
pub fn is_digit_radix(c: char, radix: uint) -> bool
Checks if a char parses as a numeric digit in the given radix
Compared to is_numeric(), this function only recognizes the
characters 0-9, a-z and A-Z.
Return value
Returns true if c is a valid digit under radix, and false
otherwise.
Panics
Panics if given a radix > 36.
Note
This just wraps to_digit().