Struct std::collections::hash_map::VacantEntry 1.0.0
[−]
[src]
pub struct VacantEntry<'a, K: 'a, V: 'a> {
// some fields omitted
}A view into a single empty location in a HashMap.
It is part of the Entry enum.
Methods
impl<'a, K: 'a, V: 'a> VacantEntry<'a, K, V>[src]
fn key(&self) -> &K1.10.0
Gets a reference to the key that would be used when inserting a value
through the VacantEntry.
Examples
fn main() { use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); assert_eq!(map.entry("poneyland").key(), &"poneyland"); }use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); assert_eq!(map.entry("poneyland").key(), &"poneyland");
fn into_key(self) -> K
Unstable (
map_entry_recover_keys #34285)Take ownership of the key.
Examples
#![feature(map_entry_recover_keys)] fn main() { use std::collections::HashMap; use std::collections::hash_map::Entry; let mut map: HashMap<&str, u32> = HashMap::new(); if let Entry::Vacant(v) = map.entry("poneyland") { v.into_key(); } }#![feature(map_entry_recover_keys)] use std::collections::HashMap; use std::collections::hash_map::Entry; let mut map: HashMap<&str, u32> = HashMap::new(); if let Entry::Vacant(v) = map.entry("poneyland") { v.into_key(); }
fn insert(self, value: V) -> &'a mut V
Sets the value of the entry with the VacantEntry's key, and returns a mutable reference to it.
Examples
fn main() { use std::collections::HashMap; use std::collections::hash_map::Entry; let mut map: HashMap<&str, u32> = HashMap::new(); if let Entry::Vacant(o) = map.entry("poneyland") { o.insert(37); } assert_eq!(map["poneyland"], 37); }use std::collections::HashMap; use std::collections::hash_map::Entry; let mut map: HashMap<&str, u32> = HashMap::new(); if let Entry::Vacant(o) = map.entry("poneyland") { o.insert(37); } assert_eq!(map["poneyland"], 37);