Struct std::comm::MessagesUnstable
[-]
[+]
[src]
pub struct Messages<'a, T: 'a> {
// some fields omitted
}An iterator over messages on a receiver, this iterator will block
whenever next is called, waiting for a new message, and None will be
returned when the corresponding channel has hung up.