Function std::intrinsics::breakpointExperimental
[-]
[+]
[src]
pub unsafe fn breakpoint()
Execute a breakpoint trap, for inspection by a debugger.
pub unsafe fn breakpoint()
Execute a breakpoint trap, for inspection by a debugger.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).