Function std::intrinsics::ceilf64Experimental
[-]
[+]
[src]
pub unsafe fn ceilf64(f64) -> f64
Returns the smallest integer greater than or equal to an f64.
pub unsafe fn ceilf64(f64) -> f64
Returns the smallest integer greater than or equal to an f64.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).