Function std::intrinsics::copysignf32
[−]
[src]
pub unsafe extern "rust-intrinsic" fn copysignf32(x: f32, y: f32) -> f32
Unstable
: intrinsics are unlikely to ever be stabilized, instead they should be used through stabilized interfaces in the rest of the standard library
Copies the sign from y`yto` to x`xfor` for f32`f32` values.