Function std::intrinsics::copysignf64Experimental
[-]
[+]
[src]
pub unsafe fn copysignf64(f64, f64) -> f64
Copies the sign from y to x for f64 values.
pub unsafe fn copysignf64(f64, f64) -> f64
Copies the sign from y to x for f64 values.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).