Function std::intrinsics::ctlz64Experimental
[-]
[+]
[src]
pub unsafe fn ctlz64(u64) -> u64
Returns the number of leading bits unset in a u64.
pub unsafe fn ctlz64(u64) -> u64
Returns the number of leading bits unset in a u64.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).