Function std::intrinsics::ctlz8Experimental
[-]
[+]
[src]
pub unsafe fn ctlz8(u8) -> u8
Returns the number of leading bits unset in a u8.
pub unsafe fn ctlz8(u8) -> u8
Returns the number of leading bits unset in a u8.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).