Function std::intrinsics::cttz32Experimental
[-]
[+]
[src]
pub unsafe fn cttz32(u32) -> u32
Returns the number of trailing bits unset in a u32.
pub unsafe fn cttz32(u32) -> u32
Returns the number of trailing bits unset in a u32.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).