Function std::intrinsics::floorf32Experimental
[-]
[+]
[src]
pub unsafe fn floorf32(f32) -> f32
Returns the largest integer less than or equal to an f32.
pub unsafe fn floorf32(f32) -> f32
Returns the largest integer less than or equal to an f32.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).