Function std::intrinsics::floorf64Experimental
[-]
[+]
[src]
pub unsafe fn floorf64(f64) -> f64
Returns the largest integer less than or equal to an f64.
pub unsafe fn floorf64(f64) -> f64
Returns the largest integer less than or equal to an f64.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).