Enum std::io::FileModeExperimental
[-]
[+]
[src]
pub enum FileMode {
Open,
Append,
Truncate,
}A mode specifies how a file should be opened or created. These modes are
passed to File::open_mode and are used to control where the file is
positioned when it is initially opened.
Variants
Open | Opens a file positioned at the beginning. |
Append | Opens a file positioned at EOF. |
Truncate | Opens a file, truncating it if it already exists. |