Trait std::io::fs::PathExtensionsExperimental
[-]
[+]
[src]
pub trait PathExtensions {
fn stat(&self) -> IoResult<FileStat>;
fn lstat(&self) -> IoResult<FileStat>;
fn exists(&self) -> bool;
fn is_file(&self) -> bool;
fn is_dir(&self) -> bool;
}Utility methods for paths.
Required Methods
fn stat(&self) -> IoResult<FileStat>
Get information on the file, directory, etc at this path.
Consult the fs::stat documentation for more info.
This call preserves identical runtime/error semantics with file::stat.
fn lstat(&self) -> IoResult<FileStat>
Get information on the file, directory, etc at this path, not following symlinks.
Consult the fs::lstat documentation for more info.
This call preserves identical runtime/error semantics with file::lstat.
fn exists(&self) -> bool
Boolean value indicator whether the underlying file exists on the local
filesystem. Returns false in exactly the cases where fs::stat fails.
fn is_file(&self) -> bool
Whether the underlying implementation (be it a file path, or something else) points at a "regular file" on the FS. Will return false for paths to non-existent locations or directories or other non-regular files (named pipes, etc). Follows links when making this determination.
fn is_dir(&self) -> bool
Whether the underlying implementation (be it a file path, or something else) is pointing at a directory in the underlying FS. Will return false for paths to non-existent locations or if the item is not a directory (eg files, named pipes, etc). Follows links when making this determination.
Implementors
impl PathExtensions for Path