Struct std::io::net::addrinfo::HintExperimental
[-]
[+]
[src]
pub struct Hint {
pub family: uint,
pub socktype: Option<SocketType>,
pub protocol: Option<Protocol>,
pub flags: uint,
}This structure is used to provide hints when fetching addresses for a remote host to control how the lookup is performed.
For details on these fields, see their corresponding definitions via
man -s 3 getaddrinfo
Fields
family | |
socktype | |
protocol | |
flags |