Struct std::io::CharsExperimental
[-]
[+]
[src]
pub struct Chars<'r, T: 'r> {
// some fields omitted
}An iterator that reads a utf8-encoded character on each iteration,
until .read_char() encounters EndOfFile.
Notes about the Iteration Protocol
The Chars may yield None and thus terminate
an iteration, but continue to yield elements if iteration
is attempted again.
Error
Any error other than EndOfFile that is produced by the underlying Reader
is returned by the iterator and should be handled by the caller.