Struct std::io::IncomingConnectionsExperimental
[-]
[+]
[src]
pub struct IncomingConnections<'a, A: 'a> {
// some fields omitted
}An infinite iterator over incoming connection attempts.
Calling next will block the task until a connection is attempted.
Since connection attempts can continue forever, this iterator always returns
Some. The Some contains the IoResult representing whether the
connection attempt was successful. A successful connection will be wrapped
in Ok. A failed connection is represented as an Err.