Struct std::io::UnstableFileStatUnstable
[-]
[+]
[src]
pub struct UnstableFileStat {
pub device: u64,
pub inode: u64,
pub rdev: u64,
pub nlink: u64,
pub uid: u64,
pub gid: u64,
pub blksize: u64,
pub blocks: u64,
pub flags: u64,
pub gen: u64,
}This structure represents all of the possible information which can be
returned from a stat syscall which is not contained in the FileStat
structure. This information is not necessarily platform independent, and may
have different meanings or no meaning at all on some platforms.