Function std::io::test::raise_fd_limitExperimental
[-]
[+]
[src]
pub fn raise_fd_limit()
Raises the file descriptor limit when running tests if necessary
pub fn raise_fd_limit()
Raises the file descriptor limit when running tests if necessary
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).