Trait std::io::AcceptorExperimental
[-]
[+]
[src]
pub trait Acceptor<T> {
fn accept(&mut self) -> IoResult<T>;
fn incoming<'r>(&'r mut self) -> IncomingConnections<'r, Self> { ... }
}An acceptor is a value that presents incoming connections
Required Methods
Provided Methods
fn incoming<'r>(&'r mut self) -> IncomingConnections<'r, Self>
Create an iterator over incoming connection attempts.
Note that I/O errors will be yielded by the iterator itself.
Implementors
impl<T, A: Acceptor<T>> Acceptor<T> for IoResult<A>impl Acceptor<TcpStream> for TcpAcceptorimpl Acceptor<UnixStream> for UnixAcceptor