std::io::Result
[−]
[src]
type Result<T> = Result<T, Error>;
A specialized Result`Result` type for I/O operations.
This type is broadly used across std::io`std::io` for any operation which may
produce an error.
This typedef is generally used to avoid writing out io::Error directly and
is otherwise a direct mapping to Result`Result`.
While usual Rust style is to import types directly, aliases of Result`Resultoften are not, to make it easier to distinguish between them.Resultis generally assumed to bestd::result::Result, and so users of this alias will generally useio::Resultinstead of shadowing the prelude's import ofstd::result::Result`.
Examples
A convenience function that bubbles an io::Result to its caller:
use std::io; fn get_string() -> io::Result<String> { let mut buffer = String::new(); try!(io::stdin().read_line(&mut buffer)); Ok(buffer) }