Struct std::io::util::MultiWriterExperimental
[-]
[+]
[src]
pub struct MultiWriter {
// some fields omitted
}A Writer which multiplexes writes to a set of Writers.
The Writers are delegated to in order. If any Writer returns an error,
that error is returned immediately and remaining Writers are not called.
Methods
impl MultiWriter
fn new(writers: Vec<Box<Writer + 'static>>) -> MultiWriter
Creates a new MultiWriter