Struct std::io::util::NullWriterExperimental
[-]
[+]
[src]
pub struct NullWriter;
A Writer which ignores bytes written to it, like /dev/null.
pub struct NullWriter;
A Writer which ignores bytes written to it, like /dev/null.
impl Writer for NullWriterfn write(&mut self, _buf: &[u8]) -> IoResult<()>fn flush(&mut self) -> IoResult<()>fn write_fmt(&mut self, fmt: Arguments) -> IoResult<()>fn write_str(&mut self, s: &str) -> IoResult<()>fn write_line(&mut self, s: &str) -> IoResult<()>fn write_char(&mut self, c: char) -> IoResult<()>fn write_int(&mut self, n: int) -> IoResult<()>fn write_uint(&mut self, n: uint) -> IoResult<()>fn write_le_uint(&mut self, n: uint) -> IoResult<()>fn write_le_int(&mut self, n: int) -> IoResult<()>fn write_be_uint(&mut self, n: uint) -> IoResult<()>fn write_be_int(&mut self, n: int) -> IoResult<()>fn write_be_u64(&mut self, n: u64) -> IoResult<()>fn write_be_u32(&mut self, n: u32) -> IoResult<()>fn write_be_u16(&mut self, n: u16) -> IoResult<()>fn write_be_i64(&mut self, n: i64) -> IoResult<()>fn write_be_i32(&mut self, n: i32) -> IoResult<()>fn write_be_i16(&mut self, n: i16) -> IoResult<()>fn write_be_f64(&mut self, f: f64) -> IoResult<()>fn write_be_f32(&mut self, f: f32) -> IoResult<()>fn write_le_u64(&mut self, n: u64) -> IoResult<()>fn write_le_u32(&mut self, n: u32) -> IoResult<()>fn write_le_u16(&mut self, n: u16) -> IoResult<()>fn write_le_i64(&mut self, n: i64) -> IoResult<()>fn write_le_i32(&mut self, n: i32) -> IoResult<()>fn write_le_i16(&mut self, n: i16) -> IoResult<()>fn write_le_f64(&mut self, f: f64) -> IoResult<()>fn write_le_f32(&mut self, f: f32) -> IoResult<()>fn write_u8(&mut self, n: u8) -> IoResult<()>fn write_i8(&mut self, n: i8) -> IoResult<()>impl Copy for NullWriter
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).