Struct std::iter::ClonedExperimental
[-]
[+]
[src]
pub struct Cloned<I> {
// some fields omitted
}An iterator that clones the elements of an underlying iterator
pub struct Cloned<I> {
// some fields omitted
}An iterator that clones the elements of an underlying iterator
impl<A: Clone, D: Deref<A>, I: Iterator<D>> Iterator<A> for Cloned<I>fn next(&mut self) -> Option<A>fn size_hint(&self) -> (uint, Option<uint>)fn size_hint(&self) -> (uint, Option<uint>)impl<A: Clone, D: Deref<A>, I: DoubleEndedIterator<D>> DoubleEndedIterator<A> for Cloned<I>impl<A: Clone, D: Deref<A>, I: ExactSizeIterator<D>> ExactSizeIterator<A> for Cloned<I>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).