Struct std::iter::FilterStable
[-]
[+]
[src]
pub struct Filter<A, I, P> {
// some fields omitted
}An iterator that filters the elements of iter with predicate
pub struct Filter<A, I, P> {
// some fields omitted
}An iterator that filters the elements of iter with predicate
impl<A, I, P> Clone for Filter<A, I, P>fn clone(&self) -> Filter<A, I, P>fn clone_from(&mut self, &Filter<A, I, P>)impl<A, I, P> Iterator<A> for Filter<A, I, P>fn next(&mut self) -> Option<A>fn size_hint(&self) -> (uint, Option<uint>)fn size_hint(&self) -> (uint, Option<uint>)impl<A, I, P> DoubleEndedIterator<A> for Filter<A, I, P>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).