Struct std::iter::MapStable
[-]
[+]
[src]
pub struct Map<A, B, I: Iterator<A>, F: FnMut(A) -> B> {
// some fields omitted
}An iterator that maps the values of iter with f
pub struct Map<A, B, I: Iterator<A>, F: FnMut(A) -> B> {
// some fields omitted
}An iterator that maps the values of iter with f
impl<A, B, I, F> ExactSizeIterator<B> for Map<A, B, I, F>impl<A, B, I, F> Clone for Map<A, B, I, F>fn clone(&self) -> Map<A, B, I, F>fn clone_from(&mut self, &Map<A, B, I, F>)impl<A, B, I, F> Iterator<B> for Map<A, B, I, F>fn next(&mut self) -> Option<B>fn size_hint(&self) -> (uint, Option<uint>)fn size_hint(&self) -> (uint, Option<uint>)impl<A, B, I, F> DoubleEndedIterator<B> for Map<A, B, I, F>impl<A, B, I, F> RandomAccessIterator<B> for Map<A, B, I, F>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).