pub struct Scan<A, B, I, St, F> {
pub state: St,
// some fields omitted
}An iterator to maintain state while iterating another iterator
Fields
state | The current internal state to be passed to the closure next.
|