Struct std::iter::SkipWhileStable
[-]
[+]
[src]
pub struct SkipWhile<A, I, P> {
// some fields omitted
}An iterator that rejects elements while predicate is true
pub struct SkipWhile<A, I, P> {
// some fields omitted
}An iterator that rejects elements while predicate is true
impl<A, I, P> Clone for SkipWhile<A, I, P>fn clone(&self) -> SkipWhile<A, I, P>fn clone_from(&mut self, &SkipWhile<A, I, P>)impl<A, I, P> Iterator<A> for SkipWhile<A, I, P>
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).