Struct std::iter::TakeStable
[-]
[+]
[src]
pub struct Take<T> {
// some fields omitted
}An iterator that only iterates over the first n iterations of iter.
pub struct Take<T> {
// some fields omitted
}An iterator that only iterates over the first n iterations of iter.
impl<A, T: Iterator<A>> Iterator<A> for Take<T>fn next(&mut self) -> Option<A>fn size_hint(&self) -> (uint, Option<uint>)fn size_hint(&self) -> (uint, Option<uint>)impl<A, T: RandomAccessIterator<A>> RandomAccessIterator<A> for Take<T>impl<T: Clone> Clone for Take<T>fn clone(&self) -> Take<T>fn clone_from(&mut self, &Take<T>)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).