Trait std::marker::Copy 1.0.0
[−]
[src]
#[lang = "copy"]pub trait Copy: Clone { }
Types whose values can be duplicated simply by copying bits.
By default, variable bindings have 'move semantics.' In other words:
#[derive(Debug)] struct Foo; let x = Foo; let y = x; // `x` has moved into `y`, and so cannot be used // println!("{:?}", x); // error: use of moved valueRun
However, if a type implements Copy, it instead has 'copy semantics':
// We can derive a `Copy` implementation. `Clone` is also required, as it's // a supertrait of `Copy`. #[derive(Debug, Copy, Clone)] struct Foo; let x = Foo; let y = x; // `y` is a copy of `x` println!("{:?}", x); // A-OK!Run
It's important to note that in these two examples, the only difference is whether you
are allowed to access x after the assignment. Under the hood, both a copy and a move
can result in bits being copied in memory, although this is sometimes optimized away.
How can I implement Copy?
There are two ways to implement Copy on your type. The simplest is to use derive:
#[derive(Copy, Clone)] struct MyStruct;Run
You can also implement Copy and Clone manually:
struct MyStruct; impl Copy for MyStruct { } impl Clone for MyStruct { fn clone(&self) -> MyStruct { *self } }Run
There is a small difference between the two: the derive strategy will also place a Copy
bound on type parameters, which isn't always desired.
What's the difference between Copy and Clone?
Copies happen implicitly, for example as part of an assignment y = x. The behavior of
Copy is not overloadable; it is always a simple bit-wise copy.
Cloning is an explicit action, x.clone(). The implementation of Clone can
provide any type-specific behavior necessary to duplicate values safely. For example,
the implementation of Clone for String needs to copy the pointed-to string
buffer in the heap. A simple bitwise copy of String values would merely copy the
pointer, leading to a double free down the line. For this reason, String is Clone
but not Copy.
Clone is a supertrait of Copy, so everything which is Copy must also implement
Clone. If a type is Copy then its Clone implementation only needs to return *self
(see the example above).
When can my type be Copy?
A type can implement Copy if all of its components implement Copy. For example, this
struct can be Copy:
struct Point { x: i32, y: i32, }Run
A struct can be Copy, and i32 is Copy, therefore Point is eligible to be Copy.
By contrast, consider
struct PointList { points: Vec<Point>, }Run
The struct PointList cannot implement Copy, because Vec<T> is not Copy. If we
attempt to derive a Copy implementation, we'll get an error:
the trait `Copy` may not be implemented for this type; field `points` does not implement `Copy`
When can't my type be Copy?
Some types can't be copied safely. For example, copying &mut T would create an aliased
mutable reference. Copying String would duplicate responsibility for managing the
String's buffer, leading to a double free.
Generalizing the latter case, any type implementing Drop can't be Copy, because it's
managing some resource besides its own size_of::<T> bytes.
If you try to implement Copy on a struct or enum containing non-Copy data, you will get
the error E0204.
When should my type be Copy?
Generally speaking, if your type can implement Copy, it should. Keep in mind, though,
that implementing Copy is part of the public API of your type. If the type might become
non-Copy in the future, it could be prudent to omit the Copy implementation now, to
avoid a breaking API change.
Implementors
impl Copy for ReseedWithDefaultimpl Copy for LogNormalimpl Copy for Normalimpl Copy for Isaac64Rngimpl Copy for ChaChaRngimpl Copy for Expimpl Copy for Exp1impl Copy for IsaacRngimpl Copy for StandardNormalimpl Copy for _Unwind_Reason_Codeimpl Copy for _Unwind_Actionimpl Copy for FpCategoryimpl Copy for Errorimpl<T> Copy for Wrapping<T> where
T: Copy,impl<T, E> Copy for Result<T, E> where
E: Copy,
T: Copy,impl<T> Copy for Discriminant<T>impl Copy for CharTryFromErrorimpl<'a> Copy for Arguments<'a>impl Copy for Utf8Errorimpl<T> Copy for NonZero<T> where
T: Zeroable + Copy,impl<T> Copy for Shared<T> where
T: ?Sized,impl<T> Copy for Option<T> where
T: Copy,impl<Idx> Copy for RangeToInclusive<Idx> where
Idx: Copy,impl Copy for RangeFullimpl Copy for TryFromIntErrorimpl Copy for TypeIdimpl<T> Copy for PhantomData<T> where
T: ?Sized,impl Copy for SearchStepimpl Copy for TraitObjectimpl Copy for std::sync::atomic::Orderingimpl Copy for std::cmp::Orderingimpl<Idx> Copy for RangeTo<Idx> where
Idx: Copy,impl<T> Copy for Unique<T> where
T: ?Sized,impl Copy for passwdimpl Copy for if_nameindeximpl Copy for groupimpl Copy for sockaddr_in6impl Copy for statimpl Copy for ipv6_mreqimpl Copy for winsizeimpl Copy for sigvalimpl Copy for statvfsimpl Copy for sockaddr_unimpl Copy for addrinfoimpl Copy for fd_setimpl Copy for keventimpl Copy for sf_hdtrimpl Copy for timespecimpl Copy for fstore_timpl Copy for proc_bsdinfoimpl Copy for pthread_mutex_timpl Copy for utimbufimpl Copy for sockaddrimpl Copy for in6_addrimpl Copy for lconvimpl Copy for pthread_attr_timpl Copy for statfsimpl Copy for dqblkimpl Copy for rusageimpl Copy for proc_threadinfoimpl Copy for siginfo_timpl Copy for pthread_rwlock_timpl Copy for sigactionimpl Copy for timeval32impl Copy for aiocbimpl Copy for lingerimpl Copy for cmsghdrimpl Copy for pthread_condattr_timpl Copy for pollfdimpl Copy for fsid_timpl Copy for pthread_cond_timpl Copy for glob_timpl Copy for sockaddr_inimpl Copy for termiosimpl Copy for utmpximpl Copy for proc_taskinfoimpl Copy for utsnameimpl Copy for flockimpl Copy for ip_mreqimpl Copy for tmsimpl Copy for pthread_mutexattr_timpl Copy for pthread_rwlockattr_timpl Copy for radvisoryimpl Copy for sigeventimpl Copy for hostentimpl Copy for mach_timebase_infoimpl Copy for kevent64_simpl Copy for if_msghdrimpl Copy for iovecimpl Copy for tmimpl Copy for rlimitimpl Copy for itimervalimpl Copy for proc_taskallinfoimpl Copy for timevalimpl Copy for direntimpl Copy for xsw_usageimpl Copy for stack_timpl Copy for Dl_infoimpl Copy for ifaddrsimpl Copy for if_dataimpl Copy for in_addrimpl Copy for sockaddr_storageimpl Copy for msghdrimpl Copy for ParseErrorimpl<T> Copy for Bound<T> where
T: Copy,impl Copy for ExchangeHeapSingletonimpl Copy for Heapimpl Copy for LocalKeyStateimpl Copy for ThreadIdimpl Copy for FileTypeimpl Copy for ErrorKindimpl Copy for SeekFromimpl Copy for IpAddrimpl Copy for Ipv4Addrimpl Copy for Ipv6Addrimpl Copy for Ipv6MulticastScopeimpl Copy for SocketAddrimpl Copy for SocketAddrV4impl Copy for SocketAddrV6impl Copy for Shutdownimpl<'a> Copy for Prefix<'a>impl<'a> Copy for PrefixComponent<'a>impl<'a> Copy for Component<'a>impl Copy for ExitStatusimpl<T: Copy> Copy for SendError<T>impl Copy for RecvErrorimpl Copy for TryRecvErrorimpl Copy for RecvTimeoutErrorimpl<T: Copy> Copy for TrySendError<T>impl Copy for WaitTimeoutResultimpl Copy for Durationimpl Copy for Instantimpl Copy for SystemTime