Struct std::option::IterStable
[-]
[+]
[src]
pub struct Iter<'a, A: 'a> {
// some fields omitted
}An iterator over a reference of the contained item in an Option.
pub struct Iter<'a, A: 'a> {
// some fields omitted
}An iterator over a reference of the contained item in an Option.
impl<'a, A> Iterator<&'a A> for Iter<'a, A>fn next(&mut self) -> Option<&'a A>fn size_hint(&self) -> (uint, Option<uint>)fn size_hint(&self) -> (uint, Option<uint>)impl<'a, A> DoubleEndedIterator<&'a A> for Iter<'a, A>impl<'a, A> ExactSizeIterator<&'a A> for Iter<'a, A>impl<'a, A> Clone for Iter<'a, A>fn clone(&self) -> Iter<'a, A>fn clone_from(&mut self, &Iter<'a, A>)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).