pub enum MapOption {
MapReadable,
MapWritable,
MapExecutable,
MapAddr(*const u8),
MapFd(HANDLE),
MapOffset(uint),
MapNonStandardFlags(c_int),
}Options the memory map is created with
Variants
MapReadable | The memory should be readable
|
MapWritable | The memory should be writable
|
MapExecutable | The memory should be executable
|
MapAddr | Create a map for a specific address range. Corresponds to MAP_FIXED on
POSIX.
|
MapFd | Create a memory mapping for a file with a given HANDLE.
|
MapOffset | When using MapFd, the start of the map is uint bytes from the start
of the file.
|
MapNonStandardFlags | On POSIX, this can be used to specify the default flags passed to
mmap. By default it uses MAP_PRIVATE and, if not using MapFd,
MAP_ANON. This will override both of those. This is platform-specific
(the exact values used) and ignored on Windows.
|