Function std::os::page_sizeExperimental
[-]
[+]
[src]
pub fn page_size() -> uint
Returns the page size of the current architecture in bytes.
pub fn page_size() -> uint
Returns the page size of the current architecture in bytes.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).