Trait std::os::windows::fs::MetadataExt 1.1.0
[−]
[src]
pub trait MetadataExt {
fn file_attributes(&self) -> u32;
fn creation_time(&self) -> u64;
fn last_access_time(&self) -> u64;
fn last_write_time(&self) -> u64;
fn file_size(&self) -> u64;
}Extension methods for fs::Metadata to access the raw fields contained
within.
Required Methods
fn file_attributes(&self) -> u32
Returns the value of the dwFileAttributes field of this metadata.
This field contains the file system attribute information for a file or directory.
fn creation_time(&self) -> u64
Returns the value of the ftCreationTime field of this metadata.
The returned 64-bit value represents the number of 100-nanosecond intervals since January 1, 1601 (UTC).
fn last_access_time(&self) -> u64
Returns the value of the ftLastAccessTime field of this metadata.
The returned 64-bit value represents the number of 100-nanosecond intervals since January 1, 1601 (UTC).
fn last_write_time(&self) -> u64
Returns the value of the ftLastWriteTime field of this metadata.
The returned 64-bit value represents the number of 100-nanosecond intervals since January 1, 1601 (UTC).
fn file_size(&self) -> u64
Returns the value of the nFileSize{High,Low} fields of this
metadata.
The returned value does not have meaning for directories.
Implementors
impl MetadataExt for Metadata