Trait std::os::windows::fs::OpenOptionsExt
[−]
[src]
pub trait OpenOptionsExt {
fn desired_access(&mut self, access: u32) -> &mut Self;
fn creation_disposition(&mut self, val: u32) -> &mut Self;
fn flags_and_attributes(&mut self, val: u32) -> &mut Self;
fn share_mode(&mut self, val: u32) -> &mut Self;
}: may require more thought/methods
Windows-specific extensions to OpenOptions
Required Methods
fn desired_access(&mut self, access: u32) -> &mut Self
: may require more thought/methods
Overrides the dwDesiredAccess argument to the call to CreateFile
with the specified value.
fn creation_disposition(&mut self, val: u32) -> &mut Self
: may require more thought/methods
Overrides the dwCreationDisposition argument to the call to
CreateFile with the specified value.
This will override any values of the standard create flags, for
example.
fn flags_and_attributes(&mut self, val: u32) -> &mut Self
: may require more thought/methods
Overrides the dwFlagsAndAttributes argument to the call to
CreateFile with the specified value.
This will override any values of the standard flags on the
OpenOptions structure.
fn share_mode(&mut self, val: u32) -> &mut Self
: may require more thought/methods
Overrides the dwShareMode argument to the call to CreateFile with
the specified value.
This will override any values of the standard flags on the
OpenOptions structure.
Implementors
impl OpenOptionsExt for OpenOptionsimpl OpenOptionsExt for OpenOptions