Function std::path::posix::is_sepExperimental
[-]
[+]
[src]
pub fn is_sep(c: char) -> bool
Returns whether the given char is a path separator
pub fn is_sep(c: char) -> bool
Returns whether the given char is a path separator
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).