Trait std::path::GenericPathUnsafeExperimental
[-]
[+]
[src]
pub trait GenericPathUnsafe {
unsafe fn new_unchecked<T: BytesContainer>(path: T) -> Self;
unsafe fn set_filename_unchecked<T: BytesContainer>(&mut self, filename: T);
unsafe fn push_unchecked<T: BytesContainer>(&mut self, path: T);
}A trait that represents the unsafe operations on GenericPaths
Required Methods
unsafe fn new_unchecked<T: BytesContainer>(path: T) -> Self
Creates a new Path without checking for null bytes. The resulting Path will always be normalized.
unsafe fn set_filename_unchecked<T: BytesContainer>(&mut self, filename: T)
Replaces the filename portion of the path without checking for null
bytes.
See set_filename for details.
unsafe fn push_unchecked<T: BytesContainer>(&mut self, path: T)
Pushes a path onto self without checking for null bytes.
See push for details.
Implementors
impl GenericPathUnsafe for Pathimpl GenericPathUnsafe for Path