Struct std::slice::PermutationsUnstable
[-]
[+]
[src]
pub struct Permutations<T> {
// some fields omitted
}An iterator that uses ElementSwaps to iterate through
all possible permutations of a vector.
The first iteration yields a clone of the vector as it is, then each successive element is the vector with one swap applied.
Generates even and odd permutations alternately.