Struct std::slice::RSplitNMutExperimental
[-]
[+]
[src]
pub struct RSplitNMut<'a, T: 'a, P> {
// some fields omitted
}An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.