std::str

Struct Bytes

1.0.0 · Source
pub struct Bytes<'a>(/* private fields */);
An iterator over the bytes of a string slice.

This struct is created by the bytes method on str. See its documentation for more.