Trait std::str::FromStrUnstable
[-]
[+]
[src]
pub trait FromStr {
fn from_str(s: &str) -> Option<Self>;
}A trait to abstract the idea of creating a new instance of a type from a string.
Required Methods
fn from_str(s: &str) -> Option<Self>
Parses a string s to return an optional value of this type. If the
string is ill-formatted, the None is returned.
Implementors
impl FromStr for f32impl FromStr for f64impl FromStr for intimpl FromStr for i8impl FromStr for i16impl FromStr for i32impl FromStr for i64impl FromStr for uintimpl FromStr for u8impl FromStr for u16impl FromStr for u32impl FromStr for u64impl FromStr for boolimpl FromStr for IpAddrimpl FromStr for SocketAddrimpl FromStr for Pathimpl FromStr for Pathimpl FromStr for String