std::sync::LockResult
[−]
[src]
type LockResult<Guard> = Result<Guard, PoisonError<Guard>>;
A type alias for the result of a lock method which can be poisoned.
The Ok`Okvariant of this result indicates that the primitive was not poisoned, and theGuardis contained within. TheErrvariant indicates that the primitive was poisoned. Note that theErrvariant *also* carries the associated guard, and it can be acquired through theinto_inner`
method.