Enum syntax::ast::InlinedItemExperimental
[-]
[+]
[src]
pub enum InlinedItem {
IIItem(P<Item>),
IITraitItem(DefId, TraitItem),
IIImplItem(DefId, ImplItem),
IIForeign(P<ForeignItem>),
}The data we save and restore about an inlined item or method. This is not part of the AST that we parse from a file, but it becomes part of the tree that we trans.
Variants
IIItem | |
IITraitItem | |
IIImplItem | |
IIForeign |