Enum syntax::ast::LitKind [−][src]
pub enum LitKind {
Str(Symbol, StrStyle),
ByteStr(Lrc<Vec<u8>>),
Byte(u8),
Char(char),
Int(u128, LitIntType),
Float(Symbol, FloatTy),
FloatUnsuffixed(Symbol),
Bool(bool),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Literal kind.
E.g. "foo", 42, 12.34 or bool
Variants
Str(Symbol, StrStyle)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A string literal ("foo")
ByteStr(Lrc<Vec<u8>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A byte string (b"foo")
Byte(u8)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A byte char (b'f')
Char(char)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A character literal ('a')
Int(u128, LitIntType)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An integer literal (1)
Float(Symbol, FloatTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A float literal (1f64 or 1E10f64)
FloatUnsuffixed(Symbol)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A float literal without a suffix (1.0 or 1.0E10)
Bool(bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A boolean literal
Methods
impl LitKind[src]
impl LitKindpub fn is_str(&self) -> bool[src]
pub fn is_str(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this literal is a string and false otherwise.
pub fn is_numeric(&self) -> bool[src]
pub fn is_numeric(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this is a numeric literal.
pub fn is_unsuffixed(&self) -> bool[src]
pub fn is_unsuffixed(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this literal has no suffix. Note: this will return true for literals with prefixes such as raw strings and byte strings.
pub fn is_suffixed(&self) -> bool[src]
pub fn is_suffixed(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this literal has a suffix.
impl LitKind[src]
impl LitKindfn token(&self) -> Token[src]
fn token(&self) -> Token🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn from_token(token: Token) -> Option<LitKind>[src]
fn from_token(token: Token) -> Option<LitKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?