Enum syntax::ast::NestedMetaItemKind
[−]
[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Possible values inside of compile-time attribute lists.
E.g. the '..' in #[name(..)].
Variants
MetaItem(MetaItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A full MetaItem, for recursive meta items.
Literal(Lit)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal.
E.g. "foo", 64, true