Enum syntax::ast::PatKind [−][src]
pub enum PatKind {
Wild,
Ident(BindingMode, Ident, Option<P<Pat>>),
Struct(Path, Vec<Spanned<FieldPat>>, bool),
TupleStruct(Path, Vec<P<Pat>>, Option<usize>),
Path(Option<QSelf>, Path),
Tuple(Vec<P<Pat>>, Option<usize>),
Box(P<Pat>),
Ref(P<Pat>, Mutability),
Lit(P<Expr>),
Range(P<Expr>, P<Expr>, Spanned<RangeEnd>),
Slice(Vec<P<Pat>>, Option<P<Pat>>, Vec<P<Pat>>),
Paren(P<Pat>),
Mac(Mac),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Wild🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a wildcard pattern (_)
Ident(BindingMode, Ident, Option<P<Pat>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A PatKind::Ident may either be a new bound variable (ref mut binding @ OPT_SUBPATTERN),
or a unit struct/variant pattern, or a const pattern (in the last two cases the third
field must be None). Disambiguation cannot be done with parser alone, so it happens
during name resolution.
Struct(Path, Vec<Spanned<FieldPat>>, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A struct or struct variant pattern, e.g. Variant {x, y, ..}.
The bool is true in the presence of a ...
TupleStruct(Path, Vec<P<Pat>>, Option<usize>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A tuple struct/variant pattern Variant(x, y, .., z).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Path(Option<QSelf>, Path)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A possibly qualified path pattern.
Unqualified path patterns A::B::C can legally refer to variants, structs, constants
or associated constants. Qualified path patterns <A>::B::C/<A as Trait>::B::C can
only legally refer to associated constants.
Tuple(Vec<P<Pat>>, Option<usize>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A tuple pattern (a, b).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Box(P<Pat>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A box pattern
Ref(P<Pat>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A reference pattern, e.g. &mut (a, b)
Lit(P<Expr>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal
Range(P<Expr>, P<Expr>, Spanned<RangeEnd>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A range pattern, e.g. 1...2, 1..=2 or 1..2
Slice(Vec<P<Pat>>, Option<P<Pat>>, Vec<P<Pat>>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
[a, b, ..i, y, z] is represented as:
PatKind::Slice(box [a, b], Some(i), box [y, z])
Paren(P<Pat>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parentheses in patters used for grouping, i.e. (PAT).
Mac(Mac)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A macro pattern; pre-expansion