Enum syntax::ast::PathParameters [−][src]
pub enum PathParameters {
AngleBracketed(AngleBracketedParameterData),
Parenthesized(ParenthesizedParameterData),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Parameters of a path segment.
E.g. <A, B> as in Foo<A, B> or (A, B) as in Foo(A, B)
Variants
AngleBracketed(AngleBracketedParameterData)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The <'a, A,B,C> in foo::bar::baz::<'a, A,B,C>
Parenthesized(ParenthesizedParameterData)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The (A,B) and C in Foo(A,B) -> C
Methods
impl PathParameters[src]
impl PathParameterspub fn span(&self) -> Span[src]
pub fn span(&self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?