Enum syntax::ast::RangeLimits
[−]
[src]
pub enum RangeLimits {
HalfOpen,
Closed,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Limit types of a range (inclusive or exclusive)
Variants
HalfOpen🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inclusive at the beginning, exclusive at the end
Closed🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inclusive at the beginning and end