Enum syntax::ast::SelfKind [−][src]
pub enum SelfKind {
Value(Mutability),
Region(Option<Lifetime>, Mutability),
Explicit(P<Ty>, Mutability),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Alternative representation for Args describing self parameter of methods.
E.g. &mut self as in fn foo(&mut self)
Variants
Value(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
self, mut self
Region(Option<Lifetime>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
&'lt self, &'lt mut self
Explicit(P<Ty>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
self: TYPE, mut self: TYPE