Struct syntax::ast::AnonConst [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A constant (expression) that's not an item or associated item,
but needs its own DefId for type-checking, const-eval, etc.
These are usually found nested inside types (e.g. array lengths)
or expressions (e.g. repeat counts), and also used to define
explicit discriminant values for enum variants.
Fields
id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
value: P<Expr>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?