Struct syntax::ast::Attribute [−][src]
pub struct Attribute {
pub id: AttrId,
pub style: AttrStyle,
pub path: Path,
pub tokens: TokenStream,
pub is_sugared_doc: bool,
pub span: Span,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Meta-data associated with an item Doc-comments are promoted to attributes that have is_sugared_doc = true
Fields
id: AttrId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
style: AttrStyle
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
path: Path
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tokens: TokenStream
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_sugared_doc: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Attribute[src]
impl Attributepub fn check_name(&self, name: &str) -> bool[src]
pub fn check_name(&self, name: &str) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn name(&self) -> Name[src]
pub fn name(&self) -> Name🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the last segment of the name of this attribute.
E.g. foo for #[foo], skip for #[rustfmt::skip].
pub fn value_str(&self) -> Option<Symbol>[src]
pub fn value_str(&self) -> Option<Symbol>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn meta_item_list(&self) -> Option<Vec<NestedMetaItem>>[src]
pub fn meta_item_list(&self) -> Option<Vec<NestedMetaItem>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_word(&self) -> bool[src]
pub fn is_word(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn span(&self) -> Span[src]
pub fn span(&self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_meta_item_list(&self) -> bool[src]
pub fn is_meta_item_list(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_value_str(&self) -> bool[src]
pub fn is_value_str(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates if the attribute is a Value String.
pub fn is_scoped(&self) -> bool[src]
pub fn is_scoped(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Attribute[src]
impl Attributepub fn meta(&self) -> Option<MetaItem>[src]
pub fn meta(&self) -> Option<MetaItem>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extract the MetaItem from inside this Attribute.
pub fn parse<'a, T, F>(&self, sess: &'a ParseSess, f: F) -> PResult<'a, T> where
F: FnMut(&mut Parser<'a>) -> PResult<'a, T>, [src]
pub fn parse<'a, T, F>(&self, sess: &'a ParseSess, f: F) -> PResult<'a, T> where
F: FnMut(&mut Parser<'a>) -> PResult<'a, T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn parse_list<'a, T, F>(
&self,
sess: &'a ParseSess,
f: F
) -> PResult<'a, Vec<T>> where
F: FnMut(&mut Parser<'a>) -> PResult<'a, T>, [src]
pub fn parse_list<'a, T, F>(
&self,
sess: &'a ParseSess,
f: F
) -> PResult<'a, Vec<T>> where
F: FnMut(&mut Parser<'a>) -> PResult<'a, T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn parse_meta<'a>(&self, sess: &'a ParseSess) -> PResult<'a, MetaItem>[src]
pub fn parse_meta<'a>(&self, sess: &'a ParseSess) -> PResult<'a, MetaItem>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_desugared_doc<T, F>(&self, f: F) -> T where
F: FnOnce(&Attribute) -> T, [src]
pub fn with_desugared_doc<T, F>(&self, f: F) -> T where
F: FnOnce(&Attribute) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert self to a normal #[doc="foo"] comment, if it is a
comment like /// or /** */. (Returns self unchanged for
non-sugared doc attributes.)