Struct syntax::ast::ForeignMod
[−]
[src]
pub struct ForeignMod {
pub abi: Abi,
pub items: Vec<ForeignItem>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Foreign module declaration.
E.g. extern { .. } or extern C { .. }
Fields
abi: Abi
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
items: Vec<ForeignItem>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?