Struct syntax::ast::Ident
[−]
[src]
pub struct Ident {
pub name: Symbol,
pub ctxt: SyntaxContext,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
name: Symbol
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ctxt: SyntaxContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Ident[src]
impl Identpub const fn with_empty_ctxt(name: Symbol) -> Ident[src]
pub const fn with_empty_ctxt(name: Symbol) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_str(string: &str) -> Ident[src]
pub fn from_str(string: &str) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps a string to an identifier with an empty syntax context.
pub fn without_first_quote(&self) -> Ident[src]
pub fn without_first_quote(&self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern(self) -> Ident[src]
pub fn modern(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?