Struct syntax::ast::ParenthesizedParameterData
[−]
[src]
pub struct ParenthesizedParameterData {
pub span: Span,
pub inputs: Vec<P<Ty>>,
pub output: Option<P<Ty>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A path like Foo(A,B) -> C
Fields
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Overall span
inputs: Vec<P<Ty>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
(A,B)
output: Option<P<Ty>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
C