[−][src]Struct syntax::ast::PathSegment
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A segment of a path: an identifier, an optional lifetime, and a set of types.
E.g. std, String or Box<T>
Fields
ident: Ident
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The identifier portion of this path segment.
args: Option<P<GenericArgs>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type/lifetime parameters attached to this path. They come in
two flavors: Path<A,B,C> and Path(A,B) -> C.
None means that no parameter list is supplied (Path),
Some means that parameter list is supplied (Path<X, Y>)
but it can be empty (Path<>).
P is used as a size optimization for the common case with no parameters.
Methods
impl PathSegment[src]
impl PathSegmentpub fn from_ident(ident: Ident) -> Self[src]
pub fn from_ident(ident: Ident) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn crate_root(span: Span) -> Self[src]
pub fn crate_root(span: Span) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?