Struct syntax::ast::PolyTraitRef [−][src]
pub struct PolyTraitRef {
pub bound_generic_params: Vec<GenericParam>,
pub trait_ref: TraitRef,
pub span: Span,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bound_generic_params: Vec<GenericParam>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The 'a in <'a> Foo<&'a T>
trait_ref: TraitRef
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The Foo<&'a T> in <'a> Foo<&'a T>
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl PolyTraitRef[src]
impl PolyTraitRefpub fn new(generic_params: Vec<GenericParam>, path: Path, span: Span) -> Self[src]
pub fn new(generic_params: Vec<GenericParam>, path: Path, span: Span) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?