Struct syntax::ast::QSelf [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The explicit Self type in a "qualified path". The actual
path, including the trait and the associated item, is stored
separately. position represents the index of the associated
item qualified with this Self type.
<Vec<T> as a::b::Trait>::AssociatedItem ^~~~~ ~~~~~~~~~~~~~~^ ty position = 3 <Vec<T>>::AssociatedItem ^~~~~ ^ ty position = 0
Fields
ty: P<Ty>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
path_span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The span of a::b::Trait in a path like <Vec<T> as a::b::Trait>::AssociatedItem; in the case where position == 0, this is an empty span.
position: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?