Struct syntax::ast::WhereBoundPredicate [−][src]
pub struct WhereBoundPredicate {
pub span: Span,
pub bound_generic_params: Vec<GenericParam>,
pub bounded_ty: P<Ty>,
pub bounds: GenericBounds,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A type bound.
E.g. for<'c> Foo: Send+Clone+'c
Fields
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bound_generic_params: Vec<GenericParam>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Any generics from a for binding
bounded_ty: P<Ty>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The type being bounded
bounds: GenericBounds
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Trait and lifetime bounds (Clone+Send+'static)