Type Definition syntax::ast::Lit [−][src]
type Lit = Spanned<LitKind>;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal
Methods
impl Lit[src]
impl Litfn tokens(&self) -> TokenStream[src]
fn tokens(&self) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?