syntax::ast::MrkExperimental
[-]
[+]
[src]
type Mrk = u32;
A mark represents a unique id associated with a macro expansion
type Mrk = u32;
A mark represents a unique id associated with a macro expansion
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).