Struct syntax::ast_map::blocks::FnLikeNodeExperimental
[-]
[+]
[src]
pub struct FnLikeNode<'a> {
// some fields omitted
}An FnLikeNode is a Node that is like a fn, in that it has a decl and a body (as well as a NodeId, a span, etc).
More specifically, it is one of either: - A function item, - A closure expr (i.e. an ExprClosure), or - The default implementation for a trait method.
To construct one, use the Code::from_node function.