Enum syntax::codemap::ExpnFormat [−][src]
pub enum ExpnFormat {
MacroAttribute(Symbol),
MacroBang(Symbol),
CompilerDesugaring(CompilerDesugaringKind),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The source of expansion.
Variants
MacroAttribute(Symbol)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
e.g. #[derive(...)]
MacroBang(Symbol)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
e.g. format!()
CompilerDesugaring(CompilerDesugaringKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Desugaring done by the compiler during HIR lowering.