Enum syntax::codemap::ExternalSource [−][src]
pub enum ExternalSource {
Present(String),
AbsentOk,
AbsentErr,
Unneeded,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The state of the lazy external source loading mechanism of a FileMap.
Variants
Present(String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The external source has been loaded already.
AbsentOk🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
No attempt has been made to load the external source.
AbsentErr🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A failed attempt has been made to load the external source.
Unneeded🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
No external source has to be loaded, since the FileMap represents a local crate.
Methods
impl ExternalSource[src]
impl ExternalSourcepub fn is_absent(&self) -> bool[src]
pub fn is_absent(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_source(&self) -> Option<&str>[src]
pub fn get_source(&self) -> Option<&str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?