Enum syntax::codemap::NonNarrowChar [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifies an offset of a non-narrow character in a FileMap
Variants
ZeroWidth(BytePos)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a zero-width character
Wide(BytePos)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a wide (fullwidth) character
Tab(BytePos)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a tab character, represented visually with a width of 4 characters
Methods
impl NonNarrowChar[src]
impl NonNarrowCharpub fn pos(&self) -> BytePos[src]
pub fn pos(&self) -> BytePos🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the absolute offset of the character in the CodeMap
pub fn width(&self) -> usize[src]
pub fn width(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the width of the character, 0 (zero-width) or 2 (wide)