pub enum Transparency {
Transparent,
SemiTransparent,
Opaque,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A property of a macro expansion that determines how identifiers
produced by that expansion are resolved.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by a transparent expansion is always resolved at call-site.
Call-site spans in procedural macros, hygiene opt-out in macro should use this.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by a semi-transparent expansion may be resolved
either at call-site or at definition-site.
If it's a local variable, label or $crate then it's resolved at def-site.
Otherwise it's resolved at call-site.
macro_rules macros behave like this, built-in macros currently behave like this too,
but that's an implementation detail.
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by an opaque expansion is always resolved at definition-site.
Def-site spans in procedural macros, identifiers from macro by default use this.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
Feeds this value into the given [Hasher]. Read more
Feeds a slice of this type into the given [Hasher]. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.