Struct syntax::codemap::FilePathMapping
[−]
[src]
pub struct FilePathMapping { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl FilePathMapping[src]
impl FilePathMappingpub fn empty() -> FilePathMapping[src]
pub fn empty() -> FilePathMapping🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new(mapping: Vec<(PathBuf, PathBuf)>) -> FilePathMapping[src]
pub fn new(mapping: Vec<(PathBuf, PathBuf)>) -> FilePathMapping🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn map_prefix(&self, path: PathBuf) -> (PathBuf, bool)[src]
pub fn map_prefix(&self, path: PathBuf) -> (PathBuf, bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Applies any path prefix substitution as defined by the mapping. The return value is the remapped path and a boolean indicating whether the path was affected by the mapping.