Struct syntax::codemap::StableFilemapId
[−]
[src]
pub struct StableFilemapId(_);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl StableFilemapId[src]
impl StableFilemapIdpub fn new(filemap: &FileMap) -> StableFilemapId[src]
pub fn new(filemap: &FileMap) -> StableFilemapId🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?