[−][src]Enum syntax::diagnostics::plugin::emitter::ColorConfig
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Auto🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Always🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Never🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ColorConfig[src]
impl ColorConfigTrait Implementations
impl Eq for ColorConfig[src]
impl Eq for ColorConfigfn assert_receiver_is_total_eq(&self)[src]
fn assert_receiver_is_total_eq(&self)impl PartialEq<ColorConfig> for ColorConfig[src]
impl PartialEq<ColorConfig> for ColorConfigfn eq(&self, other: &ColorConfig) -> bool[src]
fn eq(&self, other: &ColorConfig) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Debug for ColorConfig[src]
impl Debug for ColorConfigfn fmt(&self, f: &mut Formatter) -> Result<(), Error>[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>Formats the value using the given formatter. Read more
impl Copy for ColorConfig[src]
impl Copy for ColorConfigimpl Clone for ColorConfig[src]
impl Clone for ColorConfigfn clone(&self) -> ColorConfig[src]
fn clone(&self) -> ColorConfigReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more