Struct syntax::diagnostics::plugin::emitter::EmitterWriter [−][src]
pub struct EmitterWriter {
dst: Destination,
cm: Option<Rc<CodeMapper + 'static + Send + Sync>>,
short_message: bool,
teach: bool,
ui_testing: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
dst: Destination
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cm: Option<Rc<CodeMapper + 'static + Send + Sync>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
short_message: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
teach: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ui_testing: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl EmitterWriter[src]
impl EmitterWriterpub fn stderr(
color_config: ColorConfig,
code_map: Option<Rc<CodeMapper + 'static + Send + Sync>>,
short_message: bool,
teach: bool
) -> EmitterWriter[src]
pub fn stderr(
color_config: ColorConfig,
code_map: Option<Rc<CodeMapper + 'static + Send + Sync>>,
short_message: bool,
teach: bool
) -> EmitterWriter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new(
dst: Box<Write + 'static + Send>,
code_map: Option<Rc<CodeMapper + 'static + Send + Sync>>,
short_message: bool,
teach: bool
) -> EmitterWriter[src]
pub fn new(
dst: Box<Write + 'static + Send>,
code_map: Option<Rc<CodeMapper + 'static + Send + Sync>>,
short_message: bool,
teach: bool
) -> EmitterWriter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn ui_testing(self, ui_testing: bool) -> EmitterWriter[src]
pub fn ui_testing(self, ui_testing: bool) -> EmitterWriter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?