[−][src]Trait syntax::diagnostics::plugin::emitter::Emitter
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Emitter trait for emitting errors.
Required Methods
fn emit(&mut self, db: &DiagnosticBuilder)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Emit a structured diagnostic.
Provided Methods
fn should_show_explain(&self) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if should show explanations about "rustc --explain"
Implementors
impl Emitter for EmitterWriter[src]
impl Emitter for EmitterWriterfn emit(&mut self, db: &DiagnosticBuilder)[src]
fn emit(&mut self, db: &DiagnosticBuilder)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_show_explain(&self) -> bool[src]
fn should_show_explain(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Emitter for JsonEmitter[src]
impl Emitter for JsonEmitterfn emit(&mut self, db: &DiagnosticBuilder)[src]
fn emit(&mut self, db: &DiagnosticBuilder)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn should_show_explain(&self) -> bool[src]
fn should_show_explain(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?