Struct syntax::diagnostics::plugin::registry::Registry [−][src]
pub struct Registry {
descriptions: HashMap<&'static str, &'static str, RandomState>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
descriptions: HashMap<&'static str, &'static str, RandomState>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Registry[src]
impl Registrypub fn new(descriptions: &[(&'static str, &'static str)]) -> Registry[src]
pub fn new(descriptions: &[(&'static str, &'static str)]) -> Registry🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn find_description(&self, code: &str) -> Option<&'static str>[src]
pub fn find_description(&self, code: &str) -> Option<&'static str>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?