Struct syntax::diagnostics::plugin::DiagnosticStyledString [−][src]
pub struct DiagnosticStyledString(pub Vec<StringPart>);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DiagnosticStyledString[src]
impl DiagnosticStyledStringpub fn new() -> DiagnosticStyledString[src]
pub fn new() -> DiagnosticStyledString🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_normal<S>(&mut self, t: S) where
S: Into<String>, [src]
pub fn push_normal<S>(&mut self, t: S) where
S: Into<String>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_highlighted<S>(&mut self, t: S) where
S: Into<String>, [src]
pub fn push_highlighted<S>(&mut self, t: S) where
S: Into<String>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn normal<S>(t: S) -> DiagnosticStyledString where
S: Into<String>, [src]
pub fn normal<S>(t: S) -> DiagnosticStyledString where
S: Into<String>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn highlighted<S>(t: S) -> DiagnosticStyledString where
S: Into<String>, [src]
pub fn highlighted<S>(t: S) -> DiagnosticStyledString where
S: Into<String>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn content(&self) -> String[src]
pub fn content(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?