Struct syntax::diagnostics::plugin::ExplicitBug [−][src]
pub struct ExplicitBug;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Signifies that the compiler died with an explicit call to .bug
or .span_bug rather than a failed assertion, etc.