Enum syntax::early_buffered_lints::BufferedEarlyLintId [−][src]
pub enum BufferedEarlyLintId {
QuestionMarkMacroSep,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Since we cannot import LintIds from rustc::lint, we define some Ids here which can later be
passed to rustc::lint::Lint::from_parser_lint_id to get a rustc::lint::Lint.
Variants
QuestionMarkMacroSep🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Usage of ? as a macro separator is deprecated.