Struct syntax::early_buffered_lints::BufferedEarlyLint [−][src]
pub struct BufferedEarlyLint {
pub span: MultiSpan,
pub msg: String,
pub id: NodeId,
pub lint_id: BufferedEarlyLintId,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stores buffered lint info which can later be passed to librustc.
Fields
span: MultiSpan
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The span of code that we are linting on.
msg: String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The lint message.
id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The NodeId of the AST node that generated the lint.
lint_id: BufferedEarlyLintId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A lint Id that can be passed to rustc::lint::Lint::from_parser_lint_id.