Enum syntax::ext::base::Annotatable [−][src]
pub enum Annotatable {
Item(P<Item>),
TraitItem(P<TraitItem>),
ImplItem(P<ImplItem>),
ForeignItem(P<ForeignItem>),
Stmt(P<Stmt>),
Expr(P<Expr>),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Item(P<Item>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TraitItem(P<TraitItem>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ImplItem(P<ImplItem>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ForeignItem(P<ForeignItem>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stmt(P<Stmt>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Expr(P<Expr>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Annotatable[src]
impl Annotatablepub fn span(&self) -> Span[src]
pub fn span(&self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_item(self) -> P<Item>[src]
pub fn expect_item(self) -> P<Item>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn map_item_or<F, G>(self, f: F, or: G) -> Annotatable where
F: FnMut(P<Item>) -> P<Item>,
G: FnMut(Annotatable) -> Annotatable, [src]
pub fn map_item_or<F, G>(self, f: F, or: G) -> Annotatable where
F: FnMut(P<Item>) -> P<Item>,
G: FnMut(Annotatable) -> Annotatable, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_trait_item(self) -> TraitItem[src]
pub fn expect_trait_item(self) -> TraitItem🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_impl_item(self) -> ImplItem[src]
pub fn expect_impl_item(self) -> ImplItem🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_foreign_item(self) -> ForeignItem[src]
pub fn expect_foreign_item(self) -> ForeignItem🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_stmt(self) -> Stmt[src]
pub fn expect_stmt(self) -> Stmt🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expect_expr(self) -> P<Expr>[src]
pub fn expect_expr(self) -> P<Expr>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn derive_allowed(&self) -> bool[src]
pub fn derive_allowed(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?