Struct syntax::ext::expand::MacroExpander [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
cx: &'a mut ExtCtxt<'b>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
monotonic: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'b> MacroExpander<'a, 'b>[src]
impl<'a, 'b> MacroExpander<'a, 'b>pub fn new(cx: &'a mut ExtCtxt<'b>, monotonic: bool) -> Self[src]
pub fn new(cx: &'a mut ExtCtxt<'b>, monotonic: bool) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expand_crate(&mut self, krate: Crate) -> Crate[src]
pub fn expand_crate(&mut self, krate: Crate) -> Crate🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn expand_fragment(&mut self, input_fragment: AstFragment) -> AstFragment[src]
fn expand_fragment(&mut self, input_fragment: AstFragment) -> AstFragment🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn resolve_imports(&mut self)[src]
fn resolve_imports(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn collect_invocations(
&mut self,
fragment: AstFragment,
derives: &[Mark]
) -> (AstFragment, Vec<Invocation>)[src]
fn collect_invocations(
&mut self,
fragment: AstFragment,
derives: &[Mark]
) -> (AstFragment, Vec<Invocation>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Collect all macro invocations reachable at this time in this AST fragment, and replace
them with "placeholders" - dummy macro invocations with specially crafted NodeIds.
Then call into resolver that builds a skeleton ("reduced graph") of the fragment and
prepares data for resolving paths of macro invocations.
fn fully_configure(&mut self, item: Annotatable) -> Annotatable[src]
fn fully_configure(&mut self, item: Annotatable) -> Annotatable🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn expand_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>[src]
fn expand_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn expand_attr_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>[src]
fn expand_attr_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn extract_proc_macro_attr_input(
&self,
tokens: TokenStream,
span: Span
) -> TokenStream[src]
fn extract_proc_macro_attr_input(
&self,
tokens: TokenStream,
span: Span
) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn gate_proc_macro_attr_item(&self, span: Span, item: &Annotatable)[src]
fn gate_proc_macro_attr_item(&self, span: Span, item: &Annotatable)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn gate_proc_macro_expansion(&self, span: Span, fragment: &Option<AstFragment>)[src]
fn gate_proc_macro_expansion(&self, span: Span, fragment: &Option<AstFragment>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn expand_bang_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>[src]
fn expand_bang_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Expand a macro invocation. Returns the resulting expanded AST fragment.
fn gate_proc_macro_expansion_kind(&self, span: Span, kind: AstFragmentKind)[src]
fn gate_proc_macro_expansion_kind(&self, span: Span, kind: AstFragmentKind)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn expand_derive_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>[src]
fn expand_derive_invoc(
&mut self,
invoc: Invocation,
ext: &SyntaxExtension
) -> Option<AstFragment>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Expand a derive invocation. Returns the resulting expanded AST fragment.
fn parse_ast_fragment(
&mut self,
toks: TokenStream,
kind: AstFragmentKind,
path: &Path,
span: Span
) -> Option<AstFragment>[src]
fn parse_ast_fragment(
&mut self,
toks: TokenStream,
kind: AstFragmentKind,
path: &Path,
span: Span
) -> Option<AstFragment>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?