Enum syntax::ext::hygiene::CompilerDesugaringKind
[−]
[src]
pub enum CompilerDesugaringKind {
BackArrow,
DotFill,
QuestionMark,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The kind of compiler desugaring.
Variants
BackArrow🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
DotFill🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
QuestionMark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl CompilerDesugaringKind[src]
impl CompilerDesugaringKindpub fn as_symbol(&self) -> Symbol[src]
pub fn as_symbol(&self) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?