[−][src]Struct syntax::ext::hygiene::Mark
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A mark is a unique id associated with a macro expansion.
Methods
impl Mark[src]
impl Markpub fn fresh(parent: Mark) -> Mark[src]
pub fn fresh(parent: Mark) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn root() -> Mark[src]
pub fn root() -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The mark of the theoretical expansion that generates freshly parsed, unexpanded AST.
pub fn as_u32(self) -> u32[src]
pub fn as_u32(self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_u32(raw: u32) -> Mark[src]
pub fn from_u32(raw: u32) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn parent(self) -> Mark[src]
pub fn parent(self) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn expn_info(self) -> Option<ExpnInfo>[src]
pub fn expn_info(self) -> Option<ExpnInfo>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_expn_info(self, info: ExpnInfo)[src]
pub fn set_expn_info(self, info: ExpnInfo)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_default_transparency(self, transparency: Transparency)[src]
pub fn set_default_transparency(self, transparency: Transparency)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_builtin(self) -> bool[src]
pub fn is_builtin(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn set_is_builtin(self, is_builtin: bool)[src]
pub fn set_is_builtin(self, is_builtin: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_descendant_of(self, ancestor: Mark) -> bool[src]
pub fn is_descendant_of(self, ancestor: Mark) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn least_ancestor(a: Mark, b: Mark) -> Mark[src]
pub fn least_ancestor(a: Mark, b: Mark) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Computes a mark such that both input marks are descendants of (or equal to) the returned mark. That is, the following holds:
let la = least_ancestor(a, b); assert!(a.is_descendant_of(la)) assert!(b.is_descendant_of(la))
pub fn looks_like_proc_macro_derive(self) -> bool[src]
pub fn looks_like_proc_macro_derive(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?