Struct syntax::ext::hygiene::NameAndSpan [−][src]
pub struct NameAndSpan {
pub format: ExpnFormat,
pub allow_internal_unstable: bool,
pub allow_internal_unsafe: bool,
pub span: Option<Span>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
format: ExpnFormat
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The format with which the macro was invoked.
allow_internal_unstable: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether the macro is allowed to use #[unstable]/feature-gated features internally without forcing the whole crate to opt-in to them.
allow_internal_unsafe: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether the macro is allowed to use unsafe internally
even if the user crate has #![forbid(unsafe_code)].
span: Option<Span>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The span of the macro definition itself. The macro may not have a sensible definition span (e.g. something defined completely inside libsyntax) in which case this is None.
Methods
impl NameAndSpan[src]
impl NameAndSpanpub fn name(&self) -> Symbol[src]
pub fn name(&self) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?