Enum syntax::ext::tt::macro_parser::TokenTreeOrTokenTreeVec [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Either a sequence of token trees or a single one. This is used as the representation of the sequence of tokens that make up a matcher.
Variants
Tt(TokenTree)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TtSeq(Vec<TokenTree>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl TokenTreeOrTokenTreeVec[src]
impl TokenTreeOrTokenTreeVecfn len(&self) -> usize[src]
fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the number of constituent top-level token trees of self (top-level in that it
will not recursively descend into subtrees).
fn get_tt(&self, index: usize) -> TokenTree[src]
fn get_tt(&self, index: usize) -> TokenTree🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The the index-th token tree of self.