Function syntax::ext::tt::macro_parser::parse_nt [−][src]
fn parse_nt<'a>(p: &mut Parser<'a>, sp: Span, name: &str) -> Nonterminal
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A call to the "black-box" parser to parse some rust nonterminal.
Parameters
p: the "black-box" parser to usesp: theSpanwe want to parsename: the name of the metavar matcher we want to match (e.g.tt,ident,block, etc...)
Returns
The parsed nonterminal.