Type Definition syntax::ext::tt::macro_parser::NamedParseResult
[−]
[src]
type NamedParseResult = ParseResult<HashMap<Ident, Rc<NamedMatch>>>;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A ParseResult where the Success variant contains a mapping of Idents to NamedMatches.
This represents the mapping of metavars to the token trees they bind to.