Enum syntax::ext::tt::quoted::KleeneOp [−][src]
pub enum KleeneOp {
ZeroOrMore,
OneOrMore,
ZeroOrOne,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Kleene-style repetition operator for token sequences.
Variants
ZeroOrMore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Kleene star (*) for zero or more repetitions
OneOrMore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Kleene plus (+) for one or more repetitions
ZeroOrOne🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?