Function syntax::ext::tt::quoted::parse_tree [−][src]
fn parse_tree<I>(
tree: TokenTree,
trees: &mut Peekable<I>,
expect_matchers: bool,
sess: &ParseSess,
features: &Features,
attrs: &[Attribute]
) -> TokenTree where
I: Iterator<Item = TokenTree>,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Takes a tokenstream::TokenTree and returns a self::TokenTree. Specifically, this takes a
generic TokenTree, such as is used in the rest of the compiler, and returns a TokenTree
for use in parsing a macro.
Converting the given tree may involve reading more tokens.
Parameters
tree: the tree we wish to convert.trees: an iterator over trees. We may need to read more tokens from it in order to finish convertingtreeexpect_matchers: same as forparse(see above).sess: the parsing session. Any errors will be emitted to this session.features,attrs: language feature flags and attributes so that we know whether to use unstable features or not.