Struct syntax::ext::tt::quoted::SequenceRepetition [−][src]
pub struct SequenceRepetition {
pub tts: Vec<TokenTree>,
pub separator: Option<Token>,
pub op: KleeneOp,
pub num_captures: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tts: Vec<TokenTree>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The sequence of token trees
separator: Option<Token>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The optional separator
op: KleeneOp
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether the sequence can be repeated zero (*), or one or more times (+)
num_captures: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The number of Matchs that appear in the sequence (and subsequences)