Struct syntax::json::DiagnosticSpanLine [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
text: String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
highlight_start: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
1-based, character offset in self.text.
highlight_end: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl DiagnosticSpanLine[src]
impl DiagnosticSpanLinefn line_from_filemap(
fm: &FileMap,
index: usize,
h_start: usize,
h_end: usize
) -> DiagnosticSpanLine[src]
fn line_from_filemap(
fm: &FileMap,
index: usize,
h_start: usize,
h_end: usize
) -> DiagnosticSpanLine🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn from_span(span: Span, je: &JsonEmitter) -> Vec<DiagnosticSpanLine>[src]
fn from_span(span: Span, je: &JsonEmitter) -> Vec<DiagnosticSpanLine>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a list of DiagnosticSpanLines from span - each line with any part
of span gets a DiagnosticSpanLine, with the highlight indicating the
span within the line.