Struct syntax::json::JsonEmitter [−][src]
pub struct JsonEmitter {
dst: Box<Write + Send>,
registry: Option<Registry>,
cm: Lrc<CodeMapper + Send + Sync>,
pretty: bool,
ui_testing: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
dst: Box<Write + Send>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
registry: Option<Registry>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cm: Lrc<CodeMapper + Send + Sync>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pretty: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ui_testing: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl JsonEmitter[src]
impl JsonEmitterpub fn stderr(
registry: Option<Registry>,
code_map: Lrc<CodeMap>,
pretty: bool
) -> JsonEmitter[src]
pub fn stderr(
registry: Option<Registry>,
code_map: Lrc<CodeMap>,
pretty: bool
) -> JsonEmitter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn basic(pretty: bool) -> JsonEmitter[src]
pub fn basic(pretty: bool) -> JsonEmitter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new(
dst: Box<Write + Send>,
registry: Option<Registry>,
code_map: Lrc<CodeMap>,
pretty: bool
) -> JsonEmitter[src]
pub fn new(
dst: Box<Write + Send>,
registry: Option<Registry>,
code_map: Lrc<CodeMap>,
pretty: bool
) -> JsonEmitter🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn ui_testing(self, ui_testing: bool) -> Self[src]
pub fn ui_testing(self, ui_testing: bool) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?