Enum syntax::parse::parser::AliasKind [−][src]
pub enum AliasKind {
Weak(P<Ty>),
Existential(GenericBounds),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether the type alias or associated type is a concrete type or an existential type
Variants
Weak(P<Ty>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Just a new name for the same type
Existential(GenericBounds)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Only trait impls of the type will be usable, not the actual type itself