Enum syntax::parse::parser::Error [−][src]
pub enum Error {
FileNotFoundForModule {
mod_name: String,
default_path: String,
secondary_path: String,
dir_path: String,
},
DuplicatePaths {
mod_name: String,
default_path: String,
secondary_path: String,
},
UselessDocComment,
InclusiveRangeWithNoEnd,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
FileNotFoundForModule🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of FileNotFoundForModule
mod_name: String | 🔬 This is a nightly-only experimental API. ( |
default_path: String | 🔬 This is a nightly-only experimental API. ( |
secondary_path: String | 🔬 This is a nightly-only experimental API. ( |
dir_path: String | 🔬 This is a nightly-only experimental API. ( |
DuplicatePaths🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of DuplicatePaths
mod_name: String | 🔬 This is a nightly-only experimental API. ( |
default_path: String | 🔬 This is a nightly-only experimental API. ( |
secondary_path: String | 🔬 This is a nightly-only experimental API. ( |
UselessDocComment🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
InclusiveRangeWithNoEnd🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Error[src]
impl Errorpub fn span_err<S: Into<MultiSpan>>(
self,
sp: S,
handler: &Handler
) -> DiagnosticBuilder[src]
pub fn span_err<S: Into<MultiSpan>>(
self,
sp: S,
handler: &Handler
) -> DiagnosticBuilder🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?