[−][src]Trait syntax::parse::parser::RecoverQPath
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Associated Constants
const PATH_STYLE: PathStyle
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn to_ty(&self) -> Option<P<Ty>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_string(&self) -> String
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl RecoverQPath for Expr[src]
impl RecoverQPath for Exprfn to_ty(&self) -> Option<P<Ty>>[src]
fn to_ty(&self) -> Option<P<Ty>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self[src]
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_string(&self) -> String[src]
fn to_string(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
const PATH_STYLE: PathStyle[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl RecoverQPath for Pat[src]
impl RecoverQPath for Patfn to_ty(&self) -> Option<P<Ty>>[src]
fn to_ty(&self) -> Option<P<Ty>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self[src]
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_string(&self) -> String[src]
fn to_string(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
const PATH_STYLE: PathStyle[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl RecoverQPath for Ty[src]
impl RecoverQPath for Tyconst PATH_STYLE: PathStyle[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_ty(&self) -> Option<P<Ty>>[src]
fn to_ty(&self) -> Option<P<Ty>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self[src]
fn to_recovered(&self, qself: Option<QSelf>, path: Path) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn to_string(&self) -> String[src]
fn to_string(&self) -> String🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?