Struct syntax::parse::token::LazyTokenStream [−][src]
pub struct LazyTokenStream(Lock<Option<TokenStream>>);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LazyTokenStream[src]
impl LazyTokenStreamfn new() -> Self[src]
fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn force<F: FnOnce() -> TokenStream>(&self, f: F) -> TokenStream[src]
fn force<F: FnOnce() -> TokenStream>(&self, f: F) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?