Enum syntax::print::pp::BreaksExperimental
[-]
[+]
[src]
pub enum Breaks {
Consistent,
Inconsistent,
}Variants
Consistent | |
Inconsistent |
pub enum Breaks {
Consistent,
Inconsistent,
}Consistent | |
Inconsistent |
impl PartialEq for Breaksimpl Copy for Breaksimpl Clone for Breaksfn clone(&self) -> Breaksfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).