[−][src]Trait syntax::print::pprust::PpAnn
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provided Methods
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl PpAnn for NoAnn[src]
impl PpAnn for NoAnnfn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn pre(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>[src]
fn post(&self, _state: &mut State, _node: AnnNode) -> Result<()>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?