[−][src]Struct syntax::ptr::P
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An owned smart pointer.
Fields
ptr: Box<T>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: 'static> P<T>[src]
impl<T: 'static> P<T>pub fn and_then<U, F>(self, f: F) -> U where
F: FnOnce(T) -> U, [src]
pub fn and_then<U, F>(self, f: F) -> U where
F: FnOnce(T) -> U, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Move out of the pointer.
Intended for chaining transformations not covered by map.
pub fn into_inner(self) -> T[src]
pub fn into_inner(self) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Equivalent to and_then(|x| x)
pub fn map<F>(self, f: F) -> P<T> where
F: FnOnce(T) -> T, [src]
pub fn map<F>(self, f: F) -> P<T> where
F: FnOnce(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Transform the inner value, consuming self and producing a new P<T>.
impl<T> P<[T]>[src]
impl<T> P<[T]>pub fn new() -> P<[T]>[src]
pub fn new() -> P<[T]>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_vec(v: Vec<T>) -> P<[T]>[src]
pub fn from_vec(v: Vec<T>) -> P<[T]>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn into_vec(self) -> Vec<T>[src]
pub fn into_vec(self) -> Vec<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?