[−][src]Struct syntax::source_map::MultiSpan
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A collection of spans. Spans have two orthogonal attributes:
- they can be primary spans. In this case they are the locus of
the error, and would be rendered with
^^^. - they can have a label. In this case, the label is written next to the mark in the snippet when we render.
Fields
primary_spans: Vec<Span>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span_labels: Vec<(Span, String)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl MultiSpan[src]
impl MultiSpanpub fn new() -> MultiSpan[src]
pub fn new() -> MultiSpan🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_span(primary_span: Span) -> MultiSpan[src]
pub fn from_span(primary_span: Span) -> MultiSpan🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_spans(vec: Vec<Span>) -> MultiSpan[src]
pub fn from_spans(vec: Vec<Span>) -> MultiSpan🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push_span_label(&mut self, span: Span, label: String)[src]
pub fn push_span_label(&mut self, span: Span, label: String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn primary_span(&self) -> Option<Span>[src]
pub fn primary_span(&self) -> Option<Span>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Selects the first primary span (if any)
pub fn primary_spans(&self) -> &[Span][src]
pub fn primary_spans(&self) -> &[Span]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns all primary spans.
pub fn replace(&mut self, before: Span, after: Span) -> bool[src]
pub fn replace(&mut self, before: Span, after: Span) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Replaces all occurrences of one Span with another. Used to move Spans in areas that don't display well (like std macros). Returns true if replacements occurred.
pub fn span_labels(&self) -> Vec<SpanLabel>[src]
pub fn span_labels(&self) -> Vec<SpanLabel>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the strings to highlight. We always ensure that there
is an entry for each of the primary spans -- for each primary
span P, if there is at least one label with span P, we return
those labels (marked as primary). But otherwise we return
SpanLabel instances with empty labels.