[−][src]Struct syntax::source_map::SourceFile
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A single source in the SourceMap.
Fields
name: FileName
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The name of the file that the source came from, source that doesn't
originate from files has names between angle brackets by convention,
e.g. <anon>
name_was_remapped: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if the name field above has been modified by --remap-path-prefix
unmapped_path: Option<FileName>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The unmapped path of the file that the source came from.
Set to None if the SourceFile was imported from an external crate.
crate_of_origin: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Indicates which crate this SourceFile was imported from.
src: Option<Rc<String>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The complete source code
src_hash: u128
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The source code's hash
external_src: Lock<ExternalSource>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The external source code (used for external crates, which will have a None
value as self.src.
start_pos: BytePos
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The start position of this source in the SourceMap
end_pos: BytePos
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The end position of this source in the SourceMap
lines: Vec<BytePos>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Locations of lines beginnings in the source code
multibyte_chars: Vec<MultiByteChar>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Locations of multi-byte characters in the source code
non_narrow_chars: Vec<NonNarrowChar>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Width of characters that are not narrow in the source code
name_hash: u128
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A hash of the filename, used for speeding up the incr. comp. hashing.
Methods
impl SourceFile[src]
impl SourceFilepub fn new(
name: FileName,
name_was_remapped: bool,
unmapped_path: FileName,
src: String,
start_pos: BytePos
) -> SourceFile[src]
pub fn new(
name: FileName,
name_was_remapped: bool,
unmapped_path: FileName,
src: String,
start_pos: BytePos
) -> SourceFile🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn line_begin_pos(&self, pos: BytePos) -> BytePos[src]
pub fn line_begin_pos(&self, pos: BytePos) -> BytePos🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the BytePos of the beginning of the current line.
pub fn add_external_src<F>(&self, get_src: F) -> bool where
F: FnOnce() -> Option<String>, [src]
pub fn add_external_src<F>(&self, get_src: F) -> bool where
F: FnOnce() -> Option<String>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add externally loaded source. If the hash of the input doesn't match or no input is supplied via None, it is interpreted as an error and the corresponding enum variant is set. The return value signifies whether some kind of source is present.
pub fn get_line(&self, line_number: usize) -> Option<Cow<str>>[src]
pub fn get_line(&self, line_number: usize) -> Option<Cow<str>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Get a line from the list of pre-computed line-beginnings. The line number here is 0-based.
pub fn is_real_file(&self) -> bool[src]
pub fn is_real_file(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_imported(&self) -> bool[src]
pub fn is_imported(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn byte_length(&self) -> u32[src]
pub fn byte_length(&self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn count_lines(&self) -> usize[src]
pub fn count_lines(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn lookup_line(&self, pos: BytePos) -> Option<usize>[src]
pub fn lookup_line(&self, pos: BytePos) -> Option<usize>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the line containing the given position. The return value is the
index into the lines array of this SourceFile, not the 1-based line
number. If the source_file is empty or the position is located before the
first line, None is returned.
pub fn line_bounds(&self, line_index: usize) -> (BytePos, BytePos)[src]
pub fn line_bounds(&self, line_index: usize) -> (BytePos, BytePos)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains(&self, byte_pos: BytePos) -> bool[src]
pub fn contains(&self, byte_pos: BytePos) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?