[−][src]Struct syntax::source_map::SpanData
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Spans represent a region of code, used for error reporting. Positions in spans are absolute positions from the beginning of the source_map, not positions relative to SourceFiles. Methods on the SourceMap can be used to relate spans back to the original source. You must be careful if the span crosses more than one file - you will not be able to use many of the functions on spans in source_map and you cannot assume that the length of the span = hi - lo; there may be space in the BytePos range between files.
SpanData is public because Span uses a thread-local interner and can't be
sent to other threads, but some pieces of performance infra run in a separate thread.
Using Span is generally preferred.
Fields
lo: BytePos
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
hi: BytePos
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ctxt: SyntaxContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Information about where the macro came from, if this piece of code was created by a macro expansion.
Methods
impl SpanData[src]
impl SpanDatapub fn with_lo(&self, lo: BytePos) -> Span[src]
pub fn with_lo(&self, lo: BytePos) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_hi(&self, hi: BytePos) -> Span[src]
pub fn with_hi(&self, hi: BytePos) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_ctxt(&self, ctxt: SyntaxContext) -> Span[src]
pub fn with_ctxt(&self, ctxt: SyntaxContext) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?