Struct syntax::symbol::InternedString [−][src]
pub struct InternedString {
symbol: Symbol,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a string stored in the string interner
Fields
symbol: Symbol
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl InternedString[src]
impl InternedStringpub fn with<F, R>(self, f: F) -> R where
F: FnOnce(&str) -> R, [src]
pub fn with<F, R>(self, f: F) -> R where
F: FnOnce(&str) -> R, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_symbol(self) -> Symbol[src]
pub fn as_symbol(self) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_str(self) -> LocalInternedString[src]
pub fn as_str(self) -> LocalInternedString🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?