Struct syntax::symbol::Interner [−][src]
pub struct Interner {
names: HashMap<Box<str>, Symbol, BuildHasherDefault<FxHasher>>,
strings: Vec<Box<str>>,
gensyms: Vec<Symbol>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
names: HashMap<Box<str>, Symbol, BuildHasherDefault<FxHasher>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
strings: Vec<Box<str>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
gensyms: Vec<Symbol>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Interner[src]
impl Internerpub fn new() -> Interner[src]
pub fn new() -> Interner🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn intern(&mut self, string: &str) -> Symbol[src]
pub fn intern(&mut self, string: &str) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn interned(&self, symbol: Symbol) -> Symbol[src]
pub fn interned(&self, symbol: Symbol) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, symbol: Symbol) -> &str[src]
pub fn get(&self, symbol: Symbol) -> &str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Interner[src]
impl Internerpub fn fresh() -> Interner[src]
pub fn fresh() -> Interner🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?