Struct syntax::tokenstream::Delimited [−][src]
pub struct Delimited {
pub delim: DelimToken,
pub tts: ThinTokenStream,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A delimited sequence of token trees
Fields
delim: DelimToken
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The type of delimiter
tts: ThinTokenStream
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The delimited sequence of token trees
Methods
impl Delimited[src]
impl Delimitedpub fn open_token(&self) -> Token[src]
pub fn open_token(&self) -> Token🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the opening delimiter as a token.
pub fn close_token(&self) -> Token[src]
pub fn close_token(&self) -> Token🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the closing delimiter as a token.
pub fn open_tt(&self, span: Span) -> TokenTree[src]
pub fn open_tt(&self, span: Span) -> TokenTree🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the opening delimiter as a token tree.
pub fn close_tt(&self, span: Span) -> TokenTree[src]
pub fn close_tt(&self, span: Span) -> TokenTree🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the closing delimiter as a token tree.
pub fn stream(&self) -> TokenStream[src]
pub fn stream(&self) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the token trees inside the delimiters.