Struct syntax::tokenstream::StreamCursor [−][src]
struct StreamCursor {
stream: RcSlice<TokenStream>,
index: usize,
stack: Vec<(RcSlice<TokenStream>, usize)>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
stream: RcSlice<TokenStream>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
index: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
stack: Vec<(RcSlice<TokenStream>, usize)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl StreamCursor[src]
impl StreamCursorfn new(stream: RcSlice<TokenStream>) -> Self[src]
fn new(stream: RcSlice<TokenStream>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn next_as_stream(&mut self) -> Option<TokenStream>[src]
fn next_as_stream(&mut self) -> Option<TokenStream>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn insert(&mut self, stream: RcSlice<TokenStream>)[src]
fn insert(&mut self, stream: RcSlice<TokenStream>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?