Struct syntax::tokenstream::TokenStreamBuilder [−][src]
pub struct TokenStreamBuilder(Vec<TokenStream>);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl TokenStreamBuilder[src]
impl TokenStreamBuilderpub fn new() -> TokenStreamBuilder[src]
pub fn new() -> TokenStreamBuilder🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn push<T: Into<TokenStream>>(&mut self, stream: T)[src]
pub fn push<T: Into<TokenStream>>(&mut self, stream: T)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn add<T: Into<TokenStream>>(self, stream: T) -> Self[src]
pub fn add<T: Into<TokenStream>>(self, stream: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn build(self) -> TokenStream[src]
pub fn build(self) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn push_all_but_last_tree(&mut self, stream: &TokenStream)[src]
fn push_all_but_last_tree(&mut self, stream: &TokenStream)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn push_all_but_first_tree(&mut self, stream: &TokenStream)[src]
fn push_all_but_first_tree(&mut self, stream: &TokenStream)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?