[−][src]Trait syntax::util::move_map::MoveMap
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Required Methods
fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>,
F: FnMut(T) -> I,
I: IntoIterator<Item = T>,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provided Methods
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T,
F: FnMut(T) -> T,
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementations on Foreign Types
impl<T> MoveMap<T> for Vec<T>[src]
impl<T> MoveMap<T> for Vec<T>fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, [src]
fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, [src]
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<T> MoveMap<T> for P<[T]>[src]
impl<T> MoveMap<T> for P<[T]>fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, [src]
fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, [src]
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T> MoveMap<T> for OneVector<T>[src]
impl<T> MoveMap<T> for OneVector<T>fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, [src]
fn move_flat_map<F, I>(self, f: F) -> Self where
F: FnMut(T) -> I,
I: IntoIterator<Item = T>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, [src]
fn move_map<F>(self, f: F) -> Self where
F: FnMut(T) -> T, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?