[−][src]Trait syntax::visit::Visitor
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Each method of the Visitor trait is a hook to be potentially
overridden. Each method's default implementation recursively visits
the substructure of the input via the corresponding walk method;
e.g. the visit_mod method by default calls visit::walk_mod.
If you want to ensure that your code handles every variant
explicitly, you need to override each method. (And you also need
to monitor future changes to Visitor in case a new method with a
new default implementation gets introduced.)
Provided Methods
fn visit_name(&mut self, _span: Span, _name: Name)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ident(&mut self, ident: Ident)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mod(
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_foreign_item(&mut self, i: &'ast ForeignItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_item(&mut self, i: &'ast Item)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_local(&mut self, l: &'ast Local)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_block(&mut self, b: &'ast Block)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_stmt(&mut self, s: &'ast Stmt)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_arm(&mut self, a: &'ast Arm)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_pat(&mut self, p: &'ast Pat)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_anon_const(&mut self, c: &'ast AnonConst)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr(&mut self, ex: &'ast Expr)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr_post(&mut self, _ex: &'ast Expr)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ty(&mut self, t: &'ast Ty)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_param(&mut self, param: &'ast GenericParam)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generics(&mut self, g: &'ast Generics)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn(&mut self, fk: FnKind<'ast>, fd: &'ast FnDecl, s: Span, _: NodeId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_item(&mut self, ti: &'ast TraitItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_impl_item(&mut self, ii: &'ast ImplItem)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_ref(&mut self, t: &'ast TraitRef)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_param_bound(&mut self, bounds: &'ast GenericBound)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_poly_trait_ref(
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant_data(
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_struct_field(&mut self, s: &'ast StructField)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_enum_def(
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant(
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_label(&mut self, label: &'ast Label)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_lifetime(&mut self, lifetime: &'ast Lifetime)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac(&mut self, _mac: &'ast Mac)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path(&mut self, path: &'ast Path, _id: NodeId)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_use_tree(&mut self, use_tree: &'ast UseTree, id: NodeId, _nested: bool)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_args(
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_assoc_type_binding(&mut self, type_binding: &'ast TypeBinding)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_attribute(&mut self, attr: &'ast Attribute)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tt(&mut self, tt: TokenTree)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tts(&mut self, tts: TokenStream)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_token(&mut self, _t: Token)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_vis(&mut self, vis: &'ast Visibility)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn_ret_ty(&mut self, ret_ty: &'ast FunctionRetTy)
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Implementors
impl<'a> Visitor<'a> for PostExpansionVisitor<'a>[src]
impl<'a> Visitor<'a> for PostExpansionVisitor<'a>fn visit_attribute(&mut self, attr: &Attribute)[src]
fn visit_attribute(&mut self, attr: &Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_name(&mut self, sp: Span, name: Name)[src]
fn visit_name(&mut self, sp: Span, name: Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_use_tree(&mut self, use_tree: &'a UseTree, id: NodeId, _nested: bool)[src]
fn visit_use_tree(&mut self, use_tree: &'a UseTree, id: NodeId, _nested: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_item(&mut self, i: &'a Item)[src]
fn visit_item(&mut self, i: &'a Item)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_foreign_item(&mut self, i: &'a ForeignItem)[src]
fn visit_foreign_item(&mut self, i: &'a ForeignItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ty(&mut self, ty: &'a Ty)[src]
fn visit_ty(&mut self, ty: &'a Ty)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn_ret_ty(&mut self, ret_ty: &'a FunctionRetTy)[src]
fn visit_fn_ret_ty(&mut self, ret_ty: &'a FunctionRetTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr(&mut self, e: &'a Expr)[src]
fn visit_expr(&mut self, e: &'a Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_arm(&mut self, arm: &'a Arm)[src]
fn visit_arm(&mut self, arm: &'a Arm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_pat(&mut self, pattern: &'a Pat)[src]
fn visit_pat(&mut self, pattern: &'a Pat)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn(
&mut self,
fn_kind: FnKind<'a>,
fn_decl: &'a FnDecl,
span: Span,
_node_id: NodeId
)[src]
fn visit_fn(
&mut self,
fn_kind: FnKind<'a>,
fn_decl: &'a FnDecl,
span: Span,
_node_id: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_item(&mut self, ti: &'a TraitItem)[src]
fn visit_trait_item(&mut self, ti: &'a TraitItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_impl_item(&mut self, ii: &'a ImplItem)[src]
fn visit_impl_item(&mut self, ii: &'a ImplItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path(&mut self, path: &'a Path, _id: NodeId)[src]
fn visit_path(&mut self, path: &'a Path, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_vis(&mut self, vis: &'a Visibility)[src]
fn visit_vis(&mut self, vis: &'a Visibility)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ident(&mut self, ident: Ident)[src]
fn visit_ident(&mut self, ident: Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mod(
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)[src]
fn visit_mod(
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)[src]
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_local(&mut self, l: &'ast Local)[src]
fn visit_local(&mut self, l: &'ast Local)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_block(&mut self, b: &'ast Block)[src]
fn visit_block(&mut self, b: &'ast Block)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_stmt(&mut self, s: &'ast Stmt)[src]
fn visit_stmt(&mut self, s: &'ast Stmt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_anon_const(&mut self, c: &'ast AnonConst)[src]
fn visit_anon_const(&mut self, c: &'ast AnonConst)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr_post(&mut self, _ex: &'ast Expr)[src]
fn visit_expr_post(&mut self, _ex: &'ast Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_param(&mut self, param: &'ast GenericParam)[src]
fn visit_generic_param(&mut self, param: &'ast GenericParam)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generics(&mut self, g: &'ast Generics)[src]
fn visit_generics(&mut self, g: &'ast Generics)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)[src]
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_ref(&mut self, t: &'ast TraitRef)[src]
fn visit_trait_ref(&mut self, t: &'ast TraitRef)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_param_bound(&mut self, bounds: &'ast GenericBound)[src]
fn visit_param_bound(&mut self, bounds: &'ast GenericBound)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_poly_trait_ref(
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)[src]
fn visit_poly_trait_ref(
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant_data(
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)[src]
fn visit_variant_data(
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_struct_field(&mut self, s: &'ast StructField)[src]
fn visit_struct_field(&mut self, s: &'ast StructField)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_enum_def(
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)[src]
fn visit_enum_def(
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant(
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)[src]
fn visit_variant(
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_label(&mut self, label: &'ast Label)[src]
fn visit_label(&mut self, label: &'ast Label)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_lifetime(&mut self, lifetime: &'ast Lifetime)[src]
fn visit_lifetime(&mut self, lifetime: &'ast Lifetime)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac(&mut self, _mac: &'ast Mac)[src]
fn visit_mac(&mut self, _mac: &'ast Mac)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)[src]
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)[src]
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_args(
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)[src]
fn visit_generic_args(
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)[src]
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_assoc_type_binding(&mut self, type_binding: &'ast TypeBinding)[src]
fn visit_assoc_type_binding(&mut self, type_binding: &'ast TypeBinding)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tt(&mut self, tt: TokenTree)[src]
fn visit_tt(&mut self, tt: TokenTree)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tts(&mut self, tts: TokenStream)[src]
fn visit_tts(&mut self, tts: TokenStream)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_token(&mut self, _t: Token)[src]
fn visit_token(&mut self, _t: Token)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a> Visitor<'a> for ShowSpanVisitor<'a>[src]
impl<'a> Visitor<'a> for ShowSpanVisitor<'a>fn visit_expr(&mut self, e: &'a Expr)[src]
fn visit_expr(&mut self, e: &'a Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_pat(&mut self, p: &'a Pat)[src]
fn visit_pat(&mut self, p: &'a Pat)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ty(&mut self, t: &'a Ty)[src]
fn visit_ty(&mut self, t: &'a Ty)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac(&mut self, mac: &'a Mac)[src]
fn visit_mac(&mut self, mac: &'a Mac)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_name(&mut self, _span: Span, _name: Name)[src]
fn visit_name(&mut self, _span: Span, _name: Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ident(&mut self, ident: Ident)[src]
fn visit_ident(&mut self, ident: Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mod(
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)[src]
fn visit_mod(
&mut self,
m: &'ast Mod,
_s: Span,
_attrs: &[Attribute],
_n: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_foreign_item(&mut self, i: &'ast ForeignItem)[src]
fn visit_foreign_item(&mut self, i: &'ast ForeignItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)[src]
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_item(&mut self, i: &'ast Item)[src]
fn visit_item(&mut self, i: &'ast Item)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_local(&mut self, l: &'ast Local)[src]
fn visit_local(&mut self, l: &'ast Local)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_block(&mut self, b: &'ast Block)[src]
fn visit_block(&mut self, b: &'ast Block)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_stmt(&mut self, s: &'ast Stmt)[src]
fn visit_stmt(&mut self, s: &'ast Stmt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_arm(&mut self, a: &'ast Arm)[src]
fn visit_arm(&mut self, a: &'ast Arm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_anon_const(&mut self, c: &'ast AnonConst)[src]
fn visit_anon_const(&mut self, c: &'ast AnonConst)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr_post(&mut self, _ex: &'ast Expr)[src]
fn visit_expr_post(&mut self, _ex: &'ast Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_param(&mut self, param: &'ast GenericParam)[src]
fn visit_generic_param(&mut self, param: &'ast GenericParam)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generics(&mut self, g: &'ast Generics)[src]
fn visit_generics(&mut self, g: &'ast Generics)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)[src]
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn(&mut self, fk: FnKind<'ast>, fd: &'ast FnDecl, s: Span, _: NodeId)[src]
fn visit_fn(&mut self, fk: FnKind<'ast>, fd: &'ast FnDecl, s: Span, _: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_item(&mut self, ti: &'ast TraitItem)[src]
fn visit_trait_item(&mut self, ti: &'ast TraitItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_impl_item(&mut self, ii: &'ast ImplItem)[src]
fn visit_impl_item(&mut self, ii: &'ast ImplItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_ref(&mut self, t: &'ast TraitRef)[src]
fn visit_trait_ref(&mut self, t: &'ast TraitRef)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_param_bound(&mut self, bounds: &'ast GenericBound)[src]
fn visit_param_bound(&mut self, bounds: &'ast GenericBound)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_poly_trait_ref(
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)[src]
fn visit_poly_trait_ref(
&mut self,
t: &'ast PolyTraitRef,
m: &'ast TraitBoundModifier
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant_data(
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)[src]
fn visit_variant_data(
&mut self,
s: &'ast VariantData,
_: Ident,
_: &'ast Generics,
_: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_struct_field(&mut self, s: &'ast StructField)[src]
fn visit_struct_field(&mut self, s: &'ast StructField)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_enum_def(
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)[src]
fn visit_enum_def(
&mut self,
enum_definition: &'ast EnumDef,
generics: &'ast Generics,
item_id: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant(
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)[src]
fn visit_variant(
&mut self,
v: &'ast Variant,
g: &'ast Generics,
item_id: NodeId
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_label(&mut self, label: &'ast Label)[src]
fn visit_label(&mut self, label: &'ast Label)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_lifetime(&mut self, lifetime: &'ast Lifetime)[src]
fn visit_lifetime(&mut self, lifetime: &'ast Lifetime)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)[src]
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path(&mut self, path: &'ast Path, _id: NodeId)[src]
fn visit_path(&mut self, path: &'ast Path, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_use_tree(&mut self, use_tree: &'ast UseTree, id: NodeId, _nested: bool)[src]
fn visit_use_tree(&mut self, use_tree: &'ast UseTree, id: NodeId, _nested: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)[src]
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_args(
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)[src]
fn visit_generic_args(
&mut self,
path_span: Span,
generic_args: &'ast GenericArgs
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)[src]
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_assoc_type_binding(&mut self, type_binding: &'ast TypeBinding)[src]
fn visit_assoc_type_binding(&mut self, type_binding: &'ast TypeBinding)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_attribute(&mut self, attr: &'ast Attribute)[src]
fn visit_attribute(&mut self, attr: &'ast Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tt(&mut self, tt: TokenTree)[src]
fn visit_tt(&mut self, tt: TokenTree)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tts(&mut self, tts: TokenStream)[src]
fn visit_tts(&mut self, tts: TokenStream)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_token(&mut self, _t: Token)[src]
fn visit_token(&mut self, _t: Token)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_vis(&mut self, vis: &'ast Visibility)[src]
fn visit_vis(&mut self, vis: &'ast Visibility)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn_ret_ty(&mut self, ret_ty: &'ast FunctionRetTy)[src]
fn visit_fn_ret_ty(&mut self, ret_ty: &'ast FunctionRetTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'ast> Visitor<'ast> for NodeCounter[src]
impl<'ast> Visitor<'ast> for NodeCounterfn visit_ident(&mut self, ident: Ident)[src]
fn visit_ident(&mut self, ident: Ident)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mod(&mut self, m: &Mod, _s: Span, _a: &[Attribute], _n: NodeId)[src]
fn visit_mod(&mut self, m: &Mod, _s: Span, _a: &[Attribute], _n: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_foreign_item(&mut self, i: &ForeignItem)[src]
fn visit_foreign_item(&mut self, i: &ForeignItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_item(&mut self, i: &Item)[src]
fn visit_item(&mut self, i: &Item)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_local(&mut self, l: &Local)[src]
fn visit_local(&mut self, l: &Local)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_block(&mut self, b: &Block)[src]
fn visit_block(&mut self, b: &Block)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_stmt(&mut self, s: &Stmt)[src]
fn visit_stmt(&mut self, s: &Stmt)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_arm(&mut self, a: &Arm)[src]
fn visit_arm(&mut self, a: &Arm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_pat(&mut self, p: &Pat)[src]
fn visit_pat(&mut self, p: &Pat)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr(&mut self, ex: &Expr)[src]
fn visit_expr(&mut self, ex: &Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_ty(&mut self, t: &Ty)[src]
fn visit_ty(&mut self, t: &Ty)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_param(&mut self, param: &GenericParam)[src]
fn visit_generic_param(&mut self, param: &GenericParam)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generics(&mut self, g: &Generics)[src]
fn visit_generics(&mut self, g: &Generics)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn(&mut self, fk: FnKind, fd: &FnDecl, s: Span, _: NodeId)[src]
fn visit_fn(&mut self, fk: FnKind, fd: &FnDecl, s: Span, _: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_item(&mut self, ti: &TraitItem)[src]
fn visit_trait_item(&mut self, ti: &TraitItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_impl_item(&mut self, ii: &ImplItem)[src]
fn visit_impl_item(&mut self, ii: &ImplItem)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_trait_ref(&mut self, t: &TraitRef)[src]
fn visit_trait_ref(&mut self, t: &TraitRef)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_param_bound(&mut self, bounds: &GenericBound)[src]
fn visit_param_bound(&mut self, bounds: &GenericBound)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_poly_trait_ref(&mut self, t: &PolyTraitRef, m: &TraitBoundModifier)[src]
fn visit_poly_trait_ref(&mut self, t: &PolyTraitRef, m: &TraitBoundModifier)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant_data(
&mut self,
s: &VariantData,
_: Ident,
_: &Generics,
_: NodeId,
_: Span
)[src]
fn visit_variant_data(
&mut self,
s: &VariantData,
_: Ident,
_: &Generics,
_: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_struct_field(&mut self, s: &StructField)[src]
fn visit_struct_field(&mut self, s: &StructField)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_enum_def(
&mut self,
enum_definition: &EnumDef,
generics: &Generics,
item_id: NodeId,
_: Span
)[src]
fn visit_enum_def(
&mut self,
enum_definition: &EnumDef,
generics: &Generics,
item_id: NodeId,
_: Span
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_variant(&mut self, v: &Variant, g: &Generics, item_id: NodeId)[src]
fn visit_variant(&mut self, v: &Variant, g: &Generics, item_id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_lifetime(&mut self, lifetime: &Lifetime)[src]
fn visit_lifetime(&mut self, lifetime: &Lifetime)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac(&mut self, _mac: &Mac)[src]
fn visit_mac(&mut self, _mac: &Mac)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path(&mut self, path: &Path, _id: NodeId)[src]
fn visit_path(&mut self, path: &Path, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_use_tree(&mut self, use_tree: &UseTree, id: NodeId, _nested: bool)[src]
fn visit_use_tree(&mut self, use_tree: &UseTree, id: NodeId, _nested: bool)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_args(&mut self, path_span: Span, generic_args: &GenericArgs)[src]
fn visit_generic_args(&mut self, path_span: Span, generic_args: &GenericArgs)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_assoc_type_binding(&mut self, type_binding: &TypeBinding)[src]
fn visit_assoc_type_binding(&mut self, type_binding: &TypeBinding)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_attribute(&mut self, _attr: &Attribute)[src]
fn visit_attribute(&mut self, _attr: &Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_name(&mut self, _span: Span, _name: Name)[src]
fn visit_name(&mut self, _span: Span, _name: Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)[src]
fn visit_global_asm(&mut self, ga: &'ast GlobalAsm)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_anon_const(&mut self, c: &'ast AnonConst)[src]
fn visit_anon_const(&mut self, c: &'ast AnonConst)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_expr_post(&mut self, _ex: &'ast Expr)[src]
fn visit_expr_post(&mut self, _ex: &'ast Expr)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)[src]
fn visit_where_predicate(&mut self, p: &'ast WherePredicate)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_label(&mut self, label: &'ast Label)[src]
fn visit_label(&mut self, label: &'ast Label)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)[src]
fn visit_mac_def(&mut self, _mac: &'ast MacroDef, _id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)[src]
fn visit_path_segment(
&mut self,
path_span: Span,
path_segment: &'ast PathSegment
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)[src]
fn visit_generic_arg(&mut self, generic_arg: &'ast GenericArg)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tt(&mut self, tt: TokenTree)[src]
fn visit_tt(&mut self, tt: TokenTree)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_tts(&mut self, tts: TokenStream)[src]
fn visit_tts(&mut self, tts: TokenStream)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_token(&mut self, _t: Token)[src]
fn visit_token(&mut self, _t: Token)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_vis(&mut self, vis: &'ast Visibility)[src]
fn visit_vis(&mut self, vis: &'ast Visibility)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn visit_fn_ret_ty(&mut self, ret_ty: &'ast FunctionRetTy)[src]
fn visit_fn_ret_ty(&mut self, ret_ty: &'ast FunctionRetTy)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?