Struct syntax_ext::deriving::custom::ProcMacroDerive [−][src]
pub struct ProcMacroDerive {
inner: fn(_: TokenStream) -> TokenStream,
attrs: Vec<Name>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
inner: fn(_: TokenStream) -> TokenStream
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
attrs: Vec<Name>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ProcMacroDerive[src]
impl ProcMacroDerivepub fn new(
inner: fn(_: TokenStream) -> TokenStream,
attrs: Vec<Name>
) -> ProcMacroDerive[src]
pub fn new(
inner: fn(_: TokenStream) -> TokenStream,
attrs: Vec<Name>
) -> ProcMacroDerive🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?