Struct syntax_ext::deriving::generic::ty::LifetimeBounds
[−]
[src]
pub struct LifetimeBounds<'a> {
pub lifetimes: Vec<(&'a str, Vec<&'a str>)>,
pub bounds: Vec<(&'a str, Vec<Path<'a>>)>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Lifetimes and bounds on type parameters
Fields
lifetimes: Vec<(&'a str, Vec<&'a str>)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bounds: Vec<(&'a str, Vec<Path<'a>>)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> LifetimeBounds<'a>[src]
impl<'a> LifetimeBounds<'a>pub fn empty() -> LifetimeBounds<'a>[src]
pub fn empty() -> LifetimeBounds<'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_generics(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> Generics[src]
pub fn to_generics(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> Generics🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?