Enum syntax_ext::format_foreign::printf::Num [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A general number used in a printf formatting directive.
Variants
Num(u16)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A specific, fixed value.
Arg(u16)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The value is derived from a positional argument.
Next🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The value is derived from the "next" unconverted argument.
Methods
impl Num[src]
impl Numfn from_str(s: &str, arg: Option<&str>) -> Self[src]
fn from_str(s: &str, arg: Option<&str>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn translate(&self, s: &mut String) -> Result[src]
fn translate(&self, s: &mut String) -> Result🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?