Enum syntax_ext::format_foreign::printf::Substitution [−][src]
pub enum Substitution<'a> {
Format(Format<'a>),
Escape,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a single printf-style substitution.
Variants
Format(Format<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A formatted output substitution.
Escape🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A literal %% escape.
Methods
impl<'a> Substitution<'a>[src]
impl<'a> Substitution<'a>pub fn as_str(&self) -> &str[src]
pub fn as_str(&self) -> &str🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn translate(&self) -> Option<String>[src]
pub fn translate(&self) -> Option<String>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Translate this substitution into an equivalent Rust formatting directive.
This ignores cases where the substitution does not have an exact equivalent, or where the substitution would be unnecessary.