Struct syntax_ext::proc_macro_registrar::CollectProcMacros [−][src]
struct CollectProcMacros<'a> {
derives: Vec<ProcMacroDerive>,
attr_macros: Vec<ProcMacroDef>,
bang_macros: Vec<ProcMacroDef>,
in_root: bool,
handler: &'a Handler,
is_proc_macro_crate: bool,
is_test_crate: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
derives: Vec<ProcMacroDerive>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
attr_macros: Vec<ProcMacroDef>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bang_macros: Vec<ProcMacroDef>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
in_root: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
handler: &'a Handler
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_proc_macro_crate: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
is_test_crate: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> CollectProcMacros<'a>[src]
impl<'a> CollectProcMacros<'a>fn check_not_pub_in_root(&self, vis: &Visibility, sp: Span)[src]
fn check_not_pub_in_root(&self, vis: &Visibility, sp: Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn collect_custom_derive(&mut self, item: &'a Item, attr: &'a Attribute)[src]
fn collect_custom_derive(&mut self, item: &'a Item, attr: &'a Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn collect_attr_proc_macro(&mut self, item: &'a Item, attr: &'a Attribute)[src]
fn collect_attr_proc_macro(&mut self, item: &'a Item, attr: &'a Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn collect_bang_proc_macro(&mut self, item: &'a Item, attr: &'a Attribute)[src]
fn collect_bang_proc_macro(&mut self, item: &'a Item, attr: &'a Attribute)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?