[−][src]Enum syntax_pos::hygiene::Transparency
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A property of a macro expansion that determines how identifiers produced by that expansion are resolved.
Variants
Transparent🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by a transparent expansion is always resolved at call-site.
Call-site spans in procedural macros, hygiene opt-out in macro should use this.
SemiTransparent🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by a semi-transparent expansion may be resolved
either at call-site or at definition-site.
If it's a local variable, label or $crate then it's resolved at def-site.
Otherwise it's resolved at call-site.
macro_rules macros behave like this, built-in macros currently behave like this too,
but that's an implementation detail.
Opaque🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Identifier produced by an opaque expansion is always resolved at definition-site.
Def-site spans in procedural macros, identifiers from macro by default use this.