[−][src]Struct syntax_pos::hygiene::SyntaxContext
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A SyntaxContext represents a chain of macro expansions (represented by marks).
Methods
impl SyntaxContext[src]
impl SyntaxContextpub const fn empty() -> Self[src]
pub const fn empty() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn as_u32(self) -> u32[src]
pub(crate) fn as_u32(self) -> u32🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn from_u32(raw: u32) -> SyntaxContext[src]
pub(crate) fn from_u32(raw: u32) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn allocate_directly(expansion_info: ExpnInfo) -> Self[src]
pub fn allocate_directly(expansion_info: ExpnInfo) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn apply_mark(self, mark: Mark) -> SyntaxContext[src]
pub fn apply_mark(self, mark: Mark) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extend a syntax context with a given mark and default transparency for that mark.
pub fn apply_mark_with_transparency(
self,
mark: Mark,
transparency: Transparency
) -> SyntaxContext[src]
pub fn apply_mark_with_transparency(
self,
mark: Mark,
transparency: Transparency
) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extend a syntax context with a given mark and transparency
fn apply_mark_internal(
self,
mark: Mark,
transparency: Transparency
) -> SyntaxContext[src]
fn apply_mark_internal(
self,
mark: Mark,
transparency: Transparency
) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove_mark(&mut self) -> Mark[src]
pub fn remove_mark(&mut self) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pulls a single mark off of the syntax context. This effectively moves the context up one macro definition level. That is, if we have a nested macro definition as follows:
macro_rules! f { macro_rules! g { ... } }
and we have a SyntaxContext that is referring to something declared by an invocation of g (call it g1), calling remove_mark will result in the SyntaxContext for the invocation of f that created g1. Returns the mark that was removed.
pub fn marks(self) -> Vec<(Mark, Transparency)>[src]
pub fn marks(self) -> Vec<(Mark, Transparency)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn adjust(&mut self, expansion: Mark) -> Option<Mark>[src]
pub fn adjust(&mut self, expansion: Mark) -> Option<Mark>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adjust this context for resolution in a scope created by the given expansion.
For example, consider the following three resolutions of f:
mod foo { pub fn f() {} } // `f`'s `SyntaxContext` is empty. m!(f); macro m($f:ident) { mod bar { pub fn f() {} // `f`'s `SyntaxContext` has a single `Mark` from `m`. pub fn $f() {} // `$f`'s `SyntaxContext` is empty. } foo::f(); // `f`'s `SyntaxContext` has a single `Mark` from `m` //^ Since `mod foo` is outside this expansion, `adjust` removes the mark from `f`, //| and it resolves to `::foo::f`. bar::f(); // `f`'s `SyntaxContext` has a single `Mark` from `m` //^ Since `mod bar` not outside this expansion, `adjust` does not change `f`, //| and it resolves to `::bar::f`. bar::$f(); // `f`'s `SyntaxContext` is empty. //^ Since `mod bar` is not outside this expansion, `adjust` does not change `$f`, //| and it resolves to `::bar::$f`. }
This returns the expansion whose definition scope we use to privacy check the resolution,
or None if we privacy check as usual (i.e. not w.r.t. a macro definition scope).
pub fn glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>[src]
pub fn glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adjust this context for resolution in a scope created by the given expansion
via a glob import with the given SyntaxContext.
For example:
m!(f); macro m($i:ident) { mod foo { pub fn f() {} // `f`'s `SyntaxContext` has a single `Mark` from `m`. pub fn $i() {} // `$i`'s `SyntaxContext` is empty. } n(f); macro n($j:ident) { use foo::*; f(); // `f`'s `SyntaxContext` has a mark from `m` and a mark from `n` //^ `glob_adjust` removes the mark from `n`, so this resolves to `foo::f`. $i(); // `$i`'s `SyntaxContext` has a mark from `n` //^ `glob_adjust` removes the mark from `n`, so this resolves to `foo::$i`. $j(); // `$j`'s `SyntaxContext` has a mark from `m` //^ This cannot be glob-adjusted, so this is a resolution error. } }
This returns None if the context cannot be glob-adjusted.
Otherwise, it returns the scope to use when privacy checking (see adjust for details).
pub fn reverse_glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>[src]
pub fn reverse_glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Undo glob_adjust if possible:
if let Some(privacy_checking_scope) = self.reverse_glob_adjust(expansion, glob_ctxt) { assert!(self.glob_adjust(expansion, glob_ctxt) == Some(privacy_checking_scope)); }
pub fn modern(self) -> SyntaxContext[src]
pub fn modern(self) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern_and_legacy(self) -> SyntaxContext[src]
pub fn modern_and_legacy(self) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn outer(self) -> Mark[src]
pub fn outer(self) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?