Struct syntax_pos::Span [−][src]
#[repr(packed)]pub struct Span(u32);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A compressed span.
Contains either fields of SpanData inline if they are small, or index into span interner.
The primary goal of Span is to be as small as possible and fit into other structures
(that's why it uses packed as well). Decoding speed is the second priority.
See SpanData for the info on span fields in decoded representation.
Methods
impl Span[src]
impl Spanpub fn new(lo: BytePos, hi: BytePos, ctxt: SyntaxContext) -> Self[src]
pub fn new(lo: BytePos, hi: BytePos, ctxt: SyntaxContext) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn data(self) -> SpanData[src]
pub fn data(self) -> SpanData🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Span[src]
impl Spanpub fn lo(self) -> BytePos[src]
pub fn lo(self) -> BytePos🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_lo(self, lo: BytePos) -> Span[src]
pub fn with_lo(self, lo: BytePos) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn hi(self) -> BytePos[src]
pub fn hi(self) -> BytePos🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_hi(self, hi: BytePos) -> Span[src]
pub fn with_hi(self, hi: BytePos) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn ctxt(self) -> SyntaxContext[src]
pub fn ctxt(self) -> SyntaxContext🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_ctxt(self, ctxt: SyntaxContext) -> Span[src]
pub fn with_ctxt(self, ctxt: SyntaxContext) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_dummy(self) -> bool[src]
pub fn is_dummy(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if this is a dummy span with any hygienic context.
pub fn shrink_to_lo(self) -> Span[src]
pub fn shrink_to_lo(self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns a new span representing an empty span at the beginning of this span
pub fn shrink_to_hi(self) -> Span[src]
pub fn shrink_to_hi(self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns a new span representing an empty span at the end of this span
pub fn substitute_dummy(self, other: Span) -> Span[src]
pub fn substitute_dummy(self, other: Span) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns self if self is not the dummy span, and other otherwise.
pub fn contains(self, other: Span) -> bool[src]
pub fn contains(self, other: Span) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return true if self fully encloses other.
pub fn source_equal(&self, other: &Span) -> bool[src]
pub fn source_equal(&self, other: &Span) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return true if the spans are equal with regards to the source text.
Use this instead of == when either span could be generated code,
and you only care that they point to the same bytes of source text.
pub fn trim_start(self, other: Span) -> Option<Span>[src]
pub fn trim_start(self, other: Span) -> Option<Span>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns Some(span), where the start is trimmed by the end of other
pub fn source_callsite(self) -> Span[src]
pub fn source_callsite(self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the source span - this is either the supplied span, or the span for the macro callsite that expanded to it.
pub fn parent(self) -> Option<Span>[src]
pub fn parent(self) -> Option<Span>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The Span for the tokens in the previous macro expansion from which self was generated,
if any
pub fn edition(self) -> Edition[src]
pub fn edition(self) -> Edition🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Edition of the crate from which this span came.
pub fn source_callee(self) -> Option<ExpnInfo>[src]
pub fn source_callee(self) -> Option<ExpnInfo>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the source callee.
Returns None if the supplied span has no expansion trace,
else returns the ExpnInfo for the macro definition
corresponding to the source callsite.
pub fn allows_unstable(&self) -> bool[src]
pub fn allows_unstable(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if a span is "internal" to a macro in which #[unstable]
items can be used (that is, a macro marked with
#[allow_internal_unstable]).
pub fn is_compiler_desugaring(&self, kind: CompilerDesugaringKind) -> bool[src]
pub fn is_compiler_desugaring(&self, kind: CompilerDesugaringKind) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if this span arises from a compiler desugaring of kind kind.
pub fn compiler_desugaring_kind(&self) -> Option<CompilerDesugaringKind>[src]
pub fn compiler_desugaring_kind(&self) -> Option<CompilerDesugaringKind>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the compiler desugaring that created this span, or None if this span is not from a desugaring.
pub fn allows_unsafe(&self) -> bool[src]
pub fn allows_unsafe(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Check if a span is "internal" to a macro in which unsafe
can be used without triggering the unsafe_code lint
pub fn macro_backtrace(self) -> Vec<MacroBacktrace>[src]
pub fn macro_backtrace(self) -> Vec<MacroBacktrace>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to(self, end: Span) -> Span[src]
pub fn to(self, end: Span) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a Span that would enclose both self and end.
pub fn between(self, end: Span) -> Span[src]
pub fn between(self, end: Span) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a Span between the end of self to the beginning of end.
pub fn until(self, end: Span) -> Span[src]
pub fn until(self, end: Span) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a Span between the beginning of self to the beginning of end.
pub fn from_inner_byte_pos(self, start: usize, end: usize) -> Span[src]
pub fn from_inner_byte_pos(self, start: usize, end: usize) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn apply_mark(self, mark: Mark) -> Span[src]
pub fn apply_mark(self, mark: Mark) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove_mark(&mut self) -> Mark[src]
pub fn remove_mark(&mut self) -> Mark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn adjust(&mut self, expansion: Mark) -> Option<Mark>[src]
pub fn adjust(&mut self, expansion: Mark) -> Option<Mark>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>[src]
pub fn glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn reverse_glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>[src]
pub fn reverse_glob_adjust(
&mut self,
expansion: Mark,
glob_ctxt: SyntaxContext
) -> Option<Option<Mark>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern(self) -> Span[src]
pub fn modern(self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern_and_legacy(self) -> Span[src]
pub fn modern_and_legacy(self) -> Span🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?