Struct syntax_pos::symbol::keywords::Keyword
[−]
[src]
pub struct Keyword { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Keyword[src]
impl Keywordpub fn ident(self) -> Ident[src]
pub fn ident(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn name(self) -> Symbol[src]
pub fn name(self) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?