Struct syntax_pos::symbol::Ident [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
name: Symbol
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Ident[src]
impl Identpub const fn new(name: Symbol, span: Span) -> Ident[src]
pub const fn new(name: Symbol, span: Span) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub const fn with_empty_ctxt(name: Symbol) -> Ident[src]
pub const fn with_empty_ctxt(name: Symbol) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_interned_str(string: InternedString) -> Ident[src]
pub fn from_interned_str(string: InternedString) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps an interned string to an identifier with an empty syntax context.
pub fn from_str(string: &str) -> Ident[src]
pub fn from_str(string: &str) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps a string to an identifier with an empty syntax context.
pub fn with_span_pos(self, span: Span) -> Ident[src]
pub fn with_span_pos(self, span: Span) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Replace lo and hi with those from span, but keep hygiene context.
pub fn without_first_quote(self) -> Ident[src]
pub fn without_first_quote(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn modern(self) -> Ident[src]
pub fn modern(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
"Normalize" ident for use in comparisons using "item hygiene".
Identifiers with same string value become same if they came from the same "modern" macro
(e.g. macro item, but not macro_rules item) and stay different if they came from
different "modern" macros.
Technically, this operation strips all non-opaque marks from ident's syntactic context.
pub fn modern_and_legacy(self) -> Ident[src]
pub fn modern_and_legacy(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
"Normalize" ident for use in comparisons using "local variable hygiene".
Identifiers with same string value become same if they came from the same non-transparent
macro (e.g. macro or macro_rules! items) and stay different if they came from different
non-transparent macros.
Technically, this operation strips all transparent marks from ident's syntactic context.
pub fn gensym(self) -> Ident[src]
pub fn gensym(self) -> Ident🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_str(self) -> LocalInternedString[src]
pub fn as_str(self) -> LocalInternedString🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn as_interned_str(self) -> InternedString[src]
pub fn as_interned_str(self) -> InternedString🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl Ident[src]
impl Identpub fn is_special(self) -> bool[src]
pub fn is_special(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn is_used_keyword(self) -> bool[src]
pub fn is_used_keyword(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the token is a keyword used in the language.
pub fn is_unused_keyword(self) -> bool[src]
pub fn is_unused_keyword(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the token is a keyword reserved for possible future use.
pub fn is_reserved(self) -> bool[src]
pub fn is_reserved(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the token is either a special identifier or a keyword.
pub fn is_path_segment_keyword(self) -> bool[src]
pub fn is_path_segment_keyword(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A keyword or reserved identifier that can be used as a path segment.
pub fn is_raw_guess(self) -> bool[src]
pub fn is_raw_guess(self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?