Enum term::attr::AttrExperimental
[-]
[+]
[src]
pub enum Attr {
Bold,
Dim,
Italic(bool),
Underline(bool),
Blink,
Standout(bool),
Reverse,
Secure,
ForegroundColor(Color),
BackgroundColor(Color),
}Terminal attributes for use with term.attr().
Most attributes can only be turned on and must be turned off with term.reset(). The ones that can be turned off explicitly take a boolean value. Color is also represented as an attribute for convenience.