Struct test::BencherExperimental
[-]
[+]
[src]
pub struct Bencher {
pub bytes: u64,
// some fields omitted
}Manager of the benchmarking runs.
This is feed into functions marked with #[bench] to allow for
set-up & tear-down before running a piece of code repeatedly via a
call to iter.
Fields
bytes |
Methods
impl Bencher
fn iter<T, F>(&mut self, inner: F) where F: FnMut() -> T
Callback for benchmark functions to run in their body.