DescriptionListBuilder

Struct DescriptionListBuilder 

pub struct DescriptionListBuilder { /* private fields */ }
A builder struct for DescriptionList

Implementations

Source

impl DescriptionListBuilder

pub fn build(&mut self) -> DescriptionList

Finish building the element

pub fn data( &mut self, data_key: impl Into<Cow<'static, str>>, value: impl Into<Cow<'static, str>>, ) -> &mut DescriptionListBuilder

Insert a data-* property

pub fn description_details<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut DescriptionDetailsBuilder) -> &'a mut DescriptionDetailsBuilder,

Append a new DescriptionDetails element

pub fn description_term<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut DescriptionTermBuilder) -> &'a mut DescriptionTermBuilder,

Append a new DescriptionTerm element

pub fn division<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut DivisionBuilder) -> &'a mut DivisionBuilder,

Append a new Division element

pub fn script<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut ScriptBuilder) -> &'a mut ScriptBuilder,

Append a new Script element

pub fn template<F>(&mut self, f: F) -> &mut Self
where F: for<'a> FnOnce(&'a mut TemplateBuilder) -> &'a mut TemplateBuilder,

Append a new Template element

pub fn role(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the role attribute

pub fn aria_active_descendant_element( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-activedescendant attribute

pub fn aria_atomic(&mut self, value: bool) -> &mut Self

Set the value of the aria-atomic attribute

pub fn aria_braille_label( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-braillelabel attribute

pub fn aria_braille_role_description( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-brailleroledescription attribute

pub fn aria_busy(&mut self, value: bool) -> &mut Self

Set the value of the aria-busy attribute

pub fn aria_controls_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-controls attribute

pub fn aria_current(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the aria-current attribute

pub fn aria_described_by_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-describedby attribute

pub fn aria_description( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-description attribute

pub fn aria_details_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-details attribute

pub fn aria_disabled(&mut self, value: bool) -> &mut Self

Set the value of the aria-disabled attribute

pub fn aria_drop_effect( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-dropeffect attribute

pub fn aria_error_message_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-errormessage attribute

pub fn aria_flow_to_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-flowto attribute

pub fn aria_grabbed(&mut self, value: bool) -> &mut Self

Set the value of the aria-grabbed attribute

pub fn aria_has_popup( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-haspopup attribute

pub fn aria_hidden(&mut self, value: bool) -> &mut Self

Set the value of the aria-hidden attribute

pub fn aria_invalid(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the aria-invalid attribute

pub fn aria_key_shortcuts( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-keyshortcuts attribute

pub fn aria_label(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the aria-label attribute

pub fn aria_labelled_by_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-labelledby attribute

pub fn aria_live(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the aria-live attribute

pub fn aria_owns_elements( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-owns attribute

pub fn aria_relevant( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-relevant attribute

pub fn aria_role_description( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the aria-roledescription attribute

pub fn access_key(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the accesskey attribute

pub fn auto_capitalize( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the autocapitalize attribute

pub fn autofocus(&mut self, value: bool) -> &mut Self

Set the value of the autofocus attribute

pub fn class(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the class attribute

pub fn content_editable( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the contenteditable attribute

pub fn direction(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the dir attribute

pub fn draggable(&mut self, value: bool) -> &mut Self

Set the value of the draggable attribute

pub fn enter_key_hint( &mut self, value: impl Into<Cow<'static, str>>, ) -> &mut Self

Set the value of the enterkeyhint attribute

pub fn export_parts(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the exportparts attribute

pub fn hidden(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the hidden attribute

pub fn id(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the id attribute

pub fn inert(&mut self, value: bool) -> &mut Self

Set the value of the inert attribute

pub fn input_mode(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the inputmode attribute

pub fn is_(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the is attribute

pub fn item_id(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemid attribute

pub fn item_prop(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemprop attribute

pub fn item_ref(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemref attribute

pub fn item_scope(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemscope attribute

pub fn item_type(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the itemtype attribute

pub fn lang(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the lang attribute

pub fn nonce(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the nonce attribute

pub fn part(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the part attribute

pub fn slot(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the slot attribute

pub fn spellcheck(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the spellcheck attribute

pub fn style(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the style attribute

pub fn tab_index(&mut self, value: i64) -> &mut Self

Set the value of the tabindex attribute

pub fn title(&mut self, value: impl Into<Cow<'static, str>>) -> &mut Self

Set the value of the title attribute

pub fn translate(&mut self, value: bool) -> &mut Self

Set the value of the translate attribute

pub fn push<T>(&mut self, child_el: T) -> &mut Self

Push a new child element to the list of children.

pub fn extend<I, T>(&mut self, iter: I) -> &mut Self
where I: IntoIterator<Item = T>, T: Into<DescriptionListChild>,

Extend the list of children with an iterator of child elements.