pub trait Render {
// Required method
fn render(&self, f: &mut Formatter<'_>, depth: usize) -> Result;
}Expand description
Render an HTML element to a string.
This API is similar to Display, but it takes a depth argument which
allows rendered items to be indented.
Users of this crate are expected to keep using the Display interface as
normal. This trait only exists for internal bookkeeping.