pub trait SectioningContent: FlowContent { }Expand description
The Sectioning content category
Sectioning content is content that defines the scope of header and footer elements.
pub trait SectioningContent: FlowContent { }The Sectioning content category
Sectioning content is content that defines the scope of header and footer elements.