Function unicode::char::widthDeprecated
[-]
[+]
[src]
pub fn width(c: char, is_cjk: bool) -> Option<uint>
Returns this character's displayed width in columns, or None if it is a
control character other than '\x00'.
is_cjk determines behavior for characters in the Ambiguous category:
if is_cjk is true, these are 2 columns wide; otherwise, they are 1.
In CJK contexts, is_cjk should be true, else it should be false.
Unicode Standard Annex #11
recommends that these characters be treated as 1 column (i.e.,
is_cjk = false) if the context cannot be reliably determined.