Module html::web_components

source ·
Web Components

Web Components is an HTML-related technology which makes it possible to, essentially, create and use custom elements as if it were regular HTML. In addition, you can create custom versions of standard HTML elements.

Modules

Structs

  • The HTML <slot> element
  • The HTML <template> element