Struct arena::DroplessArena [−][src]
pub struct DroplessArena {
ptr: Cell<*mut u8>,
end: Cell<*mut u8>,
chunks: RefCell<Vec<TypedArenaChunk<u8>>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
ptr: Cell<*mut u8>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A pointer to the next object to be allocated.
end: Cell<*mut u8>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A pointer to the end of the allocated area. When this pointer is reached, a new chunk is allocated.
chunks: RefCell<Vec<TypedArenaChunk<u8>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A vector of arena chunks.
Methods
impl DroplessArena[src]
impl DroplessArenapub fn new() -> DroplessArena[src]
pub fn new() -> DroplessArena🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn in_arena<T: ?Sized>(&self, ptr: *const T) -> bool[src]
pub fn in_arena<T: ?Sized>(&self, ptr: *const T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn align(&self, align: usize)[src]
fn align(&self, align: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn grow(&self, needed_bytes: usize)[src]
fn grow(&self, needed_bytes: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc_raw(&self, bytes: usize, align: usize) -> &mut [u8][src]
pub fn alloc_raw(&self, bytes: usize, align: usize) -> &mut [u8]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc<T>(&self, object: T) -> &mut T[src]
pub fn alloc<T>(&self, object: T) -> &mut T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn alloc_slice<T>(&self, slice: &[T]) -> &mut [T] where
T: Copy, [src]
pub fn alloc_slice<T>(&self, slice: &[T]) -> &mut [T] where
T: Copy, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Allocates a slice of objects that are copied into the DroplessArena, returning a mutable
reference to it. Will panic if passed a zero-sized type.
Panics:
- Zero-sized types
- Zero-length slices