pub unsafe fn vld1_p64_x4(a: *const u64) -> poly64x1x4_tAvailable on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature
v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.Expand description
Load multiple single-element structures to one, two, three, or four registers Arm’s documentation
Safety
- Neon intrinsic unsafe