pub unsafe fn vld4_dup_p64(a: *const u64) -> poly64x1x4_tAvailable on (AArch64 or ARM64EC) and (AArch64 or ARM64EC or target feature
v7) and (ARM or AArch64 or ARM64EC) and target feature neon and target feature aes only.Expand description
Load single 4-element structure and replicate to all lanes of four registers Arm’s documentation
Safety
- Neon intrinsic unsafe