vst1_f32_x4

Function vst1_f32_x4 

pub unsafe fn vst1_f32_x4(a: *mut f32, b: float32x2x4_t)
🔬This is a nightly-only experimental API. (stdarch_arm_neon_intrinsics #111800)
Available on (AArch64 or target_arch=arm64ec) and ARM and target feature neon and target feature v7 only.
Store multiple single-element structures to one, two, three, or four registers Arm’s documentation

Safety

  • Neon instrinsic unsafe