pub unsafe fn s_get_barrier_state<const BARRIER_TYPE: i32>() -> u32🔬This is a nightly-only experimental API. (
stdarch_amdgpu #149988)Available on AMD GPU only.
Get the state of a specific barrier type.
The barrier_type argument must be uniform, otherwise behavior is undefined.
This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.