pub unsafe fn _syncthreads()🔬This is a nightly-only experimental API. (
stdarch_nvptx #111199)Available on NVidia GPU only.
Synchronizes all threads in the block.
This intrinsic does not behave like a normal function call; it is a “convergent” operation and as such has non-standard control-flow effects which need special treatment by the language. Rust currently does not properly support convergent operations. This operation is hence provided on a best-effort basis. Using it may result in incorrect code under some circumstances.