Struct core::ptr::NonNull 1.24.0
[−]
[src]
pub struct NonNull<T: ?Sized> { /* fields omitted */ }*mut T but non-zero and covariant.
This is often the correct thing to use when building data structures using
raw pointers, but is ultimately more dangerous to use because of its additional
properties. If you're not sure if you should use NonNull<T>, just use *mut T!
Unlike *mut T, the pointer must always be non-null, even if the pointer
is never dereferenced. This is so that enums may use this forbidden value
as a discriminant -- Option<NonNull<T>> has the same size as NonNull<T>.
However the pointer may still dangle if it isn't dereferenced.
Unlike *mut T, NonNull<T> is covariant over T. If this is incorrect
for your use case, you should include some PhantomData in your type to
provide invariance, such as PhantomData<Cell<T>> or PhantomData<&'a mut T>.
Usually this won't be necessary; covariance is correct for most safe abstractions,
such as Box, Rc, Arc, Vec, and LinkedList. This is the case because they
provide a public API that follows the normal shared XOR mutable rules of Rust.
Methods
impl<T: Sized> NonNull<T>[src]
pub fn dangling() -> Self[src]
Creates a new NonNull that is dangling, but well-aligned.
This is useful for initializing types which lazily allocate, like
Vec::new does.
impl<T: ?Sized> NonNull<T>[src]
pub const unsafe fn new_unchecked(ptr: *mut T) -> Self[src]
pub fn new(ptr: *mut T) -> Option<Self>[src]
Creates a new NonNull if ptr is non-null.
pub fn as_ptr(self) -> *mut T[src]
Acquires the underlying *mut pointer.
pub unsafe fn as_ref(&self) -> &T[src]
Dereferences the content.
The resulting lifetime is bound to self so this behaves "as if"
it were actually an instance of T that is getting borrowed. If a longer
(unbound) lifetime is needed, use &*my_ptr.as_ptr().
pub unsafe fn as_mut(&mut self) -> &mut T[src]
Mutably dereferences the content.
The resulting lifetime is bound to self so this behaves "as if"
it were actually an instance of T that is getting borrowed. If a longer
(unbound) lifetime is needed, use &mut *my_ptr.as_ptr().