Enum fmt_macros::CountExperimental
[-]
[+]
[src]
pub enum Count<'a> {
CountIs(uint),
CountIsName(&'a str),
CountIsParam(uint),
CountIsNextParam,
CountImplied,
}A count is used for the precision and width parameters of an integer, and can reference either an argument or a literal integer.