Enum fmt_macros::PieceExperimental
[-]
[+]
[src]
pub enum Piece<'a> {
String(&'a str),
NextArgument(Argument<'a>),
}A piece is a portion of the format string which represents the next part
to emit. These are emitted as a stream by the Parser class.
Variants
String | A literal string which should directly be emitted |
NextArgument | This describes that formatting should process the next argument (as specified inside) for emission. |