Inline text elements
Use the HTML inline text semantic to define the meaning, structure, or style of a word, line, or any arbitrary piece of text.
Modules
Structs
- Abbreviation
- The HTML
<abbr>element - Anchor
- The HTML
<a>element - Bidirectional
Isolate - The HTML
<bdi>element - Bidirectional
Text Override - The HTML
<bdo>element - Bold
- The HTML
<b>element - Cite
- The HTML
<cite>element - Code
- The HTML
<code>element - Data
- The HTML
<data>element - Definition
- The HTML
<dfn>element - Emphasis
- The HTML
<em>element - Italic
- The HTML
<i>element - Keyboard
Input - The HTML
<kbd>element - Line
Break - The HTML
<br>element - Line
Break Opportunity - The HTML
<wbr>element - Mark
Text - The HTML
<mark>element - Quotation
- The HTML
<q>element - Ruby
Annotation - The HTML
<ruby>element - Ruby
Fallback Parenthesis - The HTML
<rp>element - Ruby
Text - The HTML
<rt>element - Sample
Output - The HTML
<samp>element - Side
Comment - The HTML
<small>element - Span
- The HTML
<span>element - Strike
Through - The HTML
<s>element - Strong
- The HTML
<strong>element - SubScript
- The HTML
<sub>element - Super
Script - The HTML
<sup>element - Time
- The HTML
<time>element - Underline
- The HTML
<u>element - Variable
- The HTML
<var>element