[−][src]Struct rand::distributions::gamma::GammaLargeShape
Gamma distribution where the shape parameter is larger than 1.
See Gamma for sampling from a Gamma distribution with general
shape parameters.
Fields
scale: f64
c: f64
d: f64
Methods
impl GammaLargeShape[src]
impl GammaLargeShapefn new_raw(shape: f64, scale: f64) -> GammaLargeShape[src]
fn new_raw(shape: f64, scale: f64) -> GammaLargeShapeTrait Implementations
impl Clone for GammaLargeShape[src]
impl Clone for GammaLargeShapefn clone(&self) -> GammaLargeShape[src]
fn clone(&self) -> GammaLargeShapeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for GammaLargeShape[src]
impl Copy for GammaLargeShapeimpl Debug for GammaLargeShape[src]
impl Debug for GammaLargeShapefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Distribution<f64> for GammaLargeShape[src]
impl Distribution<f64> for GammaLargeShapefn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> f64[src]
fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> f64Generate a random value of T, using rng as the source of randomness.
ⓘImportant traits for DistIter<'a, D, R, T>fn sample_iter<'a, R>(&'a self, rng: &'a mut R) -> DistIter<'a, Self, R, T> where
Self: Sized,
R: Rng, [src]
fn sample_iter<'a, R>(&'a self, rng: &'a mut R) -> DistIter<'a, Self, R, T> where
Self: Sized,
R: Rng, Create an iterator that generates random values of T, using rng as the source of randomness. Read more