pub(crate) trait ResolverAstLoweringExt<'tcx> {
// Required methods
fn legacy_const_generic_args(
&self,
expr: &Expr,
tcx: TyCtxt<'tcx>,
) -> Option<Vec<usize>>;
fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>;
fn get_label_res(&self, id: NodeId) -> Option<NodeId>;
fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>;
fn extra_lifetime_params(
&self,
id: NodeId,
) -> &[(Ident, NodeId, LifetimeRes)];
fn delegation_info(&self, id: LocalDefId) -> Option<&DelegationInfo>;
fn opt_local_def_id(&self, id: NodeId) -> Option<LocalDefId>;
fn local_def_id(&self, id: NodeId) -> LocalDefId;
fn lifetime_elision_allowed(&self, id: NodeId) -> bool;
}Required Methods
fn legacy_const_generic_args( &self, expr: &Expr, tcx: TyCtxt<'tcx>, ) -> Option<Vec<usize>>
Sourcefn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>
fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>
Obtains per-namespace resolutions for use statement with the given NodeId.
Sourcefn get_label_res(&self, id: NodeId) -> Option<NodeId>
fn get_label_res(&self, id: NodeId) -> Option<NodeId>
Obtains resolution for a label with the given NodeId.
Sourcefn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>
fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>
Obtains resolution for a lifetime with the given NodeId.
Sourcefn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]
fn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]
Obtain the list of lifetimes parameters to add to an item.
Extra lifetime parameters should only be added in places that can appear
as a binder in LifetimeRes.
The extra lifetimes that appear from the parenthesized Fn-trait desugaring
should appear at the enclosing PolyTraitRef.
fn delegation_info(&self, id: LocalDefId) -> Option<&DelegationInfo>
fn opt_local_def_id(&self, id: NodeId) -> Option<LocalDefId>
fn local_def_id(&self, id: NodeId) -> LocalDefId
fn lifetime_elision_allowed(&self, id: NodeId) -> bool
Implementations on Foreign Types
Sourceimpl<'tcx> ResolverAstLoweringExt<'tcx> for ResolverAstLowering<'tcx>
impl<'tcx> ResolverAstLoweringExt<'tcx> for ResolverAstLowering<'tcx>
Sourcefn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>
fn get_import_res(&self, id: NodeId) -> PerNS<Option<Res<NodeId>>>
Obtains per-namespace resolutions for use statement with the given NodeId.
Sourcefn get_label_res(&self, id: NodeId) -> Option<NodeId>
fn get_label_res(&self, id: NodeId) -> Option<NodeId>
Obtains resolution for a label with the given NodeId.
Sourcefn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>
fn get_lifetime_res(&self, id: NodeId) -> Option<LifetimeRes>
Obtains resolution for a lifetime with the given NodeId.
Sourcefn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]
fn extra_lifetime_params(&self, id: NodeId) -> &[(Ident, NodeId, LifetimeRes)]
Obtain the list of lifetimes parameters to add to an item.
Extra lifetime parameters should only be added in places that can appear
as a binder in LifetimeRes.
The extra lifetimes that appear from the parenthesized Fn-trait desugaring
should appear at the enclosing PolyTraitRef.