pub trait ToStableHashKey {
type KeyType: Ord + Sized + StableHash;
// Required method
fn to_stable_hash_key<Hcx: StableHashCtxt>(
&self,
hcx: &mut Hcx,
) -> Self::KeyType;
}Expand description
Implement this for types that can be turned into stable keys like, for example, for DefId that can be converted to a DefPathHash. This is used for bringing maps into a predictable order before hashing them.
Required Associated Types
type KeyType: Ord + Sized + StableHash
Required Methods
fn to_stable_hash_key<Hcx: StableHashCtxt>( &self, hcx: &mut Hcx, ) -> Self::KeyType
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.