pub(crate) fn show_colored_md_content(content: &str)
Prints the markdown content with colored output.
This function is used when the output is not a terminal, but the user has requested colored output with --color=always.
--color=always