fn is_const_pat_that_looks_like_binding<'tcx>(
tcx: TyCtxt<'tcx>,
pat: &Pat<'tcx>,
) -> Option<DefId>Expand description
If the given pattern is a named constant that looks like it could have been
intended to be a binding, returns the DefId of the named constant.
Diagnostics use this to give more detailed suggestions for non-exhaustive matches.