fn do_check_unsized_params<'tcx>(
tcx: TyCtxt<'tcx>,
fn_abi: &FnAbi<'tcx, Ty<'tcx>>,
is_call: bool,
loc: impl Fn() -> (Span, HirId),
)Expand description
Emit an error when a non-rustic ABI has unsized parameters.
Unsized types do not have a stable layout, so should not be used with stable ABIs.
is_call indicates whether this is a call-site check or a definition-site check;
this is only relevant for the wording in the emitted error.