pub struct Unnormalized<I: Interner, T> {
value: T,
_tcx: PhantomData<fn() -> I>,
}Expand description
A wrapper for values that need normalization.
FIXME(#155345): This is very WIP. The plan is to replace the skip_norm_wip
spread throughout the codebase with proper normalization. This is the first
step toward switching to eager normalization with the next solver. See the
normalization refactor plan here.
We’re in a weird intermediate state as the change is too big to land in a
single PR. While this work is in progress, just use Unnormalized::new_wip
and Unnormalized::skip_norm_wip as needed.
The interner type parameter exists to constraint generic for certain impl,
e.g., Unnormalized<I, I::Clause>.
Fields
value: T_tcx: PhantomData<fn() -> I>Implementations
Sourceimpl<I: Interner, T> Unnormalized<I, T>
impl<I: Interner, T> Unnormalized<I, T>
Sourcepub fn new(value: T) -> Unnormalized<I, T>
pub fn new(value: T) -> Unnormalized<I, T>
Should only be used in limited situations where you produce an potentially unnormalized value, like in (Early)Binder/GenericPredicates instantiation.
Sourcepub fn new_wip(value: T) -> Unnormalized<I, T>
pub fn new_wip(value: T) -> Unnormalized<I, T>
FIXME: This is going to be eventually removed once we migrate the relevant
APIs to return Unnormalized.
Sourcepub fn skip_normalization(self) -> T
pub fn skip_normalization(self) -> T
Intentionally skip normalization. You probably should perform normalization in most cases.
Sourcepub fn skip_norm_wip(self) -> T
pub fn skip_norm_wip(self) -> T
FIXME: This is going to be eventually removed.
If you meet this in codebase, try using one of the normalization routines
to consume the Unnormalized wrapper. Or use skip_normalization when normalization
is really unnecessary.
pub fn map<F, U>(self, f: F) -> Unnormalized<I, U>where
F: FnOnce(T) -> U,
pub fn as_ref(&self) -> Unnormalized<I, &T>
pub fn map_ref<U, F>(&self, f: F) -> Unnormalized<I, U>
Sourceimpl<I: Interner, T, U> Unnormalized<I, (T, U)>
impl<I: Interner, T, U> Unnormalized<I, (T, U)>
pub fn unzip(self) -> (Unnormalized<I, T>, Unnormalized<I, U>)
Sourceimpl<I: Interner, T> Unnormalized<I, Binder<I, T>>
impl<I: Interner, T> Unnormalized<I, Binder<I, T>>
pub fn skip_binder(self) -> T
Sourceimpl<I: Interner> Unnormalized<I, I::Clause>
impl<I: Interner> Unnormalized<I, I::Clause>
pub fn as_trait_clause( self, ) -> Option<Unnormalized<I, Binder<I, TraitPredicate<I>>>>
pub fn kind(self) -> Unnormalized<I, Binder<I, ClauseKind<I>>>
Sourceimpl<I: Interner> Unnormalized<I, Binder<I, TraitPredicate<I>>>
impl<I: Interner> Unnormalized<I, Binder<I, TraitPredicate<I>>>
Sourceimpl<I: Interner> Unnormalized<I, Binder<I, TraitRef<I>>>
impl<I: Interner> Unnormalized<I, Binder<I, TraitRef<I>>>
pub fn self_ty(&self) -> Unnormalized<I, Binder<I, I::Ty>>
pub fn def_id(&self) -> I::TraitId
pub fn to_host_effect_clause( self, cx: I, constness: BoundConstness, ) -> Unnormalized<I, I::Clause>