Enum rustc::hir::LifetimeName [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Implicit🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
User typed nothing. e.g. the lifetime in &u32.
Underscore🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
User typed '_.
Fresh(usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Synthetic name generated when user elided a lifetime in an impl header, e.g. the lifetimes in cases like these:
impl Foo for &u32 impl Foo<'_> for u32
in that case, we rewrite to
impl<'f> Foo for &'f u32 impl<'f> Foo<'f> for u32
where 'f is something like Fresh(0). The indices are
unique per impl, but not necessarily continuous.
Static🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
User wrote 'static
Name(Name)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Some user-given name like 'x
Methods
impl LifetimeName[src]
impl LifetimeNamepub fn name(&self) -> Name[src]
pub fn name(&self) -> Name🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?