Struct rustc::hir::Path [−][src]
pub struct Path {
pub span: Span,
pub def: Def,
pub segments: HirVec<PathSegment>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A "Path" is essentially Rust's notion of a name; for instance:
std::cmp::PartialEq. It's represented as a sequence of identifiers,
along with a bunch of supporting information.
Fields
span: Span
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
def: Def
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The definition that the path resolved to.
segments: HirVec<PathSegment>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The segments in the path: the things separated by ::.
Methods
impl Path[src]
impl Pathpub fn is_global(&self) -> bool[src]
pub fn is_global(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?