Struct rustc::hir::PathSegment [−][src]
pub struct PathSegment {
pub ident: Ident,
pub args: Option<P<GenericArgs>>,
pub infer_types: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A segment of a path: an identifier, an optional lifetime, and a set of types.
Fields
ident: Ident
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The identifier portion of this path segment.
args: Option<P<GenericArgs>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type/lifetime parameters attached to this path. They come in
two flavors: Path<A,B,C> and Path(A,B) -> C. Note that
this is more than just simple syntactic sugar; the use of
parens affects the region binding rules, so we preserve the
distinction.
infer_types: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether to infer remaining type parameters, if any.
This only applies to expression and pattern paths, and
out of those only the segments with no type parameters
to begin with, e.g. Vec::new is <Vec<..>>::new::<..>.
Methods
impl PathSegment[src]
impl PathSegmentpub fn from_ident(ident: Ident) -> PathSegment[src]
pub fn from_ident(ident: Ident) -> PathSegment🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Convert an identifier to the corresponding segment.
pub fn new(ident: Ident, args: GenericArgs, infer_types: bool) -> Self[src]
pub fn new(ident: Ident, args: GenericArgs, infer_types: bool) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_generic_args<F, R>(&self, f: F) -> R where
F: FnOnce(&GenericArgs) -> R, [src]
pub fn with_generic_args<F, R>(&self, f: F) -> R where
F: FnOnce(&GenericArgs) -> R, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?