Struct rustc::hir::TraitRef [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
TraitRef's appear in impls.
resolve maps each TraitRef's ref_id to its defining trait; that's all that the ref_id is for. Note that ref_id's value is not the NodeId of the trait being referred to but just a unique NodeId that serves as a key within the DefMap.
Fields
path: Path
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ref_id: NodeId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?