[−][src]Struct rustc::infer::unify_key::RegionVidKey
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
min_vid: RegionVid
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The minimum region vid in the unification set. This is needed to have a canonical name for a type to prevent infinite recursion.