Struct rustc::lint::context::EarlyContext [−][src]
pub struct EarlyContext<'a> {
pub sess: &'a Session,
pub krate: &'a Crate,
builder: LintLevelsBuilder<'a>,
lint_sess: LintSession<'a, EarlyLintPassObject>,
buffered: LintBuffer,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Context for lint checking of the AST, after expansion, before lowering to HIR.
Fields
sess: &'a Session
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Type context we're checking in.
krate: &'a Crate
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The crate being checked.
builder: LintLevelsBuilder<'a>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lint_sess: LintSession<'a, EarlyLintPassObject>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The store of registered lints and the lint levels.
buffered: LintBuffer
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> EarlyContext<'a>[src]
impl<'a> EarlyContext<'a>fn new(sess: &'a Session, krate: &'a Crate) -> EarlyContext<'a>[src]
fn new(sess: &'a Session, krate: &'a Crate) -> EarlyContext<'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_id(&mut self, id: NodeId)[src]
fn check_id(&mut self, id: NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?