Struct rustc::lint::context::LintSession [−][src]
pub struct LintSession<'a, PassObject> {
lints: ReadGuard<'a, LintStore>,
passes: Option<Vec<PassObject>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
lints: ReadGuard<'a, LintStore>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Reference to the store of registered lints.
passes: Option<Vec<PassObject>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Trait objects for each lint pass.