Struct rustc::lint::LintLevelSets [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
list: Vec<LintSet>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lint_cap: Level
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LintLevelSets[src]
impl LintLevelSetspub fn new(sess: &Session) -> LintLevelSets[src]
pub fn new(sess: &Session) -> LintLevelSets🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn builder(sess: &Session) -> LintLevelsBuilder[src]
pub fn builder(sess: &Session) -> LintLevelsBuilder🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn process_command_line(&mut self, sess: &Session)[src]
fn process_command_line(&mut self, sess: &Session)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_lint_level(
&self,
lint: &'static Lint,
idx: u32,
aux: Option<&FxHashMap<LintId, (Level, LintSource)>>,
sess: &Session
) -> (Level, LintSource)[src]
fn get_lint_level(
&self,
lint: &'static Lint,
idx: u32,
aux: Option<&FxHashMap<LintId, (Level, LintSource)>>,
sess: &Session
) -> (Level, LintSource)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn get_lint_id_level(
&self,
id: LintId,
idx: u32,
aux: Option<&FxHashMap<LintId, (Level, LintSource)>>
) -> (Option<Level>, LintSource)[src]
fn get_lint_id_level(
&self,
id: LintId,
idx: u32,
aux: Option<&FxHashMap<LintId, (Level, LintSource)>>
) -> (Option<Level>, LintSource)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?