Enum rustc::middle::exported_symbols::ExportedSymbol [−][src]
pub enum ExportedSymbol<'tcx> {
NonGeneric(DefId),
Generic(DefId, &'tcx Substs<'tcx>),
NoDefId(SymbolName),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
NonGeneric(DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Generic(DefId, &'tcx Substs<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
NoDefId(SymbolName)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> ExportedSymbol<'tcx>[src]
impl<'tcx> ExportedSymbol<'tcx>pub fn symbol_name(&self, tcx: TyCtxt<'_, 'tcx, '_>) -> SymbolName[src]
pub fn symbol_name(&self, tcx: TyCtxt<'_, 'tcx, '_>) -> SymbolName🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn compare_stable(
&self,
tcx: TyCtxt<'_, 'tcx, '_>,
other: &ExportedSymbol<'tcx>
) -> Ordering[src]
pub fn compare_stable(
&self,
tcx: TyCtxt<'_, 'tcx, '_>,
other: &ExportedSymbol<'tcx>
) -> Ordering🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?