Enum rustc::middle::exported_symbols::SymbolExportLevel [−][src]
pub enum SymbolExportLevel {
C,
Rust,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The SymbolExportLevel of a symbols specifies from which kinds of crates
the symbol will be exported. C symbols will be exported from any
kind of crate, including cdylibs which export very few things.
Rust will only be exported if the crate produced is a Rust
dylib.
Variants
C🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Rust🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SymbolExportLevel[src]
impl SymbolExportLevelpub fn is_below_threshold(self, threshold: SymbolExportLevel) -> bool[src]
pub fn is_below_threshold(self, threshold: SymbolExportLevel) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?