Enum rustc::middle::resolve_lifetime::LifetimeDefOrigin [−][src]
pub enum LifetimeDefOrigin {
Explicit,
InBand,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The origin of a named lifetime definition.
This is used to prevent the usage of in-band lifetimes in Fn/fn syntax.
Variants
Explicit🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
InBand🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LifetimeDefOrigin[src]
impl LifetimeDefOriginfn from_is_in_band(is_in_band: bool) -> Self[src]
fn from_is_in_band(is_in_band: bool) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?