Enum rustc::middle::resolve_lifetime::Region
[−]
[src]
pub enum Region {
Static,
EarlyBound(u32, DefId, LifetimeDefOrigin),
LateBound(DebruijnIndex, DefId, LifetimeDefOrigin),
LateBoundAnon(DebruijnIndex, u32),
Free(DefId, DefId),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Static🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
EarlyBound(u32, DefId, LifetimeDefOrigin)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LateBound(DebruijnIndex, DefId, LifetimeDefOrigin)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LateBoundAnon(DebruijnIndex, u32)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Free(DefId, DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?