Struct rustc::mir::interpret::Allocation
[−]
[src]
pub struct Allocation {
pub bytes: Vec<u8>,
pub relocations: BTreeMap<u64, AllocId>,
pub undef_mask: UndefMask,
pub align: Align,
pub runtime_mutability: Mutability,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
bytes: Vec<u8>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The actual bytes of the allocation. Note that the bytes of a pointer represent the offset of the pointer
relocations: BTreeMap<u64, AllocId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps from byte addresses to allocations. Only the first byte of a pointer is inserted into the map.
undef_mask: UndefMask
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Denotes undefined memory. Reading from undefined memory is forbidden in miri
align: Align
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The alignment of the allocation to detect unaligned reads.
runtime_mutability: Mutability
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Whether the allocation (of a static) should be put into mutable memory when translating
Only happens for static mut or static with interior mutability
Methods
impl Allocation[src]
impl Allocationpub fn from_bytes(slice: &[u8]) -> Self[src]
pub fn from_bytes(slice: &[u8]) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?