[−][src]Struct rustc::mir::interpret::Relocations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<Id> Relocations<Id>[src]
impl<Id> Relocations<Id>pub fn new() -> Self[src]
pub fn new() -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_presorted(r: Vec<(Size, Id)>) -> Self[src]
pub fn from_presorted(r: Vec<(Size, Id)>) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods from Deref<Target = SortedMap<Size, AllocId>>
pub fn insert(&mut self, key: K, value: V) -> Option<V>[src]
pub fn insert(&mut self, key: K, value: V) -> Option<V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove(&mut self, key: &K) -> Option<V>[src]
pub fn remove(&mut self, key: &K) -> Option<V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, key: &K) -> Option<&V>[src]
pub fn get(&self, key: &K) -> Option<&V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get_mut(&mut self, key: &K) -> Option<&mut V>[src]
pub fn get_mut(&mut self, key: &K) -> Option<&mut V>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Iter<'a, T>pub fn iter(&self) -> Iter<(K, V)>[src]
pub fn iter(&self) -> Iter<(K, V)>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterate over elements, sorted by key
pub fn keys(
&self
) -> impl Iterator<Item = &K> + ExactSizeIterator[src]
pub fn keys(
&self
) -> impl Iterator<Item = &K> + ExactSizeIterator🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterate over the keys, sorted
pub fn values(
&self
) -> impl Iterator<Item = &V> + ExactSizeIterator[src]
pub fn values(
&self
) -> impl Iterator<Item = &V> + ExactSizeIterator🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterate over values, sorted by key
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn range<R>(&self, range: R) -> &[(K, V)] where
R: RangeBounds<K>, [src]
pub fn range<R>(&self, range: R) -> &[(K, V)] where
R: RangeBounds<K>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn remove_range<R>(&mut self, range: R) where
R: RangeBounds<K>, [src]
pub fn remove_range<R>(&mut self, range: R) where
R: RangeBounds<K>, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn offset_keys<F>(&mut self, f: F) where
F: Fn(&mut K), [src]
pub fn offset_keys<F>(&mut self, f: F) where
F: Fn(&mut K), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Mutate all keys with the given function f. This mutation must not
change the sort-order of keys.
pub fn insert_presorted(&mut self, elements: Vec<(K, V)>)[src]
pub fn insert_presorted(&mut self, elements: Vec<(K, V)>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inserts a presorted range of elements into the map. If the range can be inserted as a whole in between to existing elements of the map, this will be faster than inserting the elements individually.
It is up to the caller to make sure that the elements are sorted by key and that there are no duplicates.