Trait miri::shims::env::EvalContextExt
source · pub trait EvalContextExt<'mir, 'tcx: 'mir>: MiriInterpCxExt<'mir, 'tcx> {
// Provided method
fn get_env_var(
&mut self,
name: &OsStr
) -> InterpResult<'tcx, Option<OsString>> { ... }
}Provided Methods
sourcefn get_env_var(&mut self, name: &OsStr) -> InterpResult<'tcx, Option<OsString>>
fn get_env_var(&mut self, name: &OsStr) -> InterpResult<'tcx, Option<OsString>>
Try to get an environment variable from the interpreted program’s environment. This is useful for implementing shims which are documented to read from the environment.