Function run_make_support::fs_wrapper::read
source · pub fn read<P: AsRef<Path>>(path: P) -> Vec<u8> ⓘExpand description
A wrapper around std::fs::read which includes the file path in the panic message.
pub fn read<P: AsRef<Path>>(path: P) -> Vec<u8> ⓘA wrapper around std::fs::read which includes the file path in the panic message.