Struct rustc_borrowck::region_infer::values::LiveLoans
source · pub(crate) struct LiveLoans {
pub(crate) inflowing_loans: SparseBitMatrix<RegionVid, BorrowIndex>,
pub(crate) live_loans: SparseBitMatrix<PointIndex, BorrowIndex>,
}Expand description
Data used to compute the loans that are live at a given point in the CFG, when using
-Zpolonius=next.
Fields
inflowing_loans: SparseBitMatrix<RegionVid, BorrowIndex>The set of loans that flow into a given region. When individual regions are marked as live in the CFG, these inflowing loans are recorded as live.
live_loans: SparseBitMatrix<PointIndex, BorrowIndex>The set of loans that are live at a given point in the CFG.
Implementations