Struct rustc_borrowck::type_check::liveness::LiveVariablesVisitor
source · struct LiveVariablesVisitor<'cx, 'tcx> {
tcx: TyCtxt<'tcx>,
liveness_constraints: &'cx mut LivenessValues,
}Expand description
Visitor looking for regions that should be live within rvalues or calls.
Fields
tcx: TyCtxt<'tcx>liveness_constraints: &'cx mut LivenessValuesImplementations
sourceimpl<'cx, 'tcx> LiveVariablesVisitor<'cx, 'tcx>
impl<'cx, 'tcx> LiveVariablesVisitor<'cx, 'tcx>
sourcefn record_regions_live_at<T>(&mut self, value: T, location: Location)where
T: TypeVisitable<TyCtxt<'tcx>>,
fn record_regions_live_at<T>(&mut self, value: T, location: Location)where
T: TypeVisitable<TyCtxt<'tcx>>,
Some variable is “regular live” at location – i.e., it may be used later. This means that
all regions appearing in the type of value must be live at location.