Struct rustc_hir_typeck::fn_ctxt::LoweredTy
source · pub struct LoweredTy<'tcx> {
pub raw: Ty<'tcx>,
pub normalized: Ty<'tcx>,
}Expand description
The ty representation of a user-provided type. Depending on the use-site
we want to either use the unnormalized or the normalized form of this type.
This is a bridge between the interface of AstConv, which outputs a raw Ty,
and the API in this module, which expect Ty to be fully normalized.
Fields
raw: Ty<'tcx>The unnormalized type provided by the user.
normalized: Ty<'tcx>The normalized form of raw, stored here for efficiency.
Implementations