Struct rustc_hir_typeck::writeback::Resolver
source · struct Resolver<'cx, 'tcx> {
fcx: &'cx FnCtxt<'cx, 'tcx>,
span: &'cx dyn Locatable,
body: &'tcx Body<'tcx>,
should_normalize: bool,
}Fields
fcx: &'cx FnCtxt<'cx, 'tcx>span: &'cx dyn Locatablebody: &'tcx Body<'tcx>should_normalize: boolWhether we should normalize using the new solver, disabled both when using the old solver and when resolving predicates.
Implementations
sourceimpl<'cx, 'tcx> Resolver<'cx, 'tcx>
impl<'cx, 'tcx> Resolver<'cx, 'tcx>
fn new( fcx: &'cx FnCtxt<'cx, 'tcx>, span: &'cx dyn Locatable, body: &'tcx Body<'tcx> ) -> Resolver<'cx, 'tcx>
fn report_error(&self, p: impl Into<GenericArg<'tcx>>) -> ErrorGuaranteed
fn handle_term<T>( &mut self, value: T, outer_exclusive_binder: impl FnOnce(T) -> DebruijnIndex, new_err: impl Fn(TyCtxt<'tcx>, ErrorGuaranteed) -> T ) -> T