Struct rustc_infer::infer::error_reporting::nice_region_error::util::AnonymousParamInfo
source · pub struct AnonymousParamInfo<'tcx> {
pub param: &'tcx Param<'tcx>,
pub param_ty: Ty<'tcx>,
pub bound_region: BoundRegionKind,
pub param_ty_span: Span,
pub is_first: bool,
}Expand description
Information about the anonymous region we are searching for.
Fields
param: &'tcx Param<'tcx>The parameter corresponding to the anonymous region.
param_ty: Ty<'tcx>The type corresponding to the anonymous region parameter.
bound_region: BoundRegionKindThe ty::BoundRegionKind corresponding to the anonymous region.
param_ty_span: SpanThe Span of the parameter type.
is_first: boolSignals that the argument is the first parameter in the declaration.