Struct rustc_infer::infer::outlives::for_liveness::FreeRegionsVisitor
source · pub struct FreeRegionsVisitor<'tcx, OP: FnMut(Region<'tcx>)> {
pub tcx: TyCtxt<'tcx>,
pub param_env: ParamEnv<'tcx>,
pub op: OP,
}Expand description
Visits free regions in the type that are relevant for liveness computation.
These regions are passed to OP.
Specifically, we visit all of the regions of types recursively, except if
the type is an alias, we look at the outlives bounds in the param-env
and alias’s item bounds. If there is a unique outlives bound, then visit
that instead. If there is not a unique but there is a 'static outlives
bound, then don’t visit anything. Otherwise, walk through the opaque’s
regions structurally.
Fields
tcx: TyCtxt<'tcx>param_env: ParamEnv<'tcx>op: OPTrait Implementations
sourceimpl<'tcx, OP> TypeVisitor<TyCtxt<'tcx>> for FreeRegionsVisitor<'tcx, OP>
impl<'tcx, OP> TypeVisitor<TyCtxt<'tcx>> for FreeRegionsVisitor<'tcx, OP>
fn visit_binder<T: TypeVisitable<TyCtxt<'tcx>>>( &mut self, t: &Binder<'tcx, T> ) -> ControlFlow<Self::BreakTy>
fn visit_region(&mut self, r: Region<'tcx>) -> ControlFlow<Self::BreakTy>
fn visit_ty(&mut self, ty: Ty<'tcx>) -> ControlFlow<Self::BreakTy>
type BreakTy = !