pub(super) struct CoverageCounters {
    next_counter_id: CounterId,
    bcb_counters: IndexVec<BasicCoverageBlock, Option<BcbCounter>>,
    bcb_edge_counters: FxIndexMap<(BasicCoverageBlock, BasicCoverageBlock), BcbCounter>,
    bcb_has_incoming_edge_counters: BitSet<BasicCoverageBlock>,
    expressions: IndexVec<ExpressionId, Expression>,
}
Generates and stores coverage counter and coverage expression information associated with nodes/edges in the BCB graph.

Fields

next_counter_id: CounterIdbcb_counters: IndexVec<BasicCoverageBlock, Option<BcbCounter>>

Coverage counters/expressions that are associated with individual BCBs.

bcb_edge_counters: FxIndexMap<(BasicCoverageBlock, BasicCoverageBlock), BcbCounter>

Coverage counters/expressions that are associated with the control-flow edge between two BCBs.

The iteration order of this map can affect the precise contents of MIR, so we use FxIndexMap to avoid query stability hazards.

bcb_has_incoming_edge_counters: BitSet<BasicCoverageBlock>

Tracks which BCBs have a counter associated with some incoming edge. Only used by assertions, to verify that BCBs with incoming edge counters do not have their own physical counters (expressions are allowed).

expressions: IndexVec<ExpressionId, Expression>

Table of expression data, associating each expression ID with its corresponding operator (+ or -) and its LHS/RHS operands.

Implementations

source

impl CoverageCounters

source

pub(super) fn make_bcb_counters( basic_coverage_blocks: &CoverageGraph, bcb_has_coverage_spans: impl Fn(BasicCoverageBlock) -> bool ) -> Self

Makes BcbCounter Counters and Expressions for the BasicCoverageBlocks directly or indirectly associated with coverage spans, and accumulates additional Expressions representing intermediate values.

source

fn make_counter(&mut self) -> BcbCounter

source

fn make_expression( &mut self, lhs: BcbCounter, op: Op, rhs: BcbCounter ) -> BcbCounter

source

fn make_sum_expression( &mut self, lhs: Option<BcbCounter>, rhs: BcbCounter ) -> BcbCounter

Variant of make_expression that makes lhs optional and assumes Op::Add.

This is useful when using Iterator::fold to build an arbitrary-length sum.

source

fn next_counter(&mut self) -> CounterId

Counter IDs start from one and go up.

source

pub(super) fn num_counters(&self) -> usize

source

fn set_bcb_counter( &mut self, bcb: BasicCoverageBlock, counter_kind: BcbCounter ) -> BcbCounter

source

fn set_bcb_edge_counter( &mut self, from_bcb: BasicCoverageBlock, to_bcb: BasicCoverageBlock, counter_kind: BcbCounter ) -> BcbCounter

source

pub(super) fn bcb_counter(&self, bcb: BasicCoverageBlock) -> Option<BcbCounter>

source

pub(super) fn bcb_node_counters( &self ) -> impl Iterator<Item = (BasicCoverageBlock, &BcbCounter)>

source

pub(super) fn bcb_edge_counters( &self ) -> impl Iterator<Item = (BasicCoverageBlock, BasicCoverageBlock, &BcbCounter)>

For each edge in the BCB graph that has an associated counter, yields that edge’s from and to nodes, and its counter.

source

pub(super) fn into_expressions(self) -> IndexVec<ExpressionId, Expression>