enum CoverageSuccessors<'a> {
Chainable(BasicBlock),
NotChainable(&'a [BasicBlock]),
}Expand description
Holds the coverage-relevant successors of a basic block’s terminator, and indicates whether that block can potentially be combined into the same BCB as its sole successor.
Variants
Chainable(BasicBlock)
The terminator has exactly one straight-line successor, so its block can potentially be combined into the same BCB as that successor.
NotChainable(&'a [BasicBlock])
The block cannot be combined into the same BCB as its successor(s).
Implementations
sourceimpl CoverageSuccessors<'_>
impl CoverageSuccessors<'_>
fn is_chainable(&self) -> bool