Struct rustc_mir_transform::coverage::Instrumentor
source · struct Instrumentor<'a, 'tcx> {
tcx: TyCtxt<'tcx>,
mir_body: &'a mut Body<'tcx>,
hir_info: ExtractedHirInfo,
basic_coverage_blocks: CoverageGraph,
}Fields
tcx: TyCtxt<'tcx>mir_body: &'a mut Body<'tcx>hir_info: ExtractedHirInfobasic_coverage_blocks: CoverageGraphImplementations
sourceimpl<'a, 'tcx> Instrumentor<'a, 'tcx>
impl<'a, 'tcx> Instrumentor<'a, 'tcx>
fn new(tcx: TyCtxt<'tcx>, mir_body: &'a mut Body<'tcx>) -> Self
fn inject_counters(&'a mut self)
sourcefn create_mappings(
&self,
coverage_spans: &CoverageSpans,
coverage_counters: &CoverageCounters
) -> Vec<Mapping>
fn create_mappings( &self, coverage_spans: &CoverageSpans, coverage_counters: &CoverageCounters ) -> Vec<Mapping>
For each coverage span extracted from MIR, create a corresponding mapping.
Precondition: All BCBs corresponding to those spans have been given coverage counters.
sourcefn inject_coverage_statements(
&mut self,
bcb_has_coverage_spans: impl Fn(BasicCoverageBlock) -> bool,
coverage_counters: &CoverageCounters
)
fn inject_coverage_statements( &mut self, bcb_has_coverage_spans: impl Fn(BasicCoverageBlock) -> bool, coverage_counters: &CoverageCounters )
For each BCB node or BCB edge that has an associated coverage counter, inject any necessary coverage statements into MIR.
fn make_mir_coverage_kind(&self, counter_kind: &BcbCounter) -> CoverageKind