Struct rustc_mir_transform::dest_prop::FilterInformation
source · struct FilterInformation<'a, 'body, 'alloc, 'tcx> {
body: &'body Body<'tcx>,
points: &'a DenseLocationMap,
live: &'a SparseIntervalMatrix<Local, PointIndex>,
candidates: &'a mut Candidates<'alloc>,
write_info: &'alloc mut WriteInfo,
at: Location,
}Fields
body: &'body Body<'tcx>points: &'a DenseLocationMaplive: &'a SparseIntervalMatrix<Local, PointIndex>candidates: &'a mut Candidates<'alloc>write_info: &'alloc mut WriteInfoat: LocationImplementations
sourceimpl<'a, 'body, 'alloc, 'tcx> FilterInformation<'a, 'body, 'alloc, 'tcx>
impl<'a, 'body, 'alloc, 'tcx> FilterInformation<'a, 'body, 'alloc, 'tcx>
sourcefn filter_liveness<'b>(
candidates: &mut Candidates<'alloc>,
points: &DenseLocationMap,
live: &SparseIntervalMatrix<Local, PointIndex>,
write_info_alloc: &'alloc mut WriteInfo,
body: &'b Body<'tcx>
)
fn filter_liveness<'b>( candidates: &mut Candidates<'alloc>, points: &DenseLocationMap, live: &SparseIntervalMatrix<Local, PointIndex>, write_info_alloc: &'alloc mut WriteInfo, body: &'b Body<'tcx> )
Filters the set of candidates to remove those that conflict.
The steps we take are exactly those that are outlined at the top of the file. For each statement/terminator, we collect the set of locals that are written to in that statement/terminator, and then we remove all pairs of candidates that contain one such local and another one that is live.
We need to be careful about the ordering of operations within each statement/terminator
here. Many statements might write and read from more than one place, and we need to consider
them all. The strategy for doing this is as follows: We first gather all the places that are
written to within the statement/terminator via WriteInfo. Then, we use the liveness
analysis from before the statement/terminator (in the control flow sense) to eliminate
candidates - this is because we want to conservatively treat a pair of locals that is both
read and written in the statement/terminator to be conflicting, and the liveness analysis
before the statement/terminator will correctly report locals that are read in the
statement/terminator to be live. We are additionally conservative by treating all written to
locals as also being read from.
fn internal_filter_liveness(&mut self)
fn apply_conflicts(&mut self)