Enum rustc_mir_transform::gvn::AggregateTy
source · enum AggregateTy<'tcx> {
Array,
Tuple,
Def(DefId, GenericArgsRef<'tcx>),
}Expand description
Computing the aggregate’s type can be quite slow, so we only keep the minimal amount of information to reconstruct it when needed.
Variants