Struct rustc_pattern_analysis::usefulness::PlaceCtxt
source · pub(crate) struct PlaceCtxt<'a, 'p, Cx: TypeCx> {
pub(crate) mcx: MatchCtxt<'a, 'p, Cx>,
pub(crate) ty: Cx::Ty,
pub(crate) is_scrutinee: bool,
}Expand description
Context that provides information local to a place under investigation.
Fields
mcx: MatchCtxt<'a, 'p, Cx>ty: Cx::TyType of the place under investigation.
is_scrutinee: boolWhether the place is the original scrutinee place, as opposed to a subplace of it.
Implementations
sourceimpl<'a, 'p, Cx: TypeCx> PlaceCtxt<'a, 'p, Cx>
impl<'a, 'p, Cx: TypeCx> PlaceCtxt<'a, 'p, Cx>
sourcepub(crate) fn new_dummy(mcx: MatchCtxt<'a, 'p, Cx>, ty: Cx::Ty) -> Self
pub(crate) fn new_dummy(mcx: MatchCtxt<'a, 'p, Cx>, ty: Cx::Ty) -> Self
A PlaceCtxt when code other than is_useful needs one.
pub(crate) fn ctor_arity(&self, ctor: &Constructor<Cx>) -> usize
pub(crate) fn ctor_sub_tys(&self, ctor: &Constructor<Cx>) -> &[Cx::Ty]
pub(crate) fn ctors_for_ty(&self) -> Result<ConstructorSet<Cx>, Cx::Error>