Struct rustc_pattern_analysis::usefulness::PlaceInfo
source · struct PlaceInfo<Cx: TypeCx> {
ty: Cx::Ty,
validity: ValidityConstraint,
is_scrutinee: bool,
}Expand description
Data about a place under investigation.
Fields
ty: Cx::TyThe type of the place.
validity: ValidityConstraintWhether the place is known to contain valid data.
is_scrutinee: boolWhether the place is the scrutinee itself or a subplace of it.
Implementations
sourceimpl<Cx: TypeCx> PlaceInfo<Cx>
impl<Cx: TypeCx> PlaceInfo<Cx>
fn specialize<'a>( &'a self, cx: &'a Cx, ctor: &'a Constructor<Cx> ) -> impl Iterator<Item = Self> + ExactSizeIterator + Captures<'a>