Struct rustc_trait_selection::infer::opaque_types::OpaqueTypeDecl
source · pub struct OpaqueTypeDecl<'tcx> {
pub hidden_type: OpaqueHiddenType<'tcx>,
}Expand description
Information about the opaque types whose values we
are inferring in this function (these are the impl Trait that
appear in the return type).
Fields
The hidden types that have been inferred for this opaque type.
There can be multiple, but they are all lubed together at the end
to obtain the canonical hidden type.