Struct rustc_trait_selection::solve::search_graph::DetachedEntry
source · struct DetachedEntry<'tcx> {
head: StackDepth,
result: QueryResult<'tcx>,
}Expand description
The provisional result for a goal which is not on the stack.
Fields
head: StackDepthThe head of the smallest non-trivial cycle involving this entry.
Given the following rules, when proving A the head for
the provisional entry of C would be B.
A :- B
B :- C
C :- A + B + C
result: QueryResult<'tcx>Auto Trait Implementations
impl<'tcx> !RefUnwindSafe for DetachedEntry<'tcx>
impl<'tcx> Send for DetachedEntry<'tcx>
impl<'tcx> Sync for DetachedEntry<'tcx>
impl<'tcx> Unpin for DetachedEntry<'tcx>
impl<'tcx> !UnwindSafe for DetachedEntry<'tcx>