Struct rustc_type_ir::debug::NoInfcx
source · pub struct NoInfcx<I>(PhantomData<I>);Tuple Fields
0: PhantomData<I>Trait Implementations
sourceimpl<I: Interner> InferCtxtLike for NoInfcx<I>
impl<I: Interner> InferCtxtLike for NoInfcx<I>
type Interner = I
fn interner(&self) -> Self::Interner
fn universe_of_ty(&self, _ty: TyVid) -> Option<UniverseIndex>
fn universe_of_lt(&self, _lt: I::InferRegion) -> Option<UniverseIndex>
fn universe_of_ct(&self, _ct: ConstVid) -> Option<UniverseIndex>
sourcefn root_ty_var(&self, vid: TyVid) -> TyVid
fn root_ty_var(&self, vid: TyVid) -> TyVid
Resolve
TyVid to its root TyVid.sourcefn probe_ty_var(&self, _vid: TyVid) -> Option<I::Ty>
fn probe_ty_var(&self, _vid: TyVid) -> Option<I::Ty>
Resolve
TyVid to its inferred type, if it has been equated with a non-infer type.sourcefn opportunistic_resolve_lt_var(
&self,
_vid: I::InferRegion
) -> Option<I::Region>
fn opportunistic_resolve_lt_var( &self, _vid: I::InferRegion ) -> Option<I::Region>
Resolve
InferRegion to its inferred region, if it has been equated with
a non-infer region. Read moresourcefn root_ct_var(&self, vid: ConstVid) -> ConstVid
fn root_ct_var(&self, vid: ConstVid) -> ConstVid
Resolve
ConstVid to its root ConstVid.Auto Trait Implementations
impl<I> RefUnwindSafe for NoInfcx<I>where
I: RefUnwindSafe,
impl<I> Send for NoInfcx<I>where
I: Send,
impl<I> Sync for NoInfcx<I>where
I: Sync,
impl<I> Unpin for NoInfcx<I>where
I: Unpin,
impl<I> UnwindSafe for NoInfcx<I>where
I: UnwindSafe,