Enum rustc_type_ir::CanonicalVarKind
source · pub enum CanonicalVarKind<I: Interner> {
Ty(CanonicalTyVarKind),
PlaceholderTy(I::PlaceholderTy),
Region(UniverseIndex),
PlaceholderRegion(I::PlaceholderRegion),
Const(UniverseIndex, I::Ty),
Effect,
PlaceholderConst(I::PlaceholderConst, I::Ty),
}Expand description
Describes the “kind” of the canonical variable. This is a “kind” in the type-theory sense of the term – i.e., a “meta” type system that analyzes type-like values.
Variants
Ty(CanonicalTyVarKind)
Some kind of type inference variable.
PlaceholderTy(I::PlaceholderTy)
A “placeholder” that represents “any type”.
Region(UniverseIndex)
Region variable '?R.
PlaceholderRegion(I::PlaceholderRegion)
A “placeholder” that represents “any region”. Created when you
are solving a goal like for<'a> T: Foo<'a> to represent the
bound region 'a.
Const(UniverseIndex, I::Ty)
Some kind of const inference variable.
Effect
Effect variable '?E.
PlaceholderConst(I::PlaceholderConst, I::Ty)
A “placeholder” that represents “any const”.
Implementations
sourceimpl<I: Interner> CanonicalVarKind<I>
impl<I: Interner> CanonicalVarKind<I>
pub fn universe(self) -> UniverseIndex
sourcepub fn with_updated_universe(self, ui: UniverseIndex) -> CanonicalVarKind<I>
pub fn with_updated_universe(self, ui: UniverseIndex) -> CanonicalVarKind<I>
Replaces the universe of this canonical variable with ui.
In case this is a float or int variable, this causes an ICE if the updated universe is not the root.