[−][src]Struct rustc::session::config::OutputTypes
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl OutputTypes[src]
impl OutputTypespub fn new(entries: &[(OutputType, Option<PathBuf>)]) -> OutputTypes[src]
pub fn new(entries: &[(OutputType, Option<PathBuf>)]) -> OutputTypes🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, key: &OutputType) -> Option<&Option<PathBuf>>[src]
pub fn get(&self, key: &OutputType) -> Option<&Option<PathBuf>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains_key(&self, key: &OutputType) -> bool[src]
pub fn contains_key(&self, key: &OutputType) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Keys<'a, K, V>pub fn keys<'a>(&'a self) -> BTreeMapKeysIter<'a, OutputType, Option<PathBuf>>[src]
pub fn keys<'a>(&'a self) -> BTreeMapKeysIter<'a, OutputType, Option<PathBuf>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Values<'a, K, V>pub fn values<'a>(
&'a self
) -> BTreeMapValuesIter<'a, OutputType, Option<PathBuf>>[src]
pub fn values<'a>(
&'a self
) -> BTreeMapValuesIter<'a, OutputType, Option<PathBuf>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn should_codegen(&self) -> bool[src]
pub fn should_codegen(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?