Enum rustc::traits::object_safety::MethodViolationCode [−][src]
pub enum MethodViolationCode {
StaticMethod,
ReferencesSelf,
Generic,
NonStandardSelfType,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Reasons a method might not be object-safe.
Variants
StaticMethod🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
e.g., fn foo()
ReferencesSelf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
e.g., fn foo(&self, x: Self) or fn foo(&self) -> Self
Generic🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
e.g., fn foo<A>()
NonStandardSelfType🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
arbitrary self type, e.g. self: Rc<Self>