Struct rustc::traits::select::WithDepNode [−][src]
pub struct WithDepNode<T> {
dep_node: DepNodeIndex,
cached_value: T,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
dep_node: DepNodeIndex
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
cached_value: T
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: Clone> WithDepNode<T>[src]
impl<T: Clone> WithDepNode<T>pub fn new(dep_node: DepNodeIndex, cached_value: T) -> Self[src]
pub fn new(dep_node: DepNodeIndex, cached_value: T) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn get(&self, tcx: TyCtxt) -> T[src]
pub fn get(&self, tcx: TyCtxt) -> T🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?