Struct rustc::traits::specialize::specialization_graph::Children [−][src]
struct Children {
nonblanket_impls: FxHashMap<SimplifiedType, Vec<DefId>>,
blanket_impls: Vec<DefId>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Children of a given impl, grouped into blanket/non-blanket varieties as is
done in TraitDef.
Fields
nonblanket_impls: FxHashMap<SimplifiedType, Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Impls of the trait.
blanket_impls: Vec<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Blanket impls associated with the trait.
Methods
impl<'a, 'gcx, 'tcx> Children[src]
impl<'a, 'gcx, 'tcx> Childrenfn new() -> Children[src]
fn new() -> Children🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn insert_blindly(&mut self, tcx: TyCtxt<'a, 'gcx, 'tcx>, impl_def_id: DefId)[src]
fn insert_blindly(&mut self, tcx: TyCtxt<'a, 'gcx, 'tcx>, impl_def_id: DefId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Insert an impl into this set of children without comparing to any existing impls
fn insert(
&mut self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
impl_def_id: DefId,
simplified_self: Option<SimplifiedType>
) -> Result<Inserted, OverlapError>[src]
fn insert(
&mut self,
tcx: TyCtxt<'a, 'gcx, 'tcx>,
impl_def_id: DefId,
simplified_self: Option<SimplifiedType>
) -> Result<Inserted, OverlapError>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Attempt to insert an impl into this set of children, while comparing for specialization relationships.
ⓘImportant traits for Box<R>fn iter_mut(&'a mut self) -> Box<Iterator<Item = &'a mut DefId> + 'a>[src]
fn iter_mut(&'a mut self) -> Box<Iterator<Item = &'a mut DefId> + 'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Box<R>fn filtered_mut(
&'a mut self,
sty: SimplifiedType
) -> Box<Iterator<Item = &'a mut DefId> + 'a>[src]
fn filtered_mut(
&'a mut self,
sty: SimplifiedType
) -> Box<Iterator<Item = &'a mut DefId> + 'a>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?