Struct rustc::ty::fold::LateBoundRegionsCollector [−][src]
struct LateBoundRegionsCollector {
current_depth: u32,
regions: FxHashSet<BoundRegion>,
just_constrained: bool,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Collects all the late-bound regions it finds into a hash set.
Fields
current_depth: u32
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
regions: FxHashSet<BoundRegion>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
just_constrained: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl LateBoundRegionsCollector[src]
impl LateBoundRegionsCollectorfn new(just_constrained: bool) -> Self[src]
fn new(just_constrained: bool) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?