[−][src]Struct rustc::ty::layout::call::Uniform
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An argument passed entirely registers with the same kind (e.g. HFA / HVA on PPC64 and AArch64).
Fields
unit: Reg
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
total: Size
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The total size of the argument, which can be:
- equal to
unit.size(one scalar/vector) - a multiple of
unit.size(an array of scalar/vectors) - if
unit.kindisInteger, the last element can be shorter, i.e.{ i64, i64, i32 }for 64-bit integers with a total size of 20 bytes
Methods
impl Uniform[src]
impl Uniformpub fn align<C>(&self, cx: C) -> Align where
C: HasDataLayout, [src]
pub fn align<C>(&self, cx: C) -> Align where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?