Struct rustc::ty::layout::LayoutCx [−][src]
pub struct LayoutCx<'tcx, C> {
pub tcx: C,
pub param_env: ParamEnv<'tcx>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
tcx: C
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
param_env: ParamEnv<'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a, 'tcx> LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>[src]
impl<'a, 'tcx> LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>fn layout_raw_uncached(
self,
ty: Ty<'tcx>
) -> Result<&'tcx LayoutDetails, LayoutError<'tcx>>[src]
fn layout_raw_uncached(
self,
ty: Ty<'tcx>
) -> Result<&'tcx LayoutDetails, LayoutError<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn record_layout_for_printing(self, layout: TyLayout<'tcx>)[src]
fn record_layout_for_printing(self, layout: TyLayout<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This is invoked by the layout_raw query to record the final
layout of each type.
fn record_layout_for_printing_outlined(self, layout: TyLayout<'tcx>)[src]
fn record_layout_for_printing_outlined(self, layout: TyLayout<'tcx>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<'a, 'tcx> LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>[src]
impl<'a, 'tcx> LayoutCx<'tcx, TyCtxt<'a, 'tcx, 'tcx>>fn find_niche(
self,
layout: TyLayout<'tcx>,
count: u128
) -> Result<Option<(Size, Scalar, u128)>, LayoutError<'tcx>>[src]
fn find_niche(
self,
layout: TyLayout<'tcx>,
count: u128
) -> Result<Option<(Size, Scalar, u128)>, LayoutError<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Find the offset of a niche leaf field, starting from
the given type and recursing through aggregates, which
has at least count consecutive invalid values.
The tuple is (offset, scalar, niche_value).