Struct rustc::ty::layout::Scalar [−][src]
pub struct Scalar {
pub value: Primitive,
pub valid_range: RangeInclusive<u128>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Information about one scalar component of a Rust type.
Fields
value: Primitive
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
valid_range: RangeInclusive<u128>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Inclusive wrap-around range of valid values, that is, if min > max, it represents min..=u128::MAX followed by 0..=max.
Methods
impl Scalar[src]
impl Scalarpub fn is_bool(&self) -> bool[src]
pub fn is_bool(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Range<A>pub fn valid_range_exclusive<C>(&self, cx: C) -> Range<u128> where
C: HasDataLayout, [src]
pub fn valid_range_exclusive<C>(&self, cx: C) -> Range<u128> where
C: HasDataLayout, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the valid range as a x..y range.
If x and y are equal, the range is full, not empty.