Struct rustc::ty::trait_def::TraitImpls [−][src]
pub struct TraitImpls {
blanket_impls: Vec<DefId>,
non_blanket_impls: FxHashMap<SimplifiedType, Vec<DefId>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
blanket_impls: Vec<DefId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
non_blanket_impls: FxHashMap<SimplifiedType, Vec<DefId>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Impls indexed by their simplified self-type, for fast lookup.