Enum rustc_apfloat::ieee::Loss [−][src]
#[must_use]enum Loss { ExactlyZero, LessThanHalf, ExactlyHalf, MoreThanHalf, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Enum that represents what fraction of the LSB truncated bits of an fp number represent.
This essentially combines the roles of guard and sticky bits.
Variants
ExactlyZero🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
LessThanHalf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ExactlyHalf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
MoreThanHalf🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Loss[src]
impl Lossfn combine(self, less_significant: Loss) -> Loss[src]
fn combine(self, less_significant: Loss) -> Loss🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Combine the effect of two lost fractions.
fn through_truncation(limbs: &[u128], bits: usize) -> Loss[src]
fn through_truncation(limbs: &[u128], bits: usize) -> Loss🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the fraction lost were a bignum truncated losing the least
significant bits bits.