Struct rustc_data_structures::bitvec::BitVector [−][src]
pub struct BitVector<C: Idx> { data: Vec<u128>, marker: PhantomData<C>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A very simple BitVector type.
Fields
data: Vec<u128>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
marker: PhantomData<C>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<C: Idx> BitVector<C>[src]
impl<C: Idx> BitVector<C>pub fn new(num_bits: usize) -> BitVector<C>[src]
pub fn new(num_bits: usize) -> BitVector<C>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn count(&self) -> usize[src]
pub fn count(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains(&self, bit: C) -> bool[src]
pub fn contains(&self, bit: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if self contains the bit bit.
pub fn contains_all(&self, other: &BitVector<C>) -> bool[src]
pub fn contains_all(&self, other: &BitVector<C>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if self contains all the bits in other.
The two vectors must have the same length.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn insert(&mut self, bit: C) -> bool[src]
pub fn insert(&mut self, bit: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the bit has changed.
pub fn insert_all(&mut self)[src]
pub fn insert_all(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets all bits to true.
pub fn remove(&mut self, bit: C) -> bool[src]
pub fn remove(&mut self, bit: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the bit has changed.
pub fn merge(&mut self, all: &BitVector<C>) -> bool[src]
pub fn merge(&mut self, all: &BitVector<C>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn grow(&mut self, num_bits: C)[src]
pub fn grow(&mut self, num_bits: C)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for BitVectorIter<'a, C>pub fn iter<'a>(&'a self) -> BitVectorIter<'a, C>[src]
pub fn iter<'a>(&'a self) -> BitVectorIter<'a, C>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates over indexes of set bits in a sorted order