Struct rustc_data_structures::bitvec::SparseBitMatrix [−][src]
pub struct SparseBitMatrix<R, C> where
R: Idx,
C: Idx, { vector: IndexVec<R, SparseBitSet<C>>, }
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
vector: IndexVec<R, SparseBitSet<C>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<R: Idx, C: Idx> SparseBitMatrix<R, C>[src]
impl<R: Idx, C: Idx> SparseBitMatrix<R, C>pub fn new(rows: R, _columns: C) -> SparseBitMatrix<R, C>[src]
pub fn new(rows: R, _columns: C) -> SparseBitMatrix<R, C>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a new rows x columns matrix, initially empty.
pub fn add(&mut self, row: R, column: C) -> bool[src]
pub fn add(&mut self, row: R, column: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets the cell at (row, column) to true. Put another way, insert
column to the bitset for row.
Returns true if this changed the matrix, and false otherwise.
pub fn contains(&self, row: R, column: C) -> bool[src]
pub fn contains(&self, row: R, column: C) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Do the bits from row contain column? Put another way, is
the matrix cell at (row, column) true? Put yet another way,
if the matrix represents (transitive) reachability, can
row reach column?
pub fn merge(&mut self, read: R, write: R) -> bool[src]
pub fn merge(&mut self, read: R, write: R) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Add the bits from row read to the bits from row write,
return true if anything changed.
This is used when computing transitive reachability because if
you have an edge write -> read, because in that case
write can reach everything that read can (and
potentially more).
pub fn iter<'a>(
&'a self,
row: R
) -> impl Iterator<Item = C> + 'a[src]
pub fn iter<'a>(
&'a self,
row: R
) -> impl Iterator<Item = C> + 'a🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Iterates through all the columns set to true in a given row of the matrix.