Struct rustc_data_structures::indexed_set::IdxSet [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Represents a set (or packed family of sets), of some element type
E, where each E is identified by some unique index type T.
In other words, T is the type used to index into the bitslice
this type uses to represent the set of object it holds.
Fields
_pd: PhantomData<fn(_: &T)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
bits: [Word]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<T: Idx> IdxSet<T>[src]
impl<T: Idx> IdxSet<T>ⓘImportant traits for &'a mut Runsafe fn from_slice(s: &[Word]) -> &Self[src]
unsafe fn from_slice(s: &[Word]) -> &Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Runsafe fn from_slice_mut(s: &mut [Word]) -> &mut Self[src]
unsafe fn from_slice_mut(s: &mut [Word]) -> &mut Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
impl<T: Idx> IdxSet<T>[src]
impl<T: Idx> IdxSet<T>pub fn to_owned(&self) -> IdxSetBuf<T>[src]
pub fn to_owned(&self) -> IdxSetBuf<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clear(&mut self)[src]
pub fn clear(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes all elements
pub fn set_up_to(&mut self, universe_size: usize)[src]
pub fn set_up_to(&mut self, universe_size: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sets all elements up to universe_size
fn trim_to(&mut self, universe_size: usize)[src]
fn trim_to(&mut self, universe_size: usize)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Clear all elements above universe_size.
pub fn remove(&mut self, elem: &T) -> bool[src]
pub fn remove(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Removes elem from the set self; returns true iff this changed self.
pub fn add(&mut self, elem: &T) -> bool[src]
pub fn add(&mut self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Adds elem to the set self; returns true iff this changed self.
ⓘImportant traits for &'a mut Rpub fn range(&self, elems: &Range<T>) -> &Self[src]
pub fn range(&self, elems: &Range<T>) -> &Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for &'a mut Rpub fn range_mut(&mut self, elems: &Range<T>) -> &mut Self[src]
pub fn range_mut(&mut self, elems: &Range<T>) -> &mut Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn contains(&self, elem: &T) -> bool[src]
pub fn contains(&self, elem: &T) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true iff set self contains elem.
pub fn words(&self) -> &[Word][src]
pub fn words(&self) -> &[Word]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn words_mut(&mut self) -> &mut [Word][src]
pub fn words_mut(&mut self) -> &mut [Word]🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn clone_from(&mut self, other: &IdxSet<T>)[src]
pub fn clone_from(&mut self, other: &IdxSet<T>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn union(&mut self, other: &IdxSet<T>) -> bool[src]
pub fn union(&mut self, other: &IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn subtract(&mut self, other: &IdxSet<T>) -> bool[src]
pub fn subtract(&mut self, other: &IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn intersect(&mut self, other: &IdxSet<T>) -> bool[src]
pub fn intersect(&mut self, other: &IdxSet<T>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ⓘImportant traits for Iter<'a, T>pub fn iter(&self) -> Iter<T>[src]
pub fn iter(&self) -> Iter<T>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?