Enum rustc_driver::pretty::PpSourceMode [−][src]
pub enum PpSourceMode {
PpmNormal,
PpmEveryBodyLoops,
PpmExpanded,
PpmIdentified,
PpmExpandedIdentified,
PpmExpandedHygiene,
PpmTyped,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
PpmNormal🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmEveryBodyLoops🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmExpanded🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmIdentified🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmExpandedIdentified🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmExpandedHygiene🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
PpmTyped🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl PpSourceMode[src]
impl PpSourceModefn call_with_pp_support<'tcx, A, F>(
&self,
sess: &'tcx Session,
hir_map: Option<&Map<'tcx>>,
f: F
) -> A where
F: FnOnce(&PrinterSupport) -> A, [src]
fn call_with_pp_support<'tcx, A, F>(
&self,
sess: &'tcx Session,
hir_map: Option<&Map<'tcx>>,
f: F
) -> A where
F: FnOnce(&PrinterSupport) -> A, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Constructs a PrinterSupport object and passes it to f.
fn call_with_pp_support_hir<'tcx, A, F>(
&self,
sess: &'tcx Session,
cstore: &'tcx CrateStoreDyn,
hir_map: &Map<'tcx>,
analysis: &CrateAnalysis,
resolutions: &Resolutions,
arenas: &'tcx AllArenas<'tcx>,
output_filenames: &OutputFilenames,
id: &str,
f: F
) -> A where
F: FnOnce(&HirPrinterSupport, &Crate) -> A, [src]
fn call_with_pp_support_hir<'tcx, A, F>(
&self,
sess: &'tcx Session,
cstore: &'tcx CrateStoreDyn,
hir_map: &Map<'tcx>,
analysis: &CrateAnalysis,
resolutions: &Resolutions,
arenas: &'tcx AllArenas<'tcx>,
output_filenames: &OutputFilenames,
id: &str,
f: F
) -> A where
F: FnOnce(&HirPrinterSupport, &Crate) -> A, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?