Struct rustc_driver::RustcDefaultCalls [−][src]
pub struct RustcDefaultCalls;
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl RustcDefaultCalls[src]
impl RustcDefaultCallspub fn list_metadata(
sess: &Session,
cstore: &CrateStore,
matches: &Matches,
input: &Input
) -> Compilation[src]
pub fn list_metadata(
sess: &Session,
cstore: &CrateStore,
matches: &Matches,
input: &Input
) -> Compilation🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn print_crate_info(
trans: &TransCrate,
sess: &Session,
input: Option<&Input>,
odir: &Option<PathBuf>,
ofile: &Option<PathBuf>
) -> Compilation[src]
fn print_crate_info(
trans: &TransCrate,
sess: &Session,
input: Option<&Input>,
odir: &Option<PathBuf>,
ofile: &Option<PathBuf>
) -> Compilation🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?