Struct rustc_lint::builtin::MissingDoc [−][src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Stack of whether #[doc(hidden)] is set at each level which has lint attributes.
private_traits: HashSet<NodeId>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Private traits or trait items that leaked through. Don't check their methods.
Methods
impl MissingDoc[src]
impl MissingDocpub fn new() -> MissingDoc[src]
pub fn new() -> MissingDoc🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn check_missing_docs_attrs(
&self,
cx: &LateContext,
id: Option<NodeId>,
attrs: &[Attribute],
sp: Span,
desc: &'static str
)[src]
fn check_missing_docs_attrs(
&self,
cx: &LateContext,
id: Option<NodeId>,
attrs: &[Attribute],
sp: Span,
desc: &'static str
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?