[−][src]Struct rustc_mir::borrow_check::nll::constraints::graph::ConstraintGraph
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The construct graph organizes the constraints by their end-points.
It can be used to view a R1: R2 constraint as either an edge R1 -> R2 or R2 -> R1 depending on the direction type D.
Fields
_direction: D
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
first_constraints: IndexVec<RegionVid, Option<ConstraintIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
next_constraints: IndexVec<ConstraintIndex, Option<ConstraintIndex>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<D: ConstraintGraphDirecton> ConstraintGraph<D>[src]
impl<D: ConstraintGraphDirecton> ConstraintGraph<D>pub(crate) fn new(
direction: D,
set: &ConstraintSet,
num_region_vars: usize
) -> Self[src]
pub(crate) fn new(
direction: D,
set: &ConstraintSet,
num_region_vars: usize
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Create a "dependency graph" where each region constraint R1: R2 is treated as an edge R1 -> R2. We use this graph to
construct SCCs for region inference but also for error
reporting.
pub(crate) fn region_graph<'rg>(
&'rg self,
set: &'rg ConstraintSet,
static_region: RegionVid
) -> RegionGraph<'rg, D>[src]
pub(crate) fn region_graph<'rg>(
&'rg self,
set: &'rg ConstraintSet,
static_region: RegionVid
) -> RegionGraph<'rg, D>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given the constraint set from which this graph was built creates a region graph so that you can iterate over regions and not constraints.
ⓘImportant traits for Edges<'s, D>pub(crate) fn outgoing_edges<'a>(
&'a self,
region_sup: RegionVid,
constraints: &'a ConstraintSet,
static_region: RegionVid
) -> Edges<'a, D>[src]
pub(crate) fn outgoing_edges<'a>(
&'a self,
region_sup: RegionVid,
constraints: &'a ConstraintSet,
static_region: RegionVid
) -> Edges<'a, D>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Given a region R, iterate over all constraints R: R1.