Struct rustc_mir::borrow_check::nll::region_infer::RegionDefinition [−][src]
struct RegionDefinition<'tcx> {
origin: RegionVariableOrigin,
is_universal: bool,
external_name: Option<Region<'tcx>>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
origin: RegionVariableOrigin
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Why we created this variable. Mostly these will be
RegionVariableOrigin::NLL, but some variables get created
elsewhere in the code with other causes (e.g., instantiation
late-bound-regions).
is_universal: bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if this is a universally quantified region. This means a lifetime parameter that appears in the function signature (or, in the case of a closure, in the closure environment, which of course is also in the function signature).
external_name: Option<Region<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this is 'static or an early-bound region, then this is
Some(X) where X is the name of the region.
Methods
impl<'tcx> RegionDefinition<'tcx>[src]
impl<'tcx> RegionDefinition<'tcx>fn new(origin: RegionVariableOrigin) -> Self[src]
fn new(origin: RegionVariableOrigin) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?