Struct rustc_mir::borrow_check::nll::region_infer::values::RegionValueElements [−][src]
pub(crate) struct RegionValueElements {
statements_before_block: IndexVec<BasicBlock, usize>,
num_points: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps between a Location and a PointIndex (and vice versa).
Fields
statements_before_block: IndexVec<BasicBlock, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each basic block, how many points are contained within?
num_points: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl RegionValueElements[src]
impl RegionValueElementspub(crate) fn new(mir: &Mir) -> Self[src]
pub(crate) fn new(mir: &Mir) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn point_from_location(&self, location: Location) -> PointIndex[src]
fn point_from_location(&self, location: Location) -> PointIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a Location into a PointIndex. O(1).
pub(crate) fn to_location(&self, i: PointIndex) -> Location[src]
pub(crate) fn to_location(&self, i: PointIndex) -> Location🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a PointIndex back to a location. O(N) where N is
the number of blocks; could be faster if we ever cared.