[−][src]Struct rustc_mir::borrow_check::nll::region_infer::values::RegionValueElements
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps between a Location and a PointIndex (and vice versa).
Fields
statements_before_block: IndexVec<BasicBlock, usize>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
For each basic block, how many points are contained within?
basic_blocks: IndexVec<PointIndex, BasicBlock>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Map backward from each point to the basic block that it belongs to.
num_points: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl RegionValueElements[src]
impl RegionValueElementspub(crate) fn new(mir: &Mir) -> Self[src]
pub(crate) fn new(mir: &Mir) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub(crate) fn num_points(&self) -> usize[src]
pub(crate) fn num_points(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Total number of point indices
pub(crate) fn point_from_location(&self, location: Location) -> PointIndex[src]
pub(crate) fn point_from_location(&self, location: Location) -> PointIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a Location into a PointIndex. O(1).
pub(crate) fn entry_point(&self, block: BasicBlock) -> PointIndex[src]
pub(crate) fn entry_point(&self, block: BasicBlock) -> PointIndex🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a Location into a PointIndex. O(1).
pub(crate) fn to_location(&self, index: PointIndex) -> Location[src]
pub(crate) fn to_location(&self, index: PointIndex) -> Location🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Converts a PointIndex back to a location. O(1).
pub(crate) fn point_in_range(&self, index: PointIndex) -> bool[src]
pub(crate) fn point_in_range(&self, index: PointIndex) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Sometimes we get point-indices back from bitsets that may be out of range (because they round up to the nearest 2^N number of bits). Use this function to filter such points out if you like.
pub(crate) fn push_predecessors(
&self,
mir: &Mir,
index: PointIndex,
stack: &mut Vec<PointIndex>
)[src]
pub(crate) fn push_predecessors(
&self,
mir: &Mir,
index: PointIndex,
stack: &mut Vec<PointIndex>
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Pushes all predecessors of index onto stack.