[−][src]Struct rustc_mir::borrow_check::nll::type_check::relate_tys::TypeRelating
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
infcx: &'cx InferCtxt<'cx, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ambient_variance: Variance
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
How are we relating a and b?
- covariant means
a <: b - contravariant means
b <: a - invariant means `a == b
- bivariant means that it doesn't matter
a_scopes: Vec<BoundRegionScope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When we pass through a set of binders (e.g., when looking into
a fn type), we push a new bound region scope onto here. This
will contain the instantiated region for each region in those
binders. When we then encounter a ReLateBound(d, br), we can
use the debruijn index d to find the right scope, and then
bound region name br to find the specific instantiation from
within that scope. See replace_bound_region.
This field stores the instantiations for late-bound regions in
the a type.
b_scopes: Vec<BoundRegionScope>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Same as a_scopes, but for the b type.
locations: Locations
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Where (and why) is this relation taking place?
borrowck_context: Option<&'cx mut BorrowCheckContext<'bccx, 'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
This will be Some when we are running the type check as part
of NLL, and None if we are running a "sanity check".
canonical_var_values: IndexVec<CanonicalVar, Option<Kind<'tcx>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
As we execute, the type on the LHS may come from a canonical
source. In that case, we will sometimes find a constraint like
?0 = B, where B is a type from the RHS. The first time we
find that, we simply record B (and the list of scopes that
tells us how to interpret B). The next time we encounter
?0, then, we can read this value out and use it.
One problem: these variables may be in some other universe, how can we enforce that? I guess I could add some kind of "minimum universe constraint" that we can feed to the NLL checker. --> also, we know this doesn't happen
Methods
impl<'cx, 'bccx, 'gcx, 'tcx> TypeRelating<'cx, 'bccx, 'gcx, 'tcx>[src]
impl<'cx, 'bccx, 'gcx, 'tcx> TypeRelating<'cx, 'bccx, 'gcx, 'tcx>fn new(
infcx: &'cx InferCtxt<'cx, 'gcx, 'tcx>,
ambient_variance: Variance,
locations: Locations,
borrowck_context: Option<&'cx mut BorrowCheckContext<'bccx, 'tcx>>,
canonical_var_infos: CanonicalVarInfos<'tcx>
) -> Self[src]
fn new(
infcx: &'cx InferCtxt<'cx, 'gcx, 'tcx>,
ambient_variance: Variance,
locations: Locations,
borrowck_context: Option<&'cx mut BorrowCheckContext<'bccx, 'tcx>>,
canonical_var_infos: CanonicalVarInfos<'tcx>
) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn ambient_covariance(&self) -> bool[src]
fn ambient_covariance(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn ambient_contravariance(&self) -> bool[src]
fn ambient_contravariance(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn create_scope(
&mut self,
value: &Binder<impl TypeFoldable<'tcx>>,
universally_quantified: UniversallyQuantified
) -> BoundRegionScope[src]
fn create_scope(
&mut self,
value: &Binder<impl TypeFoldable<'tcx>>,
universally_quantified: UniversallyQuantified
) -> BoundRegionScope🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn lookup_bound_region(
debruijn: DebruijnIndex,
br: &BoundRegion,
first_free_index: DebruijnIndex,
scopes: &[BoundRegionScope]
) -> RegionVid[src]
fn lookup_bound_region(
debruijn: DebruijnIndex,
br: &BoundRegion,
first_free_index: DebruijnIndex,
scopes: &[BoundRegionScope]
) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When we encounter binders during the type traversal, we record
the value to substitute for each of the things contained in
that binder. (This will be either a universal placeholder or
an existential inference variable.) Given the debruijn index
debruijn (and name br) of some binder we have now
encountered, this routine finds the value that we instantiated
the region with; to do so, it indexes backwards into the list
of ambient scopes scopes.
fn replace_bound_region(
&self,
universal_regions: &UniversalRegions<'tcx>,
r: Region<'tcx>,
first_free_index: DebruijnIndex,
scopes: &[BoundRegionScope]
) -> RegionVid[src]
fn replace_bound_region(
&self,
universal_regions: &UniversalRegions<'tcx>,
r: Region<'tcx>,
first_free_index: DebruijnIndex,
scopes: &[BoundRegionScope]
) -> RegionVid🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If r is a bound region, find the scope in which it is bound
(from scopes) and return the value that we instantiated it
with. Otherwise just return r.
fn push_outlives(&mut self, sup: RegionVid, sub: RegionVid)[src]
fn push_outlives(&mut self, sup: RegionVid, sub: RegionVid)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Push a new outlives requirement into our output set of constraints.
fn relate_var(
&mut self,
var: CanonicalVar,
b_kind: Kind<'tcx>
) -> RelateResult<'tcx, Kind<'tcx>>[src]
fn relate_var(
&mut self,
var: CanonicalVar,
b_kind: Kind<'tcx>
) -> RelateResult<'tcx, Kind<'tcx>>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
When we encounter a canonical variable var in the output,
equate it with kind. If the variable has been previously
equated, then equate it again.
fn generalize_value(&self, kind: Kind<'tcx>) -> Kind<'tcx>[src]
fn generalize_value(&self, kind: Kind<'tcx>) -> Kind<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?