Trait rustc_mir::borrow_check::place_ext::PlaceExt [−][src]
pub(crate) trait PlaceExt<'tcx> {
fn is_unsafe_place(
&self,
tcx: TyCtxt<'_, '_, 'tcx>,
mir: &Mir<'tcx>
) -> bool;
fn root_local(&self) -> Option<Local>;
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Extension methods for the Place type.
Required Methods
fn is_unsafe_place(&self, tcx: TyCtxt<'_, '_, 'tcx>, mir: &Mir<'tcx>) -> bool
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
True if this is a deref of a raw pointer.
fn root_local(&self) -> Option<Local>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If this is a place like x.f.g, returns the local
x. Returns None if this is based in a static.
Implementations on Foreign Types
impl<'tcx> PlaceExt<'tcx> for Place<'tcx>[src]
impl<'tcx> PlaceExt<'tcx> for Place<'tcx>fn is_unsafe_place(&self, tcx: TyCtxt<'_, '_, 'tcx>, mir: &Mir<'tcx>) -> bool[src]
fn is_unsafe_place(&self, tcx: TyCtxt<'_, '_, 'tcx>, mir: &Mir<'tcx>) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn root_local(&self) -> Option<Local>[src]
fn root_local(&self) -> Option<Local>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?