Enum rustc_mir::dataflow::move_paths::IllegalMoveOriginKind [−][src]
enum IllegalMoveOriginKind<'tcx> {
Static,
BorrowedContent,
InteriorOfTypeWithDestructor {
container_ty: Ty<'tcx>,
},
InteriorOfSliceOrArray {
ty: Ty<'tcx>,
is_index: bool,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Static🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
BorrowedContent🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
InteriorOfTypeWithDestructor🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of InteriorOfTypeWithDestructor
container_ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
InteriorOfSliceOrArray🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields of InteriorOfSliceOrArray
ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
is_index: bool | 🔬 This is a nightly-only experimental API. ( |