Enum rustc_mir::dataflow::move_paths::IllegalMoveOriginKind [−][src]
pub(crate) enum IllegalMoveOriginKind<'tcx> {
Static,
BorrowedContent {
target_ty: Ty<'tcx>,
},
InteriorOfTypeWithDestructor {
container_ty: Ty<'tcx>,
},
InteriorOfSliceOrArray {
ty: Ty<'tcx>,
is_index: bool,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Static🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from static variable.
BorrowedContent🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from behind a reference.
Fields of BorrowedContent
target_ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
InteriorOfTypeWithDestructor🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move from field of an ADT that
implements Drop. Rust maintains invariant that all Drop
ADT's remain fully-initialized so that user-defined destructor
can safely read from all of the ADT's fields.
Fields of InteriorOfTypeWithDestructor
container_ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
InteriorOfSliceOrArray🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Illegal move due to attempt to move out of a slice or array.
Fields of InteriorOfSliceOrArray
ty: Ty<'tcx> | 🔬 This is a nightly-only experimental API. ( |
is_index: bool | 🔬 This is a nightly-only experimental API. ( |