Struct rustc_mir::monomorphize::collector::InliningMap [−][src]
pub struct InliningMap<'tcx> {
index: FxHashMap<MonoItem<'tcx>, (usize, usize)>,
targets: Vec<MonoItem<'tcx>>,
inlines: BitVector,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Maps every mono item to all mono items it references in its body.
Fields
index: FxHashMap<MonoItem<'tcx>, (usize, usize)>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
targets: Vec<MonoItem<'tcx>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
inlines: BitVector
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'tcx> InliningMap<'tcx>[src]
impl<'tcx> InliningMap<'tcx>fn new() -> InliningMap<'tcx>[src]
fn new() -> InliningMap<'tcx>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn record_accesses<I>(&mut self, source: MonoItem<'tcx>, new_targets: I) where
I: Iterator<Item = (MonoItem<'tcx>, bool)> + ExactSizeIterator, [src]
fn record_accesses<I>(&mut self, source: MonoItem<'tcx>, new_targets: I) where
I: Iterator<Item = (MonoItem<'tcx>, bool)> + ExactSizeIterator, 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_inlining_candidates<F>(&self, source: MonoItem<'tcx>, f: F) where
F: FnMut(MonoItem<'tcx>), [src]
pub fn with_inlining_candidates<F>(&self, source: MonoItem<'tcx>, f: F) where
F: FnMut(MonoItem<'tcx>), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn iter_accesses<F>(&self, f: F) where
F: FnMut(MonoItem<'tcx>, &[MonoItem<'tcx>]), [src]
pub fn iter_accesses<F>(&self, f: F) where
F: FnMut(MonoItem<'tcx>, &[MonoItem<'tcx>]), 🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?