Struct rustc_mir::util::liveness::LivenessResults
[−]
[src]
pub struct LivenessResults {
pub regular: LivenessResult,
pub drop: LivenessResult,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A combination of liveness results, used in NLL.
Fields
regular: LivenessResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Liveness results where a regular use makes a variable X live, but not a drop.
drop: LivenessResult
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Liveness results where a drop makes a variable X live, but not a regular use.
Methods
impl LivenessResults[src]
impl LivenessResultspub fn compute<'tcx>(mir: &Mir<'tcx>) -> LivenessResults[src]
pub fn compute<'tcx>(mir: &Mir<'tcx>) -> LivenessResults🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?