Enum rustc_resolve::ResolutionError [−][src]
enum ResolutionError<'a> {
TypeParametersFromOuterFunction(Def),
NameAlreadyUsedInTypeParameterList(Name, &'a Span),
MethodNotMemberOfTrait(Name, &'a str),
TypeNotMemberOfTrait(Name, &'a str),
ConstNotMemberOfTrait(Name, &'a str),
VariableNotBoundInPattern(&'a BindingError),
VariableBoundWithDifferentMode(Name, Span),
IdentifierBoundMoreThanOnceInParameterList(&'a str),
IdentifierBoundMoreThanOnceInSamePattern(&'a str),
UndeclaredLabel(&'a str, Option<Name>),
SelfImportsOnlyAllowedWithin,
SelfImportCanOnlyAppearOnceInTheList,
SelfImportOnlyInImportListWithNonEmptyPrefix,
UnresolvedImport(Option<(Span, &'a str, &'a str)>),
FailedToResolve(&'a str),
CannotCaptureDynamicEnvironmentInFnItem,
AttemptToUseNonConstantValueInConstant,
BindingShadowsSomethingUnacceptable(&'a str, Name, &'a NameBinding<'a>),
ForwardDeclaredTyParam,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
TypeParametersFromOuterFunction(Def)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0401: can't use type parameters from outer function
NameAlreadyUsedInTypeParameterList(Name, &'a Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0403: the name is already used for a type parameter in this type parameter list
MethodNotMemberOfTrait(Name, &'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0407: method is not a member of trait
TypeNotMemberOfTrait(Name, &'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0437: type is not a member of trait
ConstNotMemberOfTrait(Name, &'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0438: const is not a member of trait
VariableNotBoundInPattern(&'a BindingError)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0408: variable {} is not bound in all patterns
VariableBoundWithDifferentMode(Name, Span)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0409: variable {} is bound in inconsistent ways within the same match arm
IdentifierBoundMoreThanOnceInParameterList(&'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0415: identifier is bound more than once in this parameter list
IdentifierBoundMoreThanOnceInSamePattern(&'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0416: identifier is bound more than once in the same pattern
UndeclaredLabel(&'a str, Option<Name>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0426: use of undeclared label
SelfImportsOnlyAllowedWithin🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0429: self imports are only allowed within a { } list
SelfImportCanOnlyAppearOnceInTheList🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0430: self import can only appear once in the list
SelfImportOnlyInImportListWithNonEmptyPrefix🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0431: self import can only appear in an import list with a non-empty prefix
UnresolvedImport(Option<(Span, &'a str, &'a str)>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0432: unresolved import
FailedToResolve(&'a str)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0433: failed to resolve
CannotCaptureDynamicEnvironmentInFnItem🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0434: can't capture dynamic environment in a fn item
AttemptToUseNonConstantValueInConstant🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0435: attempt to use a non-constant value in a constant
BindingShadowsSomethingUnacceptable(&'a str, Name, &'a NameBinding<'a>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0530: X bindings cannot shadow Ys
ForwardDeclaredTyParam🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
error E0128: type parameters with a default cannot use forward declared identifiers