Enum rustc_typeck::check::op::BinOpCategory [−][src]
enum BinOpCategory {
Shortcircuit,
Shift,
Math,
Bitwise,
Comparison,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Shortcircuit🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
&&, || -- cannot be overridden
Shift🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
<<, >> -- when shifting a single integer, rhs can be any integer type. For simd, types must match.
Math🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
+, -, etc -- takes equal types, produces same type as input, applicable to ints/floats/simd
Bitwise🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
&, |, ^ -- takes equal types, produces same type as input, applicable to ints/floats/simd/bool
Comparison🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
==, !=, etc -- takes equal types, produces bools, except for simd, which produce the input type
Methods
impl BinOpCategory[src]
impl BinOpCategoryfn from(op: BinOp) -> BinOpCategory[src]
fn from(op: BinOp) -> BinOpCategory🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?