Struct rustdoc::clean::VariantStruct [−][src]
pub struct VariantStruct {
pub struct_type: StructType,
pub fields: Vec<Item>,
pub fields_stripped: bool,
}This is a more limited form of the standard Struct, different in that it lacks the things most items have (name, id, parameterization). Found only as a variant in an enum.
Fields
struct_type: StructType
fields: Vec<Item>
fields_stripped: bool