Struct rustdoc::html::toc::TocBuilderExperimental
[-]
[+]
[src]
pub struct TocBuilder {
// some fields omitted
}Progressive construction of a table of contents.
Methods
impl TocBuilder
fn new() -> TocBuilder
fn into_toc(self) -> Toc
Convert into a true Toc struct.
fn push<'a>(&'a mut self, level: u32, name: String, id: String) -> &'a str
Push a level level heading into the appropriate place in the
hierarchy, returning a string containing the section number in
<num>.<num>.<num> format.