Struct serialize::json::Stack [−][src]
pub struct Stack {
stack: Vec<InternalStackElement>,
str_buffer: Vec<u8>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A Stack represents the current position of the parser in the logical structure of the JSON stream. For example foo.bar[3].x
Fields
stack: Vec<InternalStackElement>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
str_buffer: Vec<u8>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Stack[src]
impl Stackpub fn new() -> Stack[src]
pub fn new() -> Stack🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usize🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns The number of elements in the Stack.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the stack is empty.
pub fn get(&self, idx: usize) -> StackElement[src]
pub fn get(&self, idx: usize) -> StackElement🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Provides access to the StackElement at a given index. lower indices are at the bottom of the stack while higher indices are at the top.
pub fn is_equal_to(&self, rhs: &[StackElement]) -> bool[src]
pub fn is_equal_to(&self, rhs: &[StackElement]) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Compares this stack with an array of StackElements.
pub fn starts_with(&self, rhs: &[StackElement]) -> bool[src]
pub fn starts_with(&self, rhs: &[StackElement]) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the bottom-most elements of this stack are the same as the ones passed as parameter.
pub fn ends_with(&self, rhs: &[StackElement]) -> bool[src]
pub fn ends_with(&self, rhs: &[StackElement]) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns true if the top-most elements of this stack are the same as the ones passed as parameter.
pub fn top(&self) -> Option<StackElement>[src]
pub fn top(&self) -> Option<StackElement>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Returns the top-most element (if any).
fn push_key(&mut self, key: String)[src]
fn push_key(&mut self, key: String)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn push_index(&mut self, index: u32)[src]
fn push_index(&mut self, index: u32)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn pop(&mut self)[src]
fn pop(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn last_is_index(&self) -> bool[src]
fn last_is_index(&self) -> bool🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
fn bump_index(&mut self)[src]
fn bump_index(&mut self)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?