Trait std::clone::Clone 1.0.0
[−]
[src]
pub trait Clone {
fn clone(&self) -> Self;
fn clone_from(&mut self, source: &Self) { ... }
}A common trait for the ability to explicitly duplicate an object.
Differs from Copy in that Copy is implicit and extremely inexpensive, while
Clone is always explicit and may or may not be expensive. In order to enforce
these characteristics, Rust does not allow you to reimplement Copy, but you
may reimplement Clone and run arbitrary code.
Since Clone is more general than Copy, you can automatically make anything
Copy be Clone as well.
Derivable
This trait can be used with #[derive] if all fields are Clone. The derived
implementation of clone calls clone on each field.
How can I implement Clone?
Types that are Copy should have a trivial implementation of Clone. More formally:
if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;.
Manual implementations should be careful to uphold this invariant; however, unsafe code
must not rely on it to ensure memory safety.
An example is an array holding more than 32 elements of a type that is Clone; the standard
library only implements Clone up until arrays of size 32. In this case, the implementation of
Clone cannot be derived, but can be implemented as:
#[derive(Copy)] struct Stats { frequencies: [i32; 100], } impl Clone for Stats { fn clone(&self) -> Stats { *self } }Run
Required Methods
fn clone(&self) -> Self
Provided Methods
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source.
a.clone_from(&b) is equivalent to a = b.clone() in functionality,
but can be overridden to reuse the resources of a to avoid unnecessary
allocations.
Implementors
impl<'a> Clone for SplitWhitespace<'a>impl Clone for DecodeUtf16Errorimpl<I> Clone for DecodeUtf16<I> where
I: Clone + Iterator<Item = u16>,impl<I> Clone for Utf16Encoder<I> where
I: Clone,impl<T> Clone for BTreeSet<T> where
T: Clone,impl<'a, T> Clone for std::collections::vec_deque::Iter<'a, T>impl<T> Clone for std::collections::linked_list::IntoIter<T> where
T: Clone,impl<T> Clone for BinaryHeap<T> where
T: Clone,impl Clone for ParseErrorimpl<T> Clone for Vec<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Intersection<'a, T>impl<K, V> Clone for BTreeMap<K, V> where
K: Clone,
V: Clone,impl<'a, T> Clone for std::collections::btree_set::Iter<'a, T>impl<T> Clone for Rc<T> where
T: ?Sized,impl<T> Clone for std::rc::Weak<T> where
T: ?Sized,impl<T> Clone for LinkedList<T> where
T: Clone,impl<T> Clone for VecDeque<T> where
T: Clone,impl<T> Clone for std::collections::vec_deque::IntoIter<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Union<'a, T>impl Clone for CannotReallocInPlaceimpl<T> Clone for std::vec::IntoIter<T> where
T: Clone,impl<T> Clone for std::collections::binary_heap::IntoIter<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Difference<'a, T>impl<'a, T> Clone for std::collections::binary_heap::Iter<'a, T>impl Clone for ExchangeHeapSingletonimpl<T> Clone for Box<[T]> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Keys<'a, K, V>impl Clone for Stringimpl Clone for Box<str>impl<'a, T> Clone for std::collections::linked_list::Iter<'a, T>impl Clone for Heapimpl<T> Clone for Box<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Values<'a, K, V>impl<T> Clone for std::sync::Weak<T> where
T: ?Sized,impl<T> Clone for Bound<T> where
T: Clone,impl<T> Clone for Arc<T> where
T: ?Sized,impl<'a, T> Clone for std::collections::btree_set::SymmetricDifference<'a, T>impl<'a, T> Clone for std::collections::btree_set::Range<'a, T>impl Clone for AllocErrimpl<'a, K, V> Clone for std::collections::btree_map::Iter<'a, K, V>impl<'a> Clone for EncodeUtf16<'a>impl Clone for Layoutimpl<'a, K, V> Clone for std::collections::btree_map::Range<'a, K, V>impl<'a, B> Clone for Cow<'a, B> where
B: ToOwned + ?Sized,impl Clone for _Unwind_Actionimpl Clone for _Unwind_Reason_Codeimpl Clone for Normalimpl Clone for Isaac64Rngimpl Clone for ReseedWithDefaultimpl Clone for LogNormalimpl Clone for IsaacRngimpl Clone for Expimpl Clone for StandardNormalimpl Clone for ChaChaRngimpl Clone for Exp1impl Clone for XorShiftRngimpl Clone for utimbufimpl Clone for timevalimpl Clone for statimpl Clone for timespecimpl<T> Clone for Rev<T> where
T: Clone,impl<'a, P> Clone for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I> Clone for DecodeUtf8<I> where
I: Clone + Iterator<Item = u8>,impl<A, B, C, D, E> Clone for (A, B, C, D, E) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,impl<Ret, A, B, C, D, E, F, G, H> Clone for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<Ret, A, B, C, D, E, F, G> Clone for fn(A, B, C, D, E, F, G) -> Retimpl<I, F> Clone for Inspect<I, F> where
F: Clone,
I: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<A, B> Clone for Chain<A, B> where
A: Clone,
B: Clone,impl<Idx> Clone for RangeFrom<Idx> where
Idx: Clone,impl<T> Clone for [T; 6] where
T: Copy,impl<I> Clone for Enumerate<I> where
I: Clone,impl<'a, 'b> Clone for StrSearcher<'a, 'b>impl<'a, P> Clone for SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H> Clone for fn(A, B, C, D, E, F, G, H) -> Retimpl Clone for SipHasher24impl Clone for TryFromIntErrorimpl<T> Clone for PhantomData<T> where
T: ?Sized,impl Clone for i32impl<Ret, A, B, C> Clone for extern "C" fn(A, B, C) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Idx> Clone for RangeTo<Idx> where
Idx: Clone,impl<Idx> Clone for std::ops::Range<Idx> where
Idx: Clone,impl<'a, P> Clone for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I, F> Clone for FilterMap<I, F> where
F: Clone,
I: Clone,impl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl Clone for CharTryFromErrorimpl<Ret, A, B, C, D, E, F> Clone for extern "C" fn(A, B, C, D, E, F) -> Retimpl<A, B, C, D, E, F, G, H> Clone for (A, B, C, D, E, F, G, H) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<I> Clone for StepBy<I> where
I: Clone,impl Clone for RangeFullimpl<T> Clone for [T; 5] where
T: Copy,impl Clone for u8impl<A, B, C, D, E, F, G, H, I> Clone for (A, B, C, D, E, F, G, H, I) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,impl<T> Clone for Unique<T> where
T: ?Sized,impl<'a, F> Clone for CharPredicateSearcher<'a, F> where
F: Clone + FnMut(char) -> bool,impl<T> Clone for [T; 1] where
T: Copy,impl<I> Clone for Skip<I> where
I: Clone,impl<I, P> Clone for Filter<I, P> where
I: Clone,
P: Clone,impl<Ret, A, B> Clone for unsafe extern "C" fn(A, B, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<T> Clone for [T; 31] where
T: Copy,impl<I, P> Clone for TakeWhile<I, P> where
I: Clone,
P: Clone,impl<T> Clone for [T; 10] where
T: Copy,impl<T> Clone for [T; 19] where
T: Copy,impl Clone for EscapeDebugimpl<T> Clone for RefCell<T> where
T: Clone,impl Clone for u32impl<T> Clone for [T; 29] where
T: Copy,impl Clone for SipHasherimpl<T> Clone for [T; 22] where
T: Copy,impl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>impl<'a, T, P> Clone for std::slice::Split<'a, T, P> where
P: Clone + FnMut(&T) -> bool,impl<T> Clone for Wrapping<T> where
T: Clone,impl<A, B, C, D, E, F, G, H, I, J, K> Clone for (A, B, C, D, E, F, G, H, I, J, K) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,
K: Clone,impl<Ret, A, B, C> Clone for fn(A, B, C) -> Retimpl<Ret> Clone for unsafe extern "C" fn() -> Retimpl<T> Clone for [T; 9] where
T: Copy,impl<I> Clone for Take<I> where
I: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<A, B> Clone for Zip<A, B> where
A: Clone,
B: Clone,impl<Ret, A> Clone for unsafe extern "C" fn(A) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<'a> Clone for LinesAny<'a>impl<'a, P> Clone for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret> Clone for extern "C" fn() -> Retimpl<Ret, A, B, C, D, E, F> Clone for extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Ret, A, B, C, D, E, F, G> Clone for unsafe fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C> Clone for extern "C" fn(A, B, C, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G> Clone for extern "C" fn(A, B, C, D, E, F, G) -> Retimpl Clone for u128impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<Ret, A, B, C, D, E, F> Clone for unsafe extern "C" fn(A, B, C, D, E, F) -> Retimpl Clone for i128impl<'a, P> Clone for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<T> Clone for [T; 8] where
T: Copy,impl<T> Clone for [T; 0] where
T: Copy,impl<I> Clone for Cycle<I> where
I: Clone,impl<Ret, A, B, C, D, E, F, G, H, I> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<'a> Clone for Bytes<'a>impl<A, B, C, D> Clone for (A, B, C, D) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,impl<A, B> Clone for (A, B) where
A: Clone,
B: Clone,impl<T> Clone for [T; 4] where
T: Copy,impl<T> Clone for [T; 16] where
T: Copy,impl<'a, P> Clone for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A> Clone for extern "C" fn(A) -> Retimpl Clone for ParseCharErrorimpl<'a, T> Clone for Chunks<'a, T>impl<T> Clone for [T; 12] where
T: Copy,impl Clone for charimpl<T> Clone for Option<T> where
T: Clone,impl<Ret, A, B, C> Clone for unsafe extern "C" fn(A, B, C, ...) -> Retimpl<I, U, F> Clone for FlatMap<I, U, F> where
F: Clone,
I: Clone,
U: Clone + IntoIterator,
<U as IntoIterator>::IntoIter: Clone,
<U as IntoIterator>::IntoIter: Clone,impl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<I> Clone for Cloned<I> where
I: Clone,impl Clone for u64impl Clone for f64impl<T> Clone for Once<T> where
T: Clone,impl<'a, P> Clone for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl Clone for u16impl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl<I, St, F> Clone for Scan<I, St, F> where
F: Clone,
I: Clone,
St: Clone,impl<Ret, A, B, C, D, E> Clone for extern "C" fn(A, B, C, D, E, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a, T> Clone for std::result::Iter<'a, T>impl Clone for FpCategoryimpl<Ret, A, B, C, D, E, F> Clone for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a> Clone for Lines<'a>impl Clone for i8impl<Ret, A> Clone for unsafe fn(A) -> Retimpl<I> Clone for Peekable<I> where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,impl<Ret, A, B, C, D, E> Clone for unsafe extern "C" fn(A, B, C, D, E) -> Retimpl Clone for i16impl<I, F> Clone for Map<I, F> where
F: Clone,
I: Clone,impl<'a, T> Clone for Windows<'a, T>impl Clone for SearchStepimpl<T> Clone for [T; 25] where
T: Copy,impl<Ret, A, B, C, D> Clone for extern "C" fn(A, B, C, D, ...) -> Retimpl<T> Clone for [T; 3] where
T: Copy,impl<Ret> Clone for fn() -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<Ret, A, B> Clone for extern "C" fn(A, B) -> Retimpl<Ret, A, B, C, D, E> Clone for unsafe fn(A, B, C, D, E) -> Retimpl<T> Clone for [T; 13] where
T: Copy,impl<T> Clone for [T; 27] where
T: Copy,impl<Ret, A, B, C, D, E, F, G> Clone for extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<Ret> Clone for unsafe fn() -> Retimpl Clone for boolimpl<A, B, C> Clone for (A, B, C) where
A: Clone,
B: Clone,
C: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<T> Clone for NonZero<T> where
T: Zeroable + Clone,impl<Ret, A, B, C, D> Clone for extern "C" fn(A, B, C, D) -> Retimpl<'a, P> Clone for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<T> Clone for [T; 23] where
T: Copy,impl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<H> Clone for BuildHasherDefault<H>impl Clone for TypeIdimpl<A, B, C, D, E, F, G, H, I, J, K, L> Clone for (A, B, C, D, E, F, G, H, I, J, K, L) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,
K: Clone,
L: Clone,impl Clone for EscapeDefaultimpl Clone for Utf8Errorimpl<Ret, A, B> Clone for unsafe extern "C" fn(A, B) -> Retimpl<Ret, A, B, C> Clone for unsafe fn(A, B, C) -> Retimpl<T> Clone for [T; 11] where
T: Copy,impl Clone for EscapeUnicodeimpl<A> Clone for Repeat<A> where
A: Clone,impl<T> Clone for *const T where
T: ?Sized,impl<Idx> Clone for RangeInclusive<Idx> where
Idx: Clone,impl<Ret, A, B, C, D> Clone for unsafe extern "C" fn(A, B, C, D, ...) -> Retimpl<Ret, A, B, C, D> Clone for unsafe fn(A, B, C, D) -> Retimpl<'a> Clone for Chars<'a>impl<A> Clone for (A,) where
A: Clone,impl<'a, A> Clone for std::option::Iter<'a, A>impl<'a, T, P> Clone for std::slice::RSplit<'a, T, P> where
P: Clone + FnMut(&T) -> bool,
T: 'a + Clone,impl<T> Clone for Discriminant<T>impl<'a, T> Clone for std::slice::Iter<'a, T>impl<'a> Clone for CharSearcher<'a>impl<T> Clone for Empty<T>impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<T> Clone for [T; 7] where
T: Copy,impl Clone for ()impl<T> Clone for [T; 26] where
T: Copy,impl Clone for i64impl Clone for Errorimpl<'a> Clone for CharIndices<'a>impl<A, B, C, D, E, F, G> Clone for (A, B, C, D, E, F, G) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,impl Clone for usizeimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl Clone for TraitObjectimpl<T> Clone for [T; 15] where
T: Copy,impl<A> Clone for std::option::IntoIter<A> where
A: Clone,impl<Ret, A> Clone for fn(A) -> Retimpl Clone for isizeimpl<T> Clone for [T; 21] where
T: Copy,impl Clone for std::cmp::Orderingimpl<T> Clone for Shared<T> where
T: ?Sized,impl<Ret, A, B> Clone for fn(A, B) -> Retimpl<Ret, A, B> Clone for unsafe fn(A, B) -> Retimpl<Ret, A, B, C, D> Clone for fn(A, B, C, D) -> Retimpl<T> Clone for [T; 14] where
T: Copy,impl<I, P> Clone for SkipWhile<I, P> where
I: Clone,
P: Clone,impl<Ret, A, B, C, D, E, F> Clone for fn(A, B, C, D, E, F) -> Retimpl<T> Clone for *mut T where
T: ?Sized,impl<Ret, A, B, C, D, E, F> Clone for unsafe fn(A, B, C, D, E, F) -> Retimpl<A, B, C, D, E, F, G, H, I, J> Clone for (A, B, C, D, E, F, G, H, I, J) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,impl<T> Clone for [T; 30] where
T: Copy,impl<'a, P> Clone for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<Ret, A> Clone for unsafe extern "C" fn(A, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, T> Clone for &'a T where
T: ?Sized,impl<Ret, A, B, C, D, E> Clone for unsafe extern "C" fn(A, B, C, D, E, ...) -> Retimpl<Ret, A, B, C, D, E> Clone for extern "C" fn(A, B, C, D, E) -> Retimpl<T> Clone for [T; 20] where
T: Copy,impl<T> Clone for [T; 24] where
T: Copy,impl<'a, P> Clone for RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H> Clone for extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C> Clone for unsafe extern "C" fn(A, B, C) -> Retimpl<I> Clone for Fuse<I> where
I: Clone,impl<Ret, A, B, C, D, E, F, G> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Retimpl Clone for ParseIntErrorimpl<Ret, A, B, C, D, E> Clone for fn(A, B, C, D, E) -> Retimpl<Ret, A> Clone for extern "C" fn(A, ...) -> Retimpl<T> Clone for [T; 18] where
T: Copy,impl Clone for SipHasher13impl Clone for f32impl<T> Clone for [T; 32] where
T: Copy,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<Ret, A, B, C, D> Clone for unsafe extern "C" fn(A, B, C, D) -> Retimpl Clone for ParseBoolErrorimpl<T, E> Clone for Result<T, E> where
E: Clone,
T: Clone,impl<T> Clone for Cell<T> where
T: Copy,impl<'a> Clone for Arguments<'a>impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,impl Clone for ParseFloatErrorimpl<T> Clone for [T; 28] where
T: Copy,impl<Ret, A, B> Clone for extern "C" fn(A, B, ...) -> Retimpl<T> Clone for [T; 2] where
T: Copy,impl<T> Clone for [T; 17] where
T: Copy,impl<Ret, A, B, C, D, E, F, G> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<A, B, C, D, E, F> Clone for (A, B, C, D, E, F) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,impl Clone for std::sync::atomic::Orderingimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl Clone for LocalKeyStateimpl Clone for ThreadIdimpl Clone for Threadimpl<K: Clone, V: Clone, S: Clone> Clone for HashMap<K, V, S>impl<'a, K, V> Clone for std::collections::hash_map::Iter<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Values<'a, K, V>impl Clone for RandomStateimpl Clone for DefaultHasherimpl<T: Clone, S: Clone> Clone for HashSet<T, S>impl<'a, K> Clone for std::collections::hash_set::Iter<'a, K>impl<'a, T, S> Clone for std::collections::hash_set::Intersection<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Difference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::SymmetricDifference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Union<'a, T, S>impl Clone for VarErrorimpl Clone for CStringimpl Clone for NulErrorimpl Clone for FromBytesWithNulErrorimpl Clone for IntoStringErrorimpl Clone for OsStringimpl Clone for Metadataimpl Clone for OpenOptionsimpl Clone for Permissionsimpl Clone for FileTypeimpl<T: Clone> Clone for Cursor<T>impl Clone for ErrorKindimpl Clone for SeekFromimpl Clone for IpAddrimpl Clone for Ipv6MulticastScopeimpl Clone for Ipv4Addrimpl Clone for Ipv6Addrimpl Clone for SocketAddrimpl Clone for SocketAddrV4impl Clone for SocketAddrV6impl Clone for AddrParseErrorimpl Clone for Shutdownimpl<'a> Clone for Prefix<'a>impl<'a> Clone for PrefixComponent<'a>impl<'a> Clone for Component<'a>impl<'a> Clone for Components<'a>impl<'a> Clone for std::path::Iter<'a>impl Clone for PathBufimpl Clone for StripPrefixErrorimpl Clone for Outputimpl Clone for ExitStatusimpl<T: Clone> Clone for SendError<T>impl Clone for RecvErrorimpl Clone for TryRecvErrorimpl Clone for RecvTimeoutErrorimpl<T: Clone> Clone for TrySendError<T>impl<T> Clone for Sender<T>impl<T> Clone for SyncSender<T>impl Clone for WaitTimeoutResultimpl Clone for Durationimpl Clone for Instantimpl Clone for SystemTimeimpl Clone for SystemTimeErrorimpl<'a> Clone for EncodeWide<'a>