Trait std::clone::Clone 1.0.0
[−]
[src]
#[lang = "clone"]pub trait Clone { fn clone(&self) -> Self; fn clone_from(&mut self, source: &Self) { ... } }
A common trait for the ability to explicitly duplicate an object.
Differs from Copy in that Copy is implicit and extremely inexpensive, while
Clone is always explicit and may or may not be expensive. In order to enforce
these characteristics, Rust does not allow you to reimplement Copy, but you
may reimplement Clone and run arbitrary code.
Since Clone is more general than Copy, you can automatically make anything
Copy be Clone as well.
Derivable
This trait can be used with #[derive] if all fields are Clone. The derived
implementation of clone calls clone on each field.
Closures
Closure types automatically implement Clone if they capture no value from the environment
or if all such captured values implement Clone themselves.
How can I implement Clone?
Types that are Copy should have a trivial implementation of Clone. More formally:
if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;.
Manual implementations should be careful to uphold this invariant; however, unsafe code
must not rely on it to ensure memory safety.
An example is an array holding more than 32 elements of a type that is Clone; the standard
library only implements Clone up until arrays of size 32. In this case, the implementation of
Clone cannot be derived, but can be implemented as:
#[derive(Copy)] struct Stats { frequencies: [i32; 100], } impl Clone for Stats { fn clone(&self) -> Stats { *self } }Run
Required Methods
fn clone(&self) -> Self
Provided Methods
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source.
a.clone_from(&b) is equivalent to a = b.clone() in functionality,
but can be overridden to reuse the resources of a to avoid unnecessary
allocations.
Implementations on Foreign Types
impl Clone for __m128i[src]
impl Clone for __m128iimpl Clone for __m256d[src]
impl Clone for __m256dimpl Clone for __m256i[src]
impl Clone for __m256iimpl Clone for __m128d[src]
impl Clone for __m128dimpl Clone for Layout[src]
impl Clone for Layoutimpl Clone for AllocErr[src]
impl Clone for AllocErrimpl Clone for CannotReallocInPlace[src]
impl Clone for CannotReallocInPlacefn clone(&self) -> CannotReallocInPlace[src]
fn clone(&self) -> CannotReallocInPlacefn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)impl Clone for __m256[src]
impl Clone for __m256impl Clone for __m128[src]
impl Clone for __m128impl Clone for TryFromSliceError[src]
impl Clone for TryFromSliceErrorfn clone(&self) -> TryFromSliceError[src]
fn clone(&self) -> TryFromSliceErrorfn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)impl Clone for CpuidResult[src]
impl Clone for CpuidResultfn clone(&self) -> CpuidResult[src]
fn clone(&self) -> CpuidResultfn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)impl<T> Clone for NonZero<T> where
T: Zeroable + Clone, [src]
impl<T> Clone for NonZero<T> where
T: Zeroable + Clone, impl Clone for __m64[src]
impl Clone for __m64impl<I> Clone for Utf16Encoder<I> where
I: Clone, [src]
impl<I> Clone for Utf16Encoder<I> where
I: Clone, ⓘImportant traits for Utf16Encoder<I>fn clone(&self) -> Utf16Encoder<I>[src]
fn clone(&self) -> Utf16Encoder<I>fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Implementors
impl Clone for NonZeroI16impl<'a> Clone for Arguments<'a>impl<T, E> Clone for Result<T, E> where
E: Clone,
T: Clone,impl<T> Clone for Empty<T>impl Clone for i8x64impl<I, U> Clone for Flatten<I> where
I: Iterator + Clone,
U: Iterator + Clone,
<I as Iterator>::Item: IntoIterator,
<<I as Iterator>::Item as IntoIterator>::IntoIter == U,
<<I as Iterator>::Item as IntoIterator>::Item == <U as Iterator>::Item,impl Clone for EscapeUnicodeimpl<I> Clone for Peekable<I> where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,impl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>impl Clone for b8x16impl Clone for CollectionAllocErrimpl Clone for f64x4impl<'a, A> Clone for std::option::Iter<'a, A>impl Clone for ParseFloatErrorimpl Clone for NonZeroU32impl Clone for u64x8impl Clone for Utf8Errorimpl Clone for i8x4impl<I, P> Clone for Filter<I, P> where
I: Clone,
P: Clone,impl<'a, P> Clone for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for i32x2impl<'a> Clone for Lines<'a>impl Clone for b8x4impl Clone for u16x16impl Clone for NonZeroU16impl Clone for f32x4impl<'a, T> Clone for std::slice::Iter<'a, T>impl Clone for b8x2impl<'a, T> Clone for std::result::Iter<'a, T>impl<T> Clone for ManuallyDrop<T> where
T: Clone,impl Clone for i16x32impl<'a> Clone for Bytes<'a>impl<T> Clone for PhantomData<T> where
T: ?Sized,impl Clone for u8x32impl<'a, T> Clone for ExactChunks<'a, T>impl<I> Clone for Take<I> where
I: Clone,impl<Y, R> Clone for GeneratorState<Y, R> where
R: Clone,
Y: Clone,impl<'a> Clone for Chars<'a>impl Clone for u64x2impl<'a, T, P> Clone for std::slice::RSplit<'a, T, P> where
P: Clone + FnMut(&T) -> bool,
T: 'a + Clone,impl<I> Clone for Enumerate<I> where
I: Clone,impl Clone for std::sync::atomic::Orderingimpl Clone for u32x2impl<'a, F> Clone for CharPredicateSearcher<'a, F> where
F: Clone + FnMut(char) -> bool,impl Clone for u8x2impl<'a, P> Clone for RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for TryFromIntErrorimpl Clone for b8x8impl Clone for i16x4impl Clone for f32x8impl<I, F> Clone for Inspect<I, F> where
F: Clone,
I: Clone,impl<T> Clone for Reverse<T> where
T: Clone,impl<I, F> Clone for FilterMap<I, F> where
F: Clone,
I: Clone,impl<A> Clone for Repeat<A> where
A: Clone,impl Clone for NonZeroU128impl<'a> Clone for LinesAny<'a>impl Clone for f32x2impl Clone for u16x2impl Clone for u32x4impl Clone for u8x64impl<Idx> Clone for RangeFrom<Idx> where
Idx: Clone,impl Clone for std::cmp::Orderingimpl Clone for i16x2impl Clone for i16x16impl Clone for EscapeDebugimpl<I, P> Clone for SkipWhile<I, P> where
I: Clone,
P: Clone,impl<H> Clone for BuildHasherDefault<H>impl Clone for SipHasherimpl Clone for NonZeroU8impl Clone for ParseCharErrorimpl<'a, P> Clone for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for u64x4impl<T> Clone for Rev<T> where
T: Clone,impl Clone for i64x4impl Clone for NoneErrorimpl Clone for f64x8impl<Idx> Clone for RangeInclusive<Idx> where
Idx: Clone,impl<'a, P> Clone for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for CharTryFromErrorimpl<I> Clone for StepBy<I> where
I: Clone,impl<'a, P> Clone for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<T> Clone for Discriminant<T>impl Clone for u16x4impl<I, U, F> Clone for FlatMap<I, U, F> where
F: Clone,
I: Clone,
U: Clone + IntoIterator,
<U as IntoIterator>::IntoIter: Clone,impl<'a, P> Clone for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I, F> Clone for Map<I, F> where
F: Clone,
I: Clone,impl Clone for NonZeroIsizeimpl<'a, T, P> Clone for std::slice::Split<'a, T, P> where
P: Clone + FnMut(&T) -> bool,impl Clone for i8x2impl Clone for i64x2impl<I, P> Clone for TakeWhile<I, P> where
I: Clone,
P: Clone,impl Clone for u32x16impl Clone for i64x8impl<T> Clone for Cell<T> where
T: Copy,impl<A, B> Clone for Zip<A, B> where
A: Clone,
B: Clone,impl Clone for u8x4impl<'a, P> Clone for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for FpCategoryimpl Clone for u16x32impl Clone for u8x8impl<I> Clone for Cycle<I> where
I: Clone,impl Clone for NonZeroU64impl<'a, T> Clone for Windows<'a, T>impl Clone for u16x8impl<T> Clone for Wrapping<T> where
T: Clone,impl Clone for NonZeroI32impl<T> Clone for Option<T> where
T: Clone,impl Clone for b8x64impl<'a, 'b> Clone for StrSearcher<'a, 'b>impl Clone for TypeIdimpl<T> Clone for NonNull<T> where
T: ?Sized,impl<T> Clone for Bound<T> where
T: Clone,impl Clone for ParseBoolErrorimpl<'a, P> Clone for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for i16x8impl<T> Clone for RefCell<T> where
T: Clone,impl<T> Clone for std::result::IntoIter<T> where
T: Clone,impl Clone for NonZeroI128impl Clone for i32x16impl Clone for u8x16impl Clone for NonZeroUsizeimpl<I> Clone for Cloned<I> where
I: Clone,impl<I> Clone for DecodeUtf8<I> where
I: Clone + Iterator<Item = u8>,impl<'a, P> Clone for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Idx> Clone for RangeTo<Idx> where
Idx: Clone,impl<I> Clone for Fuse<I> where
I: Clone,impl Clone for EscapeDefaultimpl Clone for i8x8impl Clone for f32x16impl<I> Clone for Skip<I> where
I: Clone,impl<T> Clone for Once<T> where
T: Clone,impl Clone for RangeFullimpl<A, B> Clone for Chain<A, B> where
A: Clone,
B: Clone,impl<T> Clone for Unique<T> where
T: ?Sized,impl Clone for i32x4impl<'a> Clone for CharIndices<'a>impl Clone for Durationimpl<Idx> Clone for std::ops::Range<Idx> where
Idx: Clone,impl Clone for TraitObjectimpl<'a, T> Clone for Chunks<'a, T>impl Clone for i32x8impl Clone for i8x16impl Clone for b8x32impl Clone for ParseIntErrorimpl Clone for SearchStepimpl Clone for Errorimpl Clone for f64x2impl Clone for u32x8impl<'a> Clone for CharSearcher<'a>impl Clone for NonZeroI8impl<I, St, F> Clone for Scan<I, St, F> where
F: Clone,
I: Clone,
St: Clone,impl Clone for i8x32impl<A> Clone for std::option::IntoIter<A> where
A: Clone,impl Clone for NonZeroI64impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,impl<F> Clone for RepeatWith<F> where
F: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Iter<'a, K, V>impl<'a, T> Clone for std::collections::btree_set::Range<'a, T>impl<T> Clone for LinkedList<T> where
T: Clone,impl<T> Clone for std::sync::Weak<T> where
T: ?Sized,impl<T> Clone for Arc<T> where
T: ?Sized,impl<T> Clone for std::rc::Weak<T> where
T: ?Sized,impl<'a, T> Clone for std::collections::btree_set::Intersection<'a, T>impl<'a, T> Clone for std::collections::btree_set::SymmetricDifference<'a, T>impl<T> Clone for Rc<T> where
T: ?Sized,impl Clone for Heapimpl<T> Clone for Vec<T> where
T: Clone,impl Clone for ParseErrorimpl<'a, T> Clone for std::collections::btree_set::Iter<'a, T>impl<T> Clone for std::collections::binary_heap::IntoIter<T> where
T: Clone,impl Clone for Stringimpl<'a, T> Clone for std::collections::btree_set::Difference<'a, T>impl<'a> Clone for EncodeUtf16<'a>impl<'a, K, V> Clone for std::collections::btree_map::Values<'a, K, V>impl<'a, B> Clone for Cow<'a, B> where
B: ToOwned + ?Sized,impl<T> Clone for std::collections::vec_deque::IntoIter<T> where
T: Clone,impl<K, V> Clone for BTreeMap<K, V> where
K: Clone,
V: Clone,impl<T> Clone for Box<T> where
T: Clone,impl<T> Clone for Box<[T]> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Union<'a, T>impl<'a, T> Clone for std::collections::binary_heap::Iter<'a, T>impl<'a, K, V> Clone for std::collections::btree_map::Range<'a, K, V>impl<T> Clone for std::collections::linked_list::IntoIter<T> where
T: Clone,impl Clone for ExchangeHeapSingletonimpl<T> Clone for std::vec::IntoIter<T> where
T: Clone,impl Clone for Box<str>impl<'a, T> Clone for std::collections::linked_list::Iter<'a, T>impl<T> Clone for VecDeque<T> where
T: Clone,impl<'a, T> Clone for std::collections::vec_deque::Iter<'a, T>impl<T> Clone for BinaryHeap<T> where
T: Clone,impl<T> Clone for BTreeSet<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Keys<'a, K, V>impl<I> Clone for DecodeUtf16<I> where
I: Clone + Iterator<Item = u16>,impl<'a> Clone for SplitWhitespace<'a>impl Clone for ToUppercaseimpl Clone for UnicodeVersionimpl Clone for ToLowercaseimpl Clone for DecodeUtf16Errorimpl Clone for ThreadIdimpl Clone for Threadimpl<K: Clone, V: Clone, S: Clone> Clone for HashMap<K, V, S>impl<'a, K, V> Clone for std::collections::hash_map::Iter<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Values<'a, K, V>impl Clone for RandomStateimpl Clone for DefaultHasherimpl<T: Clone, S: Clone> Clone for HashSet<T, S>impl<'a, K> Clone for std::collections::hash_set::Iter<'a, K>impl<'a, T, S> Clone for std::collections::hash_set::Intersection<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Difference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::SymmetricDifference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Union<'a, T, S>impl Clone for VarErrorimpl Clone for CStringimpl Clone for NulErrorimpl Clone for FromBytesWithNulErrorimpl Clone for IntoStringErrorimpl Clone for OsStringimpl Clone for Metadataimpl Clone for OpenOptionsimpl Clone for Permissionsimpl Clone for FileTypeimpl<T: Clone> Clone for Cursor<T>impl Clone for ErrorKindimpl Clone for SeekFromimpl Clone for IpAddrimpl Clone for Ipv6MulticastScopeimpl Clone for Ipv4Addrimpl Clone for Ipv6Addrimpl Clone for std::net::SocketAddrimpl Clone for SocketAddrV4impl Clone for SocketAddrV6impl Clone for AddrParseErrorimpl Clone for Shutdownimpl Clone for statimpl<'a> Clone for Prefix<'a>impl<'a> Clone for PrefixComponent<'a>impl<'a> Clone for Component<'a>impl<'a> Clone for Components<'a>impl<'a> Clone for std::path::Iter<'a>impl<'a> Clone for Ancestors<'a>impl Clone for PathBufimpl Clone for StripPrefixErrorimpl Clone for Outputimpl Clone for ExitStatusimpl Clone for ExitCodeimpl<T: Clone> Clone for SendError<T>impl Clone for RecvErrorimpl Clone for TryRecvErrorimpl Clone for RecvTimeoutErrorimpl<T: Clone> Clone for TrySendError<T>impl<T> Clone for Sender<T>impl<T> Clone for SyncSender<T>impl Clone for WaitTimeoutResultimpl Clone for Instantimpl Clone for SystemTimeimpl Clone for SystemTimeErrorimpl<'a> Clone for EncodeWide<'a>impl Clone for std::os::unix::net::SocketAddr