Trait std::clone::Clone 1.0.0
[−]
[src]
#[lang = "clone"]pub trait Clone { fn clone(&self) -> Self; fn clone_from(&mut self, source: &Self) { ... } }
A common trait for the ability to explicitly duplicate an object.
Differs from Copy in that Copy is implicit and extremely inexpensive, while
Clone is always explicit and may or may not be expensive. In order to enforce
these characteristics, Rust does not allow you to reimplement Copy, but you
may reimplement Clone and run arbitrary code.
Since Clone is more general than Copy, you can automatically make anything
Copy be Clone as well.
Derivable
This trait can be used with #[derive] if all fields are Clone. The derived
implementation of clone calls clone on each field.
How can I implement Clone?
Types that are Copy should have a trivial implementation of Clone. More formally:
if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;.
Manual implementations should be careful to uphold this invariant; however, unsafe code
must not rely on it to ensure memory safety.
An example is an array holding more than 32 elements of a type that is Clone; the standard
library only implements Clone up until arrays of size 32. In this case, the implementation of
Clone cannot be derived, but can be implemented as:
#[derive(Copy)] struct Stats { frequencies: [i32; 100], } impl Clone for Stats { fn clone(&self) -> Stats { *self } }Run
Required Methods
fn clone(&self) -> Self
Provided Methods
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source.
a.clone_from(&b) is equivalent to a = b.clone() in functionality,
but can be overridden to reuse the resources of a to avoid unnecessary
allocations.
Implementors
impl Clone for DecodeUtf16Errorimpl<I> Clone for DecodeUtf16<I> where
I: Clone + Iterator<Item = u16>,impl<'a> Clone for SplitWhitespace<'a>impl<I> Clone for Utf16Encoder<I> where
I: Clone,impl Clone for Box<str>impl<T> Clone for BTreeSet<T> where
T: Clone,impl<T> Clone for BinaryHeap<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::SymmetricDifference<'a, T>impl Clone for ExchangeHeapSingletonimpl<T> Clone for std::sync::Weak<T> where
T: ?Sized,impl Clone for CannotReallocInPlaceimpl<'a, T> Clone for std::collections::btree_set::Iter<'a, T>impl<'a, K, V> Clone for std::collections::btree_map::Values<'a, K, V>impl<T> Clone for std::collections::vec_deque::IntoIter<T> where
T: Clone,impl<T> Clone for Arc<T> where
T: ?Sized,impl<'a, B> Clone for Cow<'a, B> where
B: ToOwned + ?Sized,impl Clone for Layoutimpl<'a, K, V> Clone for std::collections::btree_map::Iter<'a, K, V>impl<T> Clone for Box<[T]> where
T: Clone,impl Clone for Stringimpl<T> Clone for Rc<T> where
T: ?Sized,impl<T> Clone for std::vec::IntoIter<T> where
T: Clone,impl<'a, T> Clone for std::collections::binary_heap::Iter<'a, T>impl<T> Clone for Box<T> where
T: Clone,impl<T> Clone for std::rc::Weak<T> where
T: ?Sized,impl<'a, T> Clone for std::collections::btree_set::Difference<'a, T>impl Clone for AllocErrimpl<T> Clone for std::collections::binary_heap::IntoIter<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Union<'a, T>impl Clone for ParseErrorimpl<'a> Clone for EncodeUtf16<'a>impl<'a, T> Clone for std::collections::btree_set::Intersection<'a, T>impl<T> Clone for VecDeque<T> where
T: Clone,impl<'a, T> Clone for std::collections::linked_list::Iter<'a, T>impl Clone for Heapimpl<'a, K, V> Clone for std::collections::btree_map::Keys<'a, K, V>impl<'a, T> Clone for std::collections::vec_deque::Iter<'a, T>impl<T> Clone for std::collections::linked_list::IntoIter<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Range<'a, T>impl<T> Clone for Vec<T> where
T: Clone,impl<K, V> Clone for BTreeMap<K, V> where
K: Clone,
V: Clone,impl<T> Clone for LinkedList<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Range<'a, K, V>impl<T> Clone for Bound<T> where
T: Clone,impl Clone for _Unwind_Reason_Codeimpl Clone for _Unwind_Actionimpl Clone for IsaacRngimpl Clone for ChaChaRngimpl Clone for LogNormalimpl Clone for ReseedWithDefaultimpl Clone for XorShiftRngimpl Clone for StandardNormalimpl Clone for Exp1impl Clone for Isaac64Rngimpl Clone for Expimpl Clone for Normalimpl Clone for utimbufimpl Clone for timespecimpl Clone for timevalimpl Clone for libc::windows::statimpl Clone for tmimpl<'a, T> Clone for std::result::Iter<'a, T>impl<'a> Clone for CharSearcher<'a>impl<T> Clone for NonZero<T> where
T: Zeroable + Clone,impl<I, P> Clone for SkipWhile<I, P> where
I: Clone,
P: Clone,impl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>impl<'a, P> Clone for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<A, B> Clone for Chain<A, B> where
A: Clone,
B: Clone,impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,impl<'a> Clone for Chars<'a>impl<'a, P> Clone for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I> Clone for Take<I> where
I: Clone,impl<T> Clone for PhantomData<T> where
T: ?Sized,impl Clone for std::sync::atomic::Orderingimpl<A> Clone for std::option::IntoIter<A> where
A: Clone,impl<'a, P> Clone for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I> Clone for StepBy<I> where
I: Clone,impl<T> Clone for Option<T> where
T: Clone,impl Clone for SipHasher24impl<'a> Clone for Arguments<'a>impl<T> Clone for Once<T> where
T: Clone,impl<I> Clone for DecodeUtf8<I> where
I: Clone + Iterator<Item = u8>,impl<T, E> Clone for Result<T, E> where
E: Clone,
T: Clone,impl Clone for ParseIntErrorimpl<H> Clone for BuildHasherDefault<H>impl<'a, T, P> Clone for std::slice::RSplit<'a, T, P> where
P: Clone + FnMut(&T) -> bool,
T: 'a + Clone,impl<T> Clone for RefCell<T> where
T: Clone,impl<'a, T> Clone for std::slice::Iter<'a, T>impl<'a, T> Clone for Chunks<'a, T>impl<T> Clone for Discriminant<T>impl Clone for ParseBoolErrorimpl<'a, 'b> Clone for StrSearcher<'a, 'b>impl<I> Clone for Cloned<I> where
I: Clone,impl<'a> Clone for CharIndices<'a>impl<A> Clone for Repeat<A> where
A: Clone,impl Clone for ParseCharErrorimpl<'a> Clone for LinesAny<'a>impl<'a, P> Clone for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, F> Clone for CharPredicateSearcher<'a, F> where
F: Clone + FnMut(char) -> bool,impl<T> Clone for Rev<T> where
T: Clone,impl<'a> Clone for Lines<'a>impl<Idx> Clone for RangeInclusive<Idx> where
Idx: Clone,impl Clone for SipHasherimpl<T> Clone for Empty<T>impl<I> Clone for Cycle<I> where
I: Clone,impl<I> Clone for Skip<I> where
I: Clone,impl Clone for CharTryFromErrorimpl<I, U, F> Clone for FlatMap<I, U, F> where
F: Clone,
I: Clone,
U: Clone + IntoIterator,
<U as IntoIterator>::IntoIter: Clone,
<U as IntoIterator>::IntoIter: Clone,impl<Idx> Clone for RangeTo<Idx> where
Idx: Clone,impl<T> Clone for Wrapping<T> where
T: Clone,impl<T> Clone for Shared<T> where
T: ?Sized,impl Clone for TryFromIntErrorimpl<Idx> Clone for std::ops::Range<Idx> where
Idx: Clone,impl Clone for TypeIdimpl<I, P> Clone for TakeWhile<I, P> where
I: Clone,
P: Clone,impl<'a, P> Clone for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I> Clone for Enumerate<I> where
I: Clone,impl<I, F> Clone for Map<I, F> where
F: Clone,
I: Clone,impl Clone for EscapeUnicodeimpl<I, St, F> Clone for Scan<I, St, F> where
F: Clone,
I: Clone,
St: Clone,impl<I> Clone for Peekable<I> where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,impl Clone for TraitObjectimpl Clone for SearchStepimpl<Idx> Clone for RangeFrom<Idx> where
Idx: Clone,impl Clone for ParseFloatErrorimpl Clone for Utf8Errorimpl<'a, A> Clone for std::option::Iter<'a, A>impl<I, F> Clone for FilterMap<I, F> where
F: Clone,
I: Clone,impl Clone for std::cmp::Orderingimpl<'a> Clone for Bytes<'a>impl<I> Clone for Fuse<I> where
I: Clone,impl Clone for FpCategoryimpl Clone for SipHasher13impl Clone for EscapeDefaultimpl<'a, T, P> Clone for std::slice::Split<'a, T, P> where
P: Clone + FnMut(&T) -> bool,impl Clone for RangeFullimpl<T> Clone for Unique<T> where
T: ?Sized,impl<T> Clone for Cell<T> where
T: Copy,impl<'a, P> Clone for RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, T> Clone for Windows<'a, T>impl<A, B> Clone for Zip<A, B> where
A: Clone,
B: Clone,impl Clone for EscapeDebugimpl<I, P> Clone for Filter<I, P> where
I: Clone,
P: Clone,impl<I, F> Clone for Inspect<I, F> where
F: Clone,
I: Clone,impl<'a, P> Clone for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for Errorimpl Clone for LocalKeyStateimpl Clone for ThreadIdimpl Clone for Threadimpl<K: Clone, V: Clone, S: Clone> Clone for HashMap<K, V, S>impl<'a, K, V> Clone for std::collections::hash_map::Iter<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Values<'a, K, V>impl Clone for RandomStateimpl Clone for DefaultHasherimpl<T: Clone, S: Clone> Clone for HashSet<T, S>impl<'a, K> Clone for std::collections::hash_set::Iter<'a, K>impl<'a, T, S> Clone for std::collections::hash_set::Intersection<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Difference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::SymmetricDifference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Union<'a, T, S>impl Clone for VarErrorimpl Clone for CStringimpl Clone for NulErrorimpl Clone for FromBytesWithNulErrorimpl Clone for IntoStringErrorimpl Clone for OsStringimpl Clone for Metadataimpl Clone for OpenOptionsimpl Clone for Permissionsimpl Clone for FileTypeimpl<T: Clone> Clone for Cursor<T>impl Clone for ErrorKindimpl Clone for SeekFromimpl Clone for IpAddrimpl Clone for Ipv6MulticastScopeimpl Clone for Ipv4Addrimpl Clone for Ipv6Addrimpl Clone for std::net::SocketAddrimpl Clone for SocketAddrV4impl Clone for SocketAddrV6impl Clone for AddrParseErrorimpl Clone for Shutdownimpl Clone for std::os::linux::raw::statimpl<'a> Clone for Prefix<'a>impl<'a> Clone for PrefixComponent<'a>impl<'a> Clone for Component<'a>impl<'a> Clone for Components<'a>impl<'a> Clone for std::path::Iter<'a>impl Clone for PathBufimpl Clone for StripPrefixErrorimpl Clone for Outputimpl Clone for ExitStatusimpl<T: Clone> Clone for SendError<T>impl Clone for RecvErrorimpl Clone for TryRecvErrorimpl Clone for RecvTimeoutErrorimpl<T: Clone> Clone for TrySendError<T>impl<T> Clone for Sender<T>impl<T> Clone for SyncSender<T>impl Clone for WaitTimeoutResultimpl Clone for Durationimpl Clone for Instantimpl Clone for SystemTimeimpl Clone for SystemTimeErrorimpl<'a> Clone for EncodeWide<'a>impl Clone for std::os::unix::net::SocketAddr