Trait std::clone::Clone 1.0.0[−][src]
#[lang = "clone"]pub trait Clone {#[must_use = "cloning is often expensive and is not expected to have side effects"]fn clone(&self) -> Self; fn clone_from(&mut self, source: &Self) { ... } }
A common trait for the ability to explicitly duplicate an object.
Differs from Copy in that Copy is implicit and extremely inexpensive, while
Clone is always explicit and may or may not be expensive. In order to enforce
these characteristics, Rust does not allow you to reimplement Copy, but you
may reimplement Clone and run arbitrary code.
Since Clone is more general than Copy, you can automatically make anything
Copy be Clone as well.
Derivable
This trait can be used with #[derive] if all fields are Clone. The derived
implementation of clone calls clone on each field.
How can I implement Clone?
Types that are Copy should have a trivial implementation of Clone. More formally:
if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;.
Manual implementations should be careful to uphold this invariant; however, unsafe code
must not rely on it to ensure memory safety.
An example is an array holding more than 32 elements of a type that is Clone; the standard
library only implements Clone up until arrays of size 32. In this case, the implementation of
Clone cannot be derived, but can be implemented as:
#[derive(Copy)] struct Stats { frequencies: [i32; 100], } impl Clone for Stats { fn clone(&self) -> Stats { *self } }Run
Additional implementors
In addition to the implementors listed below,
the following types also implement Clone:
- Function item types (i.e. the distinct types defined for each function)
- Function pointer types (e.g.
fn() -> i32) - Array types, for all sizes, if the item type also implements
Clone(e.g.[i32; 123456]) - Tuple types, if each component also implements
Clone(e.g.(),(i32, bool)) - Closure types, if they capture no value from the environment
or if all such captured values implement
Clonethemselves. Note that variables captured by shared reference always implementClone(even if the referent doesn't), while variables captured by mutable reference never implementClone.
Required Methods
#[must_use = "cloning is often expensive and is not expected to have side effects"]
fn clone(&self) -> Self
Provided Methods
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source.
a.clone_from(&b) is equivalent to a = b.clone() in functionality,
but can be overridden to reuse the resources of a to avoid unnecessary
allocations.
Implementations on Foreign Types
impl Clone for TryFromSliceError[src]
impl Clone for TryFromSliceErrorfn clone(&self) -> TryFromSliceError[src]
fn clone(&self) -> TryFromSliceErrorfn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Implementors
impl<'a, P> Clone for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for EscapeUnicodeimpl Clone for ParseFloatErrorimpl<T> Clone for Empty<T>impl Clone for NonZeroU16impl Clone for SipHasherimpl<Idx> Clone for std::ops::Range<Idx> where
Idx: Clone,impl<I, P> Clone for Filter<I, P> where
I: Clone,
P: Clone,impl<'a, T> Clone for std::result::Iter<'a, T>impl Clone for ToLowercaseimpl<'a, P> Clone for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>impl<T> Clone for ManuallyDrop<T> where
T: Clone,impl<T> Clone for *const T where
T: ?Sized,impl Clone for EscapeDefaultimpl<'a, P> Clone for SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for Errorimpl Clone for TryFromIntErrorimpl<I, F> Clone for Map<I, F> where
F: Clone,
I: Clone,impl<T> Clone for Discriminant<T>impl<I, F> Clone for Inspect<I, F> where
F: Clone,
I: Clone,impl<F> Clone for RepeatWith<F> where
F: Clone,impl<'a, P> Clone for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for usizeimpl<T> Clone for NonNull<T> where
T: ?Sized,impl Clone for NoneErrorimpl<'a> Clone for LinesAny<'a>impl<'a, P> Clone for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for ParseCharErrorimpl<T> Clone for RefCell<T> where
T: Clone,impl<I, F> Clone for FilterMap<I, F> where
F: Clone,
I: Clone,impl<'a> Clone for EncodeUtf16<'a>impl Clone for u16impl<A, B> Clone for Chain<A, B> where
A: Clone,
B: Clone,impl<I> Clone for DecodeUtf8<I> where
I: Clone + Iterator<Item = u8>,impl<'a, T, P> Clone for std::slice::Split<'a, T, P> where
P: Clone + FnMut(&T) -> bool,impl<A> Clone for Repeat<A> where
A: Clone,impl<T> Clone for Cell<T> where
T: Copy,impl Clone for RangeFullimpl Clone for EscapeDebugimpl Clone for UnicodeVersionimpl Clone for Layoutimpl<'a, F> Clone for CharPredicateSearcher<'a, F> where
F: Clone + FnMut(char) -> bool,impl<'a> Clone for SplitWhitespace<'a>impl<'a, T> Clone for ExactChunks<'a, T>impl Clone for i16impl Clone for CharTryFromErrorimpl Clone for Utf8Errorimpl<H> Clone for BuildHasherDefault<H>impl<T> Clone for Wrapping<T> where
T: Clone,impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,impl Clone for NonZeroUsizeimpl Clone for std::sync::atomic::Orderingimpl<'a, T, P> Clone for std::slice::RSplit<'a, T, P> where
P: Clone + FnMut(&T) -> bool,
T: 'a + Clone,impl<I> Clone for StepBy<I> where
I: Clone,impl<I, U> Clone for Flatten<I> where
I: Iterator + Clone,
U: Iterator + Clone,
<I as Iterator>::Item: IntoIterator,
<<I as Iterator>::Item as IntoIterator>::IntoIter == U,
<<I as Iterator>::Item as IntoIterator>::Item == <U as Iterator>::Item,impl Clone for isizeimpl<'a, 'b> Clone for StrSearcher<'a, 'b>impl<'a, T> Clone for Chunks<'a, T>impl Clone for ParseBoolErrorimpl<'a, T> Clone for &'a T where
T: ?Sized,impl Clone for i64impl<Y, R> Clone for GeneratorState<Y, R> where
R: Clone,
Y: Clone,impl Clone for ParseIntErrorimpl<'a, P> Clone for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, T> Clone for Windows<'a, T>impl<I> Clone for Fuse<I> where
I: Clone,impl<T> Clone for std::result::IntoIter<T> where
T: Clone,impl Clone for TypeIdimpl<T, E> Clone for Result<T, E> where
E: Clone,
T: Clone,impl Clone for AllocErrimpl Clone for u32impl<T> Clone for *mut T where
T: ?Sized,impl<I, P> Clone for SkipWhile<I, P> where
I: Clone,
P: Clone,impl Clone for !impl Clone for LocalWakerimpl Clone for i32impl<T> Clone for Reverse<T> where
T: Clone,impl Clone for f32impl<'a> Clone for CharSearcher<'a>impl<'a, P> Clone for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<T> Clone for Poll<T> where
T: Clone,impl Clone for FpCategoryimpl<I> Clone for Take<I> where
I: Clone,impl Clone for i128impl<'a> Clone for Bytes<'a>impl Clone for u8impl<'a> Clone for SplitAsciiWhitespace<'a>impl Clone for TraitObjectimpl<A> Clone for std::option::IntoIter<A> where
A: Clone,impl<I> Clone for Skip<I> where
I: Clone,impl Clone for NonZeroU32impl<Idx> Clone for RangeFrom<Idx> where
Idx: Clone,impl<I> Clone for Cloned<I> where
I: Clone,impl Clone for SearchStepimpl Clone for u128impl Clone for Durationimpl Clone for ToUppercaseimpl Clone for NonZeroU8impl<'a, T> Clone for std::slice::Iter<'a, T>impl Clone for u64impl Clone for Wakerimpl<T> Clone for Once<T> where
T: Clone,impl<'a, A> Clone for std::option::Iter<'a, A>impl<Idx> Clone for RangeTo<Idx> where
Idx: Clone,impl<T> Clone for PhantomData<T> where
T: ?Sized,impl<I, U, F> Clone for FlatMap<I, U, F> where
F: Clone,
I: Clone,
U: Clone + IntoIterator,
<U as IntoIterator>::IntoIter: Clone,impl Clone for i8impl Clone for std::cmp::Orderingimpl<A, B> Clone for Zip<A, B> where
A: Clone,
B: Clone,impl Clone for DecodeUtf16Errorimpl<I> Clone for Cycle<I> where
I: Clone,impl<T> Clone for Bound<T> where
T: Clone,impl<'a, P> Clone for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for boolimpl<'a> Clone for Chars<'a>impl Clone for Pinnedimpl<I> Clone for Enumerate<I> where
I: Clone,impl Clone for NonZeroU128impl<T> Clone for Option<T> where
T: Clone,impl<'a> Clone for Lines<'a>impl Clone for LayoutErrimpl Clone for f64impl<'a, P> Clone for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<I> Clone for Peekable<I> where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,impl Clone for NonZeroU64impl Clone for CannotReallocInPlaceimpl<'a> Clone for CharIndices<'a>impl<I, P> Clone for TakeWhile<I, P> where
I: Clone,
P: Clone,impl<Idx> Clone for RangeInclusive<Idx> where
Idx: Clone,impl<T> Clone for Rev<T> where
T: Clone,impl<I, St, F> Clone for Scan<I, St, F> where
F: Clone,
I: Clone,
St: Clone,impl Clone for charimpl<I> Clone for DecodeUtf16<I> where
I: Clone + Iterator<Item = u16>,impl<'a> Clone for Arguments<'a>impl<T> Clone for Arc<T> where
T: ?Sized,impl<T> Clone for std::sync::Weak<T> where
T: ?Sized,impl<'a, T> Clone for std::collections::btree_set::Union<'a, T>impl<T> Clone for Vec<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::Iter<'a, T>impl<T> Clone for Box<[T]> where
T: Clone,impl<T> Clone for BinaryHeap<T> where
T: Clone,impl Clone for Box<str>impl<'a, K, V> Clone for std::collections::btree_map::Iter<'a, K, V>impl<T> Clone for VecDeque<T> where
T: Clone,impl<'a, T> Clone for std::collections::btree_set::SymmetricDifference<'a, T>impl<'a, B> Clone for Cow<'a, B> where
B: ToOwned + ?Sized,impl<'a, T> Clone for std::collections::btree_set::Intersection<'a, T>impl<'a, K, V> Clone for std::collections::btree_map::Range<'a, K, V>impl Clone for ParseErrorimpl<T> Clone for std::rc::Weak<T> where
T: ?Sized,impl<'a, K, V> Clone for std::collections::btree_map::Keys<'a, K, V>impl<T> Clone for LinkedList<T> where
T: Clone,impl<K, V> Clone for BTreeMap<K, V> where
K: Clone,
V: Clone,impl<'a, T> Clone for std::collections::linked_list::Iter<'a, T>impl<'a, T> Clone for std::collections::btree_set::Range<'a, T>impl<T> Clone for BTreeSet<T> where
T: Clone,impl<'a, T> Clone for std::collections::vec_deque::Iter<'a, T>impl Clone for Globalimpl<'a, T> Clone for std::collections::btree_set::Difference<'a, T>impl<T> Clone for Rc<T> where
T: ?Sized,impl<T> Clone for std::collections::linked_list::IntoIter<T> where
T: Clone,impl<T> Clone for Box<T> where
T: Clone,impl<T> Clone for std::vec::IntoIter<T> where
T: Clone,impl<T> Clone for std::collections::binary_heap::IntoIter<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Values<'a, K, V>impl<T> Clone for std::collections::vec_deque::IntoIter<T> where
T: Clone,impl Clone for CollectionAllocErrimpl<'a, T> Clone for std::collections::binary_heap::Iter<'a, T>impl Clone for Stringimpl Clone for ThreadIdimpl Clone for Threadimpl<K: Clone, V: Clone, S: Clone> Clone for HashMap<K, V, S>impl<'a, K, V> Clone for std::collections::hash_map::Iter<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Values<'a, K, V>impl Clone for RandomStateimpl Clone for DefaultHasherimpl<T: Clone, S: Clone> Clone for HashSet<T, S>impl<'a, K> Clone for std::collections::hash_set::Iter<'a, K>impl<'a, T, S> Clone for std::collections::hash_set::Intersection<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Difference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::SymmetricDifference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Union<'a, T, S>impl Clone for VarErrorimpl Clone for CStringimpl Clone for NulErrorimpl Clone for FromBytesWithNulErrorimpl Clone for IntoStringErrorimpl Clone for Box<CStr>impl Clone for OsStringimpl Clone for Box<OsStr>impl Clone for Metadataimpl Clone for OpenOptionsimpl Clone for Permissionsimpl Clone for FileTypeimpl<T: Clone> Clone for Cursor<T>impl Clone for ErrorKindimpl Clone for SeekFromimpl Clone for IpAddrimpl Clone for Ipv6MulticastScopeimpl Clone for Ipv4Addrimpl Clone for Ipv6Addrimpl Clone for std::net::SocketAddrimpl Clone for SocketAddrV4impl Clone for SocketAddrV6impl Clone for AddrParseErrorimpl Clone for Shutdownimpl Clone for statimpl<'a> Clone for Prefix<'a>impl<'a> Clone for PrefixComponent<'a>impl<'a> Clone for Component<'a>impl<'a> Clone for Components<'a>impl<'a> Clone for std::path::Iter<'a>impl<'a> Clone for Ancestors<'a>impl Clone for PathBufimpl Clone for Box<Path>impl Clone for StripPrefixErrorimpl Clone for Outputimpl Clone for ExitStatusimpl Clone for ExitCodeimpl<T: Clone> Clone for SendError<T>impl Clone for RecvErrorimpl Clone for TryRecvErrorimpl Clone for RecvTimeoutErrorimpl<T: Clone> Clone for TrySendError<T>impl<T> Clone for Sender<T>impl<T> Clone for SyncSender<T>impl Clone for WaitTimeoutResultimpl Clone for Instantimpl Clone for SystemTimeimpl Clone for SystemTimeErrorimpl<'a> Clone for EncodeWide<'a>impl Clone for std::os::unix::net::SocketAddr