Trait std::clone::Clone 1.0.0
[−]
[src]
pub trait Clone {
fn clone(&self) -> Self;
fn clone_from(&mut self, source: &Self) { ... }
}A common trait for the ability to explicitly duplicate an object.
Differs from Copy in that Copy is implicit and extremely inexpensive, while
Clone is always explicit and may or may not be expensive. In order to enforce
these characteristics, Rust does not allow you to reimplement Copy, but you
may reimplement Clone and run arbitrary code.
Since Clone is more general than Copy, you can automatically make anything
Copy be Clone as well.
Derivable
This trait can be used with #[derive] if all fields are Clone. The derived
implementation of clone calls clone on each field.
How can I implement Clone?
Types that are Copy should have a trivial implementation of Clone. More formally:
if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;.
Manual implementations should be careful to uphold this invariant; however, unsafe code
must not rely on it to ensure memory safety.
An example is an array holding more than 32 elements of a type that is Clone; the standard
library only implements Clone up until arrays of size 32. In this case, the implementation of
Clone cannot be derived, but can be implemented as:
#[derive(Copy)] struct Stats { frequencies: [i32; 100], } impl Clone for Stats { fn clone(&self) -> Stats { *self } }Run
Required Methods
fn clone(&self) -> Self
Provided Methods
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source.
a.clone_from(&b) is equivalent to a = b.clone() in functionality,
but can be overridden to reuse the resources of a to avoid unnecessary
allocations.
Implementors
impl Clone for StandardNormalimpl Clone for Isaac64Rngimpl Clone for IsaacRngimpl Clone for LogNormalimpl Clone for ReseedWithDefaultimpl Clone for XorShiftRngimpl Clone for ChaChaRngimpl Clone for Expimpl Clone for Exp1impl Clone for Normalimpl Clone for _Unwind_Reason_Codeimpl Clone for _Unwind_Actionimpl<I> Clone for DecodeUtf16<I> where
I: Clone + Iterator<Item = u16>,impl<'a> Clone for SplitWhitespace<'a>impl Clone for DecodeUtf16Errorimpl<I> Clone for Utf16Encoder<I> where
I: Clone,impl<Ret, A, B, C, D> Clone for extern "C" fn(A, B, C, D, ...) -> Retimpl<Ret> Clone for fn() -> Retimpl Clone for EscapeDebugimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl Clone for u8impl<Ret, A, B> Clone for extern "C" fn(A, B, ...) -> Retimpl<I> Clone for Enumerate<I> where
I: Clone,impl Clone for i128impl<Ret, A, B, C, D> Clone for unsafe extern "C" fn(A, B, C, D, ...) -> Retimpl<T> Clone for [T; 16] where
T: Copy,impl Clone for ParseFloatErrorimpl<T> Clone for [T; 6] where
T: Copy,impl<I, F> Clone for FilterMap<I, F> where
F: Clone,
I: Clone,impl<Ret, A, B, C> Clone for unsafe extern "C" fn(A, B, C) -> Retimpl<Ret> Clone for unsafe fn() -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, P> Clone for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for fn(A, B, C, D, E, F, G, H) -> Retimpl<T> Clone for [T; 4] where
T: Copy,impl<I> Clone for Cloned<I> where
I: Clone,impl<Ret, A> Clone for fn(A) -> Retimpl<I> Clone for StepBy<I> where
I: Clone,impl<I, St, F> Clone for Scan<I, St, F> where
F: Clone,
I: Clone,
St: Clone,impl<I> Clone for Peekable<I> where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,impl<T> Clone for Unique<T> where
T: ?Sized,impl<Ret, A, B> Clone for extern "C" fn(A, B) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<A, B, C, D, E> Clone for (A, B, C, D, E) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,impl<A, B, C, D, E, F, G, H, I, J> Clone for (A, B, C, D, E, F, G, H, I, J) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,impl<A> Clone for std::option::IntoIter<A> where
A: Clone,impl Clone for ParseCharErrorimpl<Ret, A, B, C, D> Clone for unsafe fn(A, B, C, D) -> Retimpl<'a, T, P> Clone for std::slice::Split<'a, T, P> where
P: Clone + FnMut(&T) -> bool,impl<T> Clone for Once<T> where
T: Clone,impl Clone for u32impl Clone for SipHasherimpl<T> Clone for Option<T> where
T: Clone,impl Clone for TypeIdimpl<T> Clone for *mut T where
T: ?Sized,impl<A, B, C, D, E, F, G, H, I> Clone for (A, B, C, D, E, F, G, H, I) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,impl Clone for isizeimpl<I> Clone for DecodeUtf8<I> where
I: Clone + Iterator<Item = u8>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl Clone for u64impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<'a> Clone for LinesAny<'a>impl<T> Clone for [T; 29] where
T: Copy,impl<T> Clone for [T; 32] where
T: Copy,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<T> Clone for Empty<T>impl<T> Clone for [T; 13] where
T: Copy,impl<'a> Clone for Lines<'a>impl<'a, A> Clone for std::option::Iter<'a, A>impl<T> Clone for Cell<T> where
T: Copy,impl<T> Clone for [T; 23] where
T: Copy,impl Clone for f64impl<'a, T> Clone for Windows<'a, T>impl<Ret, A> Clone for unsafe fn(A) -> Retimpl<Ret, A, B, C, D> Clone for fn(A, B, C, D) -> Retimpl<'a, P> Clone for SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<T> Clone for [T; 11] where
T: Copy,impl<T> Clone for [T; 12] where
T: Copy,impl<T> Clone for Rev<T> where
T: Clone,impl<A, B> Clone for Chain<A, B> where
A: Clone,
B: Clone,impl Clone for u128impl<T> Clone for [T; 1] where
T: Copy,impl Clone for i32impl Clone for f32impl<Ret, A, B, C, D, E, F, G> Clone for fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl Clone for RangeFullimpl Clone for charimpl<Ret, A> Clone for extern "C" fn(A) -> Retimpl<T> Clone for [T; 10] where
T: Copy,impl<T> Clone for [T; 27] where
T: Copy,impl<T, E> Clone for Result<T, E> where
E: Clone,
T: Clone,impl<'a> Clone for Bytes<'a>impl<Ret, A, B, C, D, E> Clone for unsafe extern "C" fn(A, B, C, D, E) -> Retimpl<T> Clone for [T; 7] where
T: Copy,impl<Ret, A, B, C, D, E, F> Clone for unsafe extern "C" fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<I, U, F> Clone for FlatMap<I, U, F> where
F: Clone,
I: Clone,
U: Clone + IntoIterator,
<U as IntoIterator>::IntoIter: Clone,
<U as IntoIterator>::IntoIter: Clone,impl<Ret> Clone for unsafe extern "C" fn() -> Retimpl<'a, P> Clone for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<A, B, C, D, E, F, G, H, I, J, K, L> Clone for (A, B, C, D, E, F, G, H, I, J, K, L) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,
K: Clone,
L: Clone,impl<Ret, A, B, C, D, E, F, G> Clone for extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<T> Clone for [T; 17] where
T: Copy,impl<Ret, A, B, C, D, E> Clone for fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E, F> Clone for extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<I> Clone for Cycle<I> where
I: Clone,impl<A, B, C> Clone for (A, B, C) where
A: Clone,
B: Clone,
C: Clone,impl<T> Clone for Discriminant<T>impl<T> Clone for [T; 28] where
T: Copy,impl<T> Clone for [T; 0] where
T: Copy,impl<Ret, A, B, C, D> Clone for extern "C" fn(A, B, C, D) -> Retimpl<Ret, A> Clone for unsafe extern "C" fn(A) -> Retimpl Clone for FpCategoryimpl<'a, P> Clone for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, P> Clone for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for i16impl<Ret, A, B> Clone for unsafe extern "C" fn(A, B) -> Retimpl<Ret, A> Clone for extern "C" fn(A, ...) -> Retimpl<Ret, A, B, C, D, E> Clone for unsafe extern "C" fn(A, B, C, D, E, ...) -> Retimpl Clone for Utf8Errorimpl<'a> Clone for Arguments<'a>impl<'a, P> Clone for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<T> Clone for [T; 30] where
T: Copy,impl<T> Clone for [T; 14] where
T: Copy,impl<Ret, A, B, C, D, E, F> Clone for fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl<A> Clone for (A,) where
A: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<T> Clone for *const T where
T: ?Sized,impl Clone for std::sync::atomic::Orderingimpl Clone for usizeimpl<I> Clone for Fuse<I> where
I: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C> Clone for unsafe extern "C" fn(A, B, C, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<Idx> Clone for RangeTo<Idx> where
Idx: Clone,impl<I, F> Clone for Map<I, F> where
F: Clone,
I: Clone,impl<T> Clone for [T; 21] where
T: Copy,impl<'a, T> Clone for Chunks<'a, T>impl Clone for i8impl<Ret, A, B, C, D, E, F, G> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<T> Clone for [T; 15] where
T: Copy,impl<Ret, A, B, C> Clone for unsafe fn(A, B, C) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<I, F> Clone for Inspect<I, F> where
F: Clone,
I: Clone,impl<Ret, A, B, C, D, E, F> Clone for unsafe fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Clone for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<Ret, A, B, C> Clone for extern "C" fn(A, B, C, ...) -> Retimpl<T> Clone for [T; 22] where
T: Copy,impl<A, B, C, D, E, F, G> Clone for (A, B, C, D, E, F, G) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<Ret, A, B> Clone for unsafe fn(A, B) -> Retimpl<T> Clone for [T; 19] where
T: Copy,impl Clone for SipHasher24impl<T> Clone for [T; 5] where
T: Copy,impl<T> Clone for [T; 25] where
T: Copy,impl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<A> Clone for Repeat<A> where
A: Clone,impl Clone for TryFromIntErrorimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<'a, T, P> Clone for std::slice::RSplit<'a, T, P> where
P: Clone + FnMut(&T) -> bool,
T: 'a + Clone,impl<H> Clone for BuildHasherDefault<H>impl<Ret, A, B, C, D, E> Clone for extern "C" fn(A, B, C, D, E) -> Retimpl<T> Clone for RefCell<T> where
T: Clone,impl<A, B, C, D> Clone for (A, B, C, D) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,impl<Ret, A, B, C, D, E, F, G, H> Clone for extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<I> Clone for Skip<I> where
I: Clone,impl<T> Clone for [T; 26] where
T: Copy,impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,impl<T> Clone for [T; 20] where
T: Copy,impl Clone for EscapeDefaultimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<T> Clone for NonZero<T> where
T: Zeroable + Clone,impl<A, B> Clone for (A, B) where
A: Clone,
B: Clone,impl<Ret, A, B, C, D, E> Clone for extern "C" fn(A, B, C, D, E, ...) -> Retimpl<'a, 'b> Clone for StrSearcher<'a, 'b>impl<T> Clone for Shared<T> where
T: ?Sized,impl<Ret, A, B, C, D, E, F> Clone for extern "C" fn(A, B, C, D, E, F) -> Retimpl<Idx> Clone for RangeFrom<Idx> where
Idx: Clone,impl<Ret, A, B, C, D> Clone for unsafe extern "C" fn(A, B, C, D) -> Retimpl<I> Clone for Take<I> where
I: Clone,impl<T> Clone for Wrapping<T> where
T: Clone,impl<Ret, A, B, C> Clone for fn(A, B, C) -> Retimpl<'a, T> Clone for std::result::Iter<'a, T>impl<'a, P> Clone for RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<'a, T> Clone for std::slice::Iter<'a, T>impl<T> Clone for [T; 31] where
T: Copy,impl<Ret, A, B> Clone for unsafe extern "C" fn(A, B, ...) -> Retimpl<'a> Clone for Chars<'a>impl<Ret> Clone for extern "C" fn() -> Retimpl<A, B, C, D, E, F> Clone for (A, B, C, D, E, F) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,impl<A, B> Clone for Zip<A, B> where
A: Clone,
B: Clone,impl Clone for i64impl Clone for boolimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a, T> Clone for &'a T where
T: ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<T> Clone for [T; 2] where
T: Copy,impl<Ret, A, B> Clone for fn(A, B) -> Retimpl Clone for SipHasher13impl<T> Clone for [T; 24] where
T: Copy,impl<A, B, C, D, E, F, G, H, I, J, K> Clone for (A, B, C, D, E, F, G, H, I, J, K) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,
I: Clone,
J: Clone,
K: Clone,impl<I, P> Clone for Filter<I, P> where
I: Clone,
P: Clone,impl<'a, P> Clone for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl<T> Clone for [T; 18] where
T: Copy,impl Clone for u16impl Clone for CharTryFromErrorimpl Clone for ()impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E> Clone for unsafe fn(A, B, C, D, E) -> Retimpl<'a, F> Clone for CharPredicateSearcher<'a, F> where
F: Clone + FnMut(char) -> bool,impl Clone for std::cmp::Orderingimpl<'a> Clone for CharSearcher<'a>impl<'a, P> Clone for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for SearchStepimpl<'a> Clone for CharIndices<'a>impl<T> Clone for [T; 9] where
T: Copy,impl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F> Clone for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Clone for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Clone for fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Idx> Clone for std::ops::Range<Idx> where
Idx: Clone,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Clone for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<'a, P> Clone for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Clone,impl Clone for EscapeUnicodeimpl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>impl<Ret, A, B, C, D, E, F, G> Clone for unsafe fn(A, B, C, D, E, F, G) -> Retimpl<I, P> Clone for TakeWhile<I, P> where
I: Clone,
P: Clone,impl<T> Clone for [T; 8] where
T: Copy,impl Clone for TraitObjectimpl<Ret, A> Clone for unsafe extern "C" fn(A, ...) -> Retimpl<T> Clone for [T; 3] where
T: Copy,impl Clone for Errorimpl<A, B, C, D, E, F, G, H> Clone for (A, B, C, D, E, F, G, H) where
A: Clone,
B: Clone,
C: Clone,
D: Clone,
E: Clone,
F: Clone,
G: Clone,
H: Clone,impl Clone for ParseIntErrorimpl<Ret, A, B, C> Clone for extern "C" fn(A, B, C) -> Retimpl<Idx> Clone for RangeInclusive<Idx> where
Idx: Clone,impl<Ret, A, B, C, D, E, F, G> Clone for extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<T> Clone for PhantomData<T> where
T: ?Sized,impl<I, P> Clone for SkipWhile<I, P> where
I: Clone,
P: Clone,impl Clone for ParseBoolErrorimpl Clone for hostentimpl Clone for sockaddr_storageimpl Clone for fsid_timpl Clone for cmsghdrimpl Clone for signalfd_siginfoimpl Clone for fd_setimpl Clone for sockaddr_in6impl Clone for lconvimpl Clone for msqid_dsimpl Clone for tmimpl Clone for sem_timpl Clone for tmsimpl Clone for msginfoimpl Clone for sockaddr_nlimpl Clone for sockaddr_llimpl Clone for glob_timpl Clone for siginfo_timpl Clone for sockaddr_unimpl Clone for mmsghdrimpl Clone for mq_attrimpl Clone for dirent64impl Clone for epoll_eventimpl Clone for pollfdimpl Clone for cpu_set_timpl Clone for sched_paramimpl Clone for sembufimpl Clone for sigactionimpl Clone for stack_timpl Clone for addrinfoimpl Clone for rlimit64impl Clone for sockaddrimpl Clone for statfsimpl Clone for glob64_timpl Clone for dqblkimpl Clone for __timevalimpl Clone for statvfsimpl Clone for shmid_dsimpl Clone for in_addrimpl Clone for sigeventimpl Clone for direntimpl Clone for pthread_attr_timpl Clone for sigvalimpl Clone for utmpximpl Clone for winsizeimpl Clone for __exit_statusimpl Clone for pthread_condattr_timpl Clone for pthread_mutexattr_timpl Clone for utsnameimpl Clone for sigset_timpl Clone for msghdrimpl Clone for timevalimpl Clone for Dl_infoimpl Clone for timespecimpl Clone for if_nameindeximpl Clone for termiosimpl Clone for sysinfoimpl Clone for aiocbimpl Clone for utimbufimpl Clone for rusageimpl Clone for libc::unix::notbsd::linux::other::b64::aarch64::statimpl Clone for ip_mreqimpl Clone for groupimpl Clone for ipc_permimpl Clone for itimervalimpl Clone for rlimitimpl Clone for stat64impl Clone for pthread_cond_timpl Clone for iovecimpl Clone for pthread_rwlock_timpl Clone for sockaddr_inimpl Clone for in6_addrimpl Clone for lingerimpl Clone for spwdimpl Clone for ifaddrsimpl Clone for flockimpl Clone for passwdimpl Clone for ucredimpl Clone for pthread_mutex_timpl Clone for ipv6_mreqimpl<T> Clone for Rc<T> where
T: ?Sized,impl<'a, K, V> Clone for std::collections::btree_map::Range<'a, K, V>impl<'a, T> Clone for std::collections::btree_set::Range<'a, T>impl<T> Clone for VecDeque<T> where
T: Clone,impl<T> Clone for Arc<T> where
T: ?Sized,impl<T> Clone for std::sync::Weak<T> where
T: ?Sized,impl Clone for AllocErrimpl<T> Clone for Bound<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Values<'a, K, V>impl<'a, T> Clone for std::collections::btree_set::Iter<'a, T>impl<T> Clone for std::vec::IntoIter<T> where
T: Clone,impl Clone for CannotReallocInPlaceimpl<T> Clone for Box<[T]> where
T: Clone,impl<T> Clone for Box<T> where
T: Clone,impl Clone for Heapimpl<T> Clone for LinkedList<T> where
T: Clone,impl Clone for Box<str>impl<T> Clone for std::rc::Weak<T> where
T: ?Sized,impl<T> Clone for BTreeSet<T> where
T: Clone,impl<'a> Clone for EncodeUtf16<'a>impl<'a, K, V> Clone for std::collections::btree_map::Keys<'a, K, V>impl<T> Clone for std::collections::linked_list::IntoIter<T> where
T: Clone,impl Clone for Stringimpl<T> Clone for Vec<T> where
T: Clone,impl<'a, T> Clone for std::collections::vec_deque::Iter<'a, T>impl Clone for ParseErrorimpl<T> Clone for std::collections::vec_deque::IntoIter<T> where
T: Clone,impl<T> Clone for std::collections::binary_heap::IntoIter<T> where
T: Clone,impl<'a, K, V> Clone for std::collections::btree_map::Iter<'a, K, V>impl Clone for Layoutimpl<T> Clone for BinaryHeap<T> where
T: Clone,impl<K, V> Clone for BTreeMap<K, V> where
K: Clone,
V: Clone,impl<'a, T> Clone for std::collections::linked_list::Iter<'a, T>impl<'a, T> Clone for std::collections::btree_set::SymmetricDifference<'a, T>impl<'a, T> Clone for std::collections::btree_set::Intersection<'a, T>impl<'a, T> Clone for std::collections::btree_set::Union<'a, T>impl Clone for ExchangeHeapSingletonimpl<'a, T> Clone for std::collections::binary_heap::Iter<'a, T>impl<'a, T> Clone for std::collections::btree_set::Difference<'a, T>impl<'a, B> Clone for Cow<'a, B> where
B: ToOwned + ?Sized,impl Clone for LocalKeyStateimpl Clone for ThreadIdimpl Clone for Threadimpl<K: Clone, V: Clone, S: Clone> Clone for HashMap<K, V, S>impl<'a, K, V> Clone for std::collections::hash_map::Iter<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V> Clone for std::collections::hash_map::Values<'a, K, V>impl Clone for RandomStateimpl Clone for DefaultHasherimpl<T: Clone, S: Clone> Clone for HashSet<T, S>impl<'a, K> Clone for std::collections::hash_set::Iter<'a, K>impl<'a, T, S> Clone for std::collections::hash_set::Intersection<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Difference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::SymmetricDifference<'a, T, S>impl<'a, T, S> Clone for std::collections::hash_set::Union<'a, T, S>impl Clone for VarErrorimpl Clone for CStringimpl Clone for NulErrorimpl Clone for FromBytesWithNulErrorimpl Clone for IntoStringErrorimpl Clone for OsStringimpl Clone for Metadataimpl Clone for OpenOptionsimpl Clone for Permissionsimpl Clone for FileTypeimpl<T: Clone> Clone for Cursor<T>impl Clone for ErrorKindimpl Clone for SeekFromimpl Clone for IpAddrimpl Clone for Ipv6MulticastScopeimpl Clone for Ipv4Addrimpl Clone for Ipv6Addrimpl Clone for std::net::SocketAddrimpl Clone for SocketAddrV4impl Clone for SocketAddrV6impl Clone for AddrParseErrorimpl Clone for Shutdownimpl Clone for std::os::linux::raw::statimpl<'a> Clone for Prefix<'a>impl<'a> Clone for PrefixComponent<'a>impl<'a> Clone for Component<'a>impl<'a> Clone for Components<'a>impl<'a> Clone for std::path::Iter<'a>impl Clone for PathBufimpl Clone for StripPrefixErrorimpl Clone for Outputimpl Clone for ExitStatusimpl<T: Clone> Clone for SendError<T>impl Clone for RecvErrorimpl Clone for TryRecvErrorimpl Clone for RecvTimeoutErrorimpl<T: Clone> Clone for TrySendError<T>impl<T> Clone for Sender<T>impl<T> Clone for SyncSender<T>impl Clone for WaitTimeoutResultimpl Clone for Durationimpl Clone for Instantimpl Clone for SystemTimeimpl Clone for SystemTimeErrorimpl Clone for std::os::unix::net::SocketAddr