Trait std::cmp::PartialEq 1.0.0
[−]
[src]
#[lang = "eq"]pub trait PartialEq<Rhs = Self> where
Rhs: ?Sized, { fn eq(&self, other: &Rhs) -> bool; fn ne(&self, other: &Rhs) -> bool { ... } }
Trait for equality comparisons which are partial equivalence relations.
This trait allows for partial equality, for types that do not have a full
equivalence relation. For example, in floating point numbers NaN != NaN,
so floating point types implement PartialEq but not Eq.
Formally, the equality must be (for all a, b and c):
- symmetric:
a == bimpliesb == a; and - transitive:
a == bandb == cimpliesa == c.
Note that these requirements mean that the trait itself must be implemented
symmetrically and transitively: if T: PartialEq<U> and U: PartialEq<V>
then U: PartialEq<T> and T: PartialEq<V>.
Derivable
This trait can be used with #[derive]. When derived on structs, two
instances are equal if all fields are equal, and not equal if any fields
are not equal. When derived on enums, each variant is equal to itself
and not equal to the other variants.
How can I implement PartialEq?
PartialEq only requires the eq method to be implemented; ne is defined
in terms of it by default. Any manual implementation of ne must respect
the rule that eq is a strict inverse of ne; that is, !(a == b) if and
only if a != b.
Implementations of PartialEq, PartialOrd, and Ord must agree with
each other. It's easy to accidentally make them disagree by deriving some
of the traits and manually implementing others.
An example implementation for a domain in which two books are considered the same book if their ISBN matches, even if the formats differ:
enum BookFormat { Paperback, Hardback, Ebook } struct Book { isbn: i32, format: BookFormat, } impl PartialEq for Book { fn eq(&self, other: &Book) -> bool { self.isbn == other.isbn } } let b1 = Book { isbn: 3, format: BookFormat::Paperback }; let b2 = Book { isbn: 3, format: BookFormat::Ebook }; let b3 = Book { isbn: 10, format: BookFormat::Paperback }; assert!(b1 == b2); assert!(b1 != b3);Run
Examples
let x: u32 = 0; let y: u32 = 1; assert_eq!(x == y, false); assert_eq!(x.eq(&y), false);Run
Required Methods
fn eq(&self, other: &Rhs) -> bool
This method tests for self and other values to be equal, and is used
by ==.
Provided Methods
Implementations on Foreign Types
impl PartialEq<InvalidSequence> for InvalidSequence[src]
impl PartialEq<InvalidSequence> for InvalidSequencefn eq(&self, __arg_0: &InvalidSequence) -> bool[src]
fn eq(&self, __arg_0: &InvalidSequence) -> boolfn ne(&self, __arg_0: &InvalidSequence) -> bool[src]
fn ne(&self, __arg_0: &InvalidSequence) -> boolimpl PartialEq<AllocErr> for AllocErr[src]
impl PartialEq<AllocErr> for AllocErrimpl PartialEq<Layout> for Layout[src]
impl PartialEq<Layout> for Layoutimpl PartialEq<CannotReallocInPlace> for CannotReallocInPlace[src]
impl PartialEq<CannotReallocInPlace> for CannotReallocInPlaceimpl<T> PartialEq<NonZero<T>> for NonZero<T> where
T: Zeroable + PartialEq<T>, [src]
impl<T> PartialEq<NonZero<T>> for NonZero<T> where
T: Zeroable + PartialEq<T>, impl<'a> PartialEq<Utf8LossyChunk<'a>> for Utf8LossyChunk<'a>[src]
impl<'a> PartialEq<Utf8LossyChunk<'a>> for Utf8LossyChunk<'a>fn eq(&self, __arg_0: &Utf8LossyChunk<'a>) -> bool[src]
fn eq(&self, __arg_0: &Utf8LossyChunk<'a>) -> boolfn ne(&self, __arg_0: &Utf8LossyChunk<'a>) -> bool[src]
fn ne(&self, __arg_0: &Utf8LossyChunk<'a>) -> boolImplementors
impl PartialEq<u32x8> for u32x8impl PartialEq<u8> for u8impl<'a, 'b, A, B> PartialEq<[B]> for [A; 26] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 23] where
A: PartialEq<B>,impl<A, B, C, D, E, F, G, H, I, J, K> PartialEq<(A, B, C, D, E, F, G, H, I, J, K)> for (A, B, C, D, E, F, G, H, I, J, K) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G>,
H: PartialEq<H>,
I: PartialEq<I>,
J: PartialEq<J>,
K: PartialEq<K> + ?Sized,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 9] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 25] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 30] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 30] where
A: PartialEq<B>,impl<Ret, A, B, C> PartialEq<extern "C" fn(A, B, C, ...) -> Ret> for extern "C" fn(A, B, C, ...) -> Retimpl<Ret, A> PartialEq<unsafe extern "C" fn(A) -> Ret> for unsafe extern "C" fn(A) -> Retimpl PartialEq<SearchStep> for SearchStepimpl<A, B, C, D, E, F, G, H> PartialEq<(A, B, C, D, E, F, G, H)> for (A, B, C, D, E, F, G, H) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G>,
H: PartialEq<H> + ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<fn(A, B, C, D, E, F, G, H, I) -> Ret> for fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 22]> for [A; 22] where
A: PartialEq<B>,impl PartialEq<f64x2> for f64x2impl PartialEq<f32x2> for f32x2impl<'a, 'b, A, B> PartialEq<[A; 9]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<f64x8> for f64x8impl<'a, 'b, A, B> PartialEq<[A; 32]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 14]> for [A; 14] where
A: PartialEq<B>,impl PartialEq<u8x4> for u8x4impl PartialEq<u8x16> for u8x16impl<'a, 'b, A, B> PartialEq<[A; 15]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 8]> for [B] where
B: PartialEq<A>,impl<Idx> PartialEq<RangeInclusive<Idx>> for RangeInclusive<Idx> where
Idx: PartialEq<Idx>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 26] where
A: PartialEq<B>,impl<Ret> PartialEq<unsafe extern "C" fn() -> Ret> for unsafe extern "C" fn() -> Retimpl<Ret, A, B> PartialEq<extern "C" fn(A, B, ...) -> Ret> for extern "C" fn(A, B, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 1]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 3] where
A: PartialEq<B>,impl PartialEq<i64> for i64impl<'a, 'b, A, B> PartialEq<[A; 30]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 5] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 19]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 16]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 15] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 32]> for &'b [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl PartialEq<i32x8> for i32x8impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 8] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 20]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 23] where
A: PartialEq<B>,impl PartialEq<f32x16> for f32x16impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 2] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 0]> for &'b [B] where
B: PartialEq<A>,impl<T> PartialEq<Reverse<T>> for Reverse<T> where
T: PartialEq<T>,impl PartialEq<NonZeroIsize> for NonZeroIsizeimpl<'a, 'b, A, B> PartialEq<[B; 6]> for [A; 6] where
A: PartialEq<B>,impl<A, B> PartialEq<(A, B)> for (A, B) where
A: PartialEq<A>,
B: PartialEq<B> + ?Sized,impl<A, B, C, D, E, F, G, H, I, J> PartialEq<(A, B, C, D, E, F, G, H, I, J)> for (A, B, C, D, E, F, G, H, I, J) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G>,
H: PartialEq<H>,
I: PartialEq<I>,
J: PartialEq<J> + ?Sized,impl<'a, 'b, A, B> PartialEq<[A; 26]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 1] where
A: PartialEq<B>,impl PartialEq<b8x4> for b8x4impl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 9]> for [A; 9] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 12]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 19]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<u8x2> for u8x2impl<'a, 'b, A, B> PartialEq<[B; 3]> for [A; 3] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b B> for &'a A where
A: PartialEq<B> + ?Sized,
B: ?Sized,impl PartialEq<i32x16> for i32x16impl<'a, 'b, A, B> PartialEq<[B; 30]> for [A; 30] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 6] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 20] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 21]> for &'b [B] where
B: PartialEq<A>,impl<T> PartialEq<Wrapping<T>> for Wrapping<T> where
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<[A; 29]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<i8> for i8impl PartialEq<u64> for u64impl<Ret, A, B, C, D, E, F> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 23]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 11]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<!> for !impl<'a, 'b, A, B> PartialEq<[A; 28]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 5]> for [A; 5] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 23]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<u64x8> for u64x8impl<'a, 'b, A, B> PartialEq<[B; 15]> for [A; 15] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 22]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G> PartialEq<extern "C" fn(A, B, C, D, E, F, G, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 4]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 23]> for [A; 23] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b B> for &'a mut A where
A: PartialEq<B> + ?Sized,
B: ?Sized,impl<Ret, A, B> PartialEq<unsafe extern "C" fn(A, B) -> Ret> for unsafe extern "C" fn(A, B) -> Retimpl<Ret, A, B, C> PartialEq<unsafe fn(A, B, C) -> Ret> for unsafe fn(A, B, C) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 13] where
A: PartialEq<B>,impl<Ret, A, B> PartialEq<unsafe fn(A, B) -> Ret> for unsafe fn(A, B) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 27]> for [A; 27] where
A: PartialEq<B>,impl PartialEq<i8x16> for i8x16impl<'a, 'b, A, B> PartialEq<[B; 10]> for [A; 10] where
A: PartialEq<B>,impl<Ret, A, B, C, D> PartialEq<unsafe extern "C" fn(A, B, C, D, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 1]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<i64x2> for i64x2impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 1] where
A: PartialEq<B>,impl PartialEq<Duration> for Durationimpl<'a, 'b, A, B> PartialEq<[A; 6]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 17] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 24]> for [A; 24] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 3]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<f32x4> for f32x4impl<Ret, A, B, C, D, E, F, G, H> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<Idx> PartialEq<RangeFrom<Idx>> for RangeFrom<Idx> where
Idx: PartialEq<Idx>,impl<'a, 'b, A, B> PartialEq<[B; 18]> for [A; 18] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 3]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 29] where
A: PartialEq<B>,impl PartialEq<i8x8> for i8x8impl<T> PartialEq<*const T> for *const T where
T: ?Sized,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 15] where
A: PartialEq<B>,impl PartialEq<u32> for u32impl<'a, 'b, A, B> PartialEq<[A; 18]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 18]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 18]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 17] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 14]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F> PartialEq<extern "C" fn(A, B, C, D, E, F, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Y, R> PartialEq<GeneratorState<Y, R>> for GeneratorState<Y, R> where
R: PartialEq<R>,
Y: PartialEq<Y>,impl PartialEq<i16x32> for i16x32impl PartialEq<i32> for i32impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 32] where
A: PartialEq<B>,impl<Ret> PartialEq<unsafe fn() -> Ret> for unsafe fn() -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 25] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 31]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 31] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 25]> for [A; 25] where
A: PartialEq<B>,impl PartialEq<i8x64> for i8x64impl<Ret, A, B, C, D, E, F, G> PartialEq<unsafe fn(A, B, C, D, E, F, G) -> Ret> for unsafe fn(A, B, C, D, E, F, G) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 23] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 17]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<i8x32> for i8x32impl<'a, 'b, A, B> PartialEq<[A; 28]> for &'b [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 4]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 27]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 18] where
A: PartialEq<B>,impl PartialEq<isize> for isizeimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 20] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 25]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 11] where
A: PartialEq<B>,impl PartialEq<b8x2> for b8x2impl<Ret, A> PartialEq<extern "C" fn(A) -> Ret> for extern "C" fn(A) -> Retimpl PartialEq<NonZeroI8> for NonZeroI8impl<Ret, A> PartialEq<unsafe extern "C" fn(A, ...) -> Ret> for unsafe extern "C" fn(A, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 8] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 11]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 30]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<NonZeroI16> for NonZeroI16impl<T> PartialEq<PhantomData<T>> for PhantomData<T> where
T: ?Sized,impl PartialEq<f32x8> for f32x8impl<Ret, A> PartialEq<extern "C" fn(A, ...) -> Ret> for extern "C" fn(A, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 29]> for [A; 29] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 14]> for &'b [B] where
B: PartialEq<A>,impl<Ret, A, B> PartialEq<unsafe extern "C" fn(A, B, ...) -> Ret> for unsafe extern "C" fn(A, B, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 19] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 31]> for &'b mut [B] where
B: PartialEq<A>,impl<Ret, A> PartialEq<fn(A) -> Ret> for fn(A) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 9] where
A: PartialEq<B>,impl PartialEq<NonZeroU32> for NonZeroU32impl<'a, 'b, A, B> PartialEq<[A; 2]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 16]> for [B] where
B: PartialEq<A>,impl PartialEq<u16x2> for u16x2impl PartialEq<b8x8> for b8x8impl<'a, 'b, A, B> PartialEq<[A; 29]> for [B] where
B: PartialEq<A>,impl<T> PartialEq<Discriminant<T>> for Discriminant<T>impl<'a, 'b, A, B> PartialEq<[B; 12]> for [A; 12] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 20] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 24] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E> PartialEq<unsafe extern "C" fn(A, B, C, D, E) -> Ret> for unsafe extern "C" fn(A, B, C, D, E) -> Retimpl PartialEq<f32> for f32impl PartialEq<()> for ()impl PartialEq<i16x16> for i16x16impl<Ret, A, B, C, D, E> PartialEq<fn(A, B, C, D, E) -> Ret> for fn(A, B, C, D, E) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 26]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<u16x32> for u16x32impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 14] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 16]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut B> for &'a A where
A: PartialEq<B> + ?Sized,
B: ?Sized,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 7] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 9] where
A: PartialEq<B>,impl PartialEq<ParseBoolError> for ParseBoolErrorimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 0] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 11] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 31]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 4] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 4] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 0] where
A: PartialEq<B>,impl<T> PartialEq<NonNull<T>> for NonNull<T> where
T: ?Sized,impl<Ret, A, B, C, D, E> PartialEq<extern "C" fn(A, B, C, D, E) -> Ret> for extern "C" fn(A, B, C, D, E) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 5]> for &'b mut [B] where
B: PartialEq<A>,impl<T, E> PartialEq<Result<T, E>> for Result<T, E> where
E: PartialEq<E>,
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 2] where
A: PartialEq<B>,impl PartialEq<CharTryFromError> for CharTryFromErrorimpl<Ret, A, B, C, D> PartialEq<extern "C" fn(A, B, C, D, ...) -> Ret> for extern "C" fn(A, B, C, D, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 21] where
A: PartialEq<B>,impl PartialEq<NonZeroU128> for NonZeroU128impl<Ret, A, B, C, D, E, F, G, H> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl PartialEq<u64x2> for u64x2impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 13] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 17] where
A: PartialEq<B>,impl PartialEq<i8x4> for i8x4impl PartialEq<i32x4> for i32x4impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 3] where
A: PartialEq<B>,impl<T> PartialEq<Option<T>> for Option<T> where
T: PartialEq<T>,impl<Ret, A, B, C, D, E, F, G> PartialEq<fn(A, B, C, D, E, F, G) -> Ret> for fn(A, B, C, D, E, F, G) -> Retimpl PartialEq<u32x2> for u32x2impl<'a, 'b, A, B> PartialEq<[B; 2]> for [A; 2] where
A: PartialEq<B>,impl<Ret, A, B, C> PartialEq<unsafe extern "C" fn(A, B, C) -> Ret> for unsafe extern "C" fn(A, B, C) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 26]> for [A; 26] where
A: PartialEq<B>,impl PartialEq<u16x8> for u16x8impl<A, B, C, D, E, F, G, H, I> PartialEq<(A, B, C, D, E, F, G, H, I)> for (A, B, C, D, E, F, G, H, I) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G>,
H: PartialEq<H>,
I: PartialEq<I> + ?Sized,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 27] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 6]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 24]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 18] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 6] where
A: PartialEq<B>,impl PartialEq<i32x2> for i32x2impl<Idx> PartialEq<RangeTo<Idx>> for RangeTo<Idx> where
Idx: PartialEq<Idx>,impl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<Ret, A, B> PartialEq<extern "C" fn(A, B) -> Ret> for extern "C" fn(A, B) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 27]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 13]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 25]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 18] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 27] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 11]> for [A; 11] where
A: PartialEq<B>,impl PartialEq<ParseCharError> for ParseCharErrorimpl<'a, 'b, A, B> PartialEq<[A; 6]> for &'b [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<A> PartialEq<(A,)> for (A,) where
A: PartialEq<A> + ?Sized,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 2] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 32] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 16]> for [A; 16] where
A: PartialEq<B>,impl<A, B, C> PartialEq<(A, B, C)> for (A, B, C) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C> + ?Sized,impl PartialEq<NonZeroUsize> for NonZeroUsizeimpl<'a, 'b, A, B> PartialEq<[B; 21]> for [A; 21] where
A: PartialEq<B>,impl<Ret, A, B, C> PartialEq<fn(A, B, C) -> Ret> for fn(A, B, C) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 5]> for &'b [B] where
B: PartialEq<A>,impl<A, B, C, D, E, F> PartialEq<(A, B, C, D, E, F)> for (A, B, C, D, E, F) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F> + ?Sized,impl PartialEq<NoneError> for NoneErrorimpl<'a, 'b, A, B> PartialEq<[A; 28]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 21]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 21] where
A: PartialEq<B>,impl PartialEq<i16x2> for i16x2impl<Ret, A, B, C, D, E, F, G> PartialEq<extern "C" fn(A, B, C, D, E, F, G) -> Ret> for extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 13]> for [A; 13] where
A: PartialEq<B>,impl PartialEq<u8x8> for u8x8impl<'a, 'b, A, B> PartialEq<[A; 17]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 21] where
A: PartialEq<B>,impl PartialEq<Utf8Error> for Utf8Errorimpl PartialEq<NonZeroI32> for NonZeroI32impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 10] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 14] where
A: PartialEq<B>,impl<A, B, C, D, E, F, G> PartialEq<(A, B, C, D, E, F, G)> for (A, B, C, D, E, F, G) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G> + ?Sized,impl<A, B, C, D, E> PartialEq<(A, B, C, D, E)> for (A, B, C, D, E) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E> + ?Sized,impl PartialEq<i16x4> for i16x4impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 24] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 27] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 4]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 23]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 16] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 16] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 6] where
A: PartialEq<B>,impl<Ret, A, B, C> PartialEq<unsafe extern "C" fn(A, B, C, ...) -> Ret> for unsafe extern "C" fn(A, B, C, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 3]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F> PartialEq<fn(A, B, C, D, E, F) -> Ret> for fn(A, B, C, D, E, F) -> Retimpl<T> PartialEq<ManuallyDrop<T>> for ManuallyDrop<T> where
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 22] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 22]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<i8x2> for i8x2impl<'a, 'b, A, B> PartialEq<[A; 2]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 0]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 10] where
A: PartialEq<B>,impl PartialEq<u8x32> for u8x32impl<'a, 'b, A, B> PartialEq<[A; 7]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 12]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 17]> for [A; 17] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 2]> for &'b mut [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<fn(A, B, C, D, E, F, G, H) -> Ret> for fn(A, B, C, D, E, F, G, H) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 19]> for [A; 19] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 15] where
A: PartialEq<B>,impl<Ret, A, B> PartialEq<fn(A, B) -> Ret> for fn(A, B) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 19] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 24] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 27]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 31] where
A: PartialEq<B>,impl PartialEq<Ordering> for Orderingimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 29] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 10]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<f64x4> for f64x4impl<Ret, A, B, C, D, E, F> PartialEq<extern "C" fn(A, B, C, D, E, F) -> Ret> for extern "C" fn(A, B, C, D, E, F) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 10] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F> PartialEq<unsafe fn(A, B, C, D, E, F) -> Ret> for unsafe fn(A, B, C, D, E, F) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 25]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<u8x64> for u8x64impl<'a, 'b, A, B> PartialEq<[A; 5]> for [B] where
B: PartialEq<A>,impl PartialEq<u16x4> for u16x4impl<Ret, A, B, C, D, E> PartialEq<extern "C" fn(A, B, C, D, E, ...) -> Ret> for extern "C" fn(A, B, C, D, E, ...) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 25] where
A: PartialEq<B>,impl PartialEq<u16> for u16impl<'a, 'b, A, B> PartialEq<[A; 11]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 12] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 30] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 5] where
A: PartialEq<B>,impl PartialEq<u128> for u128impl<'a, 'b, A, B> PartialEq<[B]> for [A; 16] where
A: PartialEq<B>,impl PartialEq<Error> for Errorimpl<'a, 'b, A, B> PartialEq<[A; 20]> for &'b mut [B] where
B: PartialEq<A>,impl<Ret> PartialEq<extern "C" fn() -> Ret> for extern "C" fn() -> Retimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 22] where
A: PartialEq<B>,impl PartialEq<FpCategory> for FpCategoryimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 1] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 13]> for [B] where
B: PartialEq<A>,impl PartialEq<NonZeroU64> for NonZeroU64impl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl PartialEq<b8x32> for b8x32impl<'a, 'b, A, B> PartialEq<[A; 24]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 7] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 8]> for [A; 8] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 26]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 4] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut B> for &'a mut A where
A: PartialEq<B> + ?Sized,
B: ?Sized,impl<A, B, C, D> PartialEq<(A, B, C, D)> for (A, B, C, D) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D> + ?Sized,impl PartialEq<f64> for f64impl PartialEq<u32x4> for u32x4impl<Ret, A, B, C, D> PartialEq<extern "C" fn(A, B, C, D) -> Ret> for extern "C" fn(A, B, C, D) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 1]> for &'b mut [B] where
B: PartialEq<A>,impl<T> PartialEq<RefCell<T>> for RefCell<T> where
T: PartialEq<T> + ?Sized,impl<'a, 'b, A, B> PartialEq<[A; 15]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<usize> for usizeimpl<Ret, A, B, C, D, E> PartialEq<unsafe fn(A, B, C, D, E) -> Ret> for unsafe fn(A, B, C, D, E) -> Retimpl PartialEq<i16> for i16impl<'a, 'b, A, B> PartialEq<[A; 0]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 14]> for &'b mut [B] where
B: PartialEq<A>,impl<T> PartialEq<Cell<T>> for Cell<T> where
T: Copy + PartialEq<T>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 0] where
A: PartialEq<B>,impl PartialEq<NonZeroI128> for NonZeroI128impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 28] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 12] where
A: PartialEq<B>,impl<Ret, A, B, C, D> PartialEq<fn(A, B, C, D) -> Ret> for fn(A, B, C, D) -> Retimpl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 26] where
A: PartialEq<B>,impl PartialEq<NonZeroU8> for NonZeroU8impl<Ret, A, B, C> PartialEq<extern "C" fn(A, B, C) -> Ret> for extern "C" fn(A, B, C) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl PartialEq<i16x8> for i16x8impl<'a, 'b, A, B> PartialEq<[B; 20]> for [A; 20] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 0]> for [A; 0] where
A: PartialEq<B>,impl<Ret, A, B, C, D> PartialEq<unsafe fn(A, B, C, D) -> Ret> for unsafe fn(A, B, C, D) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 29]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<TypeId> for TypeIdimpl<'a, 'b, A, B> PartialEq<[A; 22]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<CollectionAllocErr> for CollectionAllocErrimpl PartialEq<b8x16> for b8x16impl<Ret> PartialEq<fn() -> Ret> for fn() -> Retimpl<Ret, A, B, C, D, E> PartialEq<unsafe extern "C" fn(A, B, C, D, E, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 12]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<i64x4> for i64x4impl PartialEq<bool> for boolimpl<'a, 'b, A, B> PartialEq<[B; 1]> for [A; 1] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 28]> for [A; 28] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 20]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 32]> for [A; 32] where
A: PartialEq<B>,impl<Idx> PartialEq<Range<Idx>> for Range<Idx> where
Idx: PartialEq<Idx>,impl<'a, 'b, A, B> PartialEq<[A; 9]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 10]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 13] where
A: PartialEq<B>,impl<Idx> PartialEq<RangeToInclusive<Idx>> for RangeToInclusive<Idx> where
Idx: PartialEq<Idx>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 28] where
A: PartialEq<B>,impl<Ret, A, B, C, D> PartialEq<unsafe extern "C" fn(A, B, C, D) -> Ret> for unsafe extern "C" fn(A, B, C, D) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 17]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 4]> for [A; 4] where
A: PartialEq<B>,impl PartialEq<b8x64> for b8x64impl<'a, 'b, A, B> PartialEq<[A; 24]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret> for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 28] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H> PartialEq<unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Ret> for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<'a, 'b, A, B> PartialEq<[A; 8]> for &'b mut [B] where
B: PartialEq<A>,impl<T> PartialEq<Bound<T>> for Bound<T> where
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<[A; 15]> for [B] where
B: PartialEq<A>,impl<Ret, A> PartialEq<unsafe fn(A) -> Ret> for unsafe fn(A) -> Retimpl<'a, 'b, A, B> PartialEq<[B; 31]> for [A; 31] where
A: PartialEq<B>,impl PartialEq<str> for strimpl PartialEq<RangeFull> for RangeFullimpl<'a, 'b, A, B> PartialEq<[A; 30]> for [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 7]> for &'b [B] where
B: PartialEq<A>,impl PartialEq<i128> for i128impl<T> PartialEq<*mut T> for *mut T where
T: ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 29] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 13]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[A; 19]> for &'b [B] where
B: PartialEq<A>,impl<A, B> PartialEq<[B]> for [A] where
A: PartialEq<B>,impl PartialEq<u16x16> for u16x16impl<'a, 'b, A, B> PartialEq<[A; 9]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 11] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B]> for [A; 31] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 32] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 5] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 32]> for [B] where
B: PartialEq<A>,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<'a, 'b, A, B> PartialEq<[B]> for [A; 12] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 19] where
A: PartialEq<B>,impl PartialEq<NonZeroU16> for NonZeroU16impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 8] where
A: PartialEq<B>,impl PartialEq<ParseIntError> for ParseIntErrorimpl<'a, 'b, A, B> PartialEq<[A; 21]> for &'b mut [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 3] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 8]> for &'b [B] where
B: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 14] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 10]> for &'b [B] where
B: PartialEq<A>,impl<A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<(A, B, C, D, E, F, G, H, I, J, K, L)> for (A, B, C, D, E, F, G, H, I, J, K, L) where
A: PartialEq<A>,
B: PartialEq<B>,
C: PartialEq<C>,
D: PartialEq<D>,
E: PartialEq<E>,
F: PartialEq<F>,
G: PartialEq<G>,
H: PartialEq<H>,
I: PartialEq<I>,
J: PartialEq<J>,
K: PartialEq<K>,
L: PartialEq<L> + ?Sized,impl PartialEq<ParseFloatError> for ParseFloatErrorimpl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 7] where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[A; 7]> for &'b mut [B] where
B: PartialEq<A>,impl PartialEq<NonZeroI64> for NonZeroI64impl<'a, 'b, A, B> PartialEq<[B; 7]> for [A; 7] where
A: PartialEq<B>,impl PartialEq<u64x4> for u64x4impl<'a, 'b, A, B> PartialEq<[B]> for [A; 22] where
A: PartialEq<B>,impl<Ret, A, B, C, D, E, F, G, H> PartialEq<unsafe fn(A, B, C, D, E, F, G, H) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl PartialEq<char> for charimpl PartialEq<u32x16> for u32x16impl PartialEq<i64x8> for i64x8impl<'a, 'b, A, B> PartialEq<&'b mut [B; 8]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 4]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<Vec<B>> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 18]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 1]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 25]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 15]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 26]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 23]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 5]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 12]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 9]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 12]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 2]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 27]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 8]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 29]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 17]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 5]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 1]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<String> for &'a strimpl<'a, 'b, A, B> PartialEq<[B; 11]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 10]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 3]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 29]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 0]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 11]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 14]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 20]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 2]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 22]> for Vec<A> where
A: PartialEq<B>,impl<K, V> PartialEq<BTreeMap<K, V>> for BTreeMap<K, V> where
K: PartialEq<K>,
V: PartialEq<V>,impl<'a, 'b, A, B> PartialEq<Vec<B>> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 12]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 6]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 1]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 9]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 16]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 17]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 23]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 29]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 10]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 11]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 21]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<String> for strimpl<'a, 'b, A, B> PartialEq<&'b [B; 23]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 15]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 20]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 9]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<String> for Cow<'a, str>impl<'a, 'b, A, B> PartialEq<&'b [B; 13]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 20]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 8]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 30]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 0]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<str> for Cow<'a, str>impl<'a, 'b, A, B> PartialEq<&'b mut [B; 11]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 3]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 3]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 6]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 32]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 8]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 7]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 18]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 13]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 31]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 30]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 10]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 6]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 24]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 28]> for VecDeque<A> where
A: PartialEq<B>,impl PartialEq<String> for Stringimpl<'a, 'b, A, B> PartialEq<&'b [B]> for Cow<'a, [A]> where
A: Clone + PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 20]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 14]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for Cow<'a, [A]> where
A: Clone + PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 9]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 16]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 22]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 1]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 13]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 22]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 21]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 18]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 19]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 31]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 22]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 19]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 17]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 21]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 25]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 29]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 27]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 15]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 12]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 13]> for VecDeque<A> where
A: PartialEq<B>,impl<T> PartialEq<LinkedList<T>> for LinkedList<T> where
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 1]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 23]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 12]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 2]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B> where
B: PartialEq<C> + ToOwned + ?Sized,
C: ToOwned + ?Sized,impl<'a, 'b, A, B> PartialEq<&'b [B; 7]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 5]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 26]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 11]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 18]> for VecDeque<A> where
A: PartialEq<B>,impl<T> PartialEq<Box<T>> for Box<T> where
T: PartialEq<T> + ?Sized,impl<'a, 'b, A, B> PartialEq<[B; 22]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 19]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 21]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 16]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 31]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 18]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 7]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 15]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<str> for Stringimpl<'a, 'b> PartialEq<&'a str> for Stringimpl<'a, 'b, A, B> PartialEq<[B; 14]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 4]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 24]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 30]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 32]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 30]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 9]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 5]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 0]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 24]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 25]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 28]> for Vec<A> where
A: PartialEq<B>,impl<T> PartialEq<Arc<T>> for Arc<T> where
T: PartialEq<T> + ?Sized,impl<'a, 'b, A, B> PartialEq<&'b [B; 26]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<Cow<'a, str>> for Stringimpl<'a, 'b> PartialEq<&'b str> for Cow<'a, str>impl<'a, 'b, A, B> PartialEq<&'b mut [B; 6]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 27]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 7]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 4]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 13]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 32]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 28]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 17]> for VecDeque<A> where
A: PartialEq<B>,impl<T> PartialEq<Rc<T>> for Rc<T> where
T: PartialEq<T> + ?Sized,impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 28]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 2]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 27]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 2]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 27]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 16]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 20]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 19]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 19]> for VecDeque<A> where
A: PartialEq<B>,impl PartialEq<ParseError> for ParseErrorimpl<'a, 'b> PartialEq<Cow<'a, str>> for &'b strimpl<'a, 'b, A, B> PartialEq<&'b mut [B; 28]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 26]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 15]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 3]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 29]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 21]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 0]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 10]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 17]> for Vec<A> where
A: PartialEq<B>,impl<A> PartialEq<VecDeque<A>> for VecDeque<A> where
A: PartialEq<A>,impl<'a, 'b, A, B> PartialEq<[B; 24]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 31]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<Vec<B>> for Cow<'a, [A]> where
A: Clone + PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 0]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 14]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 4]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b> PartialEq<Cow<'a, str>> for strimpl<'a, 'b, A, B> PartialEq<[B; 3]> for VecDeque<A> where
A: PartialEq<B>,impl<T> PartialEq<BTreeSet<T>> for BTreeSet<T> where
T: PartialEq<T>,impl<'a, 'b, A, B> PartialEq<&'b [B; 6]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 7]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 4]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 25]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 24]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 30]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 31]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 26]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 8]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 16]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 14]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 25]> for Vec<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<[B; 32]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b [B; 23]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 32]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 10]> for VecDeque<A> where
A: PartialEq<B>,impl<'a, 'b, A, B> PartialEq<&'b mut [B; 5]> for VecDeque<A> where
A: PartialEq<B>,impl PartialEq<UnicodeVersion> for UnicodeVersionimpl PartialEq<DecodeUtf16Error> for DecodeUtf16Errorimpl PartialEq for ThreadIdimpl<K, V, S> PartialEq for HashMap<K, V, S> where
K: Eq + Hash,
V: PartialEq,
S: BuildHasher,impl<T, S> PartialEq for HashSet<T, S> where
T: Eq + Hash,
S: BuildHasher,impl PartialEq for VarErrorimpl PartialEq for CStringimpl PartialEq for NulErrorimpl PartialEq for FromBytesWithNulErrorimpl PartialEq for IntoStringErrorimpl PartialEq for CStrimpl PartialEq for OsStringimpl PartialEq<str> for OsStringimpl PartialEq<OsString> for strimpl PartialEq for OsStrimpl PartialEq<str> for OsStrimpl PartialEq<OsStr> for strimpl<'a, 'b> PartialEq<OsStr> for OsStringimpl<'a, 'b> PartialEq<OsString> for OsStrimpl<'a, 'b> PartialEq<&'a OsStr> for OsStringimpl<'a, 'b> PartialEq<OsString> for &'a OsStrimpl<'a, 'b> PartialEq<OsStr> for Cow<'a, OsStr>impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for OsStrimpl<'a, 'b> PartialEq<&'b OsStr> for Cow<'a, OsStr>impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for &'b OsStrimpl<'a, 'b> PartialEq<OsString> for Cow<'a, OsStr>impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for OsStringimpl PartialEq for Permissionsimpl PartialEq for FileTypeimpl PartialEq for ErrorKindimpl PartialEq for SeekFromimpl PartialEq for IpAddrimpl PartialEq for Ipv6MulticastScopeimpl PartialEq for Ipv4Addrimpl PartialEq<Ipv4Addr> for IpAddrimpl PartialEq<IpAddr> for Ipv4Addrimpl PartialEq for Ipv6Addrimpl PartialEq<IpAddr> for Ipv6Addrimpl PartialEq<Ipv6Addr> for IpAddrimpl PartialEq for SocketAddrimpl PartialEq for SocketAddrV4impl PartialEq for SocketAddrV6impl PartialEq for AddrParseErrorimpl PartialEq for Shutdownimpl<'a> PartialEq for Prefix<'a>impl<'a> PartialEq for PrefixComponent<'a>impl<'a> PartialEq for Component<'a>impl<'a> PartialEq for Components<'a>impl PartialEq for PathBufimpl PartialEq for StripPrefixErrorimpl PartialEq for Pathimpl<'a, 'b> PartialEq<Path> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for Pathimpl<'a, 'b> PartialEq<&'a Path> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for &'a Pathimpl<'a, 'b> PartialEq<Path> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for Pathimpl<'a, 'b> PartialEq<&'b Path> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b Pathimpl<'a, 'b> PartialEq<PathBuf> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for PathBufimpl<'a, 'b> PartialEq<OsStr> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for OsStrimpl<'a, 'b> PartialEq<&'a OsStr> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for &'a OsStrimpl<'a, 'b> PartialEq<Cow<'a, OsStr>> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for Cow<'a, OsStr>impl<'a, 'b> PartialEq<OsString> for PathBufimpl<'a, 'b> PartialEq<PathBuf> for OsStringimpl<'a, 'b> PartialEq<OsStr> for Pathimpl<'a, 'b> PartialEq<Path> for OsStrimpl<'a, 'b> PartialEq<&'a OsStr> for Pathimpl<'a, 'b> PartialEq<Path> for &'a OsStrimpl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Pathimpl<'a, 'b> PartialEq<Path> for Cow<'a, OsStr>impl<'a, 'b> PartialEq<OsString> for Pathimpl<'a, 'b> PartialEq<Path> for OsStringimpl<'a, 'b> PartialEq<OsStr> for &'a Pathimpl<'a, 'b> PartialEq<&'a Path> for OsStrimpl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Pathimpl<'a, 'b> PartialEq<&'a Path> for Cow<'b, OsStr>impl<'a, 'b> PartialEq<OsString> for &'a Pathimpl<'a, 'b> PartialEq<&'a Path> for OsStringimpl<'a, 'b> PartialEq<OsStr> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for OsStrimpl<'a, 'b> PartialEq<&'b OsStr> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b OsStrimpl<'a, 'b> PartialEq<OsString> for Cow<'a, Path>impl<'a, 'b> PartialEq<Cow<'a, Path>> for OsStringimpl PartialEq for Outputimpl PartialEq for ExitStatusimpl<T: PartialEq> PartialEq for SendError<T>impl PartialEq for RecvErrorimpl PartialEq for TryRecvErrorimpl PartialEq for RecvTimeoutErrorimpl<T: PartialEq> PartialEq for TrySendError<T>impl PartialEq for WaitTimeoutResultimpl PartialEq for Instantimpl PartialEq for SystemTime