Trait std::fmt::Debug 1.0.0[−][src]
? formatting.
Debug should format the output in a programmer-facing, debugging context.
Generally speaking, you should just derive a Debug implementation.
When used with the alternate format specifier #?, the output is pretty-printed.
For more information on formatters, see the module-level documentation.
This trait can be used with #[derive] if all fields implement Debug. When
derived for structs, it will use the name of the struct, then {, then a
comma-separated list of each field's name and Debug value, then }. For
enums, it will use the name of the variant and, if applicable, (, then the
Debug values of the fields, then ).
Examples
Deriving an implementation:
#[derive(Debug)] struct Point { x: i32, y: i32, } let origin = Point { x: 0, y: 0 }; println!("The origin is: {:?}", origin);Run
Manually implementing:
use std::fmt; struct Point { x: i32, y: i32, } impl fmt::Debug for Point { fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result { write!(f, "Point {{ x: {}, y: {} }}", self.x, self.y) } } let origin = Point { x: 0, y: 0 }; println!("The origin is: {:?}", origin);Run
This outputs:
The origin is: Point { x: 0, y: 0 }
There are a number of debug_* methods on Formatter to help you with manual
implementations, such as debug_struct.
Debug implementations using either derive or the debug builder API
on Formatter support pretty printing using the alternate flag: {:#?}.
Pretty printing with #?:
#[derive(Debug)] struct Point { x: i32, y: i32, } let origin = Point { x: 0, y: 0 }; println!("The origin is: {:#?}", origin);Run
This outputs:
The origin is: Point {
x: 0,
y: 0
}
Required Methods
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
Examples
use std::fmt; struct Position { longitude: f32, latitude: f32, } impl fmt::Debug for Position { fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result { write!(f, "({:?}, {:?})", self.longitude, self.latitude) } } assert_eq!("(1.987, 2.983)".to_owned(), format!("{:?}", Position { longitude: 1.987, latitude: 2.983, }));Run
Implementations on Foreign Types
impl Debug for Utf8Lossy[src]
impl Debug for Utf8Lossyimpl Debug for TryFromSliceError[src]
impl Debug for TryFromSliceErrorimpl<'a> Debug for Utf8LossyChunk<'a>[src]
impl<'a> Debug for Utf8LossyChunk<'a>Implementors
impl<'a, P> Debug for Matches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl Debug for charimpl<Ret> Debug for fn() -> Retimpl<Ret, A, B, C, D, E, F, G> Debug for extern "C" fn(A, B, C, D, E, F, G) -> Retimpl Debug for AtomicI16impl<Ret, A, B, C> Debug for fn(A, B, C) -> Retimpl Debug for NonZeroU8impl<Ret, A, B, C, D, E, F, G> Debug for unsafe fn(A, B, C, D, E, F, G) -> Retimpl Debug for Any + 'staticimpl<Ret, A> Debug for unsafe fn(A) -> Retimpl<'a, T> Debug for Chunks<'a, T> where
T: 'a + Debug,impl<I, St, F> Debug for Scan<I, St, F> where
I: Debug,
St: Debug,impl<'a, T> Debug for ExactChunks<'a, T> where
T: 'a + Debug,impl<Ret, A, B, C, D, E> Debug for unsafe fn(A, B, C, D, E) -> Retimpl Debug for NonZeroU128impl<Ret, A, B, C, D> Debug for fn(A, B, C, D) -> Retimpl<T> Debug for [T; 25] where
T: Debug,impl<T> Debug for [T; 17] where
T: Debug,impl<'a, T, P> Debug for std::slice::RSplit<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<Ret, A, B, C, D, E, F, G, H> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<I, P> Debug for TakeWhile<I, P> where
I: Debug,impl Debug for AtomicI8impl Debug for i16impl<T> Debug for [T; 4] where
T: Debug,impl Debug for AtomicIsizeimpl Debug for AtomicU16impl<T9, T10, T11> Debug for (T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T9: Debug,impl<'a, T> Debug for FutureObj<'a, T>impl<T, E> Debug for Result<T, E> where
E: Debug,
T: Debug,impl<Ret> Debug for unsafe extern "C" fn() -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<I, F> Debug for Inspect<I, F> where
I: Debug,impl<Ret, A> Debug for unsafe extern "C" fn(A) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E> Debug for extern "C" fn(A, B, C, D, E) -> Retimpl<T> Debug for [T] where
T: Debug,impl<T> Debug for std::iter::Once<T> where
T: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<T> Debug for [T; 29] where
T: Debug,impl<I, U> Debug for Flatten<I> where
I: Iterator + Debug,
U: Iterator + Debug,
<I as Iterator>::Item: IntoIterator,
<<I as Iterator>::Item as IntoIterator>::IntoIter == U,
<<I as Iterator>::Item as IntoIterator>::Item == <U as Iterator>::Item,impl<F> Debug for RepeatWith<F> where
F: Debug,impl<T> Debug for Cell<T> where
T: Copy + Debug,impl<Ret, A, B, C, D> Debug for unsafe fn(A, B, C, D) -> Retimpl Debug for TypeIdimpl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<I> Debug for StepBy<I> where
I: Debug,impl Debug for isizeimpl<T> Debug for [T; 31] where
T: Debug,impl Debug for BorrowErrorimpl<Ret, A, B, C, D, E> Debug for unsafe extern "C" fn(A, B, C, D, E) -> Retimpl Debug for AtomicUsizeimpl<T> Debug for [T; 13] where
T: Debug,impl<T> Debug for [T; 9] where
T: Debug,impl<Ret, A, B, C> Debug for extern "C" fn(A, B, C) -> Retimpl<'a, T> Debug for LocalFutureObj<'a, T>impl Debug for TryFromIntErrorimpl<T> Debug for Option<T> where
T: Debug,impl<T> Debug for [T; 18] where
T: Debug,impl Debug for EscapeDebugimpl<'a, T, P> Debug for std::slice::Split<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Debug for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11) where
T0: Debug,
T1: Debug,
T10: Debug,
T11: Debug + ?Sized,
T2: Debug,
T3: Debug,
T4: Debug,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl<I> Debug for Fuse<I> where
I: Debug,impl<Ret, A> Debug for extern "C" fn(A, ...) -> Retimpl<T> Debug for [T; 15] where
T: Debug,impl Debug for u64impl<Ret, A> Debug for unsafe extern "C" fn(A, ...) -> Retimpl<T> Debug for [T; 21] where
T: Debug,impl<T> Debug for UnsafeCell<T> where
T: Debug + ?Sized,impl<'a, A> Debug for std::option::IterMut<'a, A> where
A: 'a + Debug,impl Debug for f32impl Debug for NoneErrorimpl<'b, T> Debug for Ref<'b, T> where
T: Debug + ?Sized,impl<'a, T> Debug for ExactChunksMut<'a, T> where
T: 'a + Debug,impl<'a, T> Debug for std::slice::IterMut<'a, T> where
T: 'a + Debug,impl<T> Debug for [T; 30] where
T: Debug,impl Debug for SearchStepimpl<T> Debug for [T; 26] where
T: Debug,impl<'a, P> Debug for std::str::SplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Ret, A, B, C> Debug for unsafe extern "C" fn(A, B, C) -> Retimpl<'a, P> Debug for RMatches<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<A, B> Debug for std::iter::Chain<A, B> where
A: Debug,
B: Debug,impl<I, P> Debug for SkipWhile<I, P> where
I: Debug,impl Debug for ToLowercaseimpl<Ret, A, B, C, D, E, F, G, H, I> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl Debug for ToUppercaseimpl<Ret, A, B> Debug for extern "C" fn(A, B, ...) -> Retimpl<I, U, F> Debug for FlatMap<I, U, F> where
I: Debug,
U: IntoIterator,
<U as IntoIterator>::IntoIter: Debug,impl Debug for std::fmt::Errorimpl<T> Debug for [T; 11] where
T: Debug,impl Debug for LayoutErrimpl<T> Debug for [T; 22] where
T: Debug,impl Debug for SpawnErrorKindimpl Debug for ParseIntErrorimpl<A, B> Debug for Zip<A, B> where
A: Debug,
B: Debug,impl<'a, T> Debug for Windows<'a, T> where
T: 'a + Debug,impl<Ret, A, B, C, D, E, F, G> Debug for extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl Debug for usizeimpl Debug for AtomicI32impl<'a> Debug for std::str::Lines<'a>impl<T> Debug for [T; 10] where
T: Debug,impl<'a> Debug for Location<'a>impl<Ret, A, B, C, D, E, F, G, H> Debug for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<H> Debug for BuildHasherDefault<H>impl<T> Debug for *const T where
T: ?Sized,impl Debug for std::char::EscapeDefaultimpl Debug for Wakerimpl Debug for UnicodeVersionimpl<'a> Debug for std::str::Chars<'a>impl<T> Debug for PhantomData<T> where
T: ?Sized,impl<Ret, A> Debug for extern "C" fn(A) -> Retimpl Debug for SpawnLocalObjErrorimpl<'a> Debug for SplitAsciiWhitespace<'a>impl<T> Debug for [T; 7] where
T: Debug,impl Debug for Layoutimpl<T> Debug for ManuallyDrop<T> where
T: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl Debug for std::sync::atomic::Orderingimpl Debug for u8impl Debug for AtomicI64impl Debug for Utf8Errorimpl<Ret, A, B, C, D> Debug for unsafe extern "C" fn(A, B, C, D) -> Retimpl Debug for RangeFullimpl<'a, A> Debug for std::option::Iter<'a, A> where
A: 'a + Debug,impl<'a, T, P> Debug for RSplitMut<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl Debug for i64impl<Ret, A, B> Debug for unsafe extern "C" fn(A, B, ...) -> Retimpl Debug for AllocErrimpl Debug for LocalWakerimpl<Ret> Debug for extern "C" fn() -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl Debug for NonZeroU16impl<T> Debug for AtomicPtr<T>impl Debug for u128impl<Ret, A> Debug for fn(A) -> Retimpl<'a, 'b> Debug for StrSearcher<'a, 'b>impl<I> Debug for Cycle<I> where
I: Debug,impl Debug for Pinnedimpl<Ret, A, B, C, D, E, F, G, H> Debug for extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<I> Debug for Cloned<I> where
I: Debug,impl<Ret, A, B, C, D, E, F, G> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B> Debug for extern "C" fn(A, B) -> Retimpl<I, P> Debug for Filter<I, P> where
I: Debug,impl Debug for CannotReallocInPlaceimpl<Ret, A, B, C, D, E, F, G> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl Debug for i32impl<Ret, A, B, C> Debug for unsafe fn(A, B, C) -> Retimpl<'a> Debug for PanicInfo<'a>impl<A> Debug for std::option::IntoIter<A> where
A: Debug,impl<T10, T11> Debug for (T10, T11) where
T10: Debug,
T11: Debug + ?Sized,impl<Ret, A, B, C, D, E, F> Debug for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<T3, T4, T5, T6, T7, T8, T9, T10, T11> Debug for (T3, T4, T5, T6, T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T3: Debug,
T4: Debug,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl Debug for boolimpl Debug for !impl<T> Debug for [T; 23] where
T: Debug,impl<T11> Debug for (T11,) where
T11: Debug + ?Sized,impl<Ret, A, B, C, D, E, F, G, H> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<T> Debug for [T; 19] where
T: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl Debug for EscapeUnicodeimpl<'a, 'b> Debug for CharSliceSearcher<'a, 'b>impl<T7, T8, T9, T10, T11> Debug for (T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T7: Debug,
T8: Debug,
T9: Debug,impl Debug for Any + 'static + Send + Syncimpl<'a> Debug for CharIndices<'a>impl<Ret, A, B, C, D, E, F, G> Debug for fn(A, B, C, D, E, F, G) -> Retimpl<T> Debug for RefCell<T> where
T: Debug + ?Sized,impl<I, F> Debug for Map<I, F> where
I: Debug,impl<Ret, A, B, C, D, E, F, G, H, I> Debug for fn(A, B, C, D, E, F, G, H, I) -> Retimpl Debug for std::ascii::EscapeDefaultimpl<Ret, A, B, C, D, E, F> Debug for unsafe extern "C" fn(A, B, C, D, E, F) -> Retimpl Debug for ParseCharErrorimpl<'a, F> Debug for CharPredicateSearcher<'a, F> where
F: FnMut(char) -> bool,impl<'a, T> Debug for &'a T where
T: Debug + ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<T> Debug for std::result::IntoIter<T> where
T: Debug,impl<Ret, A, B, C, D> Debug for extern "C" fn(A, B, C, D) -> Retimpl<Y, R> Debug for GeneratorState<Y, R> where
R: Debug,
Y: Debug,impl<T> Debug for [T; 27] where
T: Debug,impl Debug for NonZeroU64impl<T> Debug for [T; 1] where
T: Debug,impl<T> Debug for [T; 12] where
T: Debug,impl<T> Debug for Poll<T> where
T: Debug,impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Debug for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11) where
T1: Debug,
T10: Debug,
T11: Debug + ?Sized,
T2: Debug,
T3: Debug,
T4: Debug,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl<'a> Debug for EncodeUtf16<'a>impl<T> Debug for Bound<T> where
T: Debug,impl<'a, T> Debug for std::slice::Iter<'a, T> where
T: 'a + Debug,impl Debug for AtomicU64impl<'a, P> Debug for std::str::Split<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<'a> Debug for SplitWhitespace<'a>impl Debug for SpawnObjErrorimpl Debug for ()impl<T> Debug for [T; 6] where
T: Debug,impl<'a, P> Debug for std::str::RSplit<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<'a, P> Debug for MatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Idx> Debug for RangeToInclusive<Idx> where
Idx: Debug,impl<'a> Debug for CharSearcher<'a>impl<T> Debug for [T; 0] where
T: Debug,impl Debug for Excessimpl<Ret, A, B, C, D, E, F> Debug for extern "C" fn(A, B, C, D, E, F) -> Retimpl<T> Debug for *mut T where
T: ?Sized,impl<Idx> Debug for RangeTo<Idx> where
Idx: Debug,impl<T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Debug for (T2, T3, T4, T5, T6, T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T2: Debug,
T3: Debug,
T4: Debug,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl Debug for ParseBoolErrorimpl<Ret, A, B, C, D, E, F, G, H> Debug for fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<T> Debug for [T; 28] where
T: Debug,impl<Idx> Debug for std::ops::Range<Idx> where
Idx: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<I> Debug for Skip<I> where
I: Debug,impl<I> Debug for Peekable<I> where
I: Iterator + Debug,
<I as Iterator>::Item: Debug,impl<'a, T, P> Debug for SplitNMut<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<Ret, A, B, C> Debug for unsafe extern "C" fn(A, B, C, ...) -> Retimpl<'a, T> Debug for ChunksMut<'a, T> where
T: 'a + Debug,impl<Ret, A, B> Debug for unsafe fn(A, B) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<T> Debug for [T; 8] where
T: Debug,impl<I> Debug for DecodeUtf8<I> where
I: Iterator<Item = u8> + Debug,impl<Ret, A, B, C, D, E, F, G, H, I> Debug for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl Debug for AtomicU32impl<T> Debug for [T; 20] where
T: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl Debug for NonZeroUsizeimpl<Ret, A, B, C, D, E> Debug for extern "C" fn(A, B, C, D, E, ...) -> Retimpl Debug for NonZeroU32impl Debug for CharTryFromErrorimpl<'a, T> Debug for std::result::IterMut<'a, T> where
T: 'a + Debug,impl Debug for i128impl Debug for Durationimpl<T> Debug for [T; 32] where
T: Debug,impl<T> Debug for Wrapping<T> where
T: Debug,impl<'a, T, P> Debug for SplitMut<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<T> Debug for Reverse<T> where
T: Debug,impl<T> Debug for NonNull<T> where
T: ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B> Debug for fn(A, B) -> Retimpl Debug for f64impl<T5, T6, T7, T8, T9, T10, T11> Debug for (T5, T6, T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl Debug for Alignmentimpl<Ret, A, B, C, D, E, F> Debug for unsafe fn(A, B, C, D, E, F) -> Retimpl Debug for AtomicU8impl<'a, T> Debug for PinMut<'a, T> where
T: Debug + ?Sized,impl<T> Debug for Discriminant<T>impl<T4, T5, T6, T7, T8, T9, T10, T11> Debug for (T4, T5, T6, T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T4: Debug,
T5: Debug,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl<A> Debug for std::iter::Repeat<A> where
A: Debug,impl<'a, T, P> Debug for RSplitNMut<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<T> Debug for [T; 5] where
T: Debug,impl<'a, T, P> Debug for std::slice::SplitN<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl<I> Debug for DecodeUtf16<I> where
I: Debug + Iterator<Item = u16>,impl<Ret, A, B> Debug for unsafe extern "C" fn(A, B) -> Retimpl Debug for Any + 'static + Sendimpl Debug for DecodeUtf16Errorimpl<T> Debug for Rev<T> where
T: Debug,impl<Ret, A, B, C> Debug for extern "C" fn(A, B, C, ...) -> Retimpl<'a, T> Debug for &'a mut T where
T: Debug + ?Sized,impl<Ret, A, B, C, D> Debug for unsafe extern "C" fn(A, B, C, D, ...) -> Retimpl<I> Debug for std::iter::Take<I> where
I: Debug,impl<T6, T7, T8, T9, T10, T11> Debug for (T6, T7, T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T6: Debug,
T7: Debug,
T8: Debug,
T9: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<'a, P> Debug for RMatchIndices<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<'a> Debug for std::str::Bytes<'a>impl<T> Debug for std::iter::Empty<T>impl<Ret, A, B, C, D, E, F, G, H> Debug for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl Debug for u16impl<Ret, A, B, C, D, E, F> Debug for extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<T> Debug for [T; 16] where
T: Debug,impl Debug for AtomicBoolimpl<'a, P> Debug for RSplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<T> Debug for [T; 24] where
T: Debug,impl<Ret> Debug for unsafe fn() -> Retimpl Debug for ParseFloatErrorimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<Ret, A, B, C, D, E> Debug for unsafe extern "C" fn(A, B, C, D, E, ...) -> Retimpl<Ret, A, B, C, D, E, F> Debug for fn(A, B, C, D, E, F) -> Retimpl<T> Debug for [T; 3] where
T: Debug,impl Debug for i8impl<Ret, A, B, C, D, E, F, G, H, I, J> Debug for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl Debug for FpCategoryimpl<'a, P> Debug for SplitTerminator<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl Debug for BorrowMutErrorimpl<T> Debug for [T; 2] where
T: Debug,impl<I> Debug for Enumerate<I> where
I: Debug,impl<'b, T> Debug for RefMut<'b, T> where
T: Debug + ?Sized,impl<'a> Debug for LinesAny<'a>impl<Idx> Debug for RangeInclusive<Idx> where
Idx: Debug,impl Debug for u32impl<'a, T> Debug for std::result::Iter<'a, T> where
T: 'a + Debug,impl<'a> Debug for Arguments<'a>impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Debug for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl Debug for std::cmp::Orderingimpl<Ret, A, B, C, D> Debug for extern "C" fn(A, B, C, D, ...) -> Retimpl<Idx> Debug for RangeFrom<Idx> where
Idx: Debug,impl Debug for SipHasherimpl<'a, P> Debug for std::str::RSplitN<'a, P> where
P: Pattern<'a>,
<P as Pattern<'a>>::Searcher: Debug,impl<Ret, A, B, C, D, E, F, G, H, I> Debug for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<Ret, A, B, C, D, E> Debug for fn(A, B, C, D, E) -> Retimpl<I, F> Debug for FilterMap<I, F> where
I: Debug,impl<'a> Debug for Context<'a>impl<T> Debug for [T; 14] where
T: Debug,impl Debug for strimpl<'a, T, P> Debug for std::slice::RSplitN<'a, T, P> where
P: FnMut(&T) -> bool,
T: 'a + Debug,impl Debug for InvalidSequenceimpl<T8, T9, T10, T11> Debug for (T8, T9, T10, T11) where
T10: Debug,
T11: Debug + ?Sized,
T8: Debug,
T9: Debug,impl Debug for CollectionAllocErrimpl<'a, T> Debug for PeekMut<'a, T> where
T: Ord + Debug,impl<'a, K, V> Debug for RangeMut<'a, K, V> where
K: 'a + Debug,
V: 'a + Debug,impl<'a, T> Debug for std::collections::btree_set::Iter<'a, T> where
T: 'a + Debug,impl<'a, T> Debug for std::collections::binary_heap::Iter<'a, T> where
T: 'a + Debug,impl<T> Debug for LinkedList<T> where
T: Debug,impl<'a, T, F> Debug for std::collections::linked_list::DrainFilter<'a, T, F> where
F: FnMut(&mut T) -> bool,
T: 'a + Debug,impl<'a, T> Debug for std::collections::btree_set::Difference<'a, T> where
T: 'a + Debug,impl<'a, K, V> Debug for std::collections::btree_map::Values<'a, K, V> where
K: 'a,
V: 'a + Debug,impl Debug for ParseErrorimpl<K, V> Debug for BTreeMap<K, V> where
K: Debug,
V: Debug,impl Debug for FromUtf16Errorimpl<T> Debug for std::collections::binary_heap::IntoIter<T> where
T: Debug,impl<'a, B> Debug for Cow<'a, B> where
B: Debug + ToOwned + ?Sized,
<B as ToOwned>::Owned: Debug,impl<T> Debug for Arc<T> where
T: Debug + ?Sized,impl<T> Debug for Box<T> where
T: Debug + ?Sized,impl<T> Debug for std::sync::Weak<T> where
T: Debug + ?Sized,impl<'a, T> Debug for std::collections::vec_deque::IterMut<'a, T> where
T: 'a + Debug,impl<'a, T, F> Debug for std::vec::DrainFilter<'a, T, F> where
F: Debug + FnMut(&mut T) -> bool,
T: 'a + Debug,impl<'a, T> Debug for std::collections::binary_heap::Drain<'a, T> where
T: 'a + Debug,impl<'a, T> Debug for std::vec::Drain<'a, T> where
T: 'a + Debug,impl<K, V> Debug for std::collections::btree_map::IntoIter<K, V> where
K: Debug,
V: Debug,impl<T> Debug for VecDeque<T> where
T: Debug,impl<T> Debug for PinBox<T> where
T: Debug + ?Sized,impl<'a, T> Debug for std::collections::btree_set::SymmetricDifference<'a, T> where
T: 'a + Debug,impl<'a, K, V> Debug for std::collections::btree_map::VacantEntry<'a, K, V> where
K: 'a + Ord + Debug,
V: 'a,impl<'a, T> Debug for std::collections::linked_list::IterMut<'a, T> where
T: 'a + Debug,impl<'a, T> Debug for std::collections::btree_set::Intersection<'a, T> where
T: 'a + Debug,impl<T> Debug for std::vec::IntoIter<T> where
T: Debug,impl<T> Debug for BinaryHeap<T> where
T: Ord + Debug,impl<'a, K, V> Debug for std::collections::btree_map::Range<'a, K, V> where
K: 'a + Debug,
V: 'a + Debug,impl Debug for Stringimpl<'a, T> Debug for std::collections::vec_deque::Iter<'a, T> where
T: 'a + Debug,impl Debug for FromUtf8Errorimpl<'a, K, V> Debug for std::collections::btree_map::Keys<'a, K, V> where
K: 'a + Debug,
V: 'a,impl<'a, T> Debug for std::collections::btree_set::Range<'a, T> where
T: 'a + Debug,impl<'a, K, V> Debug for std::collections::btree_map::Entry<'a, K, V> where
K: 'a + Ord + Debug,
V: 'a + Debug,impl<'a, K, V> Debug for std::collections::btree_map::OccupiedEntry<'a, K, V> where
K: 'a + Ord + Debug,
V: 'a + Debug,impl<T> Debug for std::collections::vec_deque::IntoIter<T> where
T: Debug,impl<'a, T> Debug for std::collections::linked_list::Iter<'a, T> where
T: 'a + Debug,impl<T> Debug for Vec<T> where
T: Debug,impl Debug for Globalimpl<'a, T> Debug for std::collections::vec_deque::Drain<'a, T> where
T: 'a + Debug,impl<T> Debug for std::collections::linked_list::IntoIter<T> where
T: Debug,impl<'a, K, V> Debug for std::collections::btree_map::ValuesMut<'a, K, V> where
K: 'a + Debug,
V: 'a + Debug,impl<T> Debug for Rc<T> where
T: Debug + ?Sized,impl<'a, I> Debug for Splice<'a, I> where
I: 'a + Iterator + Debug,
<I as Iterator>::Item: Debug,impl<'a, K, V> Debug for std::collections::btree_map::IterMut<'a, K, V> where
K: 'a + Debug,
V: 'a + Debug,impl<'a, K, V> Debug for std::collections::btree_map::Iter<'a, K, V> where
K: 'a + Debug,
V: 'a + Debug,impl<T> Debug for std::rc::Weak<T> where
T: Debug + ?Sized,impl<'a> Debug for std::string::Drain<'a>impl<T> Debug for std::collections::btree_set::IntoIter<T> where
T: Debug,impl<'a, T> Debug for std::collections::btree_set::Union<'a, T> where
T: 'a + Debug,impl<T> Debug for BTreeSet<T> where
T: Debug,impl<T: 'static> Debug for LocalKey<T>impl Debug for AccessErrorimpl Debug for Builderimpl Debug for ThreadIdimpl Debug for Threadimpl<T> Debug for JoinHandle<T>impl<K, V, S> Debug for HashMap<K, V, S> where
K: Eq + Hash + Debug,
V: Debug,
S: BuildHasher,impl<'a, K: Debug, V: Debug> Debug for std::collections::hash_map::Iter<'a, K, V>impl<'a, K: Debug, V> Debug for std::collections::hash_map::Keys<'a, K, V>impl<'a, K, V: Debug> Debug for std::collections::hash_map::Values<'a, K, V>impl<'a, K: 'a + Debug, V: 'a + Debug> Debug for std::collections::hash_map::Entry<'a, K, V>impl<'a, K: 'a + Debug, V: 'a + Debug> Debug for std::collections::hash_map::OccupiedEntry<'a, K, V>impl<'a, K: 'a + Debug, V: 'a> Debug for std::collections::hash_map::VacantEntry<'a, K, V>impl<'a, K, V> Debug for std::collections::hash_map::IterMut<'a, K, V> where
K: Debug,
V: Debug,impl<K: Debug, V: Debug> Debug for std::collections::hash_map::IntoIter<K, V>impl<'a, K, V> Debug for std::collections::hash_map::ValuesMut<'a, K, V> where
K: Debug,
V: Debug,impl<'a, K, V> Debug for std::collections::hash_map::Drain<'a, K, V> where
K: Debug,
V: Debug,impl Debug for DefaultHasherimpl Debug for RandomStateimpl<T, S> Debug for HashSet<T, S> where
T: Eq + Hash + Debug,
S: BuildHasher,impl<'a, K: Debug> Debug for std::collections::hash_set::Iter<'a, K>impl<K: Debug> Debug for std::collections::hash_set::IntoIter<K>impl<'a, K: Debug> Debug for std::collections::hash_set::Drain<'a, K>impl<'a, T, S> Debug for std::collections::hash_set::Intersection<'a, T, S> where
T: Debug + Eq + Hash,
S: BuildHasher,impl<'a, T, S> Debug for std::collections::hash_set::Difference<'a, T, S> where
T: Debug + Eq + Hash,
S: BuildHasher,impl<'a, T, S> Debug for std::collections::hash_set::SymmetricDifference<'a, T, S> where
T: Debug + Eq + Hash,
S: BuildHasher,impl<'a, T, S> Debug for std::collections::hash_set::Union<'a, T, S> where
T: Debug + Eq + Hash,
S: BuildHasher,impl Debug for Varsimpl Debug for VarsOsimpl Debug for VarErrorimpl<'a> Debug for SplitPaths<'a>impl Debug for JoinPathsErrorimpl Debug for Argsimpl Debug for ArgsOsimpl Debug for NulErrorimpl Debug for FromBytesWithNulErrorimpl Debug for IntoStringErrorimpl Debug for CStringimpl Debug for CStrimpl Debug for OsStringimpl Debug for OsStrimpl Debug for ReadDirimpl Debug for OpenOptionsimpl Debug for Permissionsimpl Debug for FileTypeimpl Debug for DirBuilderimpl Debug for Fileimpl Debug for Metadataimpl Debug for DirEntryimpl<R> Debug for BufReader<R> where
R: Debug,impl<W: Debug> Debug for IntoInnerError<W>impl<W: Write> Debug for BufWriter<W> where
W: Debug,impl<W: Write> Debug for LineWriter<W> where
W: Debug,impl<T: Debug> Debug for Cursor<T>impl Debug for std::io::Errorimpl Debug for ErrorKindimpl Debug for std::io::Emptyimpl Debug for std::io::Repeatimpl Debug for Sinkimpl Debug for Stdinimpl<'a> Debug for StdinLock<'a>impl Debug for Stdoutimpl<'a> Debug for StdoutLock<'a>impl Debug for Stderrimpl<'a> Debug for StderrLock<'a>impl Debug for Initializerimpl Debug for SeekFromimpl<T: Debug, U: Debug> Debug for std::io::Chain<T, U>impl<T: Debug> Debug for std::io::Take<T>impl<R: Debug> Debug for std::io::Bytes<R>impl<R: Debug> Debug for std::io::Chars<R>impl Debug for CharsErrorimpl<B: Debug> Debug for std::io::Split<B>impl<B: Debug> Debug for std::io::Lines<B>impl Debug for IpAddrimpl Debug for Ipv6MulticastScopeimpl Debug for Ipv4Addrimpl Debug for Ipv6Addrimpl Debug for std::net::SocketAddrimpl Debug for SocketAddrV4impl Debug for SocketAddrV6impl<'a> Debug for std::net::Incoming<'a>impl Debug for TcpStreamimpl Debug for TcpListenerimpl Debug for UdpSocketimpl Debug for AddrParseErrorimpl Debug for Shutdownimpl Debug for c_voidimpl<T: Debug> Debug for AssertUnwindSafe<T>impl<'a> Debug for Prefix<'a>impl<'a> Debug for PrefixComponent<'a>impl<'a> Debug for Component<'a>impl<'a> Debug for Components<'a>impl<'a> Debug for std::path::Iter<'a>impl<'a> Debug for Ancestors<'a>impl Debug for PathBufimpl Debug for StripPrefixErrorimpl Debug for Pathimpl<'a> Debug for Display<'a>impl Debug for Childimpl Debug for ChildStdinimpl Debug for ChildStdoutimpl Debug for ChildStderrimpl Debug for Commandimpl Debug for Outputimpl Debug for Stdioimpl Debug for ExitStatusimpl Debug for ExitCodeimpl Debug for Selectimpl<'rx, T: Send + 'rx> Debug for Handle<'rx, T>impl<'a, T: Debug + 'a> Debug for std::sync::mpsc::Iter<'a, T>impl<'a, T: Debug + 'a> Debug for TryIter<'a, T>impl<T: Debug> Debug for std::sync::mpsc::IntoIter<T>impl Debug for RecvErrorimpl Debug for TryRecvErrorimpl Debug for RecvTimeoutErrorimpl<T> Debug for Sender<T>impl<T> Debug for SyncSender<T>impl<T> Debug for Receiver<T>impl<T> Debug for SendError<T>impl<T> Debug for TrySendError<T>impl Debug for Barrierimpl Debug for BarrierWaitResultimpl Debug for WaitTimeoutResultimpl Debug for Condvarimpl<T: ?Sized + Debug> Debug for Mutex<T>impl<'a, T: ?Sized + Debug> Debug for MutexGuard<'a, T>impl Debug for OnceStateimpl Debug for std::sync::Onceimpl<T: ?Sized + Debug> Debug for RwLock<T>impl<'a, T: Debug> Debug for RwLockReadGuard<'a, T>impl<'a, T: Debug> Debug for RwLockWriteGuard<'a, T>impl Debug for SystemTimeErrorimpl Debug for Instantimpl Debug for SystemTimeimpl<T> Debug for PoisonError<T>impl<T> Debug for TryLockError<T>impl Debug for std::os::unix::net::SocketAddrimpl Debug for UnixStreamimpl Debug for UnixListenerimpl<'a> Debug for std::os::unix::net::Incoming<'a>impl Debug for UnixDatagram