Trait std::hash::Hash 1.0.0[−][src]
pub trait Hash {
fn hash<H>(&self, state: &mut H)
where
H: Hasher;
fn hash_slice<H>(data: &[Self], state: &mut H)
where
H: Hasher,
{ ... }
}A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)] struct Rustacean { name: String, country: String, }Run
If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher}; struct Person { id: u32, name: String, phone: u64, } impl Hash for Person { fn hash<H: Hasher>(&self, state: &mut H) { self.id.hash(state); self.phone.hash(state); } }Run
Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)
In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won't need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Required Methods
Provided Methods
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
H: Hasher,
Implementors
impl<Ret, A, B, C, D> Hash for unsafe fn(A, B, C, D) -> Retimpl Hash for NonZeroUsizeimpl<T> Hash for [T; 25] where
T: Hash,impl<Ret, A, B, C, D, E> Hash for unsafe fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B> Hash for unsafe fn(A, B) -> Retimpl<Ret, A, B, C, D, E> Hash for extern "C" fn(A, B, C, D, E) -> Retimpl<Ret> Hash for unsafe extern "C" fn() -> Retimpl<T> Hash for [T; 13] where
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<T> Hash for [T; 27] where
T: Hash,impl<T> Hash for [T; 15] where
T: Hash,impl<T> Hash for [T; 17] where
T: Hash,impl<Idx> Hash for RangeTo<Idx> where
Idx: Hash,impl<T> Hash for [T; 22] where
T: Hash,impl<Ret, A, B, C, D, E, F> Hash for extern "C" fn(A, B, C, D, E, F) -> Retimpl<A> Hash for (A,) where
A: Hash + ?Sized,impl<Ret, A, B, C> Hash for unsafe extern "C" fn(A, B, C) -> Retimpl<T> Hash for [T; 2] where
T: Hash,impl<Idx> Hash for Range<Idx> where
Idx: Hash,impl<T> Hash for [T; 6] where
T: Hash,impl Hash for i64impl<Ret, A, B> Hash for unsafe extern "C" fn(A, B, ...) -> Retimpl<Idx> Hash for RangeFrom<Idx> where
Idx: Hash,impl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl Hash for u16impl<Ret, A, B, C> Hash for unsafe extern "C" fn(A, B, C, ...) -> Retimpl Hash for Errorimpl<T> Hash for [T; 20] where
T: Hash,impl<A, B, C, D, E, F, G, H, I, J, K, L> Hash for (A, B, C, D, E, F, G, H, I, J, K, L) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash,
L: Hash + ?Sized,impl<Ret, A, B> Hash for fn(A, B) -> Retimpl Hash for strimpl<A, B, C, D, E, F> Hash for (A, B, C, D, E, F) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash + ?Sized,impl<T, E> Hash for Result<T, E> where
E: Hash,
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Retimpl<Ret, A, B, C, D> Hash for fn(A, B, C, D) -> Retimpl<T> Hash for [T; 29] where
T: Hash,impl<T> Hash for Discriminant<T>impl<Ret, A, B, C, D, E, F, G, H> Hash for extern "C" fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B> Hash for extern "C" fn(A, B, ...) -> Retimpl<T> Hash for [T; 19] where
T: Hash,impl<Ret, A, B, C, D, E, F> Hash for extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<Ret, A, B, C, D, E, F, G> Hash for unsafe fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F> Hash for unsafe extern "C" fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<T> Hash for Reverse<T> where
T: Hash,impl<Ret, A, B, C, D> Hash for unsafe extern "C" fn(A, B, C, D) -> Retimpl<Idx> Hash for RangeToInclusive<Idx> where
Idx: Hash,impl<Ret, A, B, C, D, E> Hash for unsafe extern "C" fn(A, B, C, D, E, ...) -> Retimpl<T> Hash for [T; 8] where
T: Hash,impl<Ret, A, B, C> Hash for extern "C" fn(A, B, C, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A> Hash for unsafe extern "C" fn(A, ...) -> Retimpl<'a, T> Hash for &'a mut T where
T: Hash + ?Sized,impl<A, B, C, D, E, F, G, H, I, J> Hash for (A, B, C, D, E, F, G, H, I, J) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash + ?Sized,impl Hash for TypeIdimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<Ret> Hash for unsafe fn() -> Retimpl<Ret, A, B, C, D> Hash for extern "C" fn(A, B, C, D) -> Retimpl Hash for boolimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C> Hash for unsafe fn(A, B, C) -> Retimpl<T> Hash for [T; 10] where
T: Hash,impl<Ret> Hash for extern "C" fn() -> Retimpl<T> Hash for [T; 12] where
T: Hash,impl<T> Hash for Wrapping<T> where
T: Hash,impl<T> Hash for [T; 23] where
T: Hash,impl<Ret, A> Hash for unsafe fn(A) -> Retimpl<Idx> Hash for RangeInclusive<Idx> where
Idx: Hash,impl<T> Hash for [T; 9] where
T: Hash,impl<T> Hash for [T; 16] where
T: Hash,impl Hash for usizeimpl Hash for NonZeroU64impl<Ret, A, B, C, D, E, F, G, H> Hash for fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<T> Hash for [T; 31] where
T: Hash,impl Hash for Orderingimpl<T> Hash for [T] where
T: Hash,impl<T> Hash for [T; 18] where
T: Hash,impl Hash for charimpl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl<A, B, C, D, E, F, G, H, I> Hash for (A, B, C, D, E, F, G, H, I) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash + ?Sized,impl<T> Hash for [T; 32] where
T: Hash,impl<Ret, A, B> Hash for unsafe extern "C" fn(A, B) -> Retimpl<T> Hash for [T; 5] where
T: Hash,impl<A, B, C, D, E, F, G> Hash for (A, B, C, D, E, F, G) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash + ?Sized,impl<Ret, A, B, C, D> Hash for unsafe extern "C" fn(A, B, C, D, ...) -> Retimpl<T> Hash for *const T where
T: ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B> Hash for extern "C" fn(A, B) -> Retimpl<A, B, C, D> Hash for (A, B, C, D) where
A: Hash,
B: Hash,
C: Hash,
D: Hash + ?Sized,impl<T> Hash for *mut T where
T: ?Sized,impl<T> Hash for [T; 26] where
T: Hash,impl<T> Hash for [T; 24] where
T: Hash,impl<T> Hash for ManuallyDrop<T> where
T: Hash,impl<T> Hash for [T; 14] where
T: Hash,impl Hash for i128impl<Ret, A, B, C, D, E, F, G, H> Hash for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Retimpl Hash for Durationimpl<Ret, A, B, C, D, E, F> Hash for fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E> Hash for unsafe extern "C" fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl Hash for u8impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Hash for fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<A, B, C> Hash for (A, B, C) where
A: Hash,
B: Hash,
C: Hash + ?Sized,impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<Ret, A, B, C, D, E, F, G> Hash for fn(A, B, C, D, E, F, G) -> Retimpl<A, B, C, D, E, F, G, H, I, J, K> Hash for (A, B, C, D, E, F, G, H, I, J, K) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash + ?Sized,impl<Ret, A, B, C> Hash for fn(A, B, C) -> Retimpl Hash for i8impl Hash for Pinnedimpl<Ret, A, B, C, D, E, F, G> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<T> Hash for [T; 11] where
T: Hash,impl<T> Hash for [T; 4] where
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl Hash for NonZeroU16impl Hash for u32impl<T> Hash for [T; 0] where
T: Hash,impl<Ret> Hash for fn() -> Retimpl<Ret, A, B, C, D, E> Hash for fn(A, B, C, D, E) -> Retimpl Hash for i32impl<T> Hash for [T; 21] where
T: Hash,impl Hash for NonZeroU8impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<T> Hash for Poll<T> where
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl Hash for NonZeroU128impl<Ret, A> Hash for extern "C" fn(A) -> Retimpl<A, B, C, D, E, F, G, H> Hash for (A, B, C, D, E, F, G, H) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash + ?Sized,impl Hash for u64impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<A, B, C, D, E> Hash for (A, B, C, D, E) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash + ?Sized,impl<Y, R> Hash for GeneratorState<Y, R> where
R: Hash,
Y: Hash,impl<Ret, A, B, C, D> Hash for extern "C" fn(A, B, C, D, ...) -> Retimpl<Ret, A> Hash for unsafe extern "C" fn(A) -> Retimpl Hash for i16impl Hash for ()impl<A, B> Hash for (A, B) where
A: Hash,
B: Hash + ?Sized,impl<T> Hash for [T; 7] where
T: Hash,impl<Ret, A, B, C, D, E, F, G> Hash for extern "C" fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C> Hash for extern "C" fn(A, B, C) -> Retimpl<T> Hash for Bound<T> where
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Retimpl<Ret, A> Hash for fn(A) -> Retimpl<Ret, A, B, C, D, E> Hash for extern "C" fn(A, B, C, D, E, ...) -> Retimpl Hash for u128impl Hash for RangeFullimpl<T> Hash for [T; 30] where
T: Hash,impl<T> Hash for NonNull<T> where
T: ?Sized,impl<Ret, A, B, C, D, E, F> Hash for unsafe fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl Hash for NoneErrorimpl Hash for NonZeroU32impl<Ret, A, B, C, D, E, F, G> Hash for extern "C" fn(A, B, C, D, E, F, G, ...) -> Retimpl<T> Hash for PhantomData<T> where
T: ?Sized,impl Hash for !impl<T> Hash for Option<T> where
T: Hash,impl<'a, T> Hash for &'a T where
T: Hash + ?Sized,impl<Ret, A, B, C, D, E, F> Hash for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Retimpl<T> Hash for [T; 28] where
T: Hash,impl<T> Hash for [T; 3] where
T: Hash,impl<T> Hash for [T; 1] where
T: Hash,impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl Hash for isizeimpl<Ret, A> Hash for extern "C" fn(A, ...) -> Retimpl<T> Hash for Box<T> where
T: Hash + ?Sized,impl<K, V> Hash for BTreeMap<K, V> where
K: Hash,
V: Hash,impl<A> Hash for VecDeque<A> where
A: Hash,impl<'a, B> Hash for Cow<'a, B> where
B: Hash + ToOwned + ?Sized,impl<T> Hash for Arc<T> where
T: Hash + ?Sized,impl<T> Hash for Vec<T> where
T: Hash,impl<T> Hash for Rc<T> where
T: Hash + ?Sized,impl Hash for Stringimpl<T> Hash for LinkedList<T> where
T: Hash,impl<T> Hash for BTreeSet<T> where
T: Hash,impl Hash for ThreadIdimpl Hash for CStringimpl Hash for CStrimpl Hash for OsStringimpl Hash for OsStrimpl Hash for FileTypeimpl Hash for ErrorKindimpl Hash for IpAddrimpl Hash for Ipv6MulticastScopeimpl Hash for Ipv4Addrimpl Hash for Ipv6Addrimpl Hash for SocketAddrimpl Hash for SocketAddrV4impl Hash for SocketAddrV6impl<'a> Hash for Prefix<'a>impl<'a> Hash for PrefixComponent<'a>impl<'a> Hash for Component<'a>impl Hash for PathBufimpl Hash for Pathimpl Hash for Instantimpl Hash for SystemTime