Enum syntax::ast::MacStmtStyle [−][src]
pub enum MacStmtStyle {
Semicolon,
Braces,
NoBraces,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Semicolon🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The macro statement had a trailing semicolon, e.g. foo! { ... };
foo!(...);, foo![...];
Braces🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The macro statement had braces; e.g. foo! { ... }
NoBraces🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The macro statement had parentheses or brackets and no semicolon; e.g.
foo!(...). All of these will end up being converted into macro
expressions.