Enum syntax::ast::MetaItemKind
[−]
[src]
pub enum MetaItemKind {
Word,
List(Vec<NestedMetaItem>),
NameValue(Lit),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A compile-time attribute item.
E.g. #[test], #[derive(..)] or #[feature = "foo"]
Variants
Word🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Word meta item.
E.g. test as in #[test]
List(Vec<NestedMetaItem>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
List meta item.
E.g. derive(..) as in #[derive(..)]
NameValue(Lit)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Name value meta item.
E.g. feature = "foo" as in #[feature = "foo"]
Methods
impl MetaItemKind[src]
impl MetaItemKindpub fn tokens(&self, span: Span) -> TokenStream[src]
pub fn tokens(&self, span: Span) -> TokenStream🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?