[−][src]Enum syntax::ast::UseTreeKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Part of use item to the right of its prefix.
Variants
Simple(Option<Ident>, NodeId, NodeId)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
use prefix or use prefix as rename
The extra NodeIds are for HIR lowering, when additional statements are created for each
namespace.
Nested(Vec<(UseTree, NodeId)>)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
use prefix::{...}
Glob🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
use prefix::*