Struct syntax::ast::IdentExperimental
[-]
[+]
[src]
pub struct Ident {
pub name: Name,
pub ctxt: SyntaxContext,
}An identifier contains a Name (index into the interner table) and a SyntaxContext to track renaming and macro expansion per Flatt et al., "Macros That Work Together"
Fields
name | |
ctxt |
Methods
impl Ident
fn new(name: Name) -> Ident
Construct an identifier with the given name and an empty context: