Struct syntax::diagnostics::plugin::Substitution [−][src]
pub struct Substitution {
pub parts: Vec<SubstitutionPart>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
See the docs on CodeSuggestion::substitutions
Fields
parts: Vec<SubstitutionPart>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?