Enum syntax::ext::hygiene::CompilerDesugaringKind [−][src]
pub enum CompilerDesugaringKind {
DotFill,
QuestionMark,
Catch,
ExistentialReturnType,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The kind of compiler desugaring.
Variants
DotFill🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
QuestionMark🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Catch🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
ExistentialReturnType🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Desugaring of an impl Trait in return type position
to an existential type Foo: Trait; + replacing the
impl Trait with Foo.
Methods
impl CompilerDesugaringKind[src]
impl CompilerDesugaringKindpub fn as_symbol(&self) -> Symbol[src]
pub fn as_symbol(&self) -> Symbol🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?