Struct syntax::ext::tt::macro_parser::MatcherTtFrame [−][src]
struct MatcherTtFrame<'a> {
elts: TokenTreeOrTokenTreeSlice<'a>,
idx: usize,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An unzipping of TokenTrees... see the stack field of MatcherPos.
This is used by inner_parse_loop to keep track of delimited submatchers that we have
descended into.
Fields
elts: TokenTreeOrTokenTreeSlice<'a>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The "parent" matcher that we are descending into.
idx: usize
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The position of the "dot" in elts at the time we descended.