Struct syntax::ext::tt::quoted::Delimited [−][src]
pub struct Delimited {
pub delim: DelimToken,
pub tts: Vec<TokenTree>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Contains the sub-token-trees of a "delimited" token tree, such as the contents of (. Note
that the delimiter itself might be NoDelim.
Fields
delim: DelimToken
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
tts: Vec<TokenTree>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl Delimited[src]
impl Delimitedpub fn open_token(&self) -> Token[src]
pub fn open_token(&self) -> Token🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the opening delimiter (possibly NoDelim).
pub fn close_token(&self) -> Token[src]
pub fn close_token(&self) -> Token🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return the closing delimiter (possibly NoDelim).
pub fn open_tt(&self, span: Span) -> TokenTree[src]
pub fn open_tt(&self, span: Span) -> TokenTree🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a self::TokenTree with a Span corresponding to the opening delimiter.
pub fn close_tt(&self, span: Span) -> TokenTree[src]
pub fn close_tt(&self, span: Span) -> TokenTree🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Return a self::TokenTree with a Span corresponding to the closing delimiter.