[−][src]Struct syntax::parse::ParseSess
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Info about a parsing session.
Fields
span_diagnostic: Handler
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
unstable_features: UnstableFeatures
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
config: CrateConfig
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
missing_fragment_specifiers: Lock<FxHashSet<Span>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
raw_identifier_spans: Lock<Vec<Span>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Places where raw identifiers were used. This is used for feature gating raw identifiers
registered_diagnostics: Lock<ErrorMap>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The registered diagnostics codes
non_modrs_mods: Lock<Vec<(Ident, Span)>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
included_mod_stack: Lock<Vec<PathBuf>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Used to determine and report recursive mod inclusions
code_map: Lrc<SourceMap>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
buffered_lints: Lock<Vec<BufferedEarlyLint>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl ParseSess[src]
impl ParseSesspub fn new(file_path_mapping: FilePathMapping) -> Self[src]
pub fn new(file_path_mapping: FilePathMapping) -> Self🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn with_span_handler(
handler: Handler,
code_map: Lrc<SourceMap>
) -> ParseSess[src]
pub fn with_span_handler(
handler: Handler,
code_map: Lrc<SourceMap>
) -> ParseSess🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn source_map(&self) -> &SourceMap[src]
pub fn source_map(&self) -> &SourceMap🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn buffer_lint<S: Into<MultiSpan>>(
&self,
lint_id: BufferedEarlyLintId,
span: S,
id: NodeId,
msg: &str
)[src]
pub fn buffer_lint<S: Into<MultiSpan>>(
&self,
lint_id: BufferedEarlyLintId,
span: S,
id: NodeId,
msg: &str
)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?