Struct syntax::tokenstream::ThinTokenStream
[−]
[src]
pub struct ThinTokenStream(_);
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The TokenStream type is large enough to represent a single TokenTree without allocation.
ThinTokenStream is smaller, but needs to allocate to represent a single TokenTree.
We must use ThinTokenStream in TokenTree::Delimited to avoid infinite size due to recursion.