Enum syntax_ext::deriving::generic::ty::PtrTy [−][src]
pub enum PtrTy<'a> {
Borrowed(Option<&'a str>, Mutability),
Raw(Mutability),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The types of pointers
Variants
Borrowed(Option<&'a str>, Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
&'lifetime mut
Raw(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
*mut