Struct syntax_ext::deriving::generic::ty::Path [−][src]
pub struct Path<'a> {
path: Vec<&'a str>,
lifetime: Option<&'a str>,
params: Vec<Box<Ty<'a>>>,
kind: PathKind,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A path, e.g. ::std::option::Option::<i32> (global). Has support
for type parameters and a lifetime.
Fields
path: Vec<&'a str>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
lifetime: Option<&'a str>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
params: Vec<Box<Ty<'a>>>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
kind: PathKind
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl<'a> Path<'a>[src]
impl<'a> Path<'a>pub fn new<'r>(path: Vec<&'r str>) -> Path<'r>[src]
pub fn new<'r>(path: Vec<&'r str>) -> Path<'r>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_local<'r>(path: &'r str) -> Path<'r>[src]
pub fn new_local<'r>(path: &'r str) -> Path<'r>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn new_<'r>(
path: Vec<&'r str>,
lifetime: Option<&'r str>,
params: Vec<Box<Ty<'r>>>,
kind: PathKind
) -> Path<'r>[src]
pub fn new_<'r>(
path: Vec<&'r str>,
lifetime: Option<&'r str>,
params: Vec<Box<Ty<'r>>>,
kind: PathKind
) -> Path<'r>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ty(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> P<Ty>[src]
pub fn to_ty(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> P<Ty>🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_path(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> Path[src]
pub fn to_path(
&self,
cx: &ExtCtxt,
span: Span,
self_ty: Ident,
self_generics: &Generics
) -> Path🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?