pub trait HeadingContent: FlowContent { }Expand description
The Heading content category
Heading content defines the heading of a section (whether explicitly marked up using sectioning content elements, or implied by the heading content itself).
References
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".